(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1903819,      38796]*)
(*NotebookOutlinePosition[   1946879,      40250]*)
(*  CellTagsIndexPosition[   1944591,      40193]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Functions", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[CellGroupData[{

Cell["What is a function?", "Subsection"],

Cell[TextData[{
  "In the most general sense, a function is any conceptual object that \
accepts input and produces corresponding output based upon that input.  Of \
course, ordinary mathematical functions, such as sine or cosine, obviously \
satisfy this definition, as would vector-valued functions which produce \
output in the form of vectors rather than simple numbers.  More sophisticated \
functions might receive input in the form of a symbolic expression and return \
output in the form of a transformed expression or a plot.  Perhaps the output \
might consist of symbolic, numerical, and graphical parts bundled together in \
a list.  The output might consist of a list of possible solutions to a \
problem rather than one specific result.  The output could even be an entire \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook!"
}], "Text"],

Cell[TextData[{
  "Functions lie at the heart of ",
  StyleBox["Mathematica \[LongDash] ",
    FontSlant->"Italic"],
  "any operation it performs can be represented by a function which, when \
presented with appropriate input, returns one of the many output objects it \
recognizes.  Therefore, most of our work with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will consist of constructing functions which perform desirable tasks."
}], "Text"],

Cell[TextData[{
  "In this notebook we introduce many of the most important concepts and \
techniques used to create ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions; however, the richness of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language precludes an exhaustive treatment. Moreover, this notebook is \
rather long and many readers may find plodding through syntax to be \
exhausting in itself.  Therefore, I encourage you to skip around through the \
notebook, learning the basics now and returning for more detail later as \
needed.  Short and simple examples appear throughout the notebook and links \
to more extended and more interesting examples are provided.  Feel free to \
branch out to these examples frequently \[LongDash] although some of these \
examples employ features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that may not have been covered yet, people do not learn in the linear \
fashion of a traditional textbook.  One tends to learn best only those tools \
that are needed to solve the problem at hand, and part of solving problems is \
discovering what tools are available that might be helpful.  Only after a \
tool or technique has been recognized as potentially useful to a current \
problem is the motivation to master it strong enough to promote effective \
learning."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Acknowledgments", "Subsection"],

Cell[TextData[{
  "Prof. MacDonald (deceased) introduced the concepts of ",
  StyleBox["explicit",
    FontSlant->"Italic"],
  " and ",
  StyleBox["implicit",
    FontSlant->"Italic"],
  " functions to distinguish between functions with explicit arguments and \
named expressions that are used as functions without explicit arguments.  He \
also coined the term ",
  StyleBox["skeletal",
    FontSlant->"Italic"],
  " functions to describe unnamed pure functions whose arguments are given as \
slots rather than named variables.  I retain this descriptive nomenclature \
here."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(Off[General::spell, \ General::spell1]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implicit functions ", "Section",
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"implicit functions"],

Cell[TextData[{
  "An ",
  StyleBox["implicit function",
    FontSlant->"Italic"],
  " is simply a named expression which contains one or more symbols that are \
considered variables.  For example, below we define ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " to be a quadratic function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " are considered parameters, although here the distinction between \
variables and parameters is merely a matter of attitude."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x, a, b, c];\)\), "\n", 
    \(\(f\  = \ a\ x\^2\  + \ b\ x\  + \ c;\)\)}], "Input"],

Cell[TextData[{
  "As presently defined, ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is an implicit function which simply returns its symbolic definition."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\)], "Input"],

Cell[BoxData[
    \(c + b\ x + a\ x\^2\)], "Output"]
}, Closed]],

Cell["\<\
Numerical values can be obtained either by using replacement rules to specify \
the values of the variables and parameters\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\  /. {a \[Rule] 1, b \[Rule] 2, c \[Rule] 3, x \[Rule] 4}\)], "Input",\

  CellFrame->{{0.25, 0.25}, {0, 0.25}}],

Cell[BoxData[
    \(27\)], "Output"]
}, Closed]],

Cell["which does not alter the definition of the function", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\)], "Input"],

Cell[BoxData[
    \(c + b\ x + a\ x\^2\)], "Output"]
}, Closed]],

Cell["or by assigning values to the parameters", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a = 1; \ b = 2; \ c = 3;\), "\n", 
    \(f\)}], "Input"],

Cell[BoxData[
    \(3 + 2\ x + x\^2\)], "Output"]
}, Closed]],

Cell["and variables", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x = 4;\)\), "\n", 
    \(f\)}], "Input"],

Cell[BoxData[
    \(27\)], "Output"]
}, Closed]],

Cell[TextData[{
  "However, assignment of values precludes many of the operations we might \
wish to perform on such a function.  For example, we can no longer \
differentiate this function with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f, x]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"ivar"\), \(\(:\)\(\ \)\), "\<\"\\!\\(4\\) is not a \
valid variable. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::ivar\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(\[PartialD]\_4 27\)], "Output"]
}, Closed]],

Cell[TextData[{
  "because ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is now a number instead of a variable."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?x\)\)], "Input"],

Cell["Global`x", "Print",
  CellTags->"Info3312795150-1116509"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(x = 4\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "x"],
      Editable->False]], "Print",
  CellTags->"Info3312795150-1116509"]
}, Closed]],

Cell["Although we can undo this unfortunate assignment", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x];\)\), "\n", 
    \(D[f, x]\)}], "Input"],

Cell[BoxData[
    \(2 + 2\ x\)], "Output"]
}, Closed]],

Cell[TextData[{
  "you will soon find that unintended or obsolete assignments can be a major \
source of frustration to new users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  For example, if we neglect to clear the variables used on the rhs and \
forget that ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and/or ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " have already been assigned values, a new function"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ a\ Sin[x]\  + \ b\ Cos[x]\)], "Input"],

Cell[BoxData[
    \(2\ Cos[x] + Sin[x]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "does not contain the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " as intended.  A proper definition would require two new symbols, such as \
",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  ", but symbol creation consumes memory (both computer and human) and slows \
down evaluations."
}], "Text"],

Cell["\<\
Advice: avoid unnecessary assignments; instead, use replacement rules \
whenever possible and clear obsolete assignments promptly.\
\>", "Advice"],

Cell[BoxData[
    \(Clear[a, b, c, x]\)], "Input"],

Cell[TextData[{
  "A good technique for assigning parameters to a function is to give a set \
of replacement rules a name that clearly identifies it purpose and its \
association with the relevant function.  For example, the coefficients of the \
quadratic function called ",
  StyleBox["f", "InlineInput"],
  " above are identified below as its parameters.  Note that we employ a \
string variable to avoid evaluation of the expression for ",
  StyleBox["f", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(parameters["\<f\>"] = {a \[Rule] 1, b \[Rule] 2, 
          c \[Rule] 3};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f /. parameters["\<f\>"]\)], "Input"],

Cell[BoxData[
    \(3 + 2\ x + x\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(f /. x \[Rule] 2\) /. parameters["\<f\>"]\)], "Input"],

Cell[BoxData[
    \(11\)], "Output"]
}, Closed]],

Cell["\<\
This technique enhances the readability of notebooks and reduces the chance \
of errors due to spurious assignments.\
\>", "Text"],

Cell[TextData[{
  "Express ",
  Cell[BoxData[
      \(TraditionalForm\`f = 1\/\(1\  + \ 1\/\(1 + z\^2\)\)\)]],
  " as an implicit function of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ".  Plot ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] sin(x)\)]],
  "."
}], "Exercise",
  FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
  "Express ",
  Cell[BoxData[
      \(TraditionalForm\`f = 1\/\(1\  + \ 1\/\(1 + z\^2\)\)\)]],
  " as an implicit function of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ".  Evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]f\/\[PartialD]x\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] sin(x)\)]],
  "."
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Explicit functions", "Section",
  CellTags->"explicit functions"],

Cell["\<\
Explicit functions receive their variables as arguments.  The definitions can \
be made using either immediate or delayed assignments, as for implicit \
functions, but we recommend delayed assignment to avoid conflicts with \
pre-existing symbols.  The arguments can be expressed as symbols, patterns, \
or a mixture of types.  The functions may be represented in terms of several \
rules, with the rule that applies to a particular set of arguments chosen by \
pattern matching.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Patterns as arguments", "Subsection",
  CellTags->{"patterns as arguments", "explicit functions"}],

Cell["\<\
Often the most convenient method for specifying the arguments of an explicit \
function is to use patterns rather than explicit symbols.  Consider a \
function\
\>", "Text"],

Cell[BoxData[
    \(Clear[g]\)], "Input"],

Cell[BoxData[
    \(\(g[x_] = x\^2\ Exp[\(-x\^2\)];\)\)], "Input"],

Cell[TextData[{
  "whose argument is expressed in terms of the pattern",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["x_", "InlineInput"],
  ".   The single underscore (",
  StyleBox["Blank", "InlineInput"],
  ") is the symbol for a blank pattern that may assume any value, symbolic or \
numeric.  Attaching the blank pattern to the symbol ",
  StyleBox["x", "InlineInput"],
  " in the form of ",
  StyleBox["x_", "InlineInput"],
  " indicates that the pattern will be referred to as ",
  StyleBox["x", "InlineInput"],
  " on the right-hand side (rhs) of the definition statement.  Note that this \
usage of the symbol ",
  StyleBox["x", "InlineInput"],
  " does not conflict with any global definitions that might already exist.  \
Thus,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[x]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-x\^2\)\ x\^2\)], "Output"]
}, Closed]],

Cell["gives the expected result while", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[y]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-y\^2\)\ y\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "now gives the corresponding expression with ",
  StyleBox["x", "InlineInput"],
  " replaced by ",
  StyleBox["y", "InlineInput"],
  ".  Similarly,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[2]\)], "Input"],

Cell[BoxData[
    \(4\/\[ExponentialE]\^4\)], "Output"]
}, Closed]],

Cell["now evaluates to an exact numerical expression and", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[2. ]\)], "Input"],

Cell[BoxData[
    \(0.07326255555493671`\)], "Output"]
}, Closed]],

Cell["\<\
evaluates to an approximate number.  There is also nothing to stop us from \
using a string as the argument, \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g["\<stuff\>"]\)], "Input"],

Cell[BoxData[
    \("stuff"\^2\ \[ExponentialE]\^\(-"stuff"\^2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g["\<stuff\>"] // FullForm\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Times[Power["\<stuff\>", 2], 
          Power[E, Times[\(-1\), Power["\<stuff\>", 2]]]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell["\<\
even if the result is uninterpretable as a mathematical function.  It is also \
possible to use a function as the argument.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[g[z]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-2\)\ z\^2 - \[ExponentialE]\^\(\(-2\)\ z\^2\)\ \
z\^4\)\ z\^4\)], "Output"]
}, Closed]],

Cell["\<\
This technique can be very useful for recursive functions, such as iterated \
function systems, or for symbolic manipulation and will be explored at \
greater depth later.\
\>", "Text"],

Cell["\<\
Similarly, functions of several variables can be constructed using different \
symbols to identify each pattern.\
\>", "Text"],

Cell[BoxData[
    \(\(g[x_, y_] = \ x\^\(2 + y\)\ Exp[\(-x\^2\)];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({g[x, y], g[x, 0], g[x, 2], g[x, \(-4\)], g[2, 2], 
      g[x, "\<stuff\>"]}\)], "Input"],

Cell[BoxData[
    \({\[ExponentialE]\^\(-x\^2\)\ x\^\(2 + y\), \[ExponentialE]\^\(-x\^2\)\ \
x\^2, \[ExponentialE]\^\(-x\^2\)\ x\^4, \[ExponentialE]\^\(-x\^2\)\/x\^2, 
      16\/\[ExponentialE]\^4, \[ExponentialE]\^\(-x\^2\)\ x\^\(2 + "stuff"\)}\
\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Each of these forms evaluates in the expected manner.  However, why didn't \
we use a different symbol for this new function?  Will a second definition \
for the same symbol, namely ",
  StyleBox["g", "InlineInput"],
  ", conflict with the first?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[z]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-z\^2\)\ z\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Evidently, there is no conflict between these definitions!  Harmonious \
coexistence arises from the method that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses to interpret expressions.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " stores the rules associated with each symbol and then, when evaluating \
expressions, scans its rule tables for any rules associated with the symbols \
that appear in that expression, beginning with those defined by the user and \
proceeding to the built-in rules that apply to any symbol of the same type.  \
The appropriate rule is selected by pattern matching.  The rules associated \
with the symbol ",
  StyleBox["g", "InlineInput"],
  " can be inspected using the ",
  StyleBox["?", "InlineInput"],
  " operator; sometimes ",
  StyleBox["??", "InlineInput"],
  " will give even more information."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?g\)\)], "Input"],

Cell["Global`g", "Print",
  CellTags->"Info3312795210-5631052"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(g[x_] = \[ExponentialE]\^\(-x\^2\)\ x\^2\)},
                {" "},
                {\(g[x_, y_] = \[ExponentialE]\^\(-x\^2\)\ x\^\(2 + y\)\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "g"],
      Editable->False]], "Print",
  CellTags->"Info3312795210-5631052"]
}, Closed]],

Cell[TextData[{
  "Here we find two rules associated with the symbol ",
  StyleBox["g", "InlineInput"],
  ".  If our expression matches the pattern ",
  StyleBox["g[x_]", "InlineInput"],
  " the rule for that pattern is applied, or if our expression matches ",
  StyleBox["g[x_,y_]", "InlineInput"],
  " the corresponding rule is applied.  There is no conflict because the \
patterns are unique.  On the other hand, no evaluation is performed when the \
expression involves an unrecognized pattern."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[x, y, z]\)], "Input"],

Cell[BoxData[
    \(g[x, y, z]\)], "Output"]
}, Closed]],

Cell["\<\
Therefore,  this technique can be used to define generalized functions which \
actually consist of several different functional relationships that are \
assigned the same symbolic name by virtue of their conceptual relationship \
but which apply to different input patterns.  Of course, care should be \
exercised in the design of functions with multiple definitions to avoid \
overlapping or ambiguous patterns.\
\>", "Text"],

Cell["\<\
Explain the behavior of the following functions: g[x_]=\[Pi] or h[_]=\[Pi].  \
Are they equivalent?\
\>", "Exercise"],

Cell[TextData[{
  "Explain the behavior of the following function:\n\tClear[f];\n\tf[x_] = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  ";\n\tf[x_,y_] = ",
  Cell[BoxData[
      \(TraditionalForm\`x\^y\)]],
  ";\nEvaluate f[2], f[3,2], f[x,",
  Cell[BoxData[
      \(y\/Log[x]\)]],
  "].  How do these several definitions coexist peacefully?"
}], "Exercise"],

Cell["\<\
Explain the behavior of the following function:
\tarea[\"rectangle\",b_,h_] = b h;
\tarea[\"triangle\",b_,h_] = b h /2
Add similar definitions for parallelograms and trapezoids (you may need more \
arguments!) and verify that the new definitions do not conflict with the \
previous definitions.  Why is it better to place the symbolic arguments \
before the patterns?\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Delayed assignment", "Subsection"],

Cell[TextData[{
  "Immediate assignment in the form ",
  StyleBox["lhs=rhs", "InlineInput"],
  " is appropriate when ",
  StyleBox["rhs", "InlineInput"],
  " provides an immediate result that can be delivered without further \
processing of the ",
  StyleBox["lhs", "InlineInput"],
  ".  However, if ",
  StyleBox["rhs", "InlineInput"],
  " is more complicated, such as the result of a plotting command, that \
cannot be evaluated directly, then we should use delayed assignment of the \
form ",
  StyleBox["lhs:=rhs", "InlineInput"],
  ".  Consider the following function intended to produce a graph of the \
derivative of a function of a single variable over a specified domain."
}], "Text"],

Cell[BoxData[
    \(PlotDerivative[f_, {x_, xmin_, xmax_}] := 
      Plot[Evaluate[D[f[x], x]], {x, xmin, xmax}]\)], "Input"],

Cell["An example of the use of this function is given below.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotDerivative[AiryAi, {x, \(-10\), 4}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.704082 0.0680272 0.306259 0.298173 [
[.02381 .29376 -9 -9 ]
[.02381 .29376 9 0 ]
[.15986 .29376 -6 -9 ]
[.15986 .29376 6 0 ]
[.29592 .29376 -6 -9 ]
[.29592 .29376 6 0 ]
[.43197 .29376 -6 -9 ]
[.43197 .29376 6 0 ]
[.56803 .29376 -6 -9 ]
[.56803 .29376 6 0 ]
[.84014 .29376 -3 -9 ]
[.84014 .29376 3 0 ]
[.97619 .29376 -3 -9 ]
[.97619 .29376 3 0 ]
[.69158 .00809 -12 -4.5 ]
[.69158 .00809 0 4.5 ]
[.69158 .15717 -24 -4.5 ]
[.69158 .15717 0 4.5 ]
[.69158 .45535 -18 -4.5 ]
[.69158 .45535 0 4.5 ]
[.69158 .60443 -6 -4.5 ]
[.69158 .60443 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30626 m
.02381 .31251 L
s
[(-10)] .02381 .29376 0 1 Mshowa
.15986 .30626 m
.15986 .31251 L
s
[(-8)] .15986 .29376 0 1 Mshowa
.29592 .30626 m
.29592 .31251 L
s
[(-6)] .29592 .29376 0 1 Mshowa
.43197 .30626 m
.43197 .31251 L
s
[(-4)] .43197 .29376 0 1 Mshowa
.56803 .30626 m
.56803 .31251 L
s
[(-2)] .56803 .29376 0 1 Mshowa
.84014 .30626 m
.84014 .31251 L
s
[(2)] .84014 .29376 0 1 Mshowa
.97619 .30626 m
.97619 .31251 L
s
[(4)] .97619 .29376 0 1 Mshowa
.125 Mabswid
.05782 .30626 m
.05782 .31001 L
s
.09184 .30626 m
.09184 .31001 L
s
.12585 .30626 m
.12585 .31001 L
s
.19388 .30626 m
.19388 .31001 L
s
.22789 .30626 m
.22789 .31001 L
s
.2619 .30626 m
.2619 .31001 L
s
.32993 .30626 m
.32993 .31001 L
s
.36395 .30626 m
.36395 .31001 L
s
.39796 .30626 m
.39796 .31001 L
s
.46599 .30626 m
.46599 .31001 L
s
.5 .30626 m
.5 .31001 L
s
.53401 .30626 m
.53401 .31001 L
s
.60204 .30626 m
.60204 .31001 L
s
.63605 .30626 m
.63605 .31001 L
s
.67007 .30626 m
.67007 .31001 L
s
.7381 .30626 m
.7381 .31001 L
s
.77211 .30626 m
.77211 .31001 L
s
.80612 .30626 m
.80612 .31001 L
s
.87415 .30626 m
.87415 .31001 L
s
.90816 .30626 m
.90816 .31001 L
s
.94218 .30626 m
.94218 .31001 L
s
.25 Mabswid
0 .30626 m
1 .30626 L
s
.70408 .00809 m
.71033 .00809 L
s
[(-1)] .69158 .00809 1 0 Mshowa
.70408 .15717 m
.71033 .15717 L
s
[(-0.5)] .69158 .15717 1 0 Mshowa
.70408 .45535 m
.71033 .45535 L
s
[(0.5)] .69158 .45535 1 0 Mshowa
.70408 .60443 m
.71033 .60443 L
s
[(1)] .69158 .60443 1 0 Mshowa
.125 Mabswid
.70408 .0379 m
.70783 .0379 L
s
.70408 .06772 m
.70783 .06772 L
s
.70408 .09754 m
.70783 .09754 L
s
.70408 .12736 m
.70783 .12736 L
s
.70408 .18699 m
.70783 .18699 L
s
.70408 .21681 m
.70783 .21681 L
s
.70408 .24662 m
.70783 .24662 L
s
.70408 .27644 m
.70783 .27644 L
s
.70408 .33608 m
.70783 .33608 L
s
.70408 .36589 m
.70783 .36589 L
s
.70408 .39571 m
.70783 .39571 L
s
.70408 .42553 m
.70783 .42553 L
s
.70408 .48516 m
.70783 .48516 L
s
.70408 .51498 m
.70783 .51498 L
s
.70408 .5448 m
.70783 .5448 L
s
.70408 .57462 m
.70783 .57462 L
s
.25 Mabswid
.70408 0 m
.70408 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60081 L
.02605 .59776 L
.02846 .58834 L
.03068 .57653 L
.03279 .56278 L
.0375 .52359 L
.04262 .46994 L
.06244 .21398 L
.07308 .09639 L
.07844 .05419 L
.0815 .03662 L
.08286 .03036 L
.08435 .02471 L
.08571 .02067 L
.08696 .01783 L
.08816 .01596 L
.08944 .01488 L
.0907 .01472 L
.09188 .01538 L
.09295 .01666 L
.0941 .01875 L
.09536 .0219 L
.09675 .02636 L
.09956 .03847 L
.10215 .05325 L
.10458 .06992 L
.11503 .16808 L
.12493 .28532 L
.13375 .39192 L
.13877 .44747 L
.14349 .49344 L
.14852 .53398 L
.15314 .56197 L
.15555 .57274 L
.15808 .58114 L
.15939 .5843 L
.16062 .58647 L
.16132 .5874 L
.16196 .58803 L
.1627 .5885 L
.1634 .58871 L
.16446 .58858 L
.16563 .58779 L
.16685 .58628 L
.168 .58422 L
.17004 .57901 L
.17224 .57129 L
.1748 .55957 L
.17724 .54591 L
Mistroke
.18182 .51417 L
.19143 .42677 L
.20166 .31633 L
.21125 .21297 L
.22006 .13099 L
.22508 .09365 L
.23037 .06345 L
.23313 .05185 L
.23569 .04368 L
.23716 .04016 L
.2385 .03771 L
.23924 .03666 L
.24005 .03577 L
.24081 .03517 L
.24152 .03482 L
.24267 .03468 L
.24392 .03513 L
.2451 .03611 L
.24617 .03748 L
.24737 .03953 L
.24868 .0424 L
.25131 .05011 L
.25391 .06021 L
.25669 .07354 L
.2617 .10361 L
.27197 .18482 L
.28308 .28956 L
.29269 .38074 L
.30325 .46803 L
.30821 .50115 L
.31354 .52954 L
.31612 .5404 L
.31857 .54886 L
.32077 .55489 L
.32316 .55977 L
.32446 .56167 L
.32568 .56298 L
.32638 .56352 L
.32702 .56389 L
.32772 .56414 L
.32846 .56424 L
.32913 .56418 L
.32985 .56397 L
.33115 .56319 L
.33194 .56246 L
.33269 .5616 L
.33409 .55954 L
.33662 .55438 L
.33895 .54802 L
.34422 .52831 L
Mistroke
.34888 .50524 L
.3539 .47539 L
.36296 .41137 L
.38359 .24797 L
.3937 .17621 L
.39905 .14404 L
.40474 .11528 L
.41021 .09363 L
.41516 .0794 L
.41756 .07443 L
.41881 .07231 L
.42014 .07045 L
.42131 .06913 L
.42259 .06803 L
.42375 .06733 L
.42483 .06693 L
.4261 .06679 L
.42673 .06685 L
.42744 .06701 L
.42868 .06755 L
.42985 .06835 L
.43121 .06964 L
.43247 .07115 L
.4353 .07569 L
.4376 .08052 L
.44012 .08691 L
.4452 .10307 L
.45482 .144 L
.46376 .19118 L
.48251 .30265 L
.50283 .41379 L
.51394 .46021 L
.51882 .47634 L
.52419 .49089 L
.52925 .50148 L
.53398 .50864 L
.53659 .51146 L
.53898 .51336 L
.5403 .51414 L
.54099 .51447 L
.54173 .51476 L
.54244 .51499 L
.54309 .51514 L
.54434 .51532 L
.54555 .51533 L
.54668 .5152 L
.54792 .51491 L
.54861 .51467 L
.54924 .51442 L
.55051 .51379 L
Mistroke
.5519 .51293 L
.55441 .51089 L
.55921 .50543 L
.56364 .49869 L
.57376 .47818 L
.58448 .45052 L
.62231 .33857 L
.63309 .31035 L
.64334 .2871 L
.65331 .26826 L
.66258 .25427 L
.67155 .24391 L
.67614 .23975 L
.68111 .2361 L
.68657 .23303 L
.68907 .23194 L
.69172 .23099 L
.69411 .23031 L
.69537 .23001 L
.69673 .22974 L
.69798 .22953 L
.69911 .22938 L
.70026 .22926 L
.70134 .22917 L
.70248 .22912 L
.70371 .22909 L
.70486 .22909 L
.70593 .22912 L
.7071 .22919 L
.70839 .22929 L
.70974 .22944 L
.71099 .22961 L
.71358 .23005 L
.71594 .23056 L
.72124 .23204 L
.73071 .23568 L
.73966 .24 L
.77811 .26233 L
.79759 .27303 L
.81902 .2829 L
.83937 .29019 L
.85841 .29529 L
.86881 .29746 L
.87869 .29918 L
.89722 .30164 L
.90683 .30259 L
.91706 .30341 L
.93545 .30448 L
.94554 .3049 L
.95644 .30524 L
Mistroke
.96673 .3055 L
.97619 .30568 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooolS0?ooo`030?noM0000000000000<00000
00<007Bo0?ooo`3oool0103oool00`000000oooo0?ooo`1n0?ooo`00o`3ooolV0?ooo`0309a8B02L
gol0oooo00L0oooo00<000000?ooo`3oool0OP3oool00?l0oooo9P3oool00`2LB4P0W=oo0?ooo`07
0?ooo`030000003oool0oooo07h0oooo003o0?ooobH0oooo00<0W4Q809cOo`3oool01`3oool40000
07d0oooo003o0?oooaX0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`030?ooo`03
09a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0OP3oool00?l0oooo9P3oool00`2LB4P0W=oo
0?ooo`070?ooo`030000003oool0oooo07h0oooo000[0?ooo`800000n03oool00`2LB4P0W=oo0?oo
o`070?ooo`030000003oool0oooo07h0oooo000Z0?ooo`030000003oool000000?D0oooo00D0gia8
00000000B9`0W4Q809cOo`080?ooo`030000003oool0oooo07h0oooo000Z0?ooo`040000003oool0
oooo00000?H0oooo00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`1n0?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool0OP3oool0
02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo
07h0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0oP3oool00`000000
oooo0?ooo`1n0?ooo`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo
00<000000?ooo`3oool0OP3oool002P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3n0?ooo`030000003oool0oooo07h0oooo000X0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o@3oool00`000000oooo0?ooo`1n0?ooo`00:03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03T0oooo0`0000310?ooo`030000003oool0oooo07h0oooo000X0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0>03oool010000000oooo0?ooo`0000310?oo
o`<00000OP3oool002P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h0?ooo`05
0000003oool0oooo0?ooo`000000`03oool00`000000oooo0?ooo`1n0?ooo`009`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo07h0oooo000W0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0OP3oool002L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`1n0?ooo`009`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo07h0oooo000V0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0OP3oool002H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0_03oool00`000000oooo0?ooo`1n0?ooo`009P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo07h0oooo000V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0OP3o
ool002H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`1n0?ooo`009P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`2k0?ooo`030000003oool0oooo07h0oooo000U0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04D0
oooo0P00001d0?ooo`030000003oool0oooo07h0oooo000U0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0480oooo
0P0000020?ooo`800000LP3oool3000007h0oooo000U0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo07h0oooo000U
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo07h0oooo000U0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo07h0oooo000U0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo07h0oooo000U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo07h0oooo000U0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo07h0oooo000U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo07h0oooo000T0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
07h0oooo000T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo07h0oooo000T0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo07h0oooo
000T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo07h0oooo000T0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`<00000OP3oool002@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0OP3oool002@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0OP3oool002@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
OP3oool002@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0OP3oool002@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0OP3oool0
02@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0OP3oool002<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0OP3oool002<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0OP3oool002<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0OP3oool002<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0OP3oool002<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0OP3oool002<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0OP3oool002<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo06P0oooo0`00001n0?ooo`008`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1n0?ooo`008`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`1n0?ooo`008`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1n0?ooo`008`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`1n0?ooo`008`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1n0?ooo`008P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`1n0?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`1n0?ooo`008P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1n0?oo
o`008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0B03oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool01@2o
M0000000000000000000M;oo00L0oooo00<000000?ooo`3oool0OP3oool00280oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00H0W4Qd0;oo
o`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3oool0oooo
0?oOW0180000M;oo00H0oooo00<000000?ooo`3oool0OP3oool00280oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04H0oooo00<0okmd001d_`3oool0
0P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0
OP3oool00280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo04H0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`030?noM000
M;l0oooo00D0oooo00<000000?ooo`3oool0OP3oool00280oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo00<0W4P00000000000000`000000
1@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03`3oool00`2LB000M;oo0?oo
o`050?ooo`@00000O@3oool00280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo04H0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:
0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1n
0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0AP3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0
M02oool02P3oool00`000000oooo0?ooo`1n0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool01P2LB000M;oo0?ooo`3ogi`0B01d
0;ooo`/0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1n0?ooo`008P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool01@3o
okl0M0000000000004P0W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`05
0?ooo`030000003oool0oooo07h0oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo07h0oooo000Q0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo07h0oooo000Q0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo07h0oooo000Q0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo07h0oooo000Q0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo07h0oooo000Q0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
07h0oooo000Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo07h0oooo000Q0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1S0?ooo`<00000OP3oool00240oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0OP3oool00240oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0OP3oool00240oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0OP3oool00240oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0OP3oool00240oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
OP3oool00200oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0OP3oool00200oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0OP3oool0
0200oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0OP3oool00200oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0OP3oool00200oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0OP3oool00200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0OP3oool00200oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0OP3oool00200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0640oooo0`00001n0?ooo`00803oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1n0?ooo`00
803oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`1n0?ooo`00803oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1n0?ooo`00803oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`1n0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0G03oool9000007`0oooo000O0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1J0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<00000N@3oool001l0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05P0oooo0P0000060?ooo`030000003oool0oooo00D0oooo
0P00001g0?ooo`007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0EP3oool2000000P0oooo00<000000?ooo`3oool01`3oool2000007D0oooo000O
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1D
0?ooo`8000002P3oool00`000000oooo0?ooo`090?ooo`800000L`3oool001l0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`800000L@3oool001l0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`800000K`3oool001l0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
303oool3000000l0oooo0P00001]0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0140oooo0P00001[0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0J03oool001l0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0D0?ooo`800000J03oool001l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0F0?ooo`800000IP3oool001h0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0H0?ooo`800000I03oool001h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0J0?ooo`800000HP3oool001h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo05l0oooo000<0?ooo`030?noM0000000000000<0000000D007Bo0?oo
o`3oool0oooo0?noM0030000000507Boo`3oool0oooo0?ooo`0000006P3oool00`000000oooo0?oo
o`0?0?ooo`050;md00000000000000000000M;l0303oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo00D0_g@0000000000000001d0;ooo`0L0?ooo`030000003oool0oooo01H0
oooo00D0omnL04P000000000000007Boo`0:0?ooo`030000003oool0oooo02@0oooo00<0oono07@0
00000000100000000`1d_ol0oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool07@3oool2000001<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`0c0?oo
o`050?oOW018000000000000001d_ol02P3oool000l0oooo00<0W4Q809cOo`3oool0103oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`80oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0>0?ooo`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool02P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00D0oooo00H0gia8001d_`3oool0oooo0?noM000M;lL0?ooo`03
0000003oool0oooo01P0oooo00<0_g@007Boo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`03
0;md000007@0_ooo0080oooo00<0giad09cOo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01l0oooo0P00000B0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3o
ool0=P3oool00`2oM000M;oo0?ooo`0:0?ooo`003`3oool00`2LB4P0W=oo0?ooo`030?ooo`030?no
M000M;l0oooo0080oooo00D0gia804RLg`3oool0oooo0000000J0?ooo`030000003oool0oooo00h0
oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`0:0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0103oool00`3ookl0M00007Boo`020?ooo`030?oo_`1dB9`0oooo01/0
oooo00<000000?ooo`3oool0603oool00`2oM000M;oo0?ooo`0;0?ooo`030000003oool0oooo02D0
oooo00<0okmd0000B02Lgol0803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240
oooo0P00000A0?ooo`030?noM00004P0W=oo03X0oooo00<0_g@007Boo`3oool02P3oool000l0oooo
00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`050?noM000M;l0oooo0?ooo`00
00006`3oool00`000000oooo0?ooo`0=0?ooo`030?noM000B9`0oooo0080oooo00<0W4Q809cOo`3o
ool02P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00L0okmd0018B01d
07@0_ooo0?ooo`3OW4P007Bo01`0oooo00<000000?ooo`3oool0503oool00`3OW4P0000000000003
0000000307Boo`3oool0oooo00T0oooo00<000000?ooo`3oool09P3oool00`3ogi`0B00004RLg`0N
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool200000100oooo00<0omnL
04P00018W=l0=@3oool00`3OW4P00000000000030000000307Boo`3oool0oooo00P0oooo00030?oo
o`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`030?oo
o`030=nLB018W=l0oooo0080oooo00D0okmd001d_`3oool0oooo0000000K0?ooo`030000003oool0
oooo00@0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3oool0gia800<0000000<0
B9cO0?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`0309a800000000000000<0000000H0
04RL0?ooo`3oool0omnL04Q8W03o_g@2000000030018W03oool0oooo01/0oooo00<000000?ooo`3o
ool02`3oool00`2LB000000000000003000000090018W03oool0oooo0?noM00007@0_ooo0?ooo`2o
M000M;oo00`0oooo00<000000?ooo`3oool06`3oool00`2LB000000000000003000000030018W03o
ool0oooo00@0oooo00<0W4P004RLg`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02D0oooo0P00000@0?ooo`0309a80018W=l0oooo03<0oooo00H0okmd0000M02oool0oooo
0;md001d_ol;0?ooo`003`3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo
00D0okmd001d_`3oool0oooo0000000K0?ooo`030000003oool0oooo00d0oooo00<0oono07A8W03o
ool00P3oool00`2LB7@0_ooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0103oool00`3ookl0M01d0;ooo`0P0?ooo`030000003oool0oooo01D0oooo00D0gia8001d_`3o
ool0_g@007Boo`0<0?ooo`030000003oool0oooo02T0oooo00<0W4Qd0;ooo`3oool06P3oool00`00
0000oooo0?ooo`0D0?ooo`<000009`3oool2000000l0oooo00<0W4Qd0;ooo`3oool0<`3oool01@3O
W4P007Bo0?ooo`2oM000M;oo00/0oooo000?0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RL
g`3oool00P3oool01@3OW4P0B9cO0?ooo`3oool0000001/0oooo00<000000?ooo`3oool03@3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030;md001d_ol0oooo00X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`050?ooo`030;md0018W=l0oooo01h0oooo00<000000?ooo`3oool05`3oool0
102LB000B9cO0;md001d_ol<0?ooo`030000003oool0oooo02@0oooo00<0gia807Boo`3oool00P3o
ool00`2oM000M;oo0?ooo`0I0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:@3o
ool2000000P0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0d0?ooo`0409a80018
W=l0_g@007Boo`/0oooo000<0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo`80oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?oo
o`070?oOW01807@0_ooo0?ooo`3ogi`0B01d0;ooo`0;0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0103oool00`3ookl0M000001d_`0N0?ooo`030000003oool0oooo01L0oooo00@0
omnL04P0B018B000M;oo303oool00`000000oooo0?ooo`0T0?ooo`070?noM00007@0_ooo0?ooo`3o
_g@0001809cOo`0I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:`3oool20000
00H0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo03D0oooo00@0omnL04P0B018B000M;oo
2`3oool000h0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo00<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`050?noM000000000000000B02L
gol0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00@0_g@000000000
000004RL6`3oool00`000000oooo0?ooo`0H0?ooo`030?noM0000000M;oo00d0oooo00<000000?oo
o`3oool0903oool01@3o_g@000000000000004P0W=oo01X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0]0?ooo`<00000103oool01@3o_g@000000000000004P0W=oo03L0oooo00<0
okmd0000001d_ol02`3oool001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0`
0?ooo`800000C03oool001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0b0?oo
o`<00000B@3oool001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0e0?ooo`<0
0000AP3oool001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0h0?ooo`@00000
@P3oool001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0l0?ooo`D00000?@3o
ool001d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`110?ooo`@00000>@3oool0
01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`150?ooo`H00000<`3oool001d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1;0?oooa0000008`3oool001d0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1K0?oooaH000003@3oool000D0ooooo`00
002Y000000<0oooo000?0?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`030000003oool0
oooo00/0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool2000000h0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0Q0?ooo`050000003oool0oooo0?ooo`0000008@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0OP3o
ool001`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1n0?ooo`00703oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo07h0oooo000L0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0OP3oool001`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1n0?ooo`00703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo07h0oooo000L
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0OP3oool001`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1n0?ooo`00703oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo07h0oooo000L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo0`00001n0?ooo`00703o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo07h0oooo000L0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0OP3oool001/0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1n0?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07h0
oooo000K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0OP3oool001/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1n0?ooo`006`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo07h0oooo000K0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0OP3oool001/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1n0?ooo`00
6`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo07h0oooo000K0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0OP3oool001/0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1n0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`<00000OP3oool001/0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1n0?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo07h0oooo000J0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0OP3oool001X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1n
0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07h0oooo000J0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0OP3oool001X0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1n0?ooo`006P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo07h0oooo000J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0OP3oool0
01X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1n0?ooo`006P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo07h0oooo000J0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo
0`00001n0?ooo`006P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07h0oooo000I
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0OP3oool001T0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`1n0?ooo`006@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo07h0oooo000I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
OP3oool001T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1n0?ooo`006@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07h0oooo000I0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0OP3oool001T0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1n0?ooo`006@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07h0oooo
000I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0OP3oool001T0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`1n0?ooo`006@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0/0?oo
o`<00000OP3oool001P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1n0?ooo`00
603oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo07h0oooo000H0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0OP3oool001P0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`1n0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
07h0oooo000H0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0OP3oool001P0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1n0?ooo`00603oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo07h0oooo000H0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo00D0okmd
000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@00000000000000000
07Boo`070?ooo`030000003oool0oooo07h0oooo000H0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00H0
W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3o
ool0oooo0?oOW0180000M;oo00H0oooo00<000000?ooo`3oool0OP3oool001P0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool04@3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0okmd001d
_`3oool01@3oool00`000000oooo0?ooo`1n0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`03
0000003oool0oooo07h0oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8001d_ol0oooo00D0oooo1000001m0?ooo`005`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0B0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0OP3o
ool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool04P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0
oooo00X0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1n0?ooo`005`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0D0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool00`3ookl0M01d0;oo
o`0:0?ooo`030000003oool0oooo07h0oooo000G0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00D0oono
07@000000000001809cOo`0<0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01@3o
ool00`000000oooo0?ooo`1n0?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo07h0oooo000G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0OP3oool001L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1n0?ooo`005`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo07h0oooo000G0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0OP3oool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1n
0?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo07h0oooo000F0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03D0oooo0`00001n0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo07h0oooo000F0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0OP3o
ool001H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1n0?ooo`005P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo07h0oooo000F0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0OP3oool001H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`1n0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo07h0oooo000F
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0OP3oool001H0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`1n0?ooo`005P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo07h0oooo000F0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
OP3oool001D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0080oooo0P00000o0?ooo`030000003oool0oooo07h0oooo000E0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0C`3oool500000400oooo0`00001n0?ooo`005@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0OP3oool001D0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo07h0
oooo000E0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`1n0?ooo`005@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0OP3oool001D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo07h0oooo000E0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`1n0?ooo`005@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0OP3oool001@0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo07h0oooo000D0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1n0?ooo`00503oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0OP3oool0
01@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
07h0oooo000D0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0U`3oool00`000000
oooo0?ooo`1n0?ooo`00503oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09L0oooo
0`00001n0?ooo`00503oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool0OP3oool001@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2G
0?ooo`030000003oool0oooo07h0oooo000C0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`1n0?ooo`004`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0OP3oool001<0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo07h0oooo000C0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1n0?ooo`004`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?03oool2
000000030?ooo`000000000009`0oooo00<000000?ooo`3oool0OP3oool001<0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03h0oooo0P00002M0?oo
o`030000003oool0oooo07h0oooo000C0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo07h0oooo000B0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3N0?ooo`030000
003oool0oooo07h0oooo000B0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo07h0oooo000B0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3N0?ooo`<00000OP3oool0
0180oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0=l0oooo00<000000?ooo`3oool0OP3oool00180oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0OP3oool00180oooo
00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool000000>80oooo00<000000?ooo`3o
ool0OP3oool00140oooo00<000000?ooo`3oool0=@3oool010000000oooo0?ooo`00003R0?ooo`03
0000003oool0oooo07h0oooo000A0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool0
0000hP3oool00`000000oooo0?ooo`1n0?ooo`004@3oool00`000000oooo0?ooo`0e0?ooo`<00000
h`3oool00`000000oooo0?ooo`1n0?ooo`004@3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<0
00000?ooo`3oool0OP3oool00100oooo00<000000?ooo`3oool0o`3ooolM0?ooo`030000003oool0
oooo07h0oooo000@0?ooo`030000003oool0oooo0?l0oooo403oool00`3o_g@00000000000030000
0003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0OP3oool00100oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0OP3oool00100oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0
OP3oool000l0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`0309a8B02Lgol0oooo00L0oooo00<0
00000?ooo`3oool0OP3oool00?l0oooo9P3oool00`2LB4P0W=oo0?ooo`070?ooo`@00000O@3oool0
0?l0oooo9P3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo07h0oooo003o0?ooobH0
oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`1n0?ooo`00o`3ooolS0?ooo`050=nL
B000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`1n0?ooo`00o`3ooolU0?ooo`030=nL
B00004P0W=oo00P0oooo00<000000?ooo`3oool0OP3oool00?l0oooo<03oool00`000000oooo0?oo
o`1n0?ooo`00o`3oool`0?ooo`030000003oool0oooo07h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-10.5468, -1.0535, \
0.0521157, 0.01189}}]
}, Closed]],

Cell[TextData[{
  "Attempts to define this function using immediate assignment fail because \
neither the derivative nor the graph can be constructed before a specified \
choice of ",
  StyleBox["f", "InlineInput"],
  " is available. "
}], "Text"],

Cell[BoxData[
    \(Clear[f]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BadPlotDerivative[f_, {x_, xmin_, xmax_}] = 
      Plot[Evaluate[D[f[x], x]], {x, xmin, xmax}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Plot::"plln"\), \(\(:\)\(\ \)\), "\<\"Limiting value \\!\\(xmin\
\\) in \\!\\({x, xmin, xmax}\\) is not a machine-size real number. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::plln\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], 
        ",", \({x, xmin, xmax}\)}], "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Another advantage of delayed assignment is that the risk of conflict with \
pre-existing symbols is reduced.  Without clearing ",
  StyleBox["f", "InlineInput"],
  ", a different, but equally useless, result is obtained from the failed \
function above if an earlier definition of ",
  StyleBox["f[x]", "InlineInput"],
  " is present.  The definition using delayed assignment is immune to this \
problem."
}], "Text"],

Cell["Delayed assignment is recommended for most functions.", "Advice"],

Cell[CellGroupData[{

Cell["Example: spherical Bessel function", "Subsubsection"],

Cell[TextData[{
  "For some unknown reason, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " lacks built-in definitions for spherical Bessel functions.  These \
functions are defined as"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ScriptJ]\_\[ScriptL]\)(
        z) = \@\(\[Pi]\/2\)\ \(z\^\(\(-1\)/
              2\)\) \(\(J\_\(\[ScriptL] + 1\/2\)\)(z)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(TraditionalForm\`\(y\_\[ScriptL]\)(
        z) = \@\(\[Pi]\/2\)\ \(z\^\(\(-1\)/
              2\)\) \(\(Y\_\(\[ScriptL] + 1\/2\)\)(z)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`J\_n\)]],
  " is the regular and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_n\)]],
  " is the irregular cylinder function.  We can define our own spherical \
Bessel functions, without fancy notation, as follows."
}], "Text"],

Cell[BoxData[{
    \(\(sbessj[n_, z_]\  := \ \(\@\(\[Pi]\/2\)\) 
          z\^\(\(-1\)/2\)\ BesselJ[n + 1\/2, z];\)\), "\n", 
    \(\(sbessy[n_, z_]\  := \ \(\@\(\[Pi]\/2\)\) 
          z\^\(\(-1\)/2\)\ BesselY[n + 1\/2, z];\)\)}], "Input"],

Cell[TextData[{
  "We can also define a function which plots these functions for given order \
over a specified range.  For detailed information about plotting commands, \
see ",
  ButtonBox["plotting.nb",
    ButtonData:>{"Primary topics/plotting.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  For the present purposes it is sufficient to recognize that ",
  StyleBox["plotsbess", "InlineInput"],
  " is defined as an explicit function of three variables which specify the \
order of the Bessel function and the minimum and maximum arguments to be \
plotted.  This function uses the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot", "InlineInput"],
  " to produce a figure that displays both the regular and irregular \
spherical Bessel functions over the specified range. "
}], "Text"],

Cell[BoxData[
    \(plotsbess[n_, xmin_, xmax_] := 
      Plot[{sbessj[n, x], sbessy[n, x]}, {x, xmin, xmax}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[0, 0.001, 10];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.314248 0.289071 [
[.21429 .30175 -3 -9 ]
[.21429 .30175 3 0 ]
[.40476 .30175 -3 -9 ]
[.40476 .30175 3 0 ]
[.59524 .30175 -3 -9 ]
[.59524 .30175 3 0 ]
[.78571 .30175 -3 -9 ]
[.78571 .30175 3 0 ]
[.97619 .30175 -6 -9 ]
[.97619 .30175 6 0 ]
[.01131 .02518 -12 -4.5 ]
[.01131 .02518 0 4.5 ]
[.01131 .16971 -24 -4.5 ]
[.01131 .16971 0 4.5 ]
[.01131 .45878 -18 -4.5 ]
[.01131 .45878 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31425 m
.21429 .3205 L
s
[(2)] .21429 .30175 0 1 Mshowa
.40476 .31425 m
.40476 .3205 L
s
[(4)] .40476 .30175 0 1 Mshowa
.59524 .31425 m
.59524 .3205 L
s
[(6)] .59524 .30175 0 1 Mshowa
.78571 .31425 m
.78571 .3205 L
s
[(8)] .78571 .30175 0 1 Mshowa
.97619 .31425 m
.97619 .3205 L
s
[(10)] .97619 .30175 0 1 Mshowa
.125 Mabswid
.07143 .31425 m
.07143 .318 L
s
.11905 .31425 m
.11905 .318 L
s
.16667 .31425 m
.16667 .318 L
s
.2619 .31425 m
.2619 .318 L
s
.30952 .31425 m
.30952 .318 L
s
.35714 .31425 m
.35714 .318 L
s
.45238 .31425 m
.45238 .318 L
s
.5 .31425 m
.5 .318 L
s
.54762 .31425 m
.54762 .318 L
s
.64286 .31425 m
.64286 .318 L
s
.69048 .31425 m
.69048 .318 L
s
.7381 .31425 m
.7381 .318 L
s
.83333 .31425 m
.83333 .318 L
s
.88095 .31425 m
.88095 .318 L
s
.92857 .31425 m
.92857 .318 L
s
.25 Mabswid
0 .31425 m
1 .31425 L
s
.02381 .02518 m
.03006 .02518 L
s
[(-1)] .01131 .02518 1 0 Mshowa
.02381 .16971 m
.03006 .16971 L
s
[(-0.5)] .01131 .16971 1 0 Mshowa
.02381 .45878 m
.03006 .45878 L
s
[(0.5)] .01131 .45878 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .05408 m
.02756 .05408 L
s
.02381 .08299 m
.02756 .08299 L
s
.02381 .1119 m
.02756 .1119 L
s
.02381 .14081 m
.02756 .14081 L
s
.02381 .19862 m
.02756 .19862 L
s
.02381 .22753 m
.02756 .22753 L
s
.02381 .25643 m
.02756 .25643 L
s
.02381 .28534 m
.02756 .28534 L
s
.02381 .34316 m
.02756 .34316 L
s
.02381 .37206 m
.02756 .37206 L
s
.02381 .40097 m
.02756 .40097 L
s
.02381 .42988 m
.02756 .42988 L
s
.02381 .48769 m
.02756 .48769 L
s
.02381 .5166 m
.02756 .5166 L
s
.02381 .5455 m
.02756 .5455 L
s
.02381 .57441 m
.02756 .57441 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0239 .60332 m
.02508 .60331 L
.02615 .60329 L
.02738 .60325 L
.02855 .6032 L
.03063 .60307 L
.03288 .60288 L
.03536 .60261 L
.03799 .60225 L
.04271 .60143 L
.04758 .60033 L
.05214 .59907 L
.06254 .59542 L
.07314 .59057 L
.08283 .58517 L
.10467 .56982 L
.14437 .53207 L
.18256 .48687 L
.2232 .43388 L
.26233 .38291 L
.30391 .33383 L
.34397 .29548 L
.36234 .28161 L
.38252 .26935 L
.40245 .26039 L
.41334 .25682 L
.42351 .25432 L
.42852 .25338 L
.43396 .25258 L
.43646 .25228 L
.43911 .25202 L
.4414 .25183 L
.44386 .25167 L
.44502 .25161 L
.44624 .25156 L
.44736 .25152 L
.44841 .25149 L
.4494 .25147 L
.45045 .25146 L
.45162 .25145 L
.45268 .25146 L
.45393 .25147 L
.45509 .25149 L
.45635 .25153 L
.45769 .25157 L
.45994 .25168 L
.46242 .25184 L
.46763 .2523 L
.47258 .2529 L
.48186 .25443 L
Mistroke
.49186 .25663 L
.50275 .25962 L
.54345 .27526 L
.58263 .29436 L
.62426 .31523 L
.66437 .33266 L
.68278 .33907 L
.70297 .34465 L
.71262 .34674 L
.72295 .34856 L
.72865 .34937 L
.73385 .34998 L
.73879 .35046 L
.74402 .35086 L
.74875 .35112 L
.75144 .35122 L
.75267 .35126 L
.75396 .35129 L
.75506 .35132 L
.75627 .35134 L
.75736 .35135 L
.75838 .35135 L
.75959 .35136 L
.76069 .35136 L
.76195 .35135 L
.76314 .35133 L
.76435 .35131 L
.76567 .35128 L
.76834 .3512 L
.77081 .3511 L
.77312 .35099 L
.77833 .35065 L
.78392 .35018 L
.79407 .34902 L
.80513 .34735 L
.82524 .34333 L
.86599 .33222 L
.90522 .31953 L
.94293 .30754 L
.97619 .29852 L
Mfstroke
.09103 0 m
.0948 .02928 L
.10467 .08928 L
.12349 .17602 L
.14415 .24507 L
.1645 .29597 L
.18306 .33173 L
.20214 .36012 L
.21201 .37192 L
.2229 .38291 L
.23241 .39088 L
.24267 .39787 L
.2535 .40358 L
.25877 .40576 L
.26367 .40746 L
.26869 .40888 L
.27324 .40989 L
.27831 .41073 L
.28109 .41106 L
.28234 .41117 L
.28371 .41128 L
.28495 .41137 L
.28627 .41143 L
.287 .41146 L
.28767 .41149 L
.28898 .41151 L
.29017 .41152 L
.29147 .41152 L
.2927 .41149 L
.29384 .41146 L
.29453 .41143 L
.29527 .41139 L
.29663 .41131 L
.29915 .41111 L
.3021 .4108 L
.30481 .41044 L
.30952 .40964 L
.31457 .40856 L
.32367 .40606 L
.34435 .39799 L
.36562 .38686 L
.38576 .37439 L
.42413 .34776 L
.46496 .31925 L
.50428 .29554 L
.52401 .28596 L
.54208 .27885 L
.56146 .27311 L
.57163 .27092 L
.57724 .26995 L
Mistroke
.58233 .26922 L
.58692 .26868 L
.5919 .26822 L
.59463 .26803 L
.59715 .26788 L
.59956 .26778 L
.60077 .26774 L
.60211 .2677 L
.60334 .26767 L
.6045 .26766 L
.60555 .26765 L
.60669 .26764 L
.60793 .26765 L
.60924 .26766 L
.61037 .26767 L
.61161 .2677 L
.61381 .26777 L
.61618 .26787 L
.62049 .26812 L
.62543 .26851 L
.63004 .26899 L
.6405 .27043 L
.65069 .27228 L
.66159 .27472 L
.70305 .28746 L
.743 .30284 L
.78143 .31791 L
.80089 .3249 L
.82231 .33169 L
.84287 .33707 L
.86168 .34085 L
.87163 .34239 L
.8811 .34353 L
.88593 .34399 L
.89108 .3444 L
.89405 .34459 L
.89673 .34473 L
.89924 .34485 L
.90198 .34495 L
.9032 .34498 L
.9045 .34502 L
.90563 .34504 L
.90686 .34506 L
.90758 .34507 L
.90824 .34508 L
.90955 .34509 L
.91075 .34509 L
.91201 .34509 L
.9131 .34509 L
.91427 .34508 L
Mistroke
.91538 .34507 L
.9164 .34505 L
.91876 .345 L
.92124 .34493 L
.92373 .34483 L
.92639 .34471 L
.93119 .34443 L
.93688 .344 L
.94206 .34353 L
.95844 .34151 L
.97619 .3385 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:03oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0?l0ooooJ`3oool002P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3o0?ooof/0oooo000X0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0o`3ooom[0?ooo`00:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0
ooooJP3oool002P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooofX0oooo
000X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooomZ0?ooo`00703oool0
0`3o_g@000000000000300000003001d_`3oool0oooo00<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`3o0?ooofX0oooo000O0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`3o0?ooofX0oooo000O0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooofX0oooo000O0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooofT0oooo
000C0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?oo
o`060?ooo`@000006@3oool00`000000oooo0?ooo`3o0?ooofT0oooo000O0?ooo`0309a8B02Lgol0
oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooofT0oooo000O0?oo
o`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oo
ofT0oooo000L0?ooo`050=nLB000000004RL09a8B02Lgol01`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0?l0ooooJ@3oool001h0oooo00<0gia80000B02Lgol01`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooJ@3oool002P0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`3o0?ooofP0oooo000X0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0o`3ooomX0?ooo`00:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0?l0ooooJ03oool002P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oo
ofP0oooo000X0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00
:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooJ03oool002P0oooo0`00
000L0?ooo`030000003oool0oooo0?l0ooooI`3oool002P0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`3o0?ooofL0oooo000X0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0o`3ooomW0?ooo`00:03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0
ooooI`3oool002P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooofL0oooo
000X0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`00:03oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0ooooIP3oool002P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`3o0?ooofH0oooo000X0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00:03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0?l0ooooIP3oool002P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`3o0?ooofH0oooo000X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomV
0?ooo`00:03oool3000001h0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`00:03oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooI@3oool002P0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`3o0?ooofD0oooo000X0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0o`3ooomU0?ooo`00:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0?l0ooooI@3oool002P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oo
of@0oooo000X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00
:03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooI03oool002P0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooof@0oooo000X0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00:03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0?l0ooooH`3oool002P0oooo0`00000P0?ooo`030000003oool0oooo0?l0
ooooH`3oool002P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooof<0oooo
000X0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00:03oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooH`3oool002P0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`3o0?ooof80oooo000X0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0?l0ooooHP3oool002P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`3o0?ooof80oooo000X0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooomR
0?ooo`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooH@3oool002P0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooof40oooo000X0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00:03oool300000280oooo00<0
00000?ooo`3oool0o`3ooomQ0?ooo`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0?l0ooooH@3oool002P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?oo
of00oooo000X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00
:03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooH03oool002P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooof00oooo000X0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00:03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0?l0ooooG`3oool000/0oooo00D0okmd000000000000000007Boo`050?oo
o`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`060?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`002`3oool01P2LB7@0_ooo0?ooo`3ookl0
M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d
_ol01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooG`3oool000X0oooo
00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo00@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oooel0oooo000:0?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`040?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`0000<0oooo09a80000000010000000
1@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03`3oool00`2LB000M;oo0?oo
o`040?ooo`@00000903oool00`000000oooo0?ooo`3o0?oooeh0oooo000:0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool02P3oool00`3ookl0M000000000020000000304RLg`3oool0
oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooeh0oooo000:0?oo
o`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01d0;ooo`090?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`002`3oool01P2LB000
M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0M02oool02@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0?l0ooooGP3oool000/0oooo00D0oono07@000000000001809cOo`0<
0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool0103oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0?l0ooooG@3oool002P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`3o0?oooed0oooo000X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0o`3ooomM0?ooo`00:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo
G03oool002P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooe`0oooo000X
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00:03oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooF`3oool002P0oooo0`00000X0?ooo`03
0000003oool0oooo0?l0ooooF`3oool002P0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`3o0?oooe/0oooo000X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3o
oomJ0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooFP3oool0
02P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooeX0oooo000X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00:03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooF@3oool002P0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`3o0?oooeT0oooo000X0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0o`3ooomI0?ooo`00:03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0?l0ooooF03oool002P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?oooeP0
oooo000X0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`00:03o
ool3000002`0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00:03oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0?l0ooooE`3oool002P0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`3o0?oooeL0oooo000X0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0o`3ooomF0?ooo`00:03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo
EP3oool002P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooeH0oooo000X
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00:03oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`3o0?oooeD0oooo000X0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0L03oool>00000=D0oooo000X0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0JP3oool6000000h0oooo1P00003?0?ooo`00:03oool300000300oooo00<00000
0?ooo`3oool0IP3oool3000001X0oooo1@00003:0?ooo`00:03oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo06@0oooo0P00000R0?ooo`@00000aP3oool002P0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`1Q0?ooo`<00000:03oool200000<@0oooo000X0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0GP3oool2000002d0oooo0P0000320?ooo`00:03o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05/0oooo0`00000a0?ooo`800000`03o
ool002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1H0?ooo`800000=P3oool3
000001D0oooo5@00002C0?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0100oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`0l0?ooo`8000001`3oool01@3o
gi`0B000000000000000M;oo02l0oooo0P00000=0?ooo`H000000`3oool01@2oM000000000000000
07@0_ooo00d0oooo2000000a0?ooo`050;md00000000000000000000M;l0@P3oool00`3o_g@00000
0000000300000005001d_`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`020?ooo`00
:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0140oooo00<0_g@00000M02oool0
0P3oool00`3OW7@0W=oo0?ooo`0l0?ooo`030000003oool0oooo00T0oooo00<0_g@007Boo`3oool0
<@3oool2000000L0oooo100000080?ooo`060=nLB000M;l0oooo0?ooo`3o_g@007Bo5@3oool40000
02`0oooo00<0okmd001d_`3oool00P3oool00`2oM4P0W=oo0?ooo`130?ooo`0309a8B02Lgol0oooo
00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool30?ooo`00:03oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo0140oooo00<0okmd0000B02Lgol0?P3oool2000000`0oooo00<0_g@0
07Boo`3oool0<`3oool7000000/0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M4RL0?ooo`0H
0?ooo`<00000:@3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo04<0oooo00<0W4Q8
09cOo`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo0080oooo000X0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool04P3oool00`3ogi`0B00004RLg`0k0?oo
o`8000002P3oool00`3OW4P00000000000030000000307Boo`3oool0oooo0340oooo1@00000=0?oo
o`070?noM000B4P0M01d0;ooo`3oool0gia8001d_`0L0?ooo`<000009P3oool00`3o_g@004RL0?oo
o`020?ooo`0309a8B02Lgol0oooo04<0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo0080oooo000X0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool04`3oool00`2LB000B9cO0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00H0okmd
0000M02oool0oooo0;md001d_olb0?ooo`8000001@3oool2000000/0oooo00<0omnL04Q8W03o_g@0
0P0000000`00B9`0oooo0?ooo`0N0?ooo`8000009@3oool01@3OW4P00000000000000000B9cO04D0
oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo0080
oooo000X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0503oool00`2LB7@0_ooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo00D0gia8001d_`3oool0_g@007Boo`0_0?ooo`<0
00002@3oool2000000T0oooo00<0oono07@0M02oool09@3oool300000240oooo00<0oono07A8W03o
ool00P3oool00`2LB7@0_ooo0?ooo`130?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`020?ooo`00:03oool3000003@0oooo00<000000?ooo`3oool0
3`3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo03@0oooo0P00000@0?ooo`0409a8
0018W=l0_g@007Boobd0oooo0P00000>0?ooo`<000001`3oool00`2oM000B9cO0?ooo`0W0?ooo`<0
00007P3oool00`3o_g@0B9cO0?ooo`020?ooo`030;md001d_ol0oooo04<0oooo00<0W4Q809cOo`3o
ool00`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo0080oooo000X0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool03P3oool01`3o_g@0001d0;ooo`3oool0okmd0000
B02Lgol0=03oool00`000000oooo0?ooo`0@0?ooo`040?oOW01804P0B4P007Boob/0oooo0P00000C
0?ooo`8000001@3oool00`3ookl0M000001d_`0Z0?ooo`<000006`3oool01`3ogi`0B01d0;ooo`3o
ool0omnL04P0M02oool0@@3oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3o
ool0omnL04P0M02oool30?ooo`00:03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00l0oooo00D0okmd000000000000001809cOo`0d0?ooo`030000003oool0oooo0180oooo00<0okmd
0000001d_ol0:@3oool2000001L0oooo0P0000050?ooo`040;md0000000000000018W2X0oooo0P00
000J0?ooo`050?noM000000000000000B02Lgol0A03oool00`3OW4P0001809cOo`050?ooo`050?oo
_`1d000000000000B02Lgol0103oool002P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`150?ooo`800000?`3oool2000001/0oooo0P00000c0?ooo`<00000L@3oool002P0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03d0oooo0P00
000O0?ooo`800000=03oool3000006h0oooo000X0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0l0?ooo`8000008`3oool2000003D0oooo0P00001P
0?ooo`8000002P3oool002P0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo03/0oooo0P00000W0?ooo`800000=@3oool3000005X0oooo0`00000<0?oo
o`00:03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03D0oooo0`00001C0?ooo`@0
00003`3oool002P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo03X0oooo0P00000]0?ooo`800000>03oool2000004h0oooo0`00000C0?ooo`00:03o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0>@3o
ool200000340oooo0P00000h0?ooo`<00000B03oool3000001H0oooo000X0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo03<0oooo0P00000i0?ooo`800000@P3oool4000001T0oooo000O0?ooool00000T@0000010?oo
o`00:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`3oool2000000d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`8000001P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool2
000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00T0oooo100000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool0
02P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`800000103o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3o
ool400000180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`<000001`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000X0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool04`3oool2000003@0oooo00<000000?ooo`3oool0303oool2
000003/0oooo0P00000Z0?ooo`<000007@3oool00`000000oooo0?ooo`080?ooo`00:03oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`150?ooo`800000>`3oool3000002@0oooo0`00000[0?ooo`00:03oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`180?ooo`<00000>`3oool4000001`0oooo1000000^0?ooo`00:03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0=P3oool2000004h0oooo
0P00000m0?ooo`@000005@3oool300000380oooo000X0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0500oooo0P00
000o0?ooo`@000003P3oool3000003D0oooo000X0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0e0?ooo`800000E@3oool300000400oooo10000007
0?ooo`<00000>03oool002P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0F03oool400000400oooo1`00000k0?oo
o`00:03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0=03oool2000005l0oooo1000000l0?ooo`P00000;03oool4000000X0oooo000X0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo06<0oooo1000000e0?ooo`<00000203oool7000001h0oooo1`00000>0?ooo`00:03o
ool300000400oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo06P0oooo1000000/0?ooo`D000004P3oool:000000T0oooo2`00000E0?ooo`00:03oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0<P3oool2
000006l0oooo1000000Q0?ooo`L000008@3oool900000200oooo000X0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
07<0oooo1@00000H0?ooo`@00000D@3oool002P0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0340oooo0P00001k0?oooaP00000E@3oool002P0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0j03oool002P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo02l0oooo0P00003[0?ooo`00:03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3[
0?ooo`00:03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0;P3oool200000>h0oooo000X0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0>h0oooo000X0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/0?ooo`800000
l@3oool002P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0l@3oool002P0oooo0`0000190?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0:`3oool200000?@0oooo000X0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0?@0oooo000X0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0Z0?ooo`800000m`3oool002P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0m`3oool002P0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02P0oooo0P00
003j0?ooo`00:03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool09`3oool200000?`0oooo000X0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?`0oooo000X0?ooo`03
0000003oool0oooo04l0oooo0P00000:0?ooo`030000003oool0oooo02H0oooo0P00003o0?ooo`00
:03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`3o0?ooo`00:03oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0903oool200000?l0oooo0`3oool002P0oooo00<00000
0?ooo`3oool0D`3oool2000000@0oooo00<000000?ooo`3oool08`3oool200000?l0oooo1@3oool0
02P0oooo00<000000?ooo`3oool0E@3oool010000000oooo0?ooo`00000T0?ooo`800000o`3oool7
0?ooo`00:03oool3000005H0oooo0P00000R0?ooo`<00000o`3oool90?ooo`00:03oool00`000000
oooo0?ooo`1G0?ooo`<000007@3oool300000?l0oooo303oool002P0oooo00<000000?ooo`3oool0
EP3oool010000000oooo0?ooo`3oool4000001H0oooo0`00003o0?ooo`l0oooo000X0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool01P3oool4000000h0oooo1000003o0?oooa80oooo
000X0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool02`3oool>00000?l0oooo5P3o
ool002P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?oooc00oooo000X0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0o`3oool`0?ooo`00:03oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0?l0oooo<@3oool002P0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`3o0?oooc80oooo000X0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0o`3ooolc0?ooo`00:03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0?l0oooo=03oool002P0oooo0`00001?0?ooo`030000003oool0oooo0?l0oooo=03oool002P0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooocD0oooo000X0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00:03oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0?l0oooo=`3oool002P0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`3o0?ooocP0oooo000X0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`00:03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0
oooo>@3oool002P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooocX0oooo
000;0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md
0000000000000000001d_ol01P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0
oooo>`3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo
00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00D0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`3o0?oooc/0oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool03`3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0o`3oooll0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
00l0oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0?l0oooo?@3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`03
09a8001d_ol0oooo00@0oooo100000140?ooo`030000003oool0oooo0?l0oooo?P3oool000X0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1d0000000000800000
00<0B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo
?P3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d
07@0_ooo00T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000;
0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool00`3ookl0M01d0;ooo`090?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooom00?ooo`002`3oool01@3ookl0M0000000
000004P0W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`040?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:03oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo0?l0oooo@@3oool002P0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`3o0?oood80oooo000X0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0o`3ooom30?ooo`00:03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0
ooooA03oool002P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oood@0oooo
000X0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooom50?ooo`00:03oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0ooooAP3oool002P0oooo0`00000l0?oo
o`030000003oool0oooo0?l0ooooA`3oool002P0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000X0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
o`3ooom90?ooo`00:03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooB@3o
ool002P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooodX0oooo000X0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`00:03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooC03oool002P0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`3o0?ooodd0oooo000X0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`00:03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0?l0ooooCP3oool002P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oo
odl0oooo000X0?ooo`<00000<`3oool00`000000oooo0?ooo`3o0?oooe00oooo000X0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00:03oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo0?l0ooooDP3oool002P0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`3o0?oooe<0oooo000X0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0o`3ooomC0?ooo`00:03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0
ooooE03oool002P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooeD0oooo
000X0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00:03oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooE`3oool002P0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`3o0?oooeP0oooo000X0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0?l0ooooFP3oool002P0oooo0`00000X0?ooo`030000003oool0oooo0?l0ooooF`3o
ool002P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oooe`0oooo000X0?oo
o`030000003oool0oooo02D0oooo0P00003o0?oooel0oooo000X0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00:03oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0?l0ooooH03oool002P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`3o0?ooof40oooo000X0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooomR
0?ooo`00:03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooH`3oool002P0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooof@0oooo000X0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`00:03oool00`000000oooo0?oo
o`0L0?ooo`800000o`3ooomX0?ooo`00:03oool3000001/0oooo00<000000?ooo`3oool0o`3ooomX
0?ooo`00:03oool00`000000oooo0?ooo`0I0?ooo`800000o`3ooom[0?ooo`00:03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooJ`3oool002P0oooo00<000000?ooo`3oool0
5P3oool200000?l0ooooKP3oool002P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`3o0?ooofh0oooo000X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooom_
0?ooo`00:03oool00`000000oooo0?ooo`0B0?ooo`800000o`3ooomb0?ooo`00:03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooLP3oool001`0oooo00<0okmd000000000000
0`0000000`00M;l0oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0P00003o0?ooogD0oooo
000O0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0303oool300000?l0ooooM`3o
ool001l0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`090?ooo`<00000o`3ooomj
0?ooo`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo0080oooo1`00003o0?oo
ogd0oooo000O0?ooo`0309a8B02Lgol0oooo00H0oooo1@00003o0?oooh@0oooo000O0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool0o`3ooon60?ooo`007`3oool00`2LB4P0W=oo0?oo
o`060?ooo`030000003oool0oooo0?l0ooooQP3oool001`0oooo00D0gia800000000B9`0W4Q809cO
o`070?ooo`030000003oool0oooo0?l0ooooQP3oool001h0oooo00<0gia80000B02Lgol01`3oool0
0`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0
oooo00<000000?ooo`3oool0o`3ooon60?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-1.07744, -1.16514, \
0.0394228, 0.0129884}}]
}, Closed]],

Cell[TextData[{
  "This simple definition for ",
  StyleBox["sbessj", "InlineInput"],
  " works for most arguments, but fails for ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sbessj[0, 0]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/\\@0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ \\@\\(\[Pi]\\/2\\)\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(Indeterminate\)], "Output"]
}, Closed]],

Cell["We will see how to correct this type of problem shortly.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["exercises", "Subsubsection"],

Cell[TextData[{
  "The Stirling approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`Log[\(n!\)]\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm
      \`Log[\(n!\)] \[TildeTilde] \ 
        n\ Log[n]\  - \ n\  + \ \(1\/2\) Log[2  \[Pi]\ n]\  + \ 
          1\/\(12\ n\) + \ \[CenterEllipsis]\)]],
  ".  \na) Write functions logStirling1 using just the first two terms (the \
lowest reasonable approximation), logStirling2 including the next term, and \
logStirling3 including the next two terms.\n b) Also write functions which \
evaluate the percentage error in these approximations.  \n c) Make a LogPlot \
which displays the percentage errors for all three approximations as \
functions of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ".  [Hint: you will probably need to load the package Graphics`Graphics` to \
use LogPlot.]"
}], "Exercise"],

Cell["\<\
Write a new version of the Stirling function for which logStirling[n,1] gives \
the first approximation, logStirling[n,2] the second, and logStirling[n,3] \
the third.  Furthermore, logStirling[n] with only a single argument should \
give the most accurate formula, namely logStirling[n,3].\
\>", "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Arguments in List or Sequence form", "Subsection"],

Cell[TextData[{
  "Many explicit functions receive their arguments in the form of a sequence, \
such as ",
  StyleBox["f[a,b,c]", "InlineInput"],
  ", while others receive a list of arguments, such as ",
  StyleBox["g[{a,b,c}]", "InlineInput"],
  ".  However, we often find our arguments represented in an inappropriate \
form and need a mechanism for converting a ",
  StyleBox["List", "InlineInput"],
  " to a ",
  StyleBox["Sequence", "InlineInput"],
  ".  For example, consider the following function defined in terms of a \
sequence of three arguments.  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, a, b, c, d];\)\), "\n", 
    \(f[a_, b_, c_, d_] := d\ a\^\(b\^c\)\)}], "Input"],

Cell["\<\
We might as a result of earlier work have some of the desired arguments in \
the form of a list, but when we present that list to our function\
\>", "Text"],

Cell[BoxData[
    \(\(argumentList = {a, b, c};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[argumentList, d]\)], "Input"],

Cell[BoxData[
    \(f[{a, b, c}, d]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "no evaluation is performed because the argument sequence does not match \
the pattern employed to define the function.  A convenient solution to this \
problem is provided by the function ",
  ButtonBox["Sequence",
    ButtonStyle->"RefGuideLink"],
  ", which stores its arguments in the form of a sequence which can be \
inserted into an argument list.  Applying ",
  StyleBox["Sequence", "InlineInput"],
  " to the argumentList replaces the head ",
  StyleBox["List", "InlineInput"],
  " with the head ",
  StyleBox["Sequence", "InlineInput"],
  StyleBox[".",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(argumentSequence = Sequence @@ argumentList\)\)\)], "Input"],

Cell[BoxData[
    \(Sequence[a, b, c]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[argumentSequence, d]\)], "Input"],

Cell[BoxData[
    \(a\^\(b\^c\)\ d\)], "Output"]
}, Closed]],

Cell["\<\
In fact, a sequence of this form can be inserted into any argument list and \
will act as if the arguments were provided directly.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[g];\)\), "\n", 
    \(g[stuff, argumentSequence, moreStuff]\)}], "Input"],

Cell[BoxData[
    \(g[stuff, a, b, c, moreStuff]\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions formed from command sequences", "Section",
  CellTags->"command sequences"],

Cell[TextData[{
  "We will often need functions which require many steps to produce their \
results.  Perhaps the simplest method for assembling a multistep function is \
to define a function in terms of an expression which contains a sequence of \
commands.  The basic syntax would be: \n\t",
  StyleBox["f[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["args", "InlineInput"],
  StyleBox["_", "InlineInput",
    FontSlant->"Italic"],
  StyleBox["] :=", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" (", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["expr1; expr2; \[CenterEllipsis] ; output)", "InlineInput"],
  StyleBox["\n",
    FontSlant->"Italic"],
  "where the initial steps return their output to the next step rather than \
to the user, with only the final step returning a printed result because it \
does not end with a terminal semicolon.  For example, the following function \
finds the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^n\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\((a + b\ x)\)\^m\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions ",
  StyleBox["Expand", "InlineInput"],
  " and ",
  StyleBox["Coefficient", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[
    \(Clear[f, n, m]\)], "Input"],

Cell[BoxData[
    \(f[n_, m_]\  := \ \((temp\  = \ Expand[\((a + b\ x)\)\^m]; \ 
        Coefficient[temp, x, n])\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3, 13]\)], "Input"],

Cell[BoxData[
    \(286\ a\^10\ b\^3\)], "Output"]
}, Closed]],

Cell["\<\
Although this function achieves its goal, it has the undesirable effect of \
leaving behind detritus in the form of unwanted symbols which should have \
been temporary.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(temp\)], "Input"],

Cell[BoxData[
    \(a\^13 + 13\ a\^12\ b\ x + 78\ a\^11\ b\^2\ x\^2 + 
      286\ a\^10\ b\^3\ x\^3 + 715\ a\^9\ b\^4\ x\^4 + 
      1287\ a\^8\ b\^5\ x\^5 + 1716\ a\^7\ b\^6\ x\^6 + 
      1716\ a\^6\ b\^7\ x\^7 + 1287\ a\^5\ b\^8\ x\^8 + 
      715\ a\^4\ b\^9\ x\^9 + 286\ a\^3\ b\^10\ x\^10 + 
      78\ a\^2\ b\^11\ x\^11 + 13\ a\ b\^12\ x\^12 + b\^13\ x\^13\)], "Output"]
}, Closed]],

Cell["\<\
The simple example suggested above can be written more efficiently using pure \
functions which do not require creation of intermediate symbols, but it is \
often difficult to formulate more interesting multistep functions in readable \
fashion without creating local variables.  Traditional programming languages \
solve this problem by providing constructions known as subprograms to isolate \
the local variables which are used for intermediate steps and then are \
discarded when no longer needed.  These subprograms also protect their local \
variables from corruption by external commands.  The importance of protecting \
local variables is illustrated in a later section.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pure functions", "Section",
  CellTags->"pure functions"],

Cell[TextData[{
  "A pure function is represented by the basic syntax ",
  StyleBox["Function[var,body]", "InlineInput"],
  " where ",
  StyleBox["var", "InlineInput"],
  " represents the argument and ",
  StyleBox["body", "InlineInput"],
  " the definition of the function.  The argument can be a single variable or \
a list of variables.  The function is then applied to an argument using the \
syntax ",
  StyleBox["Function[var,body][arg]", "InlineInput"],
  " to replace ",
  StyleBox["var", "InlineInput"],
  " by ",
  StyleBox["arg", "InlineInput"],
  " in ",
  StyleBox["body", "InlineInput"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Pure functions with names", "Subsection",
  CellTags->"pure functions with names"],

Cell["\<\
If we intend to use a function several times we should assign it a name and \
refer to it by name rather than repeat its definition each time it is used.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h\  = \ Function[x, a\ x\^2\  + \ b\ x\  + \ c]\)], "Input"],

Cell[BoxData[
    \(Function[x, a\ x\^2 + b\ x + c]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[Sin[\[Phi]]\^2]\)], "Input"],

Cell[BoxData[
    \(c + b\ Sin[\[Phi]]\^2 + a\ Sin[\[Phi]]\^4\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[h[y]]\)], "Input"],

Cell[BoxData[
    \(c + b\ \((c + b\ y + a\ y\^2)\) + 
      a\ \((c + b\ y + a\ y\^2)\)\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Here ",
  StyleBox["h", "InlineInput"],
  " is simply a symbol that represents a pure function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?h\)\)], "Input"],

Cell["Global`h", "Print",
  CellTags->"Info3312795303-7827047"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(h = Function[x, a\ x\^2 + b\ x + c]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "h"],
      Editable->False]], "Print",
  CellTags->"Info3312795303-7827047"]
}, Closed]],

Cell[TextData[{
  "The formal arguments used to define the body of the function are local \
variables that will not interfere with assignments made elsewhere for symbols \
with the same names.  In the example below, the assignment given to ",
  StyleBox["x", "InlineInput"],
  " does not affect the definition of a function that uses ",
  StyleBox["x", "InlineInput"],
  " as its local variable."
}], "Text"],

Cell[BoxData[{
    \(\(x = "\<something\>";\)\), "\[IndentingNewLine]", 
    \(\(g = Function[x, x\^2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[y]\)], "Input"],

Cell[BoxData[
    \(y\^2\)], "Output"]
}, Closed]],

Cell["\<\
However, parameters that appear in the body of the functions are treated as \
global symbols.  Therefore, assignments of those parameters will affect \
subsequent evaluation of the functions and must be made with care.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[a]\)], "Input"],

Cell[BoxData[
    \(a\^3 + a\ b + c\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = 2;\)\), "\[IndentingNewLine]", 
    \(h[z]\)}], "Input"],

Cell[BoxData[
    \(c + b\ z + 2\ z\^2\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(Clear[a]\)], "Input"],

Cell[TextData[{
  "It is also important to recognize that functions defined in this manner \
are not evaluated until arguments are presented.  Therefore, it is not \
necessary to use delayed assignment to prevent premature evaluation of the \
right-hand side.  Notice how in the cell below the definition using ",
  StyleBox["Function", "InlineInput"],
  " behaves properly while similar definitions using immediate assignment \
fail, the first by failing to protect the local variable and the second by \
premature evaluation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, f2, g, y, z];\)\), "\[IndentingNewLine]", 
    \(\(f1[x_] = Expand[x];\)\), "\[IndentingNewLine]", 
    \(\(f2[y_] = Expand[y];\)\), "\[IndentingNewLine]", 
    \(\(g = Function[x, Expand[x]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f1[\((y + z)\)\^2]\)], "Input"],

Cell[BoxData[
    \("something"\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2[\((y + z)\)\^2]\)], "Input"],

Cell[BoxData[
    \(\((y + z)\)\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[\((y + z)\)\^2]\)], "Input"],

Cell[BoxData[
    \(y\^2 + 2\ y\ z + z\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "We call functions of this type ",
  StyleBox["pure",
    FontSlant->"Italic"],
  " because we define the behavior of the function, not its arguments.  In \
fact, we can manipulate a pure function by name without supplying any \
arguments at all.  For example, suppose that we require the derivative of the \
quadratic function defined above.  The derivative can be evaluated in an \
obvious fashion using the built-in function ",
  ButtonBox["D",
    ButtonStyle->"RefGuideLink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[h[y], y]\)], "Input"],

Cell[BoxData[
    \(b + 2\ a\ y\)], "Output"]
}, Closed]],

Cell[TextData[{
  "but this method requires that ",
  StyleBox["h", "InlineInput"],
  " be given an explicit argument.  We prefer the pure form using the \
conventional prime notation"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h'\)], "Input"],

Cell[BoxData[
    \(Function[x, b + 2\ a\ x]\)], "Output"]
}, Closed]],

Cell["\<\
to obtain the derivative as a pure function also.  A pure function can be \
evaluated with any suitable argument.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(h'\)[stuff], \(h'\)[2\/3]}\)], "Input"],

Cell[BoxData[
    \({b + 2\ a\ stuff, \(4\ a\)\/3 + b}\)], "Output"]
}, Closed]],

Cell["\<\
The logistic map is defined by the function f[x_]:=\[Mu] x (1-x) where \[Mu] \
is the growth parameter.  Write a pure function that embodies this mapping.  \
Use NestList to produce an iterated function sequence \
{y,f[y],f[f[y]],f[f[f[y]]],...} nested 4 times.\
\>", "Exercise"],

Cell["\<\
Pure and explicit function definitions can be mixed.  Study the behavior of \
the following function:
\tf[\[Mu]_]=Function[x,\[Mu] x (1-x)]
Evaluate the following expressions and interpret the results: 
a) f[a]  \tb) f[a][x] \tc)f[2.5][0.8]\td) NestList[f[\[Mu]],y,4]\
\>", "Exercise"],

Cell["\<\
Once again define:
\tf[\[Mu]_]=Function[x,\[Mu] x (1-x)]
Then evaluate the following expressions and interpret the results: 
a) f[a] ' \tb) f[a]'[z] \tc) f[3.5]'[0.25]\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pure functions of several variables", "Subsection",
  CellTags->"pure functions of several variables"],

Cell[TextData[{
  "Pure functions with several variables are defined by using a list of \
variable names in place of ",
  StyleBox["var", "InlineInput"],
  " and the same variable names in ",
  StyleBox["body", "InlineInput"],
  ".  When the function is evaluated it must be given a corresponding set of \
arguments, which are substituted in order."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ Function[{x, y, z}, x\ y\^\(-3\)\ Erf[z]]\)], "Input"],

Cell[BoxData[
    \(Function[{x, y, z}, \(x\ Erf[z]\)\/y\^3]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x];\)\), "\[IndentingNewLine]", 
    \(s[x, 1\/y, 4]\)}], "Input"],

Cell[BoxData[
    \(x\ y\^3\ Erf[4]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s[x, x, x]\)], "Input"],

Cell[BoxData[
    \(Erf[x]\/x\^2\)], "Output"]
}, Closed]],

Cell["\<\
Of course, you do need to supply enough input to obtain a complete \
evaluation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s[1]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Function::"fpct"\), \(\(:\)\(\ \)\), "\<\"Too many parameters \
in \\!\\({x, y, z}\\) to be filled from \\!\\(\\(\\(Function[\\(\\(\\(\\({x, \
y, z}\\)\\), \\(x\\\\ \\(\\(Erf[z]\\)\\)\\)\\/y\\^3\\)\\)]\\)\\)[1]\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Function::fpct\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(\(Function[{x, y, z}, \(x\ Erf[z]\)\/y\^3]\)[1]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Notice that even though the variables appear in ",
  StyleBox["Function", "InlineInput"],
  " without blank patterns (underscore) attached, there is no conflict \
between symbols used outside of the function definition and those used \
inside, even when the same names are involved.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x = "\<stuff\>"; \ y = "\<more stuff\>";\), "\n", 
    \(h = Function[{x, y}, x + y]\)}], "Input"],

Cell[BoxData[
    \(Function[{x, y}, x + y]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[x, y]\)], "Input"],

Cell[BoxData[
    \("more stuff" + "stuff"\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[a, b];\)\), "\n", 
    \(h[a, b]\)}], "Input"],

Cell[BoxData[
    \(a + b\)], "Output"]
}, Closed]],

Cell["The positions of the arguments matter, not their names. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\), "\[IndentingNewLine]", 
    \(\(Function[{x, y, z}, x\ \(y\^2\) z\^3]\)[z, x, y]\)}], "Input"],

Cell[BoxData[
    \(x\^2\ y\^3\ z\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Express as pure functions:\t\na) ",
  Cell[BoxData[
      \(TraditionalForm\`f[x_, y_] := x\^y\)]],
  "\tb) g[x_,y_]:={Cos[x],Sin[y]}"
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Anonymous functions", "Subsection",
  CellTags->"anonymous functions"],

Cell[TextData[{
  "Why bother giving a name to a specialized function that we will probably \
use just once and then discard?  Omission of a name avoids storing \
unnecessary definitions and conserves computational resources; it also \
relieves us of the responsibility for conceiving a memorable name that does \
not conflict with other symbols.  Nameless functions are obviously called ",
  StyleBox["anonymous",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(Clear[a, b, c]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Function[x, a\ x\^2\  + \ b\ x\  + \ c]\)], "Input"],

Cell[BoxData[
    \(Function[x, a\ x\^2 + b\ x + c]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Function[x, a\ x\^2\  + \ b\ x\  + \ c]\)[q]\)], "Input"],

Cell[BoxData[
    \(c + b\ q + a\ q\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Function[x, a\ x\^2\  + \ b\ x\  + \ c]\)[Tanh[y]]\)], "Input"],

Cell[BoxData[
    \(c + b\ Tanh[y] + a\ Tanh[y]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Function[x, a\ x\^2\  + \ b\ x\  + \ c]@Tanh[y]\)], "Input"],

Cell[BoxData[
    \(c + b\ Tanh[y] + a\ Tanh[y]\^2\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Skeletal notation", "Subsection",
  CellTags->"skeletal notation"],

Cell[TextData[{
  "Since the arguments of a pure function are only local variables, why \
bother naming them?  If a pure function is only to be used once, why bother \
naming it or using the word ",
  StyleBox["Function", "InlineInput"],
  "?  There is a very convenient notation that can be used to define pure \
functions without cluttering the world with useless names.  Thus, ",
  StyleBox["body&", "InlineInput"],
  " is equivalent to ",
  StyleBox["Function[var,body]", "InlineInput"],
  " with each variable replaced by a ",
  ButtonBox["Slot",
    ButtonStyle->"RefGuideLink"],
  ".  If only one variable is needed, it can be represented by the unnumbered \
slot ",
  StyleBox["#", "InlineInput"],
  "; but if several are needed their slots are numbered sequentially as ",
  StyleBox["#1", "InlineInput"],
  ", ",
  StyleBox["#2", "InlineInput"],
  ", etc.  MacDonald coined the term ",
  StyleBox["skeletal notation",
    FontSlant->"Italic"],
  " to describe this method of expressing functional relationships in bare \
form without fleshy names."
}], "Text"],

Cell[BoxData[
    \(Clear[a, b, c, x]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(a\ #\^2\  + \ b  #\  + \ c\  &\)\ [x]\)], "Input"],

Cell[BoxData[
    \(c + b\ x + a\ x\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(h\)\(=\)\(a\ #\^2\  + \ b  #\  + \ c\  &\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(a\ #1\^2 + b\ #1 + c &\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[stuff]\)], "Input"],

Cell[BoxData[
    \(c + b\ stuff + a\ stuff\^2\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(\(g\  = \ \((#1\  + \ 
                2  #2)\)\ Exp[\(-#3\^2\)] &;\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[x, y, z]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-z\^2\)\ \((x + 2\ y)\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Many built-in functions are pure \[LongDash] we can manipulate such \
functions without specifying arguments.  For example, here we define ",
  StyleBox["f1", "InlineInput"],
  " to be the tangent function and ",
  StyleBox["f2", "InlineInput"],
  " to be its derivative."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[f1, f2];\)\), "\[IndentingNewLine]", 
    \(\(f1 = Tan;\)\), "\[IndentingNewLine]", 
    \(f2 = f1'\)}], "Input"],

Cell[BoxData[
    \(Sec[#1]\^2 &\)], "Output"]
}, Closed]],

Cell[TextData[{
  "We find that ",
  StyleBox["f2", "InlineInput"],
  " is returned as a pure function given with skeletal notation.  There is no \
need to name the slot.  If we want a particular value, we simply fill the \
slot with the desired argument."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f1[30\ Degree], f2[30  Degree]}\)], "Input"],

Cell[BoxData[
    \({1\/\@3, 4\/3}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "A pure function can be applied to a list which contains the required \
arguments using the ",
  ButtonBox["Apply",
    ButtonStyle->"RefGuideLink"],
  " operator ",
  StyleBox["@@", "InlineInput"],
  ".  The syntax ",
  StyleBox["f@@expr", "InlineInput"],
  " replaces the head of ",
  StyleBox["expr", "InlineInput"],
  " with ",
  StyleBox["f", "InlineInput"],
  "; thus, if the expression is a list of the form ",
  StyleBox["expr=List[a,b,\[CenterEllipsis]]", "InlineInput"],
  ", normally printed as ",
  StyleBox["{a,b,\[CenterEllipsis]}", "InlineInput"],
  ",  the result is simply ",
  StyleBox["f[a,b,\[CenterEllipsis]]", "InlineInput"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(args\  = \ {x, y, z};\)\), "\n", 
    \(g @@ args\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-z\^2\)\ \((x + 2\ y)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[args]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[x, y, z]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell["\<\
If the list is long enough the slots will be filled from the beginning of the \
list, \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g @@ {x, y, z, "\<more stuff\>"}\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-z\^2\)\ \((x + 2\ y)\)\)], "Output"]
}, Closed]],

Cell["\<\
but if it is too short the expression cannot be evaluated fully, leaving an \
unfilled slot.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g @@ {x, y}\)], "Input"],

Cell[BoxData[
    RowBox[{\(Function::"slotn"\), \(\(:\)\(\ \)\), "\<\"Slot number \
\\!\\(3\\) in \\!\\(\\(\\(\\(\\((#1 + \\(\\(2\\\\ #2\\)\\))\\)\\)\\\\ \
\[ExponentialE]\\^\\(-#3\\^2\\)\\)\\) &\\) cannot be filled from \
\\!\\(\\(\\((\\(\\(\\(\\(\\((#1 + \\(\\(2\\\\ #2\\)\\))\\)\\)\\\\ \
\[ExponentialE]\\^\\(-#3\\^2\\)\\)\\) &\\))\\)\\)[\\(\\(x, y\\)\\)]\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Function::slotn\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-#3\^2\)\ \((x + 2\ y)\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Translate the following expressions into skeletal form and give examples \
of their use.\na) ",
  Cell[BoxData[
      \(TraditionalForm\`f[x_] := \(x\^2\) Cos[x]\)]],
  "\tb) g[x_]:=Expand[x]\t\tc) h[x_,y_,z_]:=Min[x,y,z] Max[x,y,z]"
}], "Exercise"],

Cell[TextData[{
  "Express the logistic map \[Mu] x (1-x) using a pattern argument for the \
parameter \[Mu] and a slot for the independent variable ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  Then evaluate Nest[f[\[Alpha]],y,4] where f is your function."
}], "Exercise"],

Cell[TextData[{
  "Write a skeletal function which selects the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " element of a list.  Test by mapping your function onto a list of the form \
{{a,b,c},{1,2,3},{\"eeny\", \"meeny\", \"miny\", \"moe\"}}."
}], "Exercise"],

Cell["\<\
Write and test a skeletal function which produces polar coordinates {r,\
\[Theta]} from Cartesian coordinates {x,y}.\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: simplification using skeletal pure functions", "Subsection"],

Cell[TextData[{
  "Often one develops a symbolic result in a series of steps, with the result \
of each step fed to a function which performs the next transformation.  Such \
calculations are conveniently performed using the postfix operator (",
  StyleBox["//", "InlineInput"],
  ") to add each step of the sequence as the calculation is developed."
}], "Text"],

Cell[TextData[{
  "For example, suppose we wish to create a function which produces the \
coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  " that appears in the expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`\((a\  + \ b\ x)\)\^13\)]],
  ".  A simple way to accomplish this task is to supply the symbolic \
expansion to a skeletal function that extracts the desired coefficient.  The \
result of the first step, the expansion, is the argument that fills the slot \
in the next step reserved by ",
  StyleBox["#", "InlineInput"],
  ".  The presence of & indicates an anonymous pure function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Expand[\((a + b\ x)\)\^13] // 
      Coefficient[#, x, 3] &\)\)\)], "Input"],

Cell[BoxData[
    \(286\ a\^10\ b\^3\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Generalizing this procedure, we can write a function with extracts the \
coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^n\)]],
  " from the expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`\((a\  + \ b\ x)\)\^m\)]],
  " for arbitrary ",
  Cell[BoxData[
      \(TraditionalForm\`n, m\)]],
  ".  Notice that we still use delayed assignment to prevent premature \
evaluation of the part of the definition using ",
  StyleBox["Expand", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f[n_, m_] := \ 
      Expand[\((a + b\ x)\)\^m] // Coefficient[#, x, n] &\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3, 13]\)], "Input"],

Cell[BoxData[
    \(286\ a\^10\ b\^3\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Notice that the internal representation employs the standard form ",
  StyleBox["(body)&[arg]", "InlineInput"],
  ", although I prefer to define such functions using postfix form."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input"],

Cell["Global`f", "Print",
  CellTags->"Info3312795419-4618591"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(f[n_, m_] := \((Coefficient[#1, x, n] &)\)[
                      Expand[\((a + b\ x)\)\^m]]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3312795419-4618591"]
}, Closed]],

Cell["\<\
An important virtue of this style of coding is that it avoids creation of \
unwanted symbols for intermediate results.  Therefore, we often use anonymous \
pure functions to perform multistep transformations in a single cell without \
creating superfluous definitions for intermediate results.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: interpolating functions", "Subsection",
  CellTags->"interpolating functions"],

Cell[TextData[{
  "Many ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "functions, such as ",
  ButtonBox["Interpolation",
    ButtonStyle->"RefGuideLink"],
  " or ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  ", return results in the form of interpolating functions.  An ",
  ButtonBox["InterpolatingFunction",
    ButtonStyle->"RefGuideLink"],
  " is used to represent an approximate function whose values are obtained by \
interpolation within a table.  Thus, ",
  StyleBox["InterpolatingFunction[domain,table]", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "is a pure function such that ",
  StyleBox["InterpolatingFunction[domain,table][x]", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "computes the function at argument ",
  StyleBox["x", "InlineInput"],
  " defined within a specified ",
  StyleBox["domain", "InlineInput"],
  " using values contained in a ",
  StyleBox["table", "InlineInput"],
  ".  In standard output only the domain is printed, with the table indicated \
schematically by",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\` <> \)], "InlineInput"],
  ".  Note that if the argument is outside the domain, a warning message is \
issued and an extrapolated value is returned; however, extrapolation tends to \
go bad very quickly outside the domain of the interpolating function and \
should be avoided."
}], "Text"],

Cell[TextData[{
  "The motion of a pendulum is described by the differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta]'\)'\)[
          t]\  == \ \(-Sin[\[Theta][t]]\)\)]],
  ".  The following function evaluates that motion for a range of times \
assuming initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta][0] == \[Theta]0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]'\)[0] == \ \[Omega]0\)]],
  ".  Notice that both the differential equation and the initial conditions \
must be formulated as equations, using ",
  StyleBox["==", "InlineInput"],
  " instead of ",
  StyleBox["=", "InlineInput"],
  ".  It is also necessary to specify the time range.  We use delayed \
assignment and give arguments in the form of blank patterns."
}], "Text"],

Cell[BoxData[
    \(swing[\[Theta]0_, \[Omega]0_, tmin_, tmax_]\  := 
      NDSolve[{\(\(\[Theta]'\)'\)[
              t] \[Equal] \ \(-Sin[\[Theta][t]]\), \[Theta][
              0] \[Equal] \[Theta]0, \(\[Theta]'\)[
              0] \[Equal] \[Omega]0}, \ \[Theta], \ {t, tmin, 
          tmax}]\)], "Input"],

Cell["\<\
A particular evaluation for specific times and initial conditions\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(swing[\(3  \[Pi]\)\/4, 0, 0, 10]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"\[Theta]", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "returns a solution in the form of a replacement rule which replaces ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " by an interpolating function.  We can now produce an explicit function of \
",
  StyleBox["t", "InlineInput"],
  " by using this replacement rule."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(swing1[
        t]\  = \ \[Theta][
          t]\  /. \(swing[\(3  \[Pi]\)\/4, 0, 0, 
            10]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
        False,
        Editable->False], "[", "t", "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "A phase diagram of angular velocity versus angle can then be obtained \
using ",
  ButtonBox["ParametricPlot",
    ButtonStyle->"RefGuideLink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[{swing1[t], D[swing1[t], t]}], {t, 0, 10}, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.202102 0.392106 0.202102 [
[.0958 .37961 -6 -9 ]
[.0958 .37961 6 0 ]
[.2979 .37961 -6 -9 ]
[.2979 .37961 6 0 ]
[.7021 .37961 -3 -9 ]
[.7021 .37961 3 0 ]
[.9042 .37961 -3 -9 ]
[.9042 .37961 3 0 ]
[.4875 .08895 -24 -4.5 ]
[.4875 .08895 0 4.5 ]
[.4875 .19 -12 -4.5 ]
[.4875 .19 0 4.5 ]
[.4875 .29106 -24 -4.5 ]
[.4875 .29106 0 4.5 ]
[.4875 .49316 -18 -4.5 ]
[.4875 .49316 0 4.5 ]
[.4875 .59421 -6 -4.5 ]
[.4875 .59421 0 4.5 ]
[.4875 .69526 -18 -4.5 ]
[.4875 .69526 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .78421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0958 .39211 m
.0958 .39836 L
s
[(-2)] .0958 .37961 0 1 Mshowa
.2979 .39211 m
.2979 .39836 L
s
[(-1)] .2979 .37961 0 1 Mshowa
.7021 .39211 m
.7021 .39836 L
s
[(1)] .7021 .37961 0 1 Mshowa
.9042 .39211 m
.9042 .39836 L
s
[(2)] .9042 .37961 0 1 Mshowa
.125 Mabswid
.13622 .39211 m
.13622 .39586 L
s
.17664 .39211 m
.17664 .39586 L
s
.21706 .39211 m
.21706 .39586 L
s
.25748 .39211 m
.25748 .39586 L
s
.33832 .39211 m
.33832 .39586 L
s
.37874 .39211 m
.37874 .39586 L
s
.41916 .39211 m
.41916 .39586 L
s
.45958 .39211 m
.45958 .39586 L
s
.54042 .39211 m
.54042 .39586 L
s
.58084 .39211 m
.58084 .39586 L
s
.62126 .39211 m
.62126 .39586 L
s
.66168 .39211 m
.66168 .39586 L
s
.74252 .39211 m
.74252 .39586 L
s
.78294 .39211 m
.78294 .39586 L
s
.82336 .39211 m
.82336 .39586 L
s
.86378 .39211 m
.86378 .39586 L
s
.05538 .39211 m
.05538 .39586 L
s
.01496 .39211 m
.01496 .39586 L
s
.94462 .39211 m
.94462 .39586 L
s
.98504 .39211 m
.98504 .39586 L
s
.25 Mabswid
0 .39211 m
1 .39211 L
s
.5 .08895 m
.50625 .08895 L
s
[(-1.5)] .4875 .08895 1 0 Mshowa
.5 .19 m
.50625 .19 L
s
[(-1)] .4875 .19 1 0 Mshowa
.5 .29106 m
.50625 .29106 L
s
[(-0.5)] .4875 .29106 1 0 Mshowa
.5 .49316 m
.50625 .49316 L
s
[(0.5)] .4875 .49316 1 0 Mshowa
.5 .59421 m
.50625 .59421 L
s
[(1)] .4875 .59421 1 0 Mshowa
.5 .69526 m
.50625 .69526 L
s
[(1.5)] .4875 .69526 1 0 Mshowa
.125 Mabswid
.5 .10916 m
.50375 .10916 L
s
.5 .12937 m
.50375 .12937 L
s
.5 .14958 m
.50375 .14958 L
s
.5 .16979 m
.50375 .16979 L
s
.5 .21022 m
.50375 .21022 L
s
.5 .23043 m
.50375 .23043 L
s
.5 .25064 m
.50375 .25064 L
s
.5 .27085 m
.50375 .27085 L
s
.5 .31127 m
.50375 .31127 L
s
.5 .33148 m
.50375 .33148 L
s
.5 .35169 m
.50375 .35169 L
s
.5 .3719 m
.50375 .3719 L
s
.5 .41232 m
.50375 .41232 L
s
.5 .43253 m
.50375 .43253 L
s
.5 .45274 m
.50375 .45274 L
s
.5 .47295 m
.50375 .47295 L
s
.5 .51337 m
.50375 .51337 L
s
.5 .53358 m
.50375 .53358 L
s
.5 .55379 m
.50375 .55379 L
s
.5 .574 m
.50375 .574 L
s
.5 .61442 m
.50375 .61442 L
s
.5 .63463 m
.50375 .63463 L
s
.5 .65484 m
.50375 .65484 L
s
.5 .67505 m
.50375 .67505 L
s
.5 .06874 m
.50375 .06874 L
s
.5 .04853 m
.50375 .04853 L
s
.5 .02832 m
.50375 .02832 L
s
.5 .00811 m
.50375 .00811 L
s
.5 .71547 m
.50375 .71547 L
s
.5 .73568 m
.50375 .73568 L
s
.5 .75589 m
.50375 .75589 L
s
.5 .7761 m
.50375 .7761 L
s
.25 Mabswid
.5 0 m
.5 .78421 L
s
0 0 m
1 0 L
1 .78421 L
0 .78421 L
closepath
clip
newpath
.5 Mabswid
.97619 .39211 m
.97618 .39034 L
.97615 .38874 L
.9761 .38688 L
.97602 .38513 L
.97583 .38201 L
.97556 .37862 L
.97516 .37488 L
.97462 .37091 L
.9734 .36376 L
.96987 .34929 L
.96432 .33302 L
.95689 .31614 L
.94679 .29733 L
.9227 .26126 L
.84879 .17962 L
.79814 .13606 L
.74275 .09668 L
.68202 .06271 L
.64538 .04683 L
.61081 .03506 L
.5924 .03008 L
.5727 .02574 L
.55572 .02283 L
.54609 .02151 L
.53694 .0205 L
.53186 .02003 L
.52632 .0196 L
.52172 .0193 L
.51662 .01904 L
.51398 .01893 L
.51113 .01884 L
.50811 .01876 L
.50528 .01871 L
.50261 .01868 L
.49981 .01867 L
.49479 .01871 L
.49007 .0188 L
.48504 .01897 L
.48029 .01919 L
.47598 .01944 L
.46542 .02027 L
.45548 .02132 L
.43751 .02389 L
.41792 .02768 L
.37907 .03818 L
.34426 .05097 L
.31296 .06515 L
.24725 .10318 L
.19474 .14172 L
Mistroke
.10764 .22425 L
.07635 .26254 L
.05473 .29475 L
.03799 .32736 L
.03161 .34443 L
.02938 .35194 L
.02736 .3601 L
.02586 .36781 L
.02484 .37495 L
.02442 .37888 L
.02413 .38246 L
.02402 .38443 L
.02396 .38548 L
.02392 .38658 L
.02388 .38754 L
.02385 .38861 L
.02382 .39048 L
.02381 .39223 L
.02382 .39407 L
.02385 .39565 L
.02391 .39737 L
.02399 .39923 L
.0241 .40122 L
.02437 .4048 L
.02474 .40844 L
.02517 .41187 L
.0262 .41832 L
.02765 .42539 L
.02964 .43323 L
.03496 .44932 L
.04893 .47933 L
.0702 .51318 L
.10103 .55242 L
.13843 .5923 L
.18883 .63768 L
.24156 .6772 L
.27502 .69846 L
.30858 .71687 L
.34462 .73339 L
.37913 .74605 L
.41726 .75639 L
.43767 .76034 L
.44881 .76204 L
.45938 .76333 L
.46872 .76423 L
.47365 .76461 L
.47888 .76494 L
.48328 .76517 L
.48813 .76535 L
.49253 .76547 L
Mistroke
.49666 .76553 L
.50182 .76554 L
.50672 .76548 L
.51112 .76538 L
.51591 .7652 L
.5211 .76495 L
.52663 .76459 L
.53655 .76375 L
.54584 .76273 L
.55585 .76137 L
.57389 .75824 L
.6071 .75023 L
.64232 .73855 L
.67945 .72273 L
.74843 .68387 L
.85447 .5992 L
.92309 .52243 L
.94793 .48492 L
.95661 .46865 L
.96402 .45194 L
.96923 .43708 L
.9714 .42931 L
.97328 .42103 L
.97459 .4135 L
.97505 .41022 L
.97545 .40664 L
.97576 .40326 L
.97597 .40011 L
.97605 .39837 L
.97611 .39679 L
.97616 .39496 L
.97619 .39324 L
.97619 .39151 L
.97617 .38965 L
.97613 .38789 L
.97607 .38629 L
.97598 .38441 L
.97586 .38236 L
.97556 .37863 L
.97514 .37473 L
.97457 .37056 L
.97326 .36305 L
.97153 .35542 L
.96955 .34818 L
.96487 .33446 L
.96467 .33394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{325, 254.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007W0001OR000`400?l00000o`00003ol`3oool0
0`000000oooo0?ooo`3a0?ooo`00l`3oool00`000000oooo0?ooo`3a0?ooo`00l`3oool00`000000
oooo0?ooo`3a0?ooo`00l`3oool00`000000oooo0?ooo`3a0?ooo`00l`3oool300000?40oooo003c
0?ooo`030000003oool0oooo0?40oooo003c0?ooo`030000003oool0oooo0?40oooo003c0?ooo`03
0000003oool0oooo0?40oooo003c0?ooo`030000003oool0oooo0?40oooo003`0?ooo`P00000k`3o
ool00>00oooo400000030?ooo`030000003oool0oooo0080oooo3`00003P0?ooo`00f@3oool70000
01<0oooo00<000000?ooo`3oool04@3oool900000=L0oooo003B0?ooo`L000006P3oool00`000000
oooo0?ooo`0J0?ooo`@00000d`3oool00<h0oooo1000000Q0?ooo`030000003oool0oooo01h0oooo
1@00003>0?ooo`00bP3oool4000002D0oooo0`00000S0?ooo`D00000b@3oool00<H0oooo1000000Y
0?ooo`030000003oool0oooo02P0oooo1@0000340?ooo`00`P3oool4000002d0oooo00<000000?oo
o`3oool0;@3oool400000<00oooo002n0?ooo`@00000<@3oool00`000000oooo0?ooo`0a0?ooo`@0
0000_03oool00;X0oooo1000000e0?ooo`030000003oool0oooo03D0oooo0P00002j0?ooo`00]`3o
ool3000003T0oooo00<000000?ooo`3oool0=`3oool300000;L0oooo002d0?ooo`<00000?03oool0
0`000000oooo0?ooo`0j0?ooo`<00000]03oool00;40oooo0`00000o0?ooo`030000003oool0oooo
03d0oooo0P00002b0?ooo`00[`3oool200000480oooo00<000000?ooo`3oool0?`3oool300000:l0
oooo002/0?ooo`<00000A03oool00`000000oooo0?ooo`120?ooo`<00000[03oool00:T0oooo0`00
00170?ooo`<00000A@3oool200000:X0oooo002V0?ooo`<00000BP3oool00`000000oooo0?ooo`17
0?ooo`800000Z03oool00:@0oooo0P00001=0?ooo`030000003oool0oooo04T0oooo0P00002V0?oo
o`00XP3oool2000004l0oooo00<000000?ooo`3oool0B`3oool300000:<0oooo002P0?ooo`800000
D@3oool00`000000oooo0?ooo`1>0?ooo`800000X@3oool009h0oooo0P00001C0?ooo`030000003o
ool0oooo0500oooo0P00002O0?ooo`00W03oool2000005D0oooo00<000000?ooo`3oool0DP3oool2
000009d0oooo002J0?ooo`800000E`3oool00`000000oooo0?ooo`1D0?ooo`800000V`3oool009P0
oooo0P00001I0?ooo`030000003oool0oooo05H0oooo0P00002I0?ooo`00UP3oool2000005/0oooo
00<000000?ooo`3oool0F03oool2000009L0oooo002D0?ooo`800000G@3oool3000005X0oooo0P00
002E0?ooo`00T`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo0P00002C
0?ooo`00T@3oool200000600oooo00<000000?ooo`3oool0GP3oool200000940oooo002?0?ooo`80
0000HP3oool00`000000oooo0?ooo`1P0?ooo`800000S`3oool008h0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`1R0?ooo`800000S@3oool008`0oooo0P00001U0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0RP3oool008X0oooo0P0000170?ooo`030?noM0000000
000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`050?ooo`050;md00000000
00000000001d_ol0203oool00`000000oooo0?ooo`1U0?ooo`800000RP3oool008T0oooo00<00000
0?ooo`3oool0BP3oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00L0_g@0
001d_`3oool0oooo0?oOW0180000M;oo00L0oooo00<000000?ooo`3oool0I`3oool2000008P0oooo
00270?ooo`800000C@3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00H0oooo00<0
00000?ooo`3oool0J@3oool2000008H0oooo00250?ooo`800000C`3oool00`2LB4P0W=oo0?ooo`0A
0?ooo`030?noM000M;l0oooo00H0oooo00<000000?ooo`3oool0J`3oool2000008@0oooo00230?oo
o`800000A@3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cO
o`3oool04@3oool00`2LB000M;oo0?ooo`060?ooo`@00000K03oool200000880oooo00220?ooo`03
0000003oool0oooo0540oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M0000000000200000003
04RLg`3oool0oooo00H0oooo00<000000?ooo`3oool0K`3oool200000800oooo00200?ooo`800000
E03oool00`2LB4P0W=oo0?ooo`0<0?ooo`030?oo_`1d07@0_ooo00/0oooo00<000000?ooo`3oool0
L@3oool2000007h0oooo001n0?ooo`800000D`3oool01@3OW4P000000018W02LB4P0W=oo00d0oooo
00<0oono07@0M02oool02`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07/0oooo
001m0?ooo`030000003oool0oooo05D0oooo00<0gia80000B02Lgol03@3oool00`3ookl0M0000000
0002000000030000M02oool0oooo00H0oooo00<000000?ooo`3oool0M03oool2000007/0oooo001k
0?ooo`800000MP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07P0oooo001i0?oo
o`800000N03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo001h0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool0N03oool2000007L0oooo001f0?ooo`800000
N`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo07@0oooo001e0?ooo`030000003o
ool0oooo07/0oooo0`00001k0?ooo`800000M03oool007<0oooo0P00001n0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0L@3oool00780oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`1n0?ooo`800000L@3oool00740oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo06h0oooo001_0?ooo`800000PP3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo06d0oooo001^0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0PP3oool2000006d0oooo001/0?ooo`800000Q@3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo06X0oooo001[0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0Q@3oool2000006X0oooo001Y0?ooo`800000R03oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo06L0oooo001X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
R03oool2000006L0oooo001V0?ooo`800000R`3oool3000008X0oooo00<000000?ooo`3oool0I03o
ool006D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo06<0oooo001T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0S03oool20000
06<0oooo001R0?ooo`800000S`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0600
oooo001Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`1O0?ooo`00G`3oool200000980oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`1N0?ooo`00GP3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0G@3oool005d0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo05`0oooo001L0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`1K0?ooo`00F`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo09@0oooo0P00001K0?ooo`00FP3oool00`000000oooo0?ooo`2F0?ooo`<00000UP3o
ool00`000000oooo0?ooo`1H0?ooo`00F@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo09L0oooo00<000000?ooo`3oool0E`3oool005P0oooo00<000000?ooo`3oool0V03oool00`00
0000oooo0?ooo`2H0?ooo`030000003oool0oooo05H0oooo001G0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1E0?ooo`00EP3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0E03oool005D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo05<0oooo001C
0?ooo`800000WP3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0580oooo001B0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`1A0?oo
o`00D@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3o
ool0D03oool00500oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo04l0oooo001?0?ooo`030000003oool0oooo0:40oooo0`00002P0?ooo`800000C`3o
ool004h0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0
oooo04`0oooo001=0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0X`3oool00`00
0000oooo0?ooo`1;0?ooo`00C03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0BP3oool004/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo04T0oooo001:0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`2I
0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool01@3oool00`000000oooo0?ooo`2W
0?ooo`030000003oool0oooo04L0oooo00180?ooo`030000003oool0oooo09d0oooo00<0W4Q809cO
o`3oool0203oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo04H0oooo00170?ooo`03
0000003oool0oooo09h0oooo00<0W4Q809cOo`3oool0203oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo04D0oooo00160?ooo`030000003oool0oooo09l0oooo00<0W4Q809cOo`3oool0
203oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04@0oooo00150?ooo`030000003o
ool0oooo09@0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02L
gol0oooo00P0oooo1000002Z0?ooo`030000003oool0oooo04<0oooo00140?ooo`030000003oool0
oooo0:40oooo00<0W4Q809cOo`3oool0203oool00`000000oooo0?ooo`2/0?ooo`030000003oool0
oooo0480oooo00130?ooo`030000003oool0oooo0:80oooo00<0W4Q809cOo`3oool0203oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0480oooo00120?ooo`030000003oool0oooo0:00
oooo00D0gia800000000B9`0W4Q809cOo`090?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool0@@3oool00440oooo00<000000?ooo`3oool0X`3oool00`3OW4P0001809cOo`090?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00400oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo03l0oooo000n0?ooo`800000/`3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo03h0oooo000m0?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0m0?ooo`00?03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0?03oool003/0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo03/0
oooo000j0?ooo`030000003oool0oooo0;H0oooo0`00002d0?ooo`030000003oool0oooo03X0oooo
000i0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0i0?ooo`00>03oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0>03oool003L0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2g0?oo
o`030000003oool0oooo03L0oooo000f0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0f0?ooo`00=@3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo0;P0oooo00<000000?ooo`3oool0=P3oool003@0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo03D0oooo000c0?ooo`030000003oool0
oooo0;d0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0d0?ooo`00<P3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0<`3oool00380
oooo00<000000?ooo`3oool0_P3oool300000;`0oooo00<000000?ooo`3oool0<P3oool00340oooo
00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0340oooo
000`0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?oo
o`0`0?ooo`00;`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0;l0oooo00<00000
0?ooo`3oool0;`3oool002h0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo02h0oooo000^0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool0`@3oool00`000000oooo0?ooo`0]0?ooo`00;@3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0<80oooo00<000000?ooo`3oool0;03oool002`0oooo00<000000?ooo`3oool0a03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo02/0oooo000[0?ooo`030000003oool0
oooo0<D0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`350?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0:P3oool002X0
oooo00<000000?ooo`3oool0aP3oool300000<D0oooo00<000000?ooo`3oool0:@3oool002T0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo02P0oooo
000X0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`0W0?ooo`009`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo0<P0oooo00<00000
0?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3o
ool0bP3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0c03o
ool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo02<0oooo000T0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`00
0000oooo0?ooo`3=0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool08@3oool00280
oooo00<000000?ooo`3oool0cP3oool300000<d0oooo00<000000?ooo`3oool08@3oool00280oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0200oooo
000Q0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`0O0?ooo`00803oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool07`3oool001l0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo01h0oooo000O0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`2c0?ooo`050?no
M000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md0000000000000000
001d_ol0203oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo01d0oooo000M0?ooo`03
0000003oool0oooo0;@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00L0oooo00<000000?ooo`3oool0
dP3oool00`000000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?ooo`2c0?ooo`030?noM000
M;l0oooo0080oooo00<0gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`060?ooo`030000003o
ool0oooo0=<0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool0]03oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0okmd001d_`3oool01P3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo
0:`0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd
001d_`3oool03`3oool00`2LB000M;oo0?ooo`060?ooo`@00000d`3oool00`000000oooo0?ooo`0J
0?ooo`006`3oool00`000000oooo0?ooo`2e0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool02P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00H0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`2f0?ooo`03
0?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01d0;ooo`0;0?ooo`03
0000003oool0oooo0=D0oooo00<000000?ooo`3oool06@3oool001T0oooo00<000000?ooo`3oool0
^03oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0M02oool02`3oool00`00
0000oooo0?ooo`3F0?ooo`030000003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo0;P0
oooo00D0oono07@000000000001809cOo`0<0?ooo`030?oo_`1d000000000080000000<0001d0;oo
o`3oool01P3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo01L0oooo000H0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0G0?ooo`00
603oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0
5P3oool001L0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo01H0oooo000G0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0fP3oool300000=X0
oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0f`3oool00`000000oooo
0?ooo`3J0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0=/0oooo00<0
00000?ooo`3oool0f`3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`3L
0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?oo
o`3oool0g03oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0B0?ooo`00
4`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0
4P3oool00180oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`3M0?ooo`030000003o
ool0oooo0140oooo000B0?ooo`030000003oool0oooo0=h0oooo00<000000?ooo`3oool0g@3oool0
0`000000oooo0?ooo`0A0?ooo`004@3oool00`000000oooo0?ooo`3O0?ooo`<00000gP3oool00`00
0000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0=h0
oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool0g`3oool00`000000oooo
0?ooo`3N0?ooo`8000004@3oool00100oooo00<000000?ooo`3oool0h03oool00`000000oooo0?oo
o`3O0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo0>00oooo00<00000
0?ooo`3oool0g`3oool200000100oooo000@0?ooo`030000003oool0oooo0>00oooo00<000000?oo
o`3oool0g`3oool200000100oooo000?0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3o
ool0h03oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`3Q0?ooo`030000
003oool0oooo0>00oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0h@3o
ool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0
oooo0>80oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`00
0000oooo0?ooo`3R0?ooo`<00000h@3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000
oooo0?ooo`3R0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool07P3oool00`3ookl0M000000000040000000307Boo`3oool0oooo05X0oooo
00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`1H0?ooo`030000003oool0oooo05/0oooo
00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`1I0?ooo`030?oo_`1d0000000000@00000
00<0M;oo0?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`0O0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0GP3oool00`2LB4P0W=oo0?oo
o`1K0?ooo`030000003oool0oooo05h0oooo00<0W4Q809cOo`3oool0G@3oool00`2oM000001d0;oo
o`020?ooo`030=nLM02Lgol0oooo01`0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0803oool00`3o_g@0001809cOo`1R0?ooo`0309a8B02Lgol0oooo05/0oooo00<00000
0?ooo`3oool0GP3oool00`2LB4P0W=oo0?ooo`1N0?ooo`030?noM00004P0W=oo0200oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool08@3oool00`3ogi`0B00004RLg`1Q0?oo
o`0309a8B02Lgol0oooo05/0oooo00<000000?ooo`3oool0GP3oool00`2LB4P0W=oo0?ooo`1O0?oo
o`030?oOW0180000B9cO0200oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3o
ool05`3oool00`2LB000000000000003000000030018W03oool0oooo00@0oooo00<0W4P004RLg`3o
ool0D`3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cOo`3o
ool0F`3oool00`000000oooo0?ooo`1N0?ooo`0309a8B02Lgol0oooo0640oooo00<0W4P004RLg`3o
ool07P3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0U0?ooo`0309a8
M02oool0oooo05h0oooo00<0W4Q809cOo`3oool0F`3oool00`000000oooo0?ooo`1N0?ooo`0309a8
B02Lgol0oooo0680oooo00<0W4Qd0;ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`00303o
ool00`000000oooo0?ooo`0P0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool0GP3o
ool00`2LB4P0W=oo0?ooo`1K0?ooo`030000003oool0oooo05h0oooo00<0W4Q809cOo`3oool0G@3o
ool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo01d0oooo00<000000?ooo`3oool02`3o
ool000`0oooo00<000000?ooo`3oool0803oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0
G03oool01@3OW4P000000018W02LB4P0W=oo05`0oooo00<000000?ooo`3oool0F`3oool01@3OW4P0
00000018W02LB4P0W=oo05h0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo01h0oooo00<0
00000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool08@3oool01@3o_g@0000000000000
04P0W=oo05l0oooo00<0gia80000B02Lgol0G03oool3000005d0oooo00<0gia80000B02Lgol0G`3o
ool01@3o_g@000000000000004P0W=oo01l0oooo00<000000?ooo`3oool02`3oool000`0oooo00<0
00000?ooo`3oool0i03oool00`000000oooo0?ooo`3S0?ooo`800000303oool000`0oooo00<00000
0?ooo`3oool0i03oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0:0?oo
o`00303oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3o
ool02P3oool000/0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`3T0?ooo`030000
003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0i03o
ool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`3U0?ooo`030000003oool0
oooo0>@0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0i@3oool00`00
0000oooo0?ooo`3T0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0>D0
oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0:0?ooo`00o`00003X000000001`3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000203oool000L0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool01@000000
oooo0?ooo`3oool0000000P0oooo000;0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000
003oool0oooo0>D0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0:0?ooo`002`3o
ool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool02P3o
ool000`0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`3T0?ooo`030000003oool0
oooo00X0oooo000<0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0i03oool00`00
0000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0>@0
oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0i03oool00`000000oooo
0?ooo`3T0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0>@0oooo0`00
003S0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo0>@0oooo00<00000
0?ooo`3oool0h`3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`3T0?oo
o`030000003oool0oooo0><0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3o
ool0i03oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000
003oool0oooo0>@0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`0;0?ooo`003@3o
ool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool02`3o
ool000d0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0hP3oool00`00
0000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0>80
oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0hP3oool00`000000oooo
0?ooo`3R0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo0>80oooo0`00
003Q0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo0>80oooo00<00000
0?ooo`3oool0h@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`3Q0?oo
o`030000003oool0oooo0>40oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3o
ool0h@3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000
003oool0oooo0>40oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0>0?ooo`00403o
ool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool03P3o
ool00100oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`3O0?ooo`030000003oool0
oooo00l0oooo000A0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0g`3oool00`00
0000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0=h0
oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool0g`3oool300000=h0oooo
00<000000?ooo`3oool0403oool00180oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?oo
o`3N0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0oooo0=h0oooo00<00000
0?ooo`3oool0g@3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo0=d0oooo00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`3o
ool0g@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0180oooo000D0?ooo`030000
003oool0oooo0=`0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0B0?ooo`00503o
ool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool04P3o
ool001D0oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`3K0?ooo`030000003oool0
oooo01<0oooo000E0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0f`3oool00`00
0000oooo0?ooo`0C0?ooo`005P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo0=X0
oooo00<000000?ooo`3oool0503oool001H0oooo00<000000?ooo`3oool0fP3oool300000=X0oooo
00<000000?ooo`3oool0503oool001L0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?oo
o`3I0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`3oool05P3oool001T0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000
003oool0oooo0=L0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0G0?ooo`006P3o
ool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool0603o
ool001X0oooo00<000000?ooo`3oool0]`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0
_g@000000000M;l01@3oool01@2oM0000000000000000000M;oo00P0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000oooo0?ooo`2f0?ooo`0609a8M02o
ool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?oo
o`3ogi`0B00007Boo`070?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool06@3oool0
01`0oooo00<000000?ooo`3oool0]03oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo
00l0oooo00<0okmd001d_`3oool01P3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo
01X0oooo000L0?ooo`030000003oool0oooo0;@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`0?0?ooo`030?noM000M;l0oooo00H0oooo1000003B0?ooo`030000003oool0oooo01/0
oooo000M0?ooo`030000003oool0oooo0;<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0?0?ooo`0309a8001d_ol0oooo00H0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`0K0?ooo`007@3oool00`000000oooo0?ooo`2c0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool02P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00H0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`0L0?ooo`007P3oool00`000000oooo0?ooo`2b
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01d0;ooo`0;
0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool07@3oool001h0oooo00<000000?oo
o`3oool0/`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0M02oool02`3o
ool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo01d0oooo000O0?ooo`030000003oool0
oooo0;80oooo00D0oono07@000000000001809cOo`0<0?ooo`030?oo_`1d000000000080000000<0
001d0;ooo`3oool01P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo01h0oooo000P
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0O
0?ooo`00803oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool07`3oool00240oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`3>0?ooo`03
0000003oool0oooo0200oooo000Q0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
c@3oool00`000000oooo0?ooo`0Q0?ooo`008P3oool00`000000oooo0?ooo`3>0?ooo`<00000c@3o
ool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool08P3oool002@0oooo00<000000?ooo`3oool0c03oool00`00
0000oooo0?ooo`3;0?ooo`030000003oool0oooo02<0oooo000T0?ooo`030000003oool0oooo0<`0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0S0?ooo`009@3oool00`000000oooo
0?ooo`3;0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0903oool002H0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo02D0oooo000W
0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0V
0?ooo`00:03oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool09`3oool002P0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0
aP3oool00`000000oooo0?ooo`0X0?ooo`00:P3oool00`000000oooo0?ooo`360?ooo`<00000a@3o
ool00`000000oooo0?ooo`0Y0?ooo`00:`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`330?ooo`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo
0?ooo`330?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0;@3oool002h0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo02h0oooo000_
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0^
0?ooo`00;`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0;l0oooo00<000000?oo
o`3oool0;`3oool00300oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo0300oooo000a0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0
_@3oool00`000000oooo0?ooo`0a0?ooo`00<P3oool00`000000oooo0?ooo`2n0?ooo`<00000_03o
ool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool0<`3oool003@0oooo00<000000?ooo`3oool0_03oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo0;/0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0=@3oool003L0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo03H0oooo000h
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0g
0?ooo`00>@3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0;H0oooo00<000000?oo
o`3oool0>03oool003X0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo0;H0oooo0`00002d0?ooo`030000
003oool0oooo03X0oooo000k0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0k0?ooo`00?03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0/`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo0;80
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0m0?ooo`00?`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0?P3oool00400oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo03l0oooo0011
0?ooo`030000003oool0oooo0:40oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`05
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0@03oool00480oooo00<000000?oo
o`3oool0X`3oool00`2LB4P0W=oo0?ooo`080?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool0@@3oool004<0oooo00<000000?ooo`3oool0XP3oool00`2LB4P0W=oo0?ooo`080?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool0@P3oool004@0oooo00<000000?ooo`3oool0
X@3oool00`2LB4P0W=oo0?ooo`080?ooo`@00000Z`3oool00`000000oooo0?ooo`120?ooo`00A@3o
ool00`000000oooo0?ooo`2P0?ooo`0309a8B02Lgol0oooo00P0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`130?ooo`00AP3oool00`000000oooo0?ooo`2O0?ooo`0309a8B02Lgol0
oooo00P0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`140?ooo`00A`3oool20000
09l0oooo00<0W4Q809cOo`3oool0203oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
04D0oooo00190?ooo`030000003oool0oooo09T0oooo00D0gia800000000B9`0W4Q809cOo`090?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3o
ool0VP3oool00`3OW4P0001809cOo`090?ooo`030000003oool0oooo0:H0oooo0P0000190?ooo`00
B`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
B@3oool004`0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo04X0oooo001=0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`1;0?ooo`00CP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
0:40oooo0P00001>0?ooo`00C`3oool200000:80oooo0`00002P0?ooo`030000003oool0oooo04h0
oooo001A0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`1?0?ooo`00DP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo09d0oooo0P00
001B0?ooo`00D`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo09`0oooo00<00000
0?ooo`3oool0DP3oool005@0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo05<0oooo001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3o
ool0VP3oool00`000000oooo0?ooo`1D0?ooo`00EP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo09P0oooo0P00001G0?ooo`00E`3oool2000009X0oooo00<000000?ooo`3oool0U`3o
ool00`000000oooo0?ooo`1G0?ooo`00F@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0F03oool005X0oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo05T0oooo001K0?ooo`030000003oool0oooo09D0
oooo0`00002C0?ooo`800000G03oool005`0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo05`0oooo001M0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`1M0?ooo`00GP3oool2000009<0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`1N0?ooo`00H03oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo08h0oooo0P00001Q0?ooo`00H@3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0H@3oool00680oooo0P00002?0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`2:0?ooo`800000I@3oool006D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo06D0oooo001V0?ooo`800000R`3oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo06H0oooo001X0?ooo`030000003oool0oooo08P0
oooo0`0000270?ooo`030000003oool0oooo06L0oooo001Y0?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0Q@3oool2000006X0oooo001Z0?ooo`800000Q`3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo06X0oooo001/0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`1[0?ooo`00K@3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo0880oooo00<000000?ooo`3oool0K03oool006h0oooo0P0000230?ooo`03
0000003oool0oooo0800oooo0P00001_0?ooo`00L03oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0K`3oool00740oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0700oooo001b0?ooo`800000O`3oool0
0`000000oooo0?ooo`1l0?ooo`800000L`3oool007@0oooo00<000000?ooo`3oool0O03oool30000
07/0oooo00<000000?ooo`3oool0L`3oool007D0oooo00<000000?ooo`3oool0N`3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo07@0oooo001f0?ooo`800000N`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo07D0oooo001h0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0M`3oool2000007P0oooo001i0?ooo`800000N03oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo07P0oooo001k0?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`1i0?ooo`00O03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo07<0oooo0P00001l0?ooo`00O@3oool2000005@0oooo00<0okmd000000000000
0`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000
000007Boo`080?ooo`030000003oool0oooo0740oooo0P00001n0?ooo`00O`3oool00`000000oooo
0?ooo`1D0?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo
0?ooo`3oool0omnL04P0001d_ol01`3oool00`000000oooo0?ooo`1_0?ooo`800000P03oool00800
oooo0P00001D0?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool01P3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo0800oooo00220?ooo`030000003oool0oooo0540oooo
00<0W4Q809cOo`3oool04@3oool00`3o_g@007Bo0?ooo`060?ooo`@00000J`3oool2000008<0oooo
00230?ooo`800000D@3oool00`2LB4P0W=oo0?ooo`0A0?ooo`0309a8001d_ol0oooo00H0oooo00<0
00000?ooo`3oool0JP3oool2000008D0oooo00250?ooo`030000003oool0oooo04h0oooo00<0W4Q8
09cOo`3oool0303oool00`3ookl0M000000000020000000304RLg`3oool0oooo00H0oooo00<00000
0?ooo`3oool0J03oool2000008L0oooo00260?ooo`800000CP3oool00`2LB4P0W=oo0?ooo`0<0?oo
o`030?oo_`1d07@0_ooo00/0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`270?oo
o`00R03oool2000004T0oooo00D0gia800000000B9`0W4Q809cOo`0=0?ooo`030?oo_`1d07@0_ooo
00/0oooo00<000000?ooo`3oool0I@3oool2000008X0oooo002:0?ooo`800000B@3oool00`3OW4P0
001809cOo`0=0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01P3oool00`000000
oooo0?ooo`1S0?ooo`800000S03oool008`0oooo0P00001U0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0S03oool008h0oooo0P00001S0?ooo`030000003oool0oooo0600oooo0P00
002?0?ooo`00T03oool200000640oooo00<000000?ooo`3oool0GP3oool200000940oooo002B0?oo
o`800000G`3oool00`000000oooo0?ooo`1L0?ooo`800000T`3oool009@0oooo0P00001M0?ooo`<0
0000F`3oool00`000000oooo0?ooo`2C0?ooo`00UP3oool2000005/0oooo00<000000?ooo`3oool0
F@3oool2000009H0oooo002H0?ooo`800000F@3oool00`000000oooo0?ooo`1G0?ooo`800000V03o
ool009X0oooo0P00001G0?ooo`030000003oool0oooo05D0oooo0P00002J0?ooo`00W03oool20000
05D0oooo00<000000?ooo`3oool0D`3oool2000009`0oooo002N0?ooo`800000D`3oool00`000000
oooo0?ooo`1A0?ooo`800000WP3oool00:00oooo0P00001A0?ooo`030000003oool0oooo04h0oooo
0`00002P0?ooo`00XP3oool2000004l0oooo00<000000?ooo`3oool0C03oool200000:<0oooo002T
0?ooo`800000C@3oool00`000000oooo0?ooo`190?ooo`<00000Y@3oool00:H0oooo0`00001:0?oo
o`030000003oool0oooo04H0oooo0`00002X0?ooo`00Z@3oool3000004L0oooo0`0000140?ooo`80
0000Z`3oool00:`0oooo0`0000140?ooo`030000003oool0oooo0440oooo0`00002]0?ooo`00[`3o
ool200000480oooo00<000000?ooo`3oool0?P3oool300000;00oooo002a0?ooo`<00000?`3oool0
0`000000oooo0?ooo`0k0?ooo`<00000/`3oool00;@0oooo0`00000l0?ooo`030000003oool0oooo
03T0oooo0P00002f0?ooo`00]`3oool3000003T0oooo00<000000?ooo`3oool0=P3oool300000;P0
oooo002j0?ooo`@00000=@3oool00`000000oooo0?ooo`0c0?ooo`<00000^`3oool00;h0oooo1000
000a0?ooo`030000003oool0oooo0300oooo0`00002n0?ooo`00`P3oool4000002d0oooo00<00000
0?ooo`3oool0;03oool400000<40oooo00360?ooo`@00000:@3oool00`000000oooo0?ooo`0X0?oo
o`@00000a@3oool00<X0oooo1000000U0?ooo`<00000903oool400000<T0oooo003>0?ooo`@00000
8@3oool00`000000oooo0?ooo`0M0?ooo`L00000c@3oool00=80oooo1@00000L0?ooo`030000003o
ool0oooo01H0oooo1`00003D0?ooo`00e`3oool;00000140oooo00<000000?ooo`3oool04P3oool4
00000=/0oooo003R0?ooobH00000g`3oool00?<0oooo00<000000?ooo`3oool0l@3oool00?<0oooo
00<000000?ooo`3oool0l@3oool00?<0oooo00<000000?ooo`3oool0l@3oool00?<0oooo00<00000
0?ooo`3oool0l@3oool00?<0oooo00<000000?ooo`3oool0l@3oool00?<0oooo0`00003a0?ooo`00
l`3oool00`000000oooo0?ooo`3a0?ooo`00l`3oool00`000000oooo0?ooo`3a0?ooo`00l`3oool0
0`000000oooo0?ooo`3a0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 486.5}, {381.125, 0}} -> {-2.47658, -1.94016, \
0.0152718, 0.0152718}}]
}, Closed]],

Cell["\<\
Notice that the phase trajectory is flattened, like an American football, \
whereas the phase trajectory for simple harmonic motion would be circular.  \
The pendulum approaches the simple harmonic oscillator as the amplitude of \
the swing approaches zero.\
\>", "Text"],

Cell[TextData[{
  "Produce a figure that displays phase trajectories for initial angles of ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Theta]\_0, \[Pi]\/10, 
        9  \[Pi]\/10, \[Pi]\/10}\)]],
  ", where we use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " iterator notation.  [Hint: Table can be used to form a list of pairs of \
functions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({{\[Theta]\_1[t], \ \[Theta]\_1\%\[Prime][
            t]}, {\[Theta]\_2[t], \ \[Theta]\_2\%\[Prime][
              t]} \[CenterEllipsis]}\)\(\ \)\)\)]],
  ", where each pair represents the phase trajectory for a different initial \
condition, and ParametricPlot can plot this entire family of trajectories \
simultaneously.]"
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Recursive functions", "Section",
  CellTags->"recursive functions"],

Cell[TextData[{
  "A function is described as recursive if it is defined in terms of itself.  \
Perhaps the simplest example is the factorial function defined by the \
recursion relation ",
  Cell[BoxData[
      \(TraditionalForm\`factorial[n]\  = \ n\ factorial[n - 1]\)]],
  " with initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`factorial[0] = 1\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(factorial[0] = \ 1;\)\), "\n", 
    \(factorial[n_] := \ n\ factorial[n - 1]\)}], "Input"],

Cell["\<\
Unfortunately, this function as written behaves poorly if given an argument \
which is not a nonnegative integer.  We will learn how to restrict such \
functions shortly, but at the present time we prefer to focus on the \
operation of valid recursive functions without worrying about such \
problems.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Table[factorial[n], {n, 0, 10}]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({1, 1, 2, 6, 24, 120, 720, 5040, 40320, 362880, 3628800}\)], "Output"]
}, Closed]],

Cell["\<\
The simple function given above is somewhat inefficient because each time it \
is evaluated it must assemble an entire sequence of values.  This can be a \
serious inefficiency for functions based upon a complicated recursion \
relation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Trace[factorial[10]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(factorial[10]\),
          HoldForm], ",", 
        TagBox[\(10\ factorial[10 - 1]\),
          HoldForm], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                TagBox[\(10 - 1\),
                  HoldForm], ",", 
                TagBox["9",
                  HoldForm]}], "}"}], ",", 
            TagBox[\(factorial[9]\),
              HoldForm], ",", 
            TagBox[\(9\ factorial[9 - 1]\),
              HoldForm], ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    TagBox[\(9 - 1\),
                      HoldForm], ",", 
                    TagBox["8",
                      HoldForm]}], "}"}], ",", 
                TagBox[\(factorial[8]\),
                  HoldForm], ",", 
                TagBox[\(8\ factorial[8 - 1]\),
                  HoldForm], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        TagBox[\(8 - 1\),
                          HoldForm], ",", 
                        TagBox["7",
                          HoldForm]}], "}"}], ",", 
                    TagBox[\(factorial[7]\),
                      HoldForm], ",", 
                    TagBox[\(7\ factorial[7 - 1]\),
                      HoldForm], ",", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{
                            TagBox[\(7 - 1\),
                              HoldForm], ",", 
                            TagBox["6",
                              HoldForm]}], "}"}], ",", 
                        TagBox[\(factorial[6]\),
                          HoldForm], ",", 
                        TagBox[\(6\ factorial[6 - 1]\),
                          HoldForm], ",", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"{", 
                              RowBox[{
                                TagBox[\(6 - 1\),
                                  HoldForm], ",", 
                                TagBox["5",
                                  HoldForm]}], "}"}], ",", 
                            TagBox[\(factorial[5]\),
                              HoldForm], ",", 
                            TagBox[\(5\ factorial[5 - 1]\),
                              HoldForm], ",", 
                            RowBox[{"{", 
                              RowBox[{
                                RowBox[{"{", 
                                  RowBox[{
                                    TagBox[\(5 - 1\),
                                      HoldForm], ",", 
                                    TagBox["4",
                                      HoldForm]}], "}"}], ",", 
                                TagBox[\(factorial[4]\),
                                  HoldForm], ",", 
                                TagBox[\(4\ factorial[4 - 1]\),
                                  HoldForm], ",", 
                                RowBox[{"{", 
                                  RowBox[{
                                    RowBox[{"{", 
                                      RowBox[{
                                        TagBox[\(4 - 1\),
                                        HoldForm], ",", 
                                        TagBox["3",
                                        HoldForm]}], "}"}], ",", 
                                    TagBox[\(factorial[3]\),
                                      HoldForm], ",", 
                                    TagBox[\(3\ factorial[3 - 1]\),
                                      HoldForm], ",", 
                                    RowBox[{"{", 
                                      RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{
                                        TagBox[\(3 - 1\),
                                        HoldForm], ",", 
                                        TagBox["2",
                                        HoldForm]}], "}"}], ",", 
                                        TagBox[\(factorial[2]\),
                                        HoldForm], ",", 
                                        TagBox[\(2\ factorial[2 - 1]\),
                                        HoldForm], ",", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{
                                        TagBox[\(2 - 1\),
                                        HoldForm], ",", 
                                        TagBox["1",
                                        HoldForm]}], "}"}], ",", 
                                        TagBox[\(factorial[1]\),
                                        HoldForm], ",", 
                                        TagBox[\(1\ factorial[1 - 1]\),
                                        HoldForm], ",", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"{", 
                                        RowBox[{
                                        TagBox[\(1 - 1\),
                                        HoldForm], ",", 
                                        TagBox["0",
                                        HoldForm]}], "}"}], ",", 
                                        TagBox[\(factorial[0]\),
                                        HoldForm], ",", 
                                        TagBox["1",
                                        HoldForm]}], "}"}], ",", 
                                        TagBox[\(1\ 1\),
                                        HoldForm], ",", 
                                        TagBox["1",
                                        HoldForm]}], "}"}], ",", 
                                        TagBox[\(2\ 1\),
                                        HoldForm], ",", 
                                        TagBox["2",
                                        HoldForm]}], "}"}], ",", 
                                    TagBox[\(3\ 2\),
                                      HoldForm], ",", 
                                    TagBox["6",
                                      HoldForm]}], "}"}], ",", 
                                TagBox[\(4\ 6\),
                                  HoldForm], ",", 
                                TagBox["24",
                                  HoldForm]}], "}"}], ",", 
                            TagBox[\(5\ 24\),
                              HoldForm], ",", 
                            TagBox["120",
                              HoldForm]}], "}"}], ",", 
                        TagBox[\(6\ 120\),
                          HoldForm], ",", 
                        TagBox["720",
                          HoldForm]}], "}"}], ",", 
                    TagBox[\(7\ 720\),
                      HoldForm], ",", 
                    TagBox["5040",
                      HoldForm]}], "}"}], ",", 
                TagBox[\(8\ 5040\),
                  HoldForm], ",", 
                TagBox["40320",
                  HoldForm]}], "}"}], ",", 
            TagBox[\(9\ 40320\),
              HoldForm], ",", 
            TagBox["362880",
              HoldForm]}], "}"}], ",", 
        TagBox[\(10\ 362880\),
          HoldForm], ",", 
        TagBox["3628800",
          HoldForm]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "A more efficient technique, called ",
  StyleBox["dynamic programming",
    FontSlant->"Italic"],
  ", is to use a definition which remembers its values."
}], "Text"],

Cell[BoxData[{
    \(\(factorial2[0] = \ 1;\)\), "\n", 
    \(factorial2[n_] := \(factorial2[n] = n\ factorial2[n - 1]\)\)}], "Input"],

Cell["\<\
The first call for a dynamic recursion relation may actually slow the \
evaluation because rules must be established for the values it will remember \
later, but subsequent evaluations will be simpler and faster.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial[100] // Timing\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, 
      933262154439441526816992388562667004907159682643816214685929638952175999\
932299156089414639761565182862536979208272237582511852109168640000000000000000\
00000000}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial2[100] // Timing\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, 
      933262154439441526816992388562667004907159682643816214685929638952175999\
932299156089414639761565182862536979208272237582511852109168640000000000000000\
00000000}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial2[100] // Timing\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, 
      933262154439441526816992388562667004907159682643816214685929638952175999\
932299156089414639761565182862536979208272237582511852109168640000000000000000\
00000000}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Trace[factorial2[10]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(factorial2[10]\),
          HoldForm], ",", 
        TagBox["3628800",
          HoldForm]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "However, dynamic programing costs memory to store the rules.  Compare the \
rules associated with ",
  StyleBox["factorial", "InlineInput"],
  " versus ",
  StyleBox["factorial2", "InlineInput"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?factorial\)\)], "Input"],

Cell["Global`factorial", "Print",
  CellTags->"Info3312795474-4594259"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(factorial[0] = 1\)},
                {" "},
                {\(factorial[n_] := n\ factorial[n - 1]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "factorial"],
      Editable->False]], "Print",
  CellTags->"Info3312795474-4594259"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?factorial2\)\)], "Input"],

Cell["Global`factorial2", "Print",
  CellTags->"Info3312795480-9399269"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(factorial2[0] = 1\)},
                {" "},
                {\(factorial2[1] = 1\)},
                {" "},
                {\(factorial2[2] = 2\)},
                {" "},
                {\(factorial2[3] = 6\)},
                {" "},
                {\(factorial2[4] = 24\)},
                {" "},
                {\(factorial2[5] = 120\)},
                {" "},
                {\(factorial2[6] = 720\)},
                {" "},
                {\(factorial2[7] = 5040\)},
                {" "},
                {\(factorial2[8] = 40320\)},
                {" "},
                {\(factorial2[9] = 362880\)},
                {" "},
                {\(factorial2[10] = 3628800\)},
                {" "},
                {\(factorial2[11] = 39916800\)},
                {" "},
                {\(factorial2[12] = 479001600\)},
                {" "},
                {\(factorial2[13] = 6227020800\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[14] = 87178291200\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[15] = 1307674368000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[16] = 20922789888000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[17] = 355687428096000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[18] = 6402373705728000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[19] = 121645100408832000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[20] = 2432902008176640000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[21] = 51090942171709440000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[22] = 1124000727777607680000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[23] = 25852016738884976640000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[24] = 620448401733239439360000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[25] = 15511210043330985984000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[26] = 403291461126605635584000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[27] = 10888869450418352160768000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[28] = 304888344611713860501504000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[29] = 8841761993739701954543616000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[30] = 265252859812191058636308480000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[31] = 8222838654177922817725562880000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[32] = 263130836933693530167218012160000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[33] = 8683317618811886495518194401280000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[34] = 
                    295232799039604140847618609643520000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[35] = 
                    10333147966386144929666651337523200000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[36] = 
                    371993326789901217467999448150835200000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[37] = 
                    13763753091226345046315979581580902400000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[38] = 
                    523022617466601111760007224100074291200000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[39] = 
                    20397882081197443358640281739902897356800000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[40] = 
                    815915283247897734345611269596115894272000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[41] = 
                    33452526613163807108170062053440751665152000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[42] = 
                    1405006117752879898543142606244511569936384000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[43] = 
                    60415263063373835637355132068513997507264512000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[44] = 
                    2658271574788448768043625811014615890319638528000000000\)}\
,
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[45] = 
                    119622220865480194561963161495657715064383733760000000000\
\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[46] = 
                    5502622159812088949850305428800254892961651752960000000000\
\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[47] = 
                    2586232415111681806429643551536119799691976323891200000000\
00\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[48] = 
                    1241391559253607267086228904737337503852148635467776000000\
0000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[49] = 
                    6082818640342675608722521633212953768875528313792102400000\
00000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[50] = 
                    3041409320171337804361260816606476884437764156896051200000\
0000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[51] = 
                    1551118753287382280224243016469303211063259720016986112000\
000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[52] = 
                    8065817517094387857166063685640376697528950544088327782400\
0000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[53] = 
                    4274883284060025564298013753389399649690343788366813724672\
000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[54] = 
                    2308436973392413804720927426830275810832785645718079411322\
88000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[55] = 
                    1269640335365827592596510084756651695958032105144943676227\
5840000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[56] = 
                    7109985878048634518540456474637249497364979788811684586874\
47040000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[57] = 
                    4052691950487721675568060190543232213498038479622660214518\
4481280000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[58] = 
                    2350561331282878571829474910515074683828862318181142924420\
699914240000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[59] = 
                    1386831185456898357379390197203894063459028767726874325408\
21294940160000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[60] = 
                    8320987112741390144276341183223364380754172606361245952449\
277696409600000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[61] = 
                    5075802138772247988008568121766252272260045289880360030994\
05939480985600000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[62] = 
                    3146997326038793752565312235495076408801228079725823219216\
3168247821107200000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[63] = 
                    1982608315404440064116146708361898137544773690227268628106\
279599612729753600000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[64] = 
                    1268869321858841641034333893351614808028655161745451921988\
01894375214704230400000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[65] = 
                    8247650592082470666723170306785496252186258551345437492922\
123134388955774976000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[66] = 
                    5443449390774430640037292402478427526442930643887988745328\
60126869671081148416000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[67] = 
                    3647111091818868528824985909660546442716763531404952459370\
1628500267962436943872000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[68] = 
                    2480035542436830599600990418569171581047399201355367672371\
710738018221445712183296000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[69] = 
                    1711224524281413113724683388812728390922705448935203693936\
48040923257279754140647424000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[70] = 
                    1197857166996989179607278372168909873645893814254642585755\
5362864628009582789845319680000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[71] = 
                    8504785885678623175211676442399260102885846081207962358864\
30763388588680378079017697280000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[72] = 
                    6123445837688608686152407038527467274077809178469732898382\
3014963978384987221689274204160000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[73] = 
                    4470115461512684340891257138125051110076800700282905015819\
080092370422104067183317016903680000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[74] = 
                    3307885441519386412259530282212537821456832518209349711706\
11926835411235700971565459250872320000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[75] = 
                    2480914081139539809194647711659403366092624388657012283779\
5894512655842677572867409443815424000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[76] = 
                    1885494701666050254987932260861146558230394535379329335672\
487982961844043495537923117729972224000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[77] = 
                    1451830920282858696340707840863082849837403792242083588467\
81574688061991349156420080065207861248000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[78] = 
                    1132428117820629783145752115873204622873174957948825199004\
8962825668835325234200766245086213177344000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[79] = 
                    8946182130782975286851441715398316520698082167795719072138\
68063227837990693501860533361810841010176000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[80] = 
                    7156945704626380229481153372318653216558465734236575257710\
9445058227039255480148842668944867280814080000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[81] = 
                    5797126020747367985879734231578109105412357244731625958745\
865049716390179693892056256184534249745940480000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[82] = 
                    4753643337012841748421382069894049466438132940679933286171\
60934076743994734899148613007131808479167119360000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[83] = 
                    3945523969720658651189747118012061057143650340764344627522\
4357528369751562996629334879591940103770870906880000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[84] = 
                    3314240134565353266999387579130131288000666286242049487118\
846032383059131291716864129885722968716753156177920000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[85] = 
                    2817104114380550276949479442260611594800566343305742064051\
01912752560026159795933451040286452340924018275123200000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[86] = 
                    2422709538367273238176552320344125971528487055242938175083\
8764496720162249742450276789464634901319465571660595200000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[87] = 
                    2107757298379527717213600518699389595229783738061356212322\
972511214654115727593174080683423236414793504734471782400000000000000000000\)}\
,
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[88] = 
                    1854826422573984391147968456455462843802209689493993466844\
21580986889562184028199319100141244804501828416633516851200000000000000000000\
\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[89] = 
                    1650795516090846108121691926245361930983966623649654185491\
352070783317103437850973939991257078760066272908038299975680000000000000000000\
0\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[90] = 
                    1485715964481761497309522733620825737885569961284688766942\
216863704985393094065876545992131370884059645617234469978112000000000000000000\
000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[91] = 
                    1352001527678402962551665687594951421475868664769066777917\
417345971536707715599947656852839547504494277511683367680081920000000000000000\
00000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[92] = 
                    1243841405464130725547532432587355307757799171587541435684\
023958293813771098351951844304612383704134735310748698265675366400000000000000\
0000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[93] = 
                    1156772507081641574759205162306240436214753229576413535186\
142281213246807121467315215203289516844845303838996289387078090752000000000000\
000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[94] = 
                    1087366156656743080273652852567866010041868035801828723074\
973744340451998694179276302291092145834154585608656512023853405306880000000000\
00000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[95] = 
                    1032997848823905926259970209939472709539774634011737286921\
225057123429398759470312487176537538542446856328223686422660735041536000000000\
0000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[96] = 
                    9916779348709496892095714015418938011581836486512677954443\
760548384922228090914999876894760370007489820750947389657543056398745600000000\
00000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[97] = 
                    9619275968248211985332842594956369871234381391917297615810\
447731933374561248187549880587917558907265126128418967967816764706783232000000\
0000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[98] = 
                    9426890448883247745626185743057242473809693764078951663494\
238777294707070023223798882976159207729119823605850588608460429412647567360000\
000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[99] = 
                    9332621544394415268169923885626670049071596826438162146859\
296389521759999322991560894146397615651828625369792082722375825118521091686400\
00000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[100] = 
                    9332621544394415268169923885626670049071596826438162146859\
296389521759999322991560894146397615651828625369792082722375825118521091686400\
0000000000000000000000\)},
                {
                  InterpretationBox[" ",
                    SpaceForm[ 1],
                    Editable->False]},
                {\(factorial2[n_] := \(factorial2[n] = 
                      n\ factorial2[n - 1]\)\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "factorial2"],
      Editable->False]], "Print",
  CellTags->"Info3312795480-9399269"]
}, Closed]],

Cell["\<\
Therefore, it is not always obvious that dynamic programming is preferred \
\[LongDash] which resource needs to be conserved, time or memory?  \
Furthermore, there are limits to recursion by either method.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial[1000] // Timing\)], "Input"],

Cell[BoxData[
    RowBox[{\($RecursionLimit::"reclim"\), \(\(:\)\(\ \)\), "\<\"Recursion \
depth of \\!\\(256\\) exceeded. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"$RecursionLimit::reclim\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({0.04700000000000004`\ Second, 
      489389408225290311733092901271992122747641930014438185921791436206203124\
861273025602658192090352943295471568899276859871968129952549363970896016506594\
138054672607994039115598724139602867552752460206879430251446817528881717616934\
579431722318828917753927863094684402529408602652094537266301773040625850796648\
709211671816414540017964294868447481393994640014498204474536640252807911188136\
566096842869176697806703766345735093564476910994554407047378605292907974902286\
464572369344980579211841524720878301517143042856054709851849017908071948335664\
474153572807392769368353720505251236285155885705425792224234438958210381693387\
131958993780199337331381988858776006413168857429132024858489651200000000000000\
000000000000000000000000000000000000000000000000000\ Hold[
          factorial[747 - 1]]}\)], "Output"]
}, Closed]],

Cell["\<\
Although such limits can sometimes be increased, usually it is better to \
rethink the problem!\
\>", "Text"],

Cell[BoxData[
    \(ClearAll[factorial2]\)], "Input"],

Cell[TextData[{
  "Interest is compounded monthly at rate ",
  StyleBox["mpr",
    FontSlant->"Italic"],
  ", monthly percentage rate.  Write a recursive function for the monthly \
balance given a unit initial investment."
}], "Exercise"],

Cell[TextData[{
  "Write a recursive version of the double factorial function, which is \
defined for positive integers as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(dfact[n]\), "=", 
          RowBox[{\(n(n - 2)\), 
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CenterEllipsis]", 
                  StyleBox["n",
                    FontSlant->"Italic"]}]], "min"]}]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\_min = 1\)]],
  " for odd or ",
  Cell[BoxData[
      \(TraditionalForm\`n\_min = 2\)]],
  " for even integers.  What happens if you give this function a negative or \
noninteger argument?  The next section deals with restrictions on arguments."
}], "Exercise"],

Cell[TextData[{
  "Fibonacci numbers satisfy the recursion relation ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n = \ F\_\(n - 1\) + \ F\_\(n - 2\)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1 = \(F\_2 = 1\)\)]],
  ".  Write a recursive function for ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n\)]],
  " using dynamic programming.  Note that you can make your definition for ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n_\)]],
  ".   [Do not worry about illegal arguments at this time.]"
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Conditions on arguments", "Section",
  CellTags->"conditions on arguments"],

Cell[CellGroupData[{

Cell["Type checking", "Subsection",
  CellTags->"type checking"],

Cell[TextData[{
  "A function definition can be restricted to arguments of a particular type \
using the syntax ",
  StyleBox["x_type", "InlineInput"],
  " where ",
  StyleBox["type", "InlineInput"],
  " may be ",
  StyleBox["Integer", "InlineInput"],
  ", ",
  StyleBox["Real", "InlineInput"],
  ", ",
  StyleBox["Complex", "InlineInput"],
  ", ",
  StyleBox["List", "InlineInput"],
  ", or ",
  StyleBox["Symbol", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[x_Integer] := \ x\^2;\)\), "\n", 
    \(\(f[x_Real]\  := \ x\^3;\)\), "\n", 
    \(\(f[x_Complex]\  := \ Abs[x]\^2;\)\), "\n", 
    \(f[x_List]\  := \ \((Plus @@ x)\)\^2\)}], "Input"],

Cell["\<\
This peculiar function gives different results for arguments that have the \
same numerical values but different types.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[2], \ f[2. ]}\)], "Input"],

Cell[BoxData[
    \({4, 8.`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[1 + I]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Here ",
  StyleBox["Plus@@x", "InlineInput"],
  " sums a list, which is then squared to produce the desired result."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[{1, 2, 3, 4}]\)], "Input"],

Cell[BoxData[
    \(100\)], "Output"]
}, Closed]],

Cell[TextData[{
  "However, ",
  StyleBox["f[a]", "InlineInput"],
  " remains unevaluated because ",
  StyleBox["a", "InlineInput"],
  " is a symbol of unknown type."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[a]\)], "Input"],

Cell[BoxData[
    \(f[a]\)], "Output"]
}, Closed]],

Cell["We can add a definition for symbols also, if we like.", "Text"],

Cell[BoxData[
    \(f[x_Symbol] := \ "\<whatever you want\>"\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[a]\)], "Input"],

Cell[BoxData[
    \("whatever you want"\)], "Output"]
}, Closed]],

Cell[TextData[{
  "This still doesn't give a result for ",
  Cell[BoxData[
      \(TraditionalForm\`f[a\^2]\)]],
  " because ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  " does not match the pattern ",
  StyleBox["_Symbol", "InlineInput"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[a\^2]\)], "Input"],

Cell[BoxData[
    \(f[a\^2]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "When in doubt, use the function ",
  ButtonBox["MatchQ",
    ButtonStyle->"RefGuideLink"],
  " to determine whether an expression matches a pattern."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({MatchQ[a, _Symbol], MatchQ[a\^2, _Symbol]}\)], "Input"],

Cell[BoxData[
    \({True, False}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input"],

Cell["Global`f", "Print",
  CellTags->"Info3312795544-2481890"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(f[x_Integer] := x\^2\)},
                {" "},
                {\(f[x_Real] := x\^3\)},
                {" "},
                {\(f[x_Complex] := Abs[x]\^2\)},
                {" "},
                {\(f[x_List] := \((Plus @@ x)\)\^2\)},
                {" "},
                {\(f[x_Symbol] := "whatever you want"\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3312795544-2481890"]
}, Closed]],

Cell["\<\
Write a recursive factorial function that only responds to integer input.\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions with conditions", "Subsection",
  CellTags->"definitions with conditions"],

Cell[TextData[{
  "Conditions can be applied to the rules that define an explicit function.  \
This technique can be used with multiple definitions to produce functions \
whose limiting cases evaluate properly or to define discontinuous or \
piecewise functions.  The basic syntax uses the ",
  ButtonBox["Condition",
    ButtonStyle->"RefGuideLink"],
  " operator (",
  StyleBox["/;", "InlineInput"],
  ") to apply conditions to one or more pattern arguments \n\t\t",
  StyleBox["f[\[CenterEllipsis], y_ /; test, z_, \[CenterEllipsis] ] := rhs", 
    "InlineInput"],
  " \t",
  StyleBox["\n",
    FontSlant->"Italic"],
  "or to a definition\n\t\t",
  StyleBox["f[x_] := rhs /; test", "InlineInput"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "where the right-hand side is returned only if all conditions evaluate to \
True.  Conditions can be used with ",
  StyleBox["SetDelayed", "InlineInput"],
  " (",
  StyleBox[":=", "InlineInput"],
  ") or ",
  StyleBox["ReplaceDelayed", "InlineInput"],
  " (",
  StyleBox[":>", "InlineInput"],
  ") but generally should not be used with ",
  StyleBox["Set", "InlineInput"],
  " (",
  StyleBox["=", "InlineInput"],
  ") or ",
  StyleBox["Replace", "InlineInput"],
  " (",
  StyleBox["\[Rule]", "InlineInput"],
  ") because evaluation occurs immediately, after which the condition is no \
longer present in the definition of the function.  Also note that all names \
appearing in a condition must appear in the pattern to which it is applied; \
otherwise, use conditional statements ",
  StyleBox["If", "InlineInput"],
  ", ",
  StyleBox["Which", "InlineInput"],
  ", or ",
  StyleBox["Switch", "InlineInput"],
  " as discussed in a later section.  Conditions should be applied to the \
smallest element containing all necessary symbols and can be applied either \
on the lhs or the rhs.  Thus,"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[x_, y_]\  := \ x\  - \ y\  /; x > y;\)\), "\n", 
    \(f[x_, y_]\  := \ y\  - \ x\  /; \ x \[LessEqual] y\)}], "Input"],

Cell[TextData[{
  "successfully computes ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]x - y\[RightBracketingBar]\)]],
  " for numerical arguments"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[4, 2], \ f[0.2, 3], f[x, y]}\)], "Input"],

Cell[BoxData[
    \({2, 2.8`, f[x, y]}\)], "Output"]
}, Closed]],

Cell["but", "Text"],

Cell[BoxData[{
    \(\(Clear[g];\)\), "\n", 
    \(\(g[x_ /; x > y, y_]\  := \ x\  - \ y\ ;\)\), "\n", 
    \(g[x_ /; \ x \[LessEqual] y, 
        y_]\  := \ \(\(y\)\(\ \)\(-\)\(\ \)\(x\)\(\ \)\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({g[4, 2], \ g[0.2, 3], g[x, y]}\)], "Input"],

Cell[BoxData[
    \({g[4, 2], g[0.2`, 3], g[x, y]}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "does not because ",
  StyleBox["y", "InlineInput"],
  " is not present in the pattern ",
  Cell[BoxData[
      FormBox[
        StyleBox["x_",
          "InlineInput"], TraditionalForm]]],
  ".  Nor does it help to apply the condition after ",
  StyleBox["y_", "InlineInput"],
  " (try it!).  On the other hand,"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[x_\  /; \ x > 0]\  := \ x;\)\), "\n", 
    \(f[x_\  /; \ x \[LessEqual] 0]\  := \ \(-x\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[\(-6\)], \ f[0], \ f[\[Pi]]}\)], "Input"],

Cell[BoxData[
    \({6, 0, \[Pi]}\)], "Output"]
}, Closed]],

Cell[BoxData[{
    \(\(Clear[g];\)\), "\n", 
    \(\(g[x_\ ]\  := \ x\ \ \  /; \ x > 0;\)\), "\n", 
    \(g[x_\ ]\  := \ \(-x\)\ \  /; \ x \[LessEqual] 0\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({g[\(-6\)], \ g[0], \ g[\[Pi]]}\)], "Input"],

Cell[BoxData[
    \({6, 0, \[Pi]}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "both compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]x\[RightBracketingBar]\)]],
  " because the condition is formed properly on either side of the \
assignment."
}], "Text"],

Cell["\<\
When possible, it is more efficient to apply the condition to the argument \
rather than to the rhs because the latter method requires evaluation of each \
rhs for which a rule exists whereas the former method can be accomplished \
with fewer evaluations.\
\>", "Text"],

Cell["\<\
Conditions can be combined using logical operators to form a single logical \
condition that evaluates to either true or false.  Composite conditions \
should be enclosed in parentheses to ensure proper parsing.  The following \
example illustrates some composite conditions.  Note that the function \
remains unevaluated if the truth of condition cannot be determined or if a \
suitable definition is absent.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\[IndentingNewLine]", 
    \(f[x_] := "\<I am a positive even integer\>"\  /; \((x > 0 && 
            Mod[x, 2] \[Equal] 0)\)\), "\[IndentingNewLine]", 
    \(f[x_] := "\<I am a negative odd integer\>"\  /; \((x < 0 && 
            Mod[x, 2] \[Equal] 1)\)\), "\[IndentingNewLine]", 
    \(f[x_] := "\<I am not an integer\>"\  /; \((Mod[x, 2] \[NotEqual] 0 && 
            Mod[x, 2] \[NotEqual] 1)\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f /@ {q, \(-2\), 8, \(-7\), \[Pi]}\)], "Input"],

Cell[BoxData[
    \({f[q], f[\(-2\)], "I am a positive even integer", 
      "I am a negative odd integer", "I am not an integer"}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: step function", "Subsubsection"],

Cell[TextData[{
  "The unit step function is defined to be +1 for positive arguments or 0 for \
negative arguments.  By convention, we choose the intermediate value of ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " for the origin.  This function can be created using multiple definitions \
that test the argument."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[step];\)\), "\n", 
    \(\(step[x_\  /; x > 0]\  := 1;\)\), "\n", 
    \(\(step[x_\  /; x \[Equal] 0]\  := 1\/2;\)\), "\n", 
    \(step[x_\  /; \ x < 0]\  := \ 0\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({step[\(-\(1\/2\)\)], \ step[0], \ step[12], \ step[x], \ 
      step[1 - x] /. x \[Rule] 0.4}\)], "Input"],

Cell[BoxData[
    \({0, 1\/2, 1, step[x], 1}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "All of these cases give the expected output except ",
  StyleBox["step[x]", "InlineInput"],
  ", which remains unevaluated because the condition is ambiguous, being \
neither definitely ",
  StyleBox["True", "InlineInput"],
  " nor definitely ",
  StyleBox["False", "InlineInput"],
  "."
}], "Text"],

Cell["\<\
Note that the condition can be applied to either the left or the right sides \
of the assignment.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[step];\)\), "\n", 
    \(\(step[x_\ ]\  := \ 1\ \ \  /; x > 0;\)\), "\n", 
    \(\(step[x_\ ]\  := \ 1\/2\  /; x \[Equal] 0;\)\), "\n", 
    \(step[x_\ ]\  := \ 0\ \ \  /; \ x < 0\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({step[\(-\(1\/2\)\)], \ step[0], \ step[12], \ step[x], \ 
      step[1 - x] /. x \[Rule] 0.4}\)], "Input"],

Cell[BoxData[
    \({0, 1\/2, 1, step[x], 1}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: spherical Bessel function at origin", "Subsubsection"],

Cell["\<\
Recall our previous definition for the regular spherical Bessel function.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[sbessj];\)\), "\n", 
    \(\(sbessj[n_, z_]\  := \ \(\@\(\[Pi]\/2\)\) 
          z\^\(\(-1\)/2\)\ BesselJ[n + 1\/2, z];\)\)}], "Input"],

Cell["\<\
Unfortunately, this simple definition cannot handle the origin.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({sbessj[0, 0], sbessj[1, 0], sbessj[n, 0]}\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/\\@0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ \\@\\(\[Pi]\\/2\\)\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/\\@0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ \\@\\(\[Pi]\\/2\\)\\\\ ComplexInfinity\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Power::"infy"\), \(\(:\)\(\ \)\), "\<\"Infinite expression \
\\!\\(1\\/\\@0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Power::infy\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Power :: \\\"infy\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({Indeterminate, Indeterminate, ComplexInfinity}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Since we should know the limits for these functions as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 0\)]],
  ", or can deduce them using ",
  ButtonBox["Limit",
    ButtonStyle->"RefGuideLink"],
  ", where we specify that the limit is to be evaluated for decreasing ",
  StyleBox["x",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[sbessj[0, x], x \[Rule] 0, Direction \[Rule] \(-1\)]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[sbessj[1, x], x \[Rule] 0, Direction \[Rule] \(-1\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell["\<\
We can include these properties in the definition of the function itself by \
applying conditions to the arguments and including several definitions \
covering various special cases. \
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[sbessj];\)\), "\n", 
    \(\(sbessj[n_, 
          z_\  /; z \[NotEqual] 
              0]\  := \ \(\@\(\[Pi]\/2\)\) \(z\^\(\(-1\)/2\)\) 
          BesselJ[n + 1\/2, z];\)\), "\n", 
    \(\(sbessj[0, 0]\  := \ 1;\)\), "\n", 
    \(sbessj[n_ /; n > 0, 0\ ]\  := \ 0\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[Table[sbessj[n, x], {n, 0, 3}]], {x, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.11976 0.483559 [
[.21429 .10726 -3 -9 ]
[.21429 .10726 3 0 ]
[.40476 .10726 -3 -9 ]
[.40476 .10726 3 0 ]
[.59524 .10726 -3 -9 ]
[.59524 .10726 3 0 ]
[.78571 .10726 -3 -9 ]
[.78571 .10726 3 0 ]
[.97619 .10726 -6 -9 ]
[.97619 .10726 6 0 ]
[.01131 .02305 -24 -4.5 ]
[.01131 .02305 0 4.5 ]
[.01131 .21647 -18 -4.5 ]
[.01131 .21647 0 4.5 ]
[.01131 .31318 -18 -4.5 ]
[.01131 .31318 0 4.5 ]
[.01131 .4099 -18 -4.5 ]
[.01131 .4099 0 4.5 ]
[.01131 .50661 -18 -4.5 ]
[.01131 .50661 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .11976 m
.21429 .12601 L
s
[(2)] .21429 .10726 0 1 Mshowa
.40476 .11976 m
.40476 .12601 L
s
[(4)] .40476 .10726 0 1 Mshowa
.59524 .11976 m
.59524 .12601 L
s
[(6)] .59524 .10726 0 1 Mshowa
.78571 .11976 m
.78571 .12601 L
s
[(8)] .78571 .10726 0 1 Mshowa
.97619 .11976 m
.97619 .12601 L
s
[(10)] .97619 .10726 0 1 Mshowa
.125 Mabswid
.07143 .11976 m
.07143 .12351 L
s
.11905 .11976 m
.11905 .12351 L
s
.16667 .11976 m
.16667 .12351 L
s
.2619 .11976 m
.2619 .12351 L
s
.30952 .11976 m
.30952 .12351 L
s
.35714 .11976 m
.35714 .12351 L
s
.45238 .11976 m
.45238 .12351 L
s
.5 .11976 m
.5 .12351 L
s
.54762 .11976 m
.54762 .12351 L
s
.64286 .11976 m
.64286 .12351 L
s
.69048 .11976 m
.69048 .12351 L
s
.7381 .11976 m
.7381 .12351 L
s
.83333 .11976 m
.83333 .12351 L
s
.88095 .11976 m
.88095 .12351 L
s
.92857 .11976 m
.92857 .12351 L
s
.25 Mabswid
0 .11976 m
1 .11976 L
s
.02381 .02305 m
.03006 .02305 L
s
[(-0.2)] .01131 .02305 1 0 Mshowa
.02381 .21647 m
.03006 .21647 L
s
[(0.2)] .01131 .21647 1 0 Mshowa
.02381 .31318 m
.03006 .31318 L
s
[(0.4)] .01131 .31318 1 0 Mshowa
.02381 .4099 m
.03006 .4099 L
s
[(0.6)] .01131 .4099 1 0 Mshowa
.02381 .50661 m
.03006 .50661 L
s
[(0.8)] .01131 .50661 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04723 m
.02756 .04723 L
s
.02381 .0714 m
.02756 .0714 L
s
.02381 .09558 m
.02756 .09558 L
s
.02381 .14394 m
.02756 .14394 L
s
.02381 .16812 m
.02756 .16812 L
s
.02381 .19229 m
.02756 .19229 L
s
.02381 .24065 m
.02756 .24065 L
s
.02381 .26483 m
.02756 .26483 L
s
.02381 .28901 m
.02756 .28901 L
s
.02381 .33736 m
.02756 .33736 L
s
.02381 .36154 m
.02756 .36154 L
s
.02381 .38572 m
.02756 .38572 L
s
.02381 .43407 m
.02756 .43407 L
s
.02381 .45825 m
.02756 .45825 L
s
.02381 .48243 m
.02756 .48243 L
s
.02381 .53079 m
.02756 .53079 L
s
.02381 .55496 m
.02756 .55496 L
s
.02381 .57914 m
.02756 .57914 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60327 L
.02729 .60321 L
.02846 .60313 L
.03053 .60292 L
.03279 .6026 L
.03527 .60215 L
.0379 .60156 L
.04262 .60018 L
.04749 .59835 L
.05205 .59626 L
.06244 .59016 L
.07305 .58207 L
.08274 .57304 L
.10458 .5474 L
.14429 .48428 L
.18248 .40869 L
.22313 .32004 L
.26226 .23478 L
.30384 .15264 L
.34391 .08845 L
.36228 .06523 L
.38246 .04471 L
.40239 .0297 L
.41329 .02372 L
.42346 .01953 L
.42847 .01796 L
.43391 .01661 L
.4364 .01611 L
.43905 .01567 L
.44134 .01535 L
.44381 .01508 L
.44497 .01498 L
.44618 .0149 L
.44731 .01483 L
.44836 .01478 L
.44935 .01475 L
.4504 .01473 L
.45157 .01472 L
.45263 .01472 L
.45388 .01474 L
.45503 .01478 L
.4563 .01483 L
.45764 .01491 L
.45989 .01509 L
.46237 .01536 L
.46758 .01613 L
.47253 .01713 L
.48182 .01968 L
Mistroke
.49181 .02335 L
.50271 .02836 L
.54341 .05451 L
.58259 .08645 L
.62422 .12138 L
.66434 .15054 L
.68276 .16126 L
.70294 .1706 L
.71259 .17411 L
.72292 .17714 L
.72863 .1785 L
.73383 .17953 L
.73876 .18034 L
.744 .181 L
.74873 .18143 L
.75142 .18161 L
.75265 .18167 L
.75394 .18173 L
.75504 .18177 L
.75625 .1818 L
.75734 .18182 L
.75836 .18183 L
.75957 .18184 L
.76066 .18183 L
.76193 .18182 L
.76312 .18179 L
.76432 .18176 L
.76565 .18171 L
.76831 .18158 L
.77079 .18141 L
.7731 .18122 L
.77831 .18066 L
.7839 .17986 L
.79405 .17793 L
.80511 .17514 L
.82522 .16842 L
.86597 .14982 L
.90521 .1286 L
.94293 .10853 L
.97619 .09345 L
Mfstroke
.02381 .11976 m
.06244 .18408 L
.10458 .24688 L
.12507 .27253 L
.14415 .29271 L
.16254 .30836 L
.17277 .31534 L
.18221 .32065 L
.19242 .32514 L
.19781 .32697 L
.20351 .32851 L
.2059 .32904 L
.20846 .32952 L
.21068 .32987 L
.2131 .33018 L
.21456 .33033 L
.21592 .33044 L
.21722 .33053 L
.21789 .33057 L
.21861 .33061 L
.21932 .33063 L
.21997 .33065 L
.22126 .33068 L
.22242 .33068 L
.22365 .33066 L
.22487 .33063 L
.22556 .3306 L
.2262 .33057 L
.22735 .3305 L
.22861 .33041 L
.2308 .3302 L
.23313 .32992 L
.23837 .32903 L
.24329 .32789 L
.25211 .32514 L
.26163 .32116 L
.28167 .30954 L
.30277 .29303 L
.34087 .25433 L
.38143 .20531 L
.42048 .15638 L
.46198 .10877 L
.48278 .08836 L
.50196 .07226 L
.52183 .05869 L
.54043 .04907 L
.54947 .04551 L
.55919 .04249 L
.56472 .04116 L
.56997 .04014 L
Mistroke
.57469 .03944 L
.57737 .03912 L
.57983 .03889 L
.58239 .03871 L
.58374 .03863 L
.58516 .03857 L
.5864 .03853 L
.58755 .03851 L
.58882 .03849 L
.58953 .03849 L
.59017 .03849 L
.59137 .0385 L
.59248 .03852 L
.5937 .03856 L
.59499 .03861 L
.59715 .03873 L
.59954 .0389 L
.60476 .03945 L
.61037 .04027 L
.62053 .04238 L
.63012 .04506 L
.64061 .0487 L
.66172 .05803 L
.70233 .08163 L
.74143 .10772 L
.78298 .13442 L
.80382 .14604 L
.82301 .15517 L
.84174 .16235 L
.85129 .1653 L
.86153 .1679 L
.87179 .1699 L
.88115 .1712 L
.88565 .17164 L
.88803 .17183 L
.89055 .17199 L
.89275 .1721 L
.89392 .17215 L
.89518 .17219 L
.89634 .17222 L
.89739 .17224 L
.89841 .17226 L
.89947 .17227 L
.9007 .17227 L
.9014 .17227 L
.90204 .17227 L
.90321 .17225 L
.90446 .17223 L
.90558 .1722 L
.90662 .17217 L
Mistroke
.909 .17207 L
.91156 .17193 L
.91391 .17177 L
.91919 .17131 L
.92369 .17079 L
.9286 .17011 L
.93755 .16855 L
.95626 .16408 L
.97619 .1577 L
Mfstroke
.02381 .11976 m
.02499 .11977 L
.02605 .11978 L
.02729 .1198 L
.02846 .11984 L
.03053 .11992 L
.03279 .12005 L
.03527 .12023 L
.0379 .12046 L
.04262 .12101 L
.04749 .12174 L
.05205 .12258 L
.06244 .125 L
.07305 .12821 L
.08274 .13177 L
.10458 .14178 L
.14429 .16571 L
.18248 .19281 L
.22313 .22182 L
.26226 .2457 L
.28367 .25575 L
.29348 .25946 L
.30384 .2627 L
.31341 .26504 L
.31848 .26603 L
.32392 .26687 L
.32648 .26719 L
.32891 .26746 L
.33128 .26767 L
.33347 .26783 L
.33554 .26795 L
.3366 .268 L
.33774 .26804 L
.33888 .26807 L
.33995 .26809 L
.34122 .26811 L
.34239 .26811 L
.34367 .2681 L
.34487 .26808 L
.34596 .26806 L
.34713 .26802 L
.34841 .26796 L
.34976 .26789 L
.35219 .26773 L
.35654 .26732 L
.36131 .26671 L
.36647 .26586 L
.37201 .26472 L
.38201 .26207 L
.39214 .25865 L
Mistroke
.40319 .25408 L
.42329 .24366 L
.46399 .21546 L
.50317 .18207 L
.5448 .14419 L
.58492 .10974 L
.62353 .0822 L
.6435 .07104 L
.65368 .06629 L
.66458 .06195 L
.67488 .05858 L
.68426 .05613 L
.68878 .05516 L
.69369 .05427 L
.69798 .05363 L
.70261 .05307 L
.70514 .05283 L
.70747 .05265 L
.70983 .0525 L
.71203 .0524 L
.7132 .05235 L
.71445 .05232 L
.71516 .0523 L
.71584 .05229 L
.71709 .05228 L
.71774 .05227 L
.71842 .05227 L
.71965 .05228 L
.72097 .0523 L
.72172 .05232 L
.72242 .05234 L
.72372 .05238 L
.72514 .05244 L
.72772 .05258 L
.73023 .05275 L
.73256 .05296 L
.73783 .05354 L
.74344 .05434 L
.75279 .0561 L
.76289 .05856 L
.78116 .06436 L
.82227 .08254 L
.86186 .10403 L
.89993 .12513 L
.94046 .14477 L
.97619 .15745 L
Mfstroke
.02381 .11976 m
.02499 .11976 L
.02605 .11976 L
.02729 .11976 L
.02846 .11976 L
.02954 .11976 L
.03053 .11976 L
.03163 .11976 L
.03279 .11976 L
.03395 .11977 L
.0352 .11977 L
.03746 .11977 L
.03884 .11978 L
.04016 .11978 L
.04262 .1198 L
.045 .11981 L
.04753 .11983 L
.0521 .11988 L
.05752 .11996 L
.06244 .12006 L
.06787 .12021 L
.07287 .12038 L
.08414 .1209 L
.09408 .12155 L
.10458 .12246 L
.12422 .12483 L
.14255 .12794 L
.1629 .13249 L
.18146 .13766 L
.22131 .15192 L
.25964 .16893 L
.30042 .18883 L
.33968 .20746 L
.37743 .22258 L
.39678 .22857 L
.40674 .23108 L
.41764 .23332 L
.42266 .23417 L
.42802 .23495 L
.43265 .2355 L
.43768 .23598 L
.44064 .23621 L
.44336 .23638 L
.44597 .2365 L
.4473 .23655 L
.44873 .23659 L
.45002 .23662 L
.4512 .23664 L
.45239 .23665 L
.45352 .23666 L
Mistroke
.45482 .23666 L
.45603 .23664 L
.45673 .23663 L
.45736 .23662 L
.45878 .23659 L
.45998 .23655 L
.46111 .23651 L
.46367 .23639 L
.46616 .23625 L
.46883 .23605 L
.47366 .23559 L
.47806 .23507 L
.48877 .23336 L
.4989 .23116 L
.51884 .22526 L
.53728 .21801 L
.5766 .19752 L
.6144 .17294 L
.65465 .14421 L
.69339 .11701 L
.73459 .0918 L
.75515 .08153 L
.77426 .07373 L
.79273 .06794 L
.80305 .06549 L
.81242 .06377 L
.81729 .06306 L
.82243 .06246 L
.82682 .06206 L
.8293 .06189 L
.83165 .06175 L
.83295 .06168 L
.83436 .06163 L
.83554 .06159 L
.83684 .06155 L
.83824 .06152 L
.83901 .06151 L
.83973 .0615 L
.84102 .0615 L
.84174 .0615 L
.8424 .0615 L
.84361 .06151 L
.84474 .06153 L
.84598 .06155 L
.8473 .06159 L
.85 .0617 L
.85246 .06183 L
.8573 .06217 L
.86242 .06267 L
.87162 .0639 L
Mistroke
.88151 .06568 L
.89241 .06816 L
.91183 .07381 L
.93271 .0814 L
.97396 .0996 L
.97619 .10066 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000
003oool0oooo0?l0ooooQP3oool000/0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`030?ooo`030000
003oool0oooo0?l0ooooQP3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`03
0;md0000000007Bo00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`03
0000003oool0oooo0:40oooo3`00003E0?ooo`002P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nL
B018W=l0oooo00/0oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`2O0?ooo`800000
3`3oool300000=80oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0303o
ool00`3ogi`0B00004RLg`070?ooo`030000003oool0oooo09`0oooo0`00000D0?ooo`<00000c`3o
ool000030?ooo`2LB000000000@0000000D004RL0?ooo`3oool0gia804RLg`030?ooo`030?noM000
M;l0oooo00h0oooo00<0W4P004RLg`3oool01@3oool4000009P0oooo0`00000J0?ooo`@00000b`3o
ool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8M02oool0
oooo00@0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0O0?ooo`800000b@3oool0
00X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo
0080oooo00<0_g@007Boo`3oool0103oool00`000000oooo0?ooo`2F0?ooo`800000903oool20000
0<L0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3o
ool0okmd0000B02Lgol01@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02H0oooo
0P0000350?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd000000000000
001809cOo`060?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`320?ooo`00:03oool00`000000oooo0?ooo`2B0?ooo`800000;@3oool200000<80oooo
000X0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0;`3oool2000001D0oooo3@00
002N0?ooo`00:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool03@3oool5000000d0oooo0`00002K0?ooo`00:03oool00`000000oooo0?ooo`2>0?oo
o`800000=P3oool2000000X0oooo0`00000E0?ooo`@00000U`3oool002P0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo0`00000L0?ooo`@0
0000T`3oool002P0oooo0`00002<0?ooo`030000003oool0oooo03X0oooo0P000000103oool00000
00000000000S0?ooo`<00000T03oool002P0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0l0?ooo`<00000:03oool2000008h0oooo000X0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0>`3oool2000000<0oooo00<000000?ooo`3oool09`3oool200000100oooo5P00
001V0?ooo`00:03oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03X0oooo0P000006
0?ooo`030000003oool0oooo02P0oooo0P0000090?ooo`D000005P3oool400000680oooo000X0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0>@3oool2000000T0oooo0P00000Z0?oo
o`8000000`3oool4000001l0oooo1000001N0?ooo`00:03oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?ooo`<0
00009`3oool4000001<0oooo3000000k0?ooo`00:03oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`800000
0P3oool2000002X0oooo0P00000;0?ooo`H00000303oool8000003<0oooo000X0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0>03oool200000140oooo00<000000?ooo`3oool08`3o
ool2000000H0oooo0P00000Z0?ooo`8000001@3oool4000001X0oooo1@00000^0?ooo`00:03oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0P0?ooo`8000002P3oool2000002X0oooo1@00000S0?ooo`@00000:P3oool0
02P0oooo0`0000230?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0503oool20000
01h0oooo0P00000>0?ooo`8000009@3oool4000000030?ooo`000000000002P0oooo1000000V0?oo
o`00:03oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0I0?ooo`8000004P3oool2000001l0oooo100000070?ooo`80
0000:P3oool3000002<0oooo000X0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
503oool2000001/0oooo0P00000=0?ooo`800000:`3oool300000200oooo000X0?ooo`030000003o
ool0oooo04D0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`0b0?ooo`030000003o
ool0oooo0100oooo00D0omnL04P000000000000007Boo`0Q0?ooo`8000007@3oool00`000000oooo
0?ooo`040?ooo`050;md0000000000000000M02oool02`3oool2000001T0oooo0P00000G0?ooo`80
00001@3oool01@2oM000000000000000000007Bo00L0oooo0P00000/0?ooo`<000002P3oool00`3o
_g@000000000000300000005001d_`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`02
0?ooo`00:03oool00`000000oooo0?ooo`160?ooo`030;md000007@0_ooo0080oooo00<0giad09cO
o`3oool0<P3oool00`000000oooo0?ooo`0C0?ooo`030;md001d_ol0oooo0200oooo00<000000?oo
o`3oool07P3oool2000000<0oooo00H0gia8001d_`3oool0oooo0?noM000M;l90?ooo`8000007@3o
ool00`000000oooo0?ooo`0A0?ooo`<000001P3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdB02L
gol0oooo00L0oooo0P00000]0?ooo`<000002P3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02o
ool0oooo0?oo_`1d07@0_ooo0`3oool002P0oooo00<000000?ooo`3oool0A`3oool00`3o_g@00018
09cOo`0e0?ooo`030000003oool0oooo01@0oooo00<0_g@007Boo`3oool07`3oool00`000000oooo
0?ooo`0Q0?ooo`050000003oool0oono07@0001d_ol00P3oool00`3ookl0M4RL0?ooo`070?ooo`03
0000003oool0oooo01h0oooo0P00000?0?ooo`8000002@3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0;md001d_ol0oooo00T0oooo0P00000^0?ooo`800000203oool00`2LB4P0W=oo0?ooo`030?ooo`03
0?noM000M;l0oooo0080oooo00<0gia804RLg`3oool00P3oool002P0oooo00<000000?ooo`3oool0
B03oool00`3ogi`0B00004RLg`0c0?ooo`030000003oool0oooo0140oooo00<0gia8000000000000
0`0000000`1d_ol0oooo0?ooo`0K0?ooo`8000009@3oool020000000okmd0018B01d07@0_ooo0?oo
o`3OW4P007Bo1P3oool2000002<0oooo00<000000?ooo`3oool02P3oool2000000/0oooo00<0okmd
0018W03oool00P3oool00`2LB4P0W=oo0?ooo`0;0?ooo`800000;P3oool2000000H0oooo00<0W4Q8
09cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo0080oooo000X0?oo
o`030000003oool0oooo04X0oooo00<0W4P004RLg`3oool0<03oool00`000000oooo0?ooo`0B0?oo
o`060?noM00007@0_ooo0?ooo`2oM000M;oo7@3oool00`000000oooo0?ooo`0V0?ooo`0300000018
B9`0okmd0080000000<004RL0?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00L0oooo0P00000>0?ooo`050=nLB0000000000000000018W=l03`3oool2000002h0oooo
0P0000040?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`1;0?ooo`0309a8M02oool0oooo02h0oooo00<0
00000?ooo`3oool0503oool01@3OW4P007Bo0?ooo`2oM000M;oo01`0oooo00<000000?ooo`3oool0
9`3oool00`3ookl000000;ooo`080?ooo`030000003oool0oooo02H0oooo0P0000050?ooo`800000
3`3oool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo00l0oooo0P00000^0?ooo`<00000
00<0oooo09a8B02Lgol0103oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo0080oooo
000X0?ooo`030000003oool0oooo04H0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?oo
o`0^0?ooo`030000003oool0oooo01D0oooo00@0W4P004RLg`2oM000M;oo6`3oool00`000000oooo
0?ooo`0Y0?ooo`030;md00000000oooo00D0oooo0P00000[0?ooo`030000003oool0oooo00800000
4@3oool00`3o_g@0B9cO0?ooo`020?ooo`030;md001d_ol0oooo0140oooo0P00000_0?ooo`800000
00<0W=oo0?ooo`3oool00P0000000`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo0080oooo
000X0?ooo`<00000AP3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0;P3oool00`000000
oooo0?ooo`0F0?ooo`040?oOW01804P0B4P007BooaX0oooo00<000000?ooo`3oool0:P3oool0103o
okl0M0000000000000030?ooo`030000003oool0oooo02`0oooo0P00000C0?ooo`070?oOW01807@0
_ooo0?ooo`3ogi`0B01d0;ooo`0D0?ooo`800000:`3oool0103OW4P000000018W02LB4P3000000<0
oooo00H0W4P007Boo`3oool0omnL04P0M02oool30?ooo`00:03oool00`000000oooo0?ooo`170?oo
o`050?noM000000000000000B02Lgol0;`3oool00`000000oooo0?ooo`0G0?ooo`030?noM0000000
M;oo01T0oooo00<000000?ooo`3oool0;@3oool01@2oM000000000000000B9`0000002h0oooo1000
000C0?ooo`050?noM000000000000000B02Lgol05`3oool2000002/0oooo00@0gia8000000000000
oooo0P0000020?ooo`050?oo_`1d000000000000B02Lgol0103oool002P0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0300oooo0P00000]0?ooo`80
0000103oool00`000000oooo0?ooo`0^0?ooo`800000:03oool2000000D0oooo00<000000?ooo`3o
ool0203oool002P0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0300oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02l0oooo0P00000T0?ooo`8000004P3oool002P0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0V0?ooo`8000002@3oool200000340oooo0P00000P0?ooo`800000
503oool002P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo02l0oooo0P0000060?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0`0?ooo`800000703oool2000001H0oooo000X0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool08@3oool2000000l0oooo0P00000b0?ooo`800000603oool2
000001P0oooo000X0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo00T0oooo0P00000O0?ooo`8000004`3oool20000
0380oooo00<000000?ooo`3oool04`3oool2000001X0oooo000X0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0^0?ooo`8000003P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool200000140
oooo0P00000L0?ooo`00:03oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo
0P00000I0?ooo`800000<P3oool2000000d0oooo0P00000N0?ooo`007`3ooooo0000094000000@3o
ool002P0oooo0P0000090?ooo`<000001P3oool00`000000oooo0?ooo`080?ooo`H000000P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo0P00000B0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`3oool0203oool2000000H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`800000103oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000X0?ooo`800000303oool4000001<0oooo2000
000P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`8000004P3oool2000002<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo008000006@3oool00`000000oooo0?ooo`080?ooo`00:03oool0
0`000000oooo0000000?0?ooo`@000005`3oool5000004@0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0/0?ooo`8000006P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02@0oooo0P00000b0?ooo`8000009P3oool002P0oooo00@000000?ooo`3oool000004P3oool4
000001P0oooo100000100?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool2
000002l0oooo0P0000000`3oool000000000000T0?ooo`00:03oool010000000oooo0?ooo`00000F
0?ooo`8000006P3oool4000003/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01d0oooo0P00000:0?ooo`800000;03oool00`000000oooo0?ooo`0Z
0?ooo`8000001@3oool200000280oooo000X0?ooo`050000003oool0oooo0?ooo`0000005`3oool2
000001`0oooo1000000f0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;@3oool2
000002P0oooo0P0000090?ooo`800000803oool002P0oooo00D000000?ooo`3oool0oooo0000000I
0?ooo`8000007P3oool3000003<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0[
0?ooo`800000903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0;0?ooo`8000007P3oool002P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`8000007`3oool3000002l0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02D0oooo0P0000020?oo
o`800000=03oool200000280oooo0P00000@0?ooo`800000703oool002P0oooo0`0000030?ooo`03
0000003oool0oooo01T0oooo0P00000P0?ooo`<00000:`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0:03oool2000003P0oooo0P00000N0?ooo`80
0000503oool2000001X0oooo000X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0P0?ooo`@000009`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:03oool3000003X0oooo00<000000?ooo`3oool0
6@3oool2000001P0oooo0`00000G0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01/0oooo0P00000T0?ooo`<000008`3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`3oool2000003T0oooo
0P00000G0?ooo`8000007@3oool3000001@0oooo000X0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0703oool2000002D0oooo0`00000P0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0>03oool2000001<0oooo0P00000R0?ooo`8000004P3oool002P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo0P00000M
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:@3oool2000002T0oooo0P000008
0?ooo`800000>P3oool2000000l0oooo0P00000V0?ooo`<000003`3oool002P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`8000009`3oool2000001X0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02P3oool2000003X0oooo0`00000:0?ooo`800000:`3oool3000000`0oooo000X0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0V0?ooo`80
0000603oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool09`3oool2000000l0oooo0P00000k0?ooo`8000001P3oool200000300oooo0P00000:0?ooo`00
:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo0P00000X0?ooo`<00000
503oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0A0?ooo`800000>`3oool2000000040?ooo`0000000000000002h0
oooo1000000<0?ooo`00:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0240oooo
0P00000Y0?ooo`8000004P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool09P3oool2000001H0oooo0P00000j0?ooo`@00000:`3oool400000100oooo
000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0X0?ooo`8000003`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0H0?ooo`800000=P3oool2000000@0oooo1000
000S0?ooo`@00000503oool002P0oooo0`0000090?ooo`030000003oool0oooo02<0oooo0P00000Z
0?ooo`8000003@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0K0?ooo`800000<@3oool3000000X0oooo1000000L
0?ooo`<00000603oool002P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02T0oooo0P00000:0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool09`3oool2000002L0oooo0P00000P0?ooo`<00000;03oool200000140oooo3@0000030?oo
o``000006`3oool002P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02X0oooo0P0000080?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02<0oooo1000000U0?ooo`<0
00007`3oool4000002L0oooo000X0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9@3oool2000002`0oooo0P0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0U0?ooo`800000:P3oool3000001h0oooo1000001=0?ooo`00:03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:`3o
ool2000000<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0;@3oool4000001H0oooo1000001A0?ooo`00:03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0;03oool3
000002`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0T0?ooo`800000=03ooolF
000005D0oooo000X0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09`3oool20000
02h0oooo0P00000Z0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`2O0?ooo`00:03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`02000002L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0S0?ooo`800000XP3oool002P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
0P3oool2000002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0:80oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:@3o
ool2000002P0oooo00<000000?ooo`3oool01@3oool200000280oooo00<000000?ooo`3oool0903o
ool2000002@0oooo0P00002U0?ooo`00:03oool300000100oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00L0oooo0P00000O0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2U0?ooo`00:03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02/0oooo0P00000T0?ooo`030000003oool0oooo
00X0oooo0P00000L0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08P3oool20000
0:P0oooo000X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo0P00000I0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2X0?ooo`00:03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02`0oooo0P00000P0?ooo`030000003oool0oooo00l0oooo
0P00000G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08@3oool200000:/0oooo
000X0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0140oooo0P00000D0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0803oool200000:d0oooo000X0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo0P00000A
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool200000:l0oooo000;0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000
000000@0000000<0M;oo0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo02h0oooo0P00000K0?ooo`030000003oool0oooo01H0oooo0`00000=0?ooo`030000003oool0
oooo0280oooo0P00000P0?ooo`800000/@3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02o
ool40?ooo`030;md0000000007Bo00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?oo
o`040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01X0oooo0P00000:0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07P3oool200000;<0oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool02`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0<03oool2000001L0oooo00<000000?ooo`3oool0703oool3000000H0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`800000]@3oool000X0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00L0oooo1000000E0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0P0?oo
o`800000103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01`0oooo0P00002g0?oo
o`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3o
ool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0340oooo0P00000C0?ooo`03
0000003oool0oooo0280oooo1000000R0?ooo`8000007@3oool200000;T0oooo000:0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`040?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02D0oooo0`00000P0?ooo`030000003oool0oooo01/0oooo0P00002k0?ooo`002P3o
ool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Boo`3oool00P3o
ool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<`3o
ool2000000l0oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`3oool3000001/0oooo
0P00000K0?ooo`<00000_@3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`07
0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`050?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool01@3oool4000001H0oooo00<000000?ooo`3oool0603oool300000<00oooo000;0?oo
o`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00H0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0e0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00X0oooo1000000A0?ooo`030000003oool0oooo01D0oooo1000
00330?ooo`00:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03H0oooo0P000008
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool4000000/0oooo0P00000D
0?ooo`@00000a`3oool002P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?oo
o`D000001@3oool00`000000oooo0?ooo`0@0?ooo`@00000b`3oool002P0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0h0?ooo`8000001@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01T0oooo6000003?0?ooo`00:03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo03T0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0hP3oool002P0oooo0`00000M0?ooo`030000003oool0oooo03T0oooo
0P0000000`3oool000000?ooo`0R0?ooo`030000003oool0oooo01/0oooo0P00003U0?ooo`00:03o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03/0oooo0P00000R0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0i@3oool002P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool000000240oooo00<000000?ooo`3oool06@3oool2
00000>P0oooo000X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>03oool01000
0000oooo0?ooo`3oool2000001h0oooo00<000000?ooo`3oool0603oool200000>X0oooo000X0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`030?oo
o`8000006`3oool00`000000oooo0?ooo`0G0?ooo`800000k03oool002P0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo0P00000H0?ooo`03
0000003oool0oooo01H0oooo0P00003^0?ooo`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0203oool3000001@0oooo00<000000?ooo`3oool0
5@3oool200000?00oooo000X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0<0?ooo`<00000403oool00`000000oooo0?ooo`0C0?ooo`<00000lP3o
ool002P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00l0oooo0P00000=0?ooo`030000003oool0oooo0100oooo1000003e0?ooo`00:03oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3oool30000
00T0oooo00<000000?ooo`3oool03@3oool400000?T0oooo000X0?ooo`<00000903oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo01D0oooo2@00000:0?ooo`H00000o@3oool002P0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo
3000003o0?ooo`@0oooo000X0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo3P3oool002P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`00:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooo`l0oooo000X0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0oooo403oool002P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`00:03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`3o0?oooa80oooo000X0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo4`3oool0
02P0oooo0`00000/0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`3o0?oooa@0oooo000X0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo5@3oool002P0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0o`3ooolF0?ooo`00:03oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oooaL0oooo000X
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F
0?ooo`800000o`3ooolJ0?ooo`00:03oool00`000000oooo0?ooo`0a0?ooo`8000007P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo6P3oool000/0oooo00D0okmd00000000
0000000007Boo`050?ooo`030;md0000000007Bo00H0oooo00D0omnL04P000000000000007Boo`05
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?l0oooo6`3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02o
ool40?ooo`030;md0000000007Bo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04`3oool200000?l0oooo7P3o
ool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030;md001d_ol0
oooo00D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00X0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`030?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?oo
o`800000o`3ooolQ0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00H0okmd0000M02oool0oooo0;md001d_ol60?ooo`@00000=P3oool2000001D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooob40oooo000:0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo0?ooo`2oM000M;oo00H0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo0P00003o
0?ooob@0oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102L
B000B9cO0;md001d_ol60?ooo`030000003oool0oooo03X0oooo0P00000A0?ooo`030000003oool0
oooo00h0oooo0P00003o0?ooobH0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo3@3o
ool0103ogi`0B01804Q8001d_ol60?ooo`030000003oool0oooo03`0oooo0P00000?0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`002`3oool01@3ookl0M0000000
000004P0W=oo00l0oooo00<0okmd0000001d_ol01P3oool00`000000oooo0?ooo`0n0?ooo`800000
3@3oool00`000000oooo0?ooo`0;0?ooo`800000o`3ooolY0?ooo`00:03oool00`000000oooo0?oo
o`100?ooo`@00000203oool00`000000oooo0?ooo`090?ooo`<00000o`3oool[0?ooo`00:03oool0
0`000000oooo0?ooo`140?ooo`D000000`3oool00`000000oooo0?ooo`040?ooo`D00000o`3oool^
0?ooo`00:03oool00`000000oooo0?ooo`190?ooo`X00000o`3ooolc0?ooo`00:03oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo>03oool002P0oooo0`00001:0?ooo`030000
003oool0oooo0?l0oooo>@3oool002P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`3o0?ooocT0oooo000X0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooolj
0?ooo`00:03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo>P3oool002P0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oooc/0oooo000X0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00:03oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo0?l0oooo>`3oool002P0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`3o0?oooc`0oooo000X0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0o`3oooll0?ooo`00:03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0
oooo?@3oool002P0oooo0`0000160?ooo`030000003oool0oooo0?l0oooo?@3oool002P0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?oooch0oooo000X0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0?l0oooo?`3oool002P0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`3o0?ooocl0oooo000X0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
o`3ooom00?ooo`00:03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo@03o
ool002P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oood40oooo000X0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo@@3oool002P0oooo0`0000110?ooo`030000
003oool0oooo0?l0oooo@P3oool002P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3o0?oood80oooo000X0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooom3
0?ooo`00:03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo@`3oool002P0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oood@0oooo000X0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooom40?ooo`002`3oool01@3o_g@000000000
00000000M;oo00D0oooo00<0_g@000000000M;l01P3oool01@2oM00000000000000007@0_ooo00D0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooodD0oooo000;0?ooo`0609a8
M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`050?ooo`060=nLB000M;l0oooo
0?ooo`3o_g@007Bo1@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooA@3o
ool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d0000
M;oo0080oooo00<0oono07A8W03oool0103oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0?l0ooooAP3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?oo
o`070?noM000B4P0M01d0;ooo`3oool0gia8001d_`050?ooo`@00000?03oool00`000000oooo0?oo
o`3o0?ooodH0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool0
0`3ogi`0B4RL0?noM002000000030018W03oool0oooo00@0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`3o0?ooodL0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool02P3oool00`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0o`3ooom70?ooo`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00/0
oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0
ooooB03oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<0?ooo`030?oo_`1d000007Bo
00P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooodP0oooo000;0?ooo`05
0?oo_`1d000000000000B02Lgol03`3oool0102oM000000000000000B9`50?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00:03oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo0?l0ooooB@3oool002P0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`3o0?ooodX0oooo000X0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
o`3ooom:0?ooo`00:03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooB`3o
ool002P0oooo0`00000h0?ooo`030000003oool0oooo0?l0ooooB`3oool002P0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`3o0?oood`0oooo000X0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00:03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0?l0ooooC@3oool002P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`3o0?ooodd0oooo000X0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`00:03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooCP3oool002P0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?ooodl0oooo000X0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00:03oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0?l0ooooD03oool002P0oooo0`00000c0?ooo`030000003oool0
oooo0?l0ooooD03oool002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oo
oe40oooo000X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00
:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooDP3oool002P0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oooe80oooo000X0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00:03oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0?l0ooooD`3oool002P0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`3o0?oooe@0oooo000X0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
o`3ooomD0?ooo`00:03oool3000002h0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00:03oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`3o0?oooeH0oooo000X0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00:03oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0?l0ooooE`3oool002P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`3o0?oooeP0oooo000X0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooomH
0?ooo`002`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool0
1@2oM000000000000000000007Bo00H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`3o0?oooeT0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000
001d_`040?ooo`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool0103oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooF@3oool000X0oooo00<0okmd001d_`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0_g@007Boo`3oool0103o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooFP3oool000X0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?noM000B9`0oooo0080oooo00<0W4Q8
09cOo`3oool0103oool4000002L0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`002P3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia8000000000000000004RLg`06
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`002P3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07A8W03oool00P3oool00`2L
B7@0_ooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomL0?oo
o`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3o
ool00P3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0o`3ooomM0?ooo`002`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0omnL04P0
M02oool0oooo0?oOW01807@0_ooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`3o0?oooed0oooo000;0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000
000004P0W=oo00H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?oooeh0oooo
000X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00:03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooG`3oool002P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`3o0?ooof00oooo000X0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00:03oool300000280oooo00<000000?ooo`3oool0
o`3ooomQ0?ooo`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooHP3o
ool002P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooof80oooo000X0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00:03oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0ooooI03oool002P0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`3o0?ooof@0oooo000X0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0o`3ooomU0?ooo`00:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0?l0ooooIP3oool002P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oo
ofL0oooo000X0?ooo`<00000703oool00`000000oooo0?ooo`3o0?ooofL0oooo000X0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`00:03oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0?l0ooooJ@3oool002P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`3o0?ooofX0oooo000X0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0o`3ooom[0?ooo`00:03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0
ooooK03oool002P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooof`0oooo
000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`00:03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooKP3oool002P0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`3o0?ooofl0oooo000X0?ooo`<000004P3oool200000?l0
ooooLP3oool002P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooog80oooo
000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00:03oool0
0`000000oooo0?ooo`0>0?ooo`800000o`3ooomf0?ooo`00:03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0ooooMP3oool002P0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?ooogL0oooo000L0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`800000o`3ooomj0?ooo`007`3oool00`2LB4P0W=oo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`007`3oool0
0`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo00D0oooo1000003o0?ooogd0oooo000O0?oo
o`0309a8B02Lgol0oooo00H0oooo00@000000?ooo`3oool0oooo1000003o0?oooh40oooo000O0?oo
o`0309a8B02Lgol0oooo00H0oooo1000003o0?ooohD0oooo000O0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool0o`3ooon60?ooo`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`030000
003oool0oooo0?l0ooooQP3oool001`0oooo00D0gia800000000B9`0W4Q809cOo`070?ooo`030000
003oool0oooo0?l0ooooQP3oool001h0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?oo
o`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-1.07744, -0.294321, \
0.0394228, 0.00776442}}]
}, Closed]],

Cell["\<\
This is certainly an improvement, but it is still not as complete as we would \
like; for example, it does not provide explicit derivatives.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[sbessj[2, z], z]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["sbessj", 
        TagBox[\((0, 1)\),
          Derivative],
        MultilineFunction->None], "[", \(2, z\), "]"}]], "Output"]
}, Closed]],

Cell["An improved version will be developed later.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "Subsubsection"],

Cell[TextData[{
  "Write and plot a function whose values are ",
  Cell[BoxData[
      \(TraditionalForm\`1 - \[LeftBracketingBar]x\[RightBracketingBar]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[LessEqual] 1\)]],
  " or 0 for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[GreaterEqual] 1\)]],
  " without using Abs."
}], "Exercise"],

Cell[TextData[{
  "The double factorial function is defined for positive integers as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(dfact[n]\), "=", 
          RowBox[{\(n(n - 2)\), 
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CenterEllipsis]", 
                  StyleBox["n",
                    FontSlant->"Italic"]}]], "min"]}]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\_min = 1\)]],
  " for odd or ",
  Cell[BoxData[
      \(TraditionalForm\`n\_min = 2\)]],
  " for even integers.  Write a recursive version of this function using \
conditions that restrict the argument to positive integers.  Be sure to test \
the function.  [Hint: you can both specify the argument type and apply a \
condition to the argument.]"
}], "Exercise"],

Cell["\<\
Write a function which returns +1 for positive even integers, -1 for positive \
odd integers, or 0 for anything else using conditions (do not use If).  Be \
sure to test your function.  [Hint: the functions OddQ and EvenQ are \
helpful.]\
\>", "Exercise"],

Cell[TextData[{
  "Suppose that the earth is modelled by a sphere of uniform density with \
mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  Then, according to Newton's law of gravity, the gravitational force per \
unit mass, ",
  Cell[BoxData[
      \(TraditionalForm\`g(r)\)]],
  ", that acts on a body would be ",
  Cell[BoxData[
      \(TraditionalForm\`G\ M/r\^2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterEqual] R\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`G\ M\ r/R\^3\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[LessEqual] R\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " is the gravitational constant.  It is simplest to employ dimensionless \
units in which {G\[Rule]1,M\[Rule]1,R\[Rule]1}; for any particular case, the \
scale can be adjusted later by multiplying ",
  Cell[BoxData[
      \(TraditionalForm\`g(r)\)]],
  " by the surface gravity ",
  Cell[BoxData[
      \(TraditionalForm\`G\ M/R\^2\)]],
  ".  Write a function for ",
  Cell[BoxData[
      \(TraditionalForm\`g(r)\)]],
  " and plot it in dimensionless form."
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pattern tests", "Subsection",
  CellTags->"predicates"],

Cell[TextData[{
  "Some conditions are best applied using ",
  StyleBox["predicates",
    FontSlant->"Italic"],
  ", which are built-in functions which ask questions that can be answered as \
either ",
  StyleBox["True", "InlineInput"],
  " or ",
  StyleBox["False", "InlineInput"],
  ".  Most of these predicates have function names which end in ",
  StyleBox["Q", "InlineInput"],
  " for question.  A list of the available predicates is easily obtained, \
plus a few interlopers such as ",
  StyleBox["LegendreQ", "InlineInput"],
  " (the Legendre function of the second kind is usually designated ",
  Cell[BoxData[
      \(TraditionalForm\`Q\_n\)]],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?*Q\)\)], "Input"],

Cell[BoxData[GridBox[{
        {
          StyleBox["System`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["ArgumentCountQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`ArgumentCountQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["InexactNumberQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`InexactNumberQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["LowerCaseQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`LowerCaseQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["OddQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`OddQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["StringQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`StringQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["ArrayQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`ArrayQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["IntegerQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`IntegerQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["MachineNumberQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`MachineNumberQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["OptionQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`OptionQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["SyntaxQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`SyntaxQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["AtomQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`AtomQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["IntervalMemberQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`IntervalMemberQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["MatchLocalNameQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`MatchLocalNameQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["OrderedQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`OrderedQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["TensorQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`TensorQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["DigitQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`DigitQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["InverseEllipticNomeQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`InverseEllipticNomeQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["MatchQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`MatchQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["PartitionsQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`PartitionsQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["TrueQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`TrueQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["EllipticNomeQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`EllipticNomeQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["LegendreQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`LegendreQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["MatrixQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`MatrixQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["PolynomialQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`PolynomialQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["UnsameQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`UnsameQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["EvenQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`EvenQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["LetterQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`LetterQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["MemberQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`MemberQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["PrimeQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`PrimeQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["UpperCaseQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`UpperCaseQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["ExactNumberQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`ExactNumberQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["LinkConnectedQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`LinkConnectedQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["NameQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`NameQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["SameQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`SameQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["ValueQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`ValueQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["FreeQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`FreeQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["LinkReadyQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`LinkReadyQ"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["NumberQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`NumberQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["StringFreeQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`StringFreeQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["VectorQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`VectorQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"]},
              {
                ButtonBox[
                  StyleBox["HypergeometricPFQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`HypergeometricPFQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["ListQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`ListQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["NumericQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3312795623-2263216", "System`NumericQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], 
                ButtonBox[
                  StyleBox["StringMatchQ",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3312795623-2263216", 
                    "System`StringMatchQ"},
                  ButtonFrame->"None",
                  ButtonNote->"System`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell["Among these some of the most important are: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?IntegerQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"IntegerQ[expr] gives True if expr is an integer, and False \
otherwise.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"IntegerQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795629-5419543"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EvenQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"EvenQ[expr] gives True if expr is an even integer, and False \
otherwise.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"EvenQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795630-5419172"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?OddQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"OddQ[expr] gives True if expr is an odd integer, and False \
otherwise.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"OddQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795631-8819510"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NumberQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"NumberQ[expr] gives True if expr is a number, and False \
otherwise.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"NumberQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795632-7419729"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?NumericQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"NumericQ[expr] gives True if expr is a numeric quantity, and \
False otherwise.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"NumericQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795634-1579497"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?VectorQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"VectorQ[expr] gives True if expr is a list or a \
one-dimensional SparseArray object, none of whose elements are themselves \
lists, and gives False otherwise. VectorQ[expr, test] gives True only if test \
yields True when applied to each of the elements in expr.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"VectorQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795635-3734403"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?MatrixQ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"MatrixQ[expr] gives True if expr is a list of lists or a \
two-dimensional SparseArray object that can represent a matrix, and gives \
False otherwise. MatrixQ[expr, test] gives True only if test yields True when \
applied to each of the matrix elements in expr.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"MatrixQ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795638-6034247"]
}, Closed]],

Cell["\<\
Unfortunately, there are also several exceptions to the naming convention for \
predicates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Positive\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"Positive[x] gives True if x is a positive number.\"\>", " ", 
      
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Positive",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795644-9360992"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Negative\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"Negative[x] gives True if x is a negative number.\"\>", " ", 
      
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Negative",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312795645-4283247"]
}, Closed]],

Cell[TextData[{
  "Predicates are used to test arguments using the syntax ",
  StyleBox["x_?", "InlineInput"],
  StyleBox["predicate", "InlineInput"],
  ".  Note that in this context the question mark is interpreted as a ",
  ButtonBox["PatternTest",
    ButtonStyle->"RefGuideLink"],
  ", which should be distinguished from the ",
  StyleBox["information escape",
    FontSlant->"Italic"],
  " character, with the same appearance, used to obtain interactive help.  \
The information escape cannot be embedded in composite expressions, whereas \
the pattern test can be used in expressions liberally."
}], "Text"],

Cell["For example, the following function", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[x_?EvenQ] := \ x\^2;\)\), "\n", 
    \(f[x_?OddQ] := \ \(-x\^3\)\)}], "Input"],

Cell["is defined for integers", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[f[n], {n, \(-5\), 5}]\)], "Input"],

Cell[BoxData[
    \({125, 16, 27, 4, 1, 0, \(-1\), 4, \(-27\), 16, \(-125\)}\)], "Output"]
}, Closed]],

Cell["but is undefined for real numbers.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[1.5]\)], "Input"],

Cell[BoxData[
    \(f[1.5`]\)], "Output"]
}, Closed]],

Cell["A pattern test can be used with a type-specific pattern.", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\[IndentingNewLine]", 
    \(f[x_Integer?
          Positive] := "\<I am a positive integer\>"\), \
"\[IndentingNewLine]", 
    \(f[x_Integer?
          Negative] := "\<I am a negative integer\>"\), \
"\[IndentingNewLine]", 
    \(f[x_Real?
          Positive] := "\<I am a positive real number\>"\), "\
\[IndentingNewLine]", 
    \(f[x_Real?
          Negative] := "\<I am a negative real number\>"\), "\
\[IndentingNewLine]", 
    \(f[x_Symbol] := "\<I don't know what I am!\>"\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f /@ {q, 14, \(-27\), \[Pi], N[\[Pi]]}\)], "Input"],

Cell[BoxData[
    \({"I don't know what I am!", "I am a positive integer", 
      "I am a negative integer", "I don't know what I am!", 
      "I am a positive real number"}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "More generally, ",
  StyleBox["x_?test", "InlineInput"],
  " is used to test a pattern using a pure function that returns either ",
  StyleBox["True", "InlineInput"],
  " or ",
  StyleBox["False", "InlineInput"],
  " when presented with an argument.  Several tests can be combined using \
logical operators.  For example, the following function is defined only for \
arguments which are positive prime numbers."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f, x];\)\), "\n", 
    \(f[x_?\((PrimeQ[#]\  && \ Positive[#] &)\)]\  := \ 1\/x\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f /@ {\(-4\), \(-3\), x, 16, 17, "\<stuff\>"}\)], "Input"],

Cell[BoxData[
    \({f[\(-4\)], f[\(-3\)], f[x], f[16], 1\/17, f["stuff"]}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "The construction ",
  StyleBox["x_?(\[CenterEllipsis]", "InlineInput"],
  StyleBox[")", "InlineInput",
    FontWeight->"Bold"],
  " indicates that the pattern ",
  StyleBox["x_", "InlineInput"],
  " is tested using the function contained within the parentheses.  The \
function is composed of two logical functions connected by a logical \
operator, in this case ",
  StyleBox["And", "InlineInput"],
  " or ",
  StyleBox["&&", "InlineInput"],
  ", to make a single logical function.  Our composite logical function \
receives a single argument in its slot, ",
  StyleBox["#", "InlineInput",
    FontWeight->"Bold"],
  ", and is identified as a pure function by the ",
  StyleBox["&", "InlineInput"],
  " operator.  The parentheses are needed with skeletal notation to identify \
the beginning and end of the pure function.  The same effect could have been \
achieved by defining the test using ",
  StyleBox["Function[var,body]", "InlineInput"],
  " instead."
}], "Text"],

Cell["\<\
Rewrite the function above using conditionals instead of a pattern test.\
\>", "Exercise"],

Cell["\<\
Write a recursive factorial function which only responds to arguments which \
are nonnegative integers.  Why are these restrictions necessary?\
\>", "Exercise"],

Cell["\<\
Write a recursive double factorial function for nonnegative integers using a \
pattern test.\
\>", "Exercise"],

Cell[CellGroupData[{

Cell["Example: a function which tests orthogonality", "Subsubsection"],

Cell[TextData[{
  "For example, suppose that we need a function that tests for the \
orthogonality of a matrix.  A matrix is orthogonal if when multiplied by its \
transpose an identity matrix is obtained.  Since orthogonality is meaningless \
for other objects, we use the predicate ",
  StyleBox["MatrixQ", "InlineInput"],
  " to restrict the definition to matrices.  We verify that the matrix is \
square using ",
  ButtonBox["Dimensions",
    ButtonStyle->"RefGuideLink"],
  " and compare the product with its transpose to the identity matrix of the \
same length.  "
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear[testOrthogonality];\)\(\n\)
    \)\), "\n", 
    \(\(testOrthogonality[matrix_?MatrixQ] := 
        MatchQ[Dimensions[matrix], {x_, x_}]\  && \ 
          matrix\  . \ Transpose[matrix] \[Equal] 
            IdentityMatrix[Length[matrix]];\)\n\), "\n", 
    \(testOrthogonality[x_?NumericQ]\  := \ x\^2 \[Equal] 1\)}], "Input"],

Cell["\<\
In the following cases our function successfully identifies a manifestly \
orthogonal matrix, rejects a matrix that is not square, and does not venture \
a guess about a symbol of uncertain character.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(testOrthogonality[{{1\/\@2, 1\/\@2}, {\(-\(1\/\@2\)\), 
          1\/\@2}}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(testOrthogonality[{{1\/\@2, 1\/\@2, 0}, {\(-\(1\/\@2\)\), 1\/\@2, 
          1}}]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(testOrthogonality[x]\)], "Input"],

Cell[BoxData[
    \(testOrthogonality[x]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "We also included a definition to handle expressions which evaluate to \
numbers, using ",
  StyleBox["NumericQ", "InlineInput"],
  " rather than ",
  StyleBox["NumberQ", "InlineInput"],
  ".  (Convince yourself that ",
  StyleBox["NumberQ", "InlineInput"],
  " is not up to the task!)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(testOrthogonality /@ {1, 2, \(-1\), \ I, \ \(1\/\@2\) \((1 + I)\), \ 
        Cos[0], Cos[0.25]}\)], "Input"],

Cell[BoxData[
    \({True, False, True, False, False, True, False}\)], "Output"]
}, Closed]],

Cell["A slightly more difficult case:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"testOrthogonality", "@", 
      TagBox[
        RowBox[{"(", GridBox[{
              {\(1\/3\), \(\(2\ \@2\)\/3\), "0"},
              {\(2\/3\), \(-\(1\/\(3\ \@2\)\)\), \(1\/\@2\)},
              {\(-\(2\/3\)\), \(1\/\(3\ \@2\)\), \(1\/\@2\)}
              }], ")"}],
        (MatrixForm[ #]&)]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Closed]],

Cell["\<\
Unfortunately, this version does not work well with matrices that contain \
approximate real numbers \[LongDash] we can use Equal with exact numbers but \
for approximate numbers the most we can expect is that the matrix times its \
transpose produces an identity matrix within some small but finite tolerance. \
 Check that if we use N to convert the above matrix to real numbers that the \
simple orthogonality test fails.  Then write an improved version that handles \
approximate numbers correctly.  [Hint: test the discrepancy with the largest \
absolute value.]\
\>", "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Arguments matching a specialized pattern", "Subsection",
  CellTags->"arguments matching patterns"],

Cell[TextData[{
  "Suppose that we need a function that acts upon data only of a specialized \
pattern, such as a list of pairs.  The basic syntax is ",
  StyleBox["x:", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["pattern", "InlineInput",
    FontWeight->"Bold"],
  " where ",
  StyleBox["x", "InlineInput"],
  " is the name used on the rhs of the definition to refer to the pattern and \
",
  StyleBox["pattern", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "is one of the many types of patterns recognized by ",
  StyleBox["Mathematica.  ",
    FontSlant->"Italic"],
  "For example, the function"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f[pairs : {{_?NumericQ, _} .. }]\  := \ 
      Sort[pairs, \ #2\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[GreaterEqual] #1\[LeftDoubleBracket]1\[RightDoubleBracket] &]\)}], "Input"],

Cell[TextData[{
  "sorts a list of pairs in order of increasing first elements.  ",
  ButtonBox["Sort",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[list,test]", "InlineInput"],
  " sorts a ",
  StyleBox["list", "InlineInput"],
  " using a logical function ",
  StyleBox["test", "InlineInput"],
  " to test the ordering of pairs of neighboring elements.  Our test employs \
an anonymous function with skeletal notation.  We used the part specification \
",
  StyleBox["\[LeftDoubleBracket]1\[RightDoubleBracket]", "InlineInput"],
  " to extract the first elements of each pair in the list and the logical \
operator ",
  StyleBox["\[GreaterEqual]", "InlineInput"],
  " to compare successive pairs that fill the two slots ",
  StyleBox["#1", "InlineInput"],
  " and ",
  StyleBox["#2", "InlineInput"],
  " in that anonymous function.  ",
  StyleBox["Sort", "InlineInput"],
  " then arranges the elements of the list to ensure that the test applied to \
neighboring elements of the output list is ",
  StyleBox["True", "InlineInput"],
  " for all neighbors.  The pattern contains two sets of curly brackets to \
describe a list of lists, with ",
  StyleBox["..", "InlineInput"],
  " indicating one or more repetitions of the inner pattern.  The inner \
pattern describes a pair whose first element in numerical (according to the \
pattern test) while the second element is arbitrary (a blank pattern)."
}], "Text"],

Cell["\<\
Thus, this function successfully orders a list in which all first elements of \
each pair are numerical expressions\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x, y];\)\), "\n", 
    \(f[{{1, 2}, {\(-1\), x}, {\(-4\), y}, {12, 3}, {Cos[0.2], 
          Sin[0.2]}}]\)}], "Input"],

Cell[BoxData[
    \({{\(-4\), y}, {\(-1\), x}, {0.9800665778412416`, 
        0.19866933079506122`}, {1, 2}, {12, 3}}\)], "Output"]
}, Closed]],

Cell["\<\
but does nothing when one or more of the first elements of a pair cannot be \
tested properly\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[a, b];\)\), "\n", 
    \(f[{{1, 2}, {\(-1\), x}, {a, b}, {\(-4\), y}, {12, 3}}]\)}], "Input"],

Cell[BoxData[
    \(f[{{1, 2}, {\(-1\), x}, {a, b}, {\(-4\), y}, {12, 3}}]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "because we used a pattern ",
  StyleBox["{{_?NumericQ,_}..}", "InlineInput"],
  " that required each first element to be numerical.  Of course, we could \
add other definitions to handle other patterns as needed."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides a very flexible language for describing an almost limitless \
variety of patterns.  For more information about using patterns, refer to ",
  StyleBox[ButtonBox["expressions.nb",
    ButtonData:>{"Primary topics/expressions.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".  Click here for a table of ",
  ButtonBox["pattern templates",
    ButtonData:>{"Primary topics/expressions.nb", "pattern templates"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell["\<\
Write a function which arranges a list of pairs in order of decreasing second \
elements.\
\>", "Exercise"],

Cell["\<\
Write a function which arranges a list of sublists in order of decreasing \
second elements, requiring only that the sublists have two or more elements \
with the second being numeric.\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Overlapping definitions", "Subsection",
  CellTags->"overlapping definitions"],

Cell[TextData[{
  "Earlier we warned about possible ambiguities that might be encountered if \
a function has several definitions which might overlap or conflict with each \
other.  Under those circumstances, which rules take precedence?  The general \
rule is to look for matching patterns beginning with the most specific \
definition and proceeding to more general definitions if needed.  If two \
definitions are judged equally specific, the first is used.  However, as \
noted by Tam, ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s notions of generality are often inscrutable. "
}], "Text"],

Cell["\<\
Consider, for example, the following functions discussed by Tam.  These \
functions appear to differ only in the order their definitions are given.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[x_Integer]\  := \ x\^2;\)\), "\n", 
    \(\(f[x_Integer?Positive]\  := \ 1/x;\)\), "\n", 
    \(f[x_Integer\  /; \ x > 50]\  := \ \(-x\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[g];\)\), "\n", 
    \(\(g[x_Integer?Positive]\  := \ 1/x;\)\), "\n", 
    \(\(g[x_Integer\  /; \ x > 50]\  := \ \(-x\);\)\), "\n", 
    \(g[x_Integer]\  := \ x\^2\)}], "Input"],

Cell[TextData[{
  "If the argument has the value 60, is a \"positive integer\" more specific \
than \"integer > 50\"?  Surely both of those tests are more specific than \
\"any integer\", yet ",
  StyleBox["f", "InlineInput"],
  " uses the definition for any integer while ",
  StyleBox["g", "InlineInput"],
  " uses the definition for positive integer without questioning its size.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[60], g[60]}\)], "Input"],

Cell[BoxData[
    \({3600, 1\/60}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Apparently ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " did not distinguish specificity but used only order.  However, we do not \
consider this observation to be robust and strongly recommend that function \
definitions should only involve compatible or nonoverlapping conditions."
}], "Text"],

Cell["\<\
Warning: use incompatible overlapping definitions only with extreme \
caution!\
\>", "Caution"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Protection of local variables", "Section",
  CellTags->"protection of local variables"],

Cell[CellGroupData[{

Cell["Need for scoping ", "Subsection"],

Cell["\<\
Protection of local variables is often crucial to the proper operation of a \
function.  The following example is discussed by Bahder.  Consider a function \
defined in terms of an integral.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[h, x, y];\)\), "\n", 
    \(h[x_]\  := \ Integrate[Sin[x + y], {y, 0, \[Pi]}]\)}], "Input"],

Cell["This definition works under many circumstances,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[x]\)], "Input"],

Cell[BoxData[
    \(2\ Cos[x]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[2]\)], "Input"],

Cell[BoxData[
    \(2\ Cos[2]\)], "Output"]
}, Closed]],

Cell["\<\
but fails when the argument conflicts with the dummy variable of \
integration\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[y]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell[TextData[{
  "As revealed by using ",
  StyleBox["Trace", "InlineInput"],
  " to follow the evaluation of the expression ",
  StyleBox["h[y]", "InlineInput"],
  ","
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Trace[\ h[y]\ ]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(h[y]\),
          HoldForm], ",", 
        TagBox[\(\[Integral]\_0\%\[Pi] Sin[y + y] \[DifferentialD]y\),
          HoldForm], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                TagBox[\(y + y\),
                  HoldForm], ",", 
                TagBox[\(2\ y\),
                  HoldForm]}], "}"}], ",", 
            TagBox[\(Sin[2\ y]\),
              HoldForm]}], "}"}], ",", 
        TagBox[\(\[Integral]\_0\%\[Pi] Sin[2\ y] \[DifferentialD]y\),
          HoldForm], ",", 
        TagBox["0",
          HoldForm]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "the problem arises when ",
  StyleBox["y", "InlineInput"],
  " replaces the pattern ",
  StyleBox["x_", "InlineInput"],
  " too early in the evaluation sequence and is confused with the integration \
variable.  One solution is to use ",
  StyleBox["Module", "InlineInput"],
  " to protect the dummy variable.  The ",
  ButtonBox["Module",
    ButtonStyle->"RefGuideLink"],
  " command provides a method for encapsulating a sequence of commands \
together with a declaration of local variables.  The basic syntax is ",
  StyleBox["Module[{vars},body]", "InlineInput"],
  " where ",
  StyleBox["{vars}", "InlineInput"],
  " is a list of local variables and ",
  StyleBox["body", "InlineInput"],
  " is the body of the function consisting of a sequence of commands \
separated by semicolons.  The final result is the output of the last \
statement, provided that it is not terminated by a semicolon.  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[h, x, y];\)\), "\n", 
    \(h[x_]\  := \ 
      Module[{y}, \ Integrate[Sin[x + y], {y, 0, \[Pi]}]\ ]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[y]\)], "Input"],

Cell[BoxData[
    \(2\ Cos[y]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "This method works because the local variable is given a unique tag each \
time that ",
  StyleBox["Module", "InlineInput"],
  " is evaluated so that its local name will not conflict with any symbols \
that exist outside of that ",
  StyleBox["Module", "InlineInput"],
  ".  The basic concept of restricting the definition of symbols to limited \
parts of a code is known as ",
  StyleBox["scoping",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["scope",
    FontSlant->"Italic"],
  " of a variable is the range of code wherein it is defined.  Symbols with \
the same names can be used for different purposes if their scopes do not \
overlap. "
}], "Text"],

Cell["\<\
Advice: using scoping constructions (Module, With, or Block) to protect local \
variables and to minimize proliferation of unnecessary symbols.\
\>", "Advice"],

Cell[TextData[{
  "Define a function f[n_]:=",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%n a\_k\)]],
  ".  Show that a scoping command, such as Module, is needed to protect the \
summation index.  Evaluate and interpret: a) f[n], b) f[k], c) f[10]-f[3]."
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Method for scoping", "Subsection"],

Cell[TextData[{
  "Every time ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluates a module, it creates new symbols by attaching a unique tag to \
the symbol for each local variable, such that the local variable ",
  StyleBox["var", "InlineInput"],
  " is represented by the symbol ",
  StyleBox["var$nnn", "InlineInput"],
  " where ",
  StyleBox["nnn", "InlineInput"],
  " is the current value of the system variable ",
  ButtonBox["$ModuleNumber",
    ButtonStyle->"RefGuideLink"],
  ".  ",
  StyleBox["$ModuleNumber", "InlineInput"],
  " is incremented every time that a ",
  StyleBox["Module", "InlineInput"],
  " is evaluated to ensure that the local variables are unique and will not \
conflict with any global symbols."
}], "Text"],

Cell["\<\
What is the current value of $ModuleNumber?  Evaluate a Module statement from \
the previous section and check the new value of $ModuleNumber.\
\>", "Exercise"],

Cell[TextData[{
  "We can peek at the operation of ",
  StyleBox["Module", "InlineInput"],
  " using ",
  StyleBox["Trace", "InlineInput"],
  ".  Upon evaluation of the following statement"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Trace[\ h[y]\ ]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(h[y]\),
          HoldForm], ",", 
        TagBox[\(Module[{y$}, \[Integral]\_0\%\[Pi] Sin[
                  y + y$] \[DifferentialD]y$]\),
          HoldForm], ",", 
        RowBox[{"{", 
          RowBox[{
            
            TagBox[\(\[Integral]\_0\%\[Pi] Sin[
                    y + y$220] \[DifferentialD]y$220\),
              HoldForm], ",", 
            TagBox[\(2\ Cos[y]\),
              HoldForm]}], "}"}], ",", 
        TagBox[\(2\ Cos[y]\),
          HoldForm]}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "you should see an output in which the ",
  StyleBox["{y}", "InlineInput"],
  " used to declare ",
  StyleBox["y",
    FontSlant->"Italic"],
  " as a local variable is replaced by ",
  StyleBox["{y$}", "InlineInput"],
  " and later the evaluation of the integral features both ",
  StyleBox["y", "InlineInput"],
  " and ",
  StyleBox["y$nnn", "InlineInput"],
  " where ",
  StyleBox["nnn", "InlineInput"],
  " is the current value of ",
  StyleBox["$ModuleNumber", "InlineInput"],
  ".  Thus, there is no confusion between the global symbol ",
  StyleBox["y", "InlineInput"],
  " used as an argument and the local symbol ",
  StyleBox["y$nnn", "InlineInput"],
  " used as a dummy variable of integration.  "
}], "Text"],

Cell[TextData[{
  "Sometimes one sees the symbols for local variables in an error message.  \
Alternatively, you can also access these symbols if you know the appropriate \
tag number.  For example, the following module resets the seed employed by \
the random number generator using the number of seconds between 1900 and the \
present, rounded to an integer.  Using ",
  StyleBox["Trace", "InlineInput"],
  " we can learn the symbol assigned to the local variable and then determine \
its value even though ",
  StyleBox["Module", "InlineInput"],
  " attempts to hide local variables."
}], "Text"],

Cell["\<\
Evaluate the following statement and then determine the seed used.\
\>", "Exercise"],

Cell[BoxData[
    \(Trace[\ 
      Module[{seconds}, seconds = Round[\ AbsoluteTime[]\ ]; 
        SeedRandom[seconds]; Random[]]\ ]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Modular programming", "Section",
  CellTags->"modular programing"],

Cell[TextData[{
  "Well-written programs tend to be modular, with each module receiving a \
limited amount of input, performing a specific task, and returning clearly \
defined results.  The internal programming of each module should be complete \
enough to cover all special cases and contingencies, thereby producing \
accurate results for valid input or complaining to the user about invalid \
input.  The modules should also contain enough documentation to be readable \
by an informed user without requiring human compilation of computer code.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides several constructions which serve these purposes."
}], "Text"],

Cell[CellGroupData[{

Cell["Scoping commands", "Subsection",
  CellTags->"scoping commands"],

Cell["\<\
Several methods are available and the most important differences between \
these methods concern the treatment of local variables.  Scoping commands may \
be nested, with scoping rules applied from the inside out.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Module", "Subsubsection",
  CellTags->"Module"],

Cell[TextData[{
  "The ",
  ButtonBox["Module",
    ButtonStyle->"RefGuideLink"],
  " command provides a method for encapsulating a sequence of commands \
together with declaration of local variables.  The basic syntax is ",
  StyleBox["Module[{vars},body]", "InlineInput"],
  " where ",
  StyleBox["{vars}", "InlineInput"],
  " is a list of local variables and ",
  StyleBox["body", "InlineInput"],
  " is the body of the function consisting of a sequence of commands \
separated by semicolons.  The final result is the output of the last \
statement, provided that it is not terminated by a semicolon.  Alternatively, \
",
  ButtonBox["Return",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[expr]", "InlineInput"],
  " can be used to return an expression."
}], "Text"],

Cell[TextData[{
  "Local variables can be given initial values using the syntax ",
  StyleBox["Module[{", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x = x\_0\)], "InlineInput"], "InlineInput"],
  StyleBox[",\[CenterEllipsis]},body]", "InlineInput"],
  " where any variable in the local list can be initialized or not.  The \
initial values can be numerical, symbolic, or the result of evaluating a \
function.  However, for best results the initial values should be based only \
upon constants or explicit arguments \[LongDash] avoid using global symbols \
in the initialization section of ",
  StyleBox["Module", "InlineInput"],
  "."
}], "Text"],

Cell[TextData[{
  "The following example takes an electrostatic potential \[Phi] and displays \
its electric field and equipotential lines in two dimensions.  The electric \
field is evaluated by forming the gradient of the potential in the \
initialization part of the module.  Two plots are constructed as local \
variables but are not displayed until the final statement, where ",
  StyleBox["Show", "InlineInput"],
  " combines them into a single figure.  "
}], "Text"],

Cell[BoxData[
    \(\(Needs["\<Graphics`PlotField`\>"];\)\)], "Input"],

Cell[BoxData[
    \(plot[\[Phi]_] := 
      Module[{Efield = \(-{D[\[Phi], x], D[\[Phi], y]}\), plot1, plot2}, 
        plot1 = ContourPlot[\[Phi], {x, \(-2\), 2}, {y, \(-2\), 2}, 
            ContourShading \[Rule] False, DisplayFunction \[Rule] Identity]; 
        plot2 = PlotVectorField[Efield, {x, \(-2\), 2}, {y, \(-2\), 2}, 
            MaxArrowLength \[Rule] 1, ScaleFactor \[Rule] None, 
            DisplayFunction \[Rule] Identity]; 
        Show[plot1, plot2, 
          DisplayFunction \[Rule] $DisplayFunction];]\)], "Input"],

Cell["\<\
We test the function using a simple dipole field.  To avoid confusing \
clutter, the strong fields near the point charges are not displayed.  Fancier \
versions of this function might include additional variables for the plotting \
ranges and options for the plotting commands that could be used to improve \
the display, but such embellishments are beyond the scope of the present \
discussion.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi] = 
        1\/\@\(x\^2 + \((y - 0.5)\)\^2\) - 
          1\/\@\(x\^2 + \((y + 0.5)\)\^2\);\)\), "\n", 
    \(\(plot[\[Phi]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.226717 0.46478 0.220485 [
[.04657 -0.0125 -6 -9 ]
[.04657 -0.0125 6 0 ]
[.27328 -0.0125 -6 -9 ]
[.27328 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.72672 -0.0125 -3 -9 ]
[.72672 -0.0125 3 0 ]
[.95343 -0.0125 -3 -9 ]
[.95343 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .24429 -12 -4.5 ]
[-0.0125 .24429 0 4.5 ]
[-0.0125 .46478 -6 -4.5 ]
[-0.0125 .46478 0 4.5 ]
[-0.0125 .68527 -6 -4.5 ]
[-0.0125 .68527 0 4.5 ]
[-0.0125 .90575 -6 -4.5 ]
[-0.0125 .90575 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04657 0 m
.04657 .00625 L
s
[(-2)] .04657 -0.0125 0 1 Mshowa
.27328 0 m
.27328 .00625 L
s
[(-1)] .27328 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.72672 0 m
.72672 .00625 L
s
[(1)] .72672 -0.0125 0 1 Mshowa
.95343 0 m
.95343 .00625 L
s
[(2)] .95343 -0.0125 0 1 Mshowa
.125 Mabswid
.09191 0 m
.09191 .00375 L
s
.13725 0 m
.13725 .00375 L
s
.1826 0 m
.1826 .00375 L
s
.22794 0 m
.22794 .00375 L
s
.31863 0 m
.31863 .00375 L
s
.36397 0 m
.36397 .00375 L
s
.40931 0 m
.40931 .00375 L
s
.45466 0 m
.45466 .00375 L
s
.54534 0 m
.54534 .00375 L
s
.59069 0 m
.59069 .00375 L
s
.63603 0 m
.63603 .00375 L
s
.68137 0 m
.68137 .00375 L
s
.77206 0 m
.77206 .00375 L
s
.8174 0 m
.8174 .00375 L
s
.86275 0 m
.86275 .00375 L
s
.90809 0 m
.90809 .00375 L
s
.00122 0 m
.00122 .00375 L
s
.99878 0 m
.99878 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-2)] -0.0125 .02381 1 0 Mshowa
0 .24429 m
.00625 .24429 L
s
[(-1)] -0.0125 .24429 1 0 Mshowa
0 .46478 m
.00625 .46478 L
s
[(0)] -0.0125 .46478 1 0 Mshowa
0 .68527 m
.00625 .68527 L
s
[(1)] -0.0125 .68527 1 0 Mshowa
0 .90575 m
.00625 .90575 L
s
[(2)] -0.0125 .90575 1 0 Mshowa
.125 Mabswid
0 .06791 m
.00375 .06791 L
s
0 .112 m
.00375 .112 L
s
0 .1561 m
.00375 .1561 L
s
0 .2002 m
.00375 .2002 L
s
0 .28839 m
.00375 .28839 L
s
0 .33249 m
.00375 .33249 L
s
0 .37659 m
.00375 .37659 L
s
0 .42068 m
.00375 .42068 L
s
0 .50888 m
.00375 .50888 L
s
0 .55297 m
.00375 .55297 L
s
0 .59707 m
.00375 .59707 L
s
0 .64117 m
.00375 .64117 L
s
0 .72936 m
.00375 .72936 L
s
0 .77346 m
.00375 .77346 L
s
0 .81756 m
.00375 .81756 L
s
0 .86165 m
.00375 .86165 L
s
0 .94985 m
.00375 .94985 L
s
0 .99395 m
.00375 .99395 L
s
.25 Mabswid
0 0 m
0 1 L
s
.04657 .99375 m
.04657 1 L
s
.27328 .99375 m
.27328 1 L
s
.5 .99375 m
.5 1 L
s
.72672 .99375 m
.72672 1 L
s
.95343 .99375 m
.95343 1 L
s
.125 Mabswid
.09191 .99625 m
.09191 1 L
s
.13725 .99625 m
.13725 1 L
s
.1826 .99625 m
.1826 1 L
s
.22794 .99625 m
.22794 1 L
s
.31863 .99625 m
.31863 1 L
s
.36397 .99625 m
.36397 1 L
s
.40931 .99625 m
.40931 1 L
s
.45466 .99625 m
.45466 1 L
s
.54534 .99625 m
.54534 1 L
s
.59069 .99625 m
.59069 1 L
s
.63603 .99625 m
.63603 1 L
s
.68137 .99625 m
.68137 1 L
s
.77206 .99625 m
.77206 1 L
s
.8174 .99625 m
.8174 1 L
s
.86275 .99625 m
.86275 1 L
s
.90809 .99625 m
.90809 1 L
s
.00122 .99625 m
.00122 1 L
s
.99878 .99625 m
.99878 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .24429 m
1 .24429 L
s
.99375 .46478 m
1 .46478 L
s
.99375 .68527 m
1 .68527 L
s
.99375 .90575 m
1 .90575 L
s
.125 Mabswid
.99625 .06791 m
1 .06791 L
s
.99625 .112 m
1 .112 L
s
.99625 .1561 m
1 .1561 L
s
.99625 .2002 m
1 .2002 L
s
.99625 .28839 m
1 .28839 L
s
.99625 .33249 m
1 .33249 L
s
.99625 .37659 m
1 .37659 L
s
.99625 .42068 m
1 .42068 L
s
.99625 .50888 m
1 .50888 L
s
.99625 .55297 m
1 .55297 L
s
.99625 .59707 m
1 .59707 L
s
.99625 .64117 m
1 .64117 L
s
.99625 .72936 m
1 .72936 L
s
.99625 .77346 m
1 .77346 L
s
.99625 .81756 m
1 .81756 L
s
.99625 .86165 m
1 .86165 L
s
.99625 .94985 m
1 .94985 L
s
.99625 .99395 m
1 .99395 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.46221 .49761 m
.5 .49365 L
.53779 .49761 L
.55073 .50153 L
.57557 .51409 L
.59697 .53828 L
.61336 .57067 L
.61427 .57502 L
.61474 .61177 L
.61336 .6191 L
.60053 .64852 L
.57557 .67675 L
.56691 .68527 L
.53779 .69665 L
.5 .70241 L
.46221 .69665 L
.43309 .68527 L
.42443 .67675 L
.39947 .64852 L
.38664 .6191 L
.38526 .61177 L
.38573 .57502 L
.38664 .57067 L
.40303 .53828 L
.42443 .51409 L
.44927 .50153 L
.46221 .49761 L
s
.46221 .49062 m
.5 .4883 L
.53779 .49062 L
.56991 .50153 L
.57557 .50419 L
.61336 .53562 L
.61486 .53828 L
.63157 .57502 L
.6351 .61177 L
.62619 .64852 L
.61336 .67215 L
.60233 .68527 L
.57557 .70686 L
.54529 .72201 L
.53779 .72348 L
.5 .72829 L
.46221 .72348 L
.45471 .72201 L
.42443 .70686 L
.39767 .68527 L
.38664 .67215 L
.37381 .64852 L
.3649 .61177 L
.36843 .57502 L
.38514 .53828 L
.38664 .53562 L
.42443 .50419 L
.43009 .50153 L
.46221 .49062 L
s
.42443 .4933 m
.46221 .48339 L
.5 .4823 L
.53779 .48339 L
.57557 .4933 L
.59333 .50153 L
.61336 .51205 L
.63857 .53828 L
.65114 .55652 L
.6588 .57502 L
.66566 .61177 L
.6622 .64852 L
.65114 .6807 L
.64801 .68527 L
.61948 .72201 L
.61336 .72751 L
.57557 .752 L
.56521 .75876 L
.53779 .76482 L
.5 .7688 L
.46221 .76482 L
.43479 .75876 L
.42443 .752 L
.38664 .72751 L
.38052 .72201 L
.35199 .68527 L
.34886 .6807 L
.3378 .64852 L
.33434 .61177 L
.3412 .57502 L
.34886 .55652 L
.36143 .53828 L
.38664 .51205 L
.40667 .50153 L
.42443 .4933 L
s
.38664 .4932 m
.42443 .48191 L
.46221 .47601 L
.5 .47565 L
.53779 .47601 L
.57557 .48191 L
.61336 .4932 L
.63067 .50153 L
.65114 .51232 L
.67983 .53828 L
.68893 .54607 L
.70488 .57502 L
.71793 .61177 L
.72174 .64852 L
.71738 .68527 L
.7049 .72201 L
.68893 .75048 L
.68296 .75876 L
.65114 .79243 L
.64749 .79551 L
.61336 .81833 L
.58331 .83226 L
.57557 .83482 L
.53779 .844 L
.5 .84697 L
.46221 .844 L
.42443 .83482 L
.41669 .83226 L
.38664 .81833 L
.35251 .79551 L
.34886 .79243 L
.31704 .75876 L
.31107 .75048 L
.2951 .72201 L
.28262 .68527 L
.27826 .64852 L
.28207 .61177 L
.29512 .57502 L
.31107 .54607 L
.32017 .53828 L
.34886 .51232 L
.36933 .50153 L
.38664 .4932 L
s
.85806 .90575 m
.87527 .869 L
.87786 .86241 L
.88735 .83226 L
.8947 .79551 L
.89745 .75876 L
.89553 .72201 L
.88868 .68527 L
.87786 .65103 L
.87637 .64852 L
.85726 .61177 L
.84008 .58667 L
.82967 .57502 L
.80229 .54819 L
.78904 .53828 L
.7645 .52167 L
.72672 .5029 L
.72315 .50153 L
.68893 .48943 L
.65114 .48014 L
.61336 .47411 L
.57557 .47049 L
.53779 .46854 L
.5 .46847 L
.46221 .46854 L
.42443 .47049 L
.38664 .47411 L
.34886 .48014 L
.31107 .48943 L
.27685 .50153 L
.27328 .5029 L
.2355 .52167 L
.21096 .53828 L
.19771 .54819 L
.17033 .57502 L
.15992 .58667 L
.14274 .61177 L
.12363 .64852 L
.12214 .65103 L
.11132 .68527 L
.10447 .72201 L
.10255 .75876 L
.1053 .79551 L
.11265 .83226 L
.12214 .86241 L
.12473 .869 L
.14194 .90575 L
s
.85806 .02381 m
.87527 .06056 L
.87786 .06715 L
.88735 .0973 L
.8947 .13405 L
.89745 .1708 L
.89553 .20755 L
.88868 .24429 L
.87786 .27854 L
.87637 .28104 L
.85726 .31779 L
.84008 .34289 L
.82967 .35454 L
.80229 .38137 L
.78904 .39129 L
.7645 .40789 L
.72672 .42666 L
.72315 .42803 L
.68893 .44013 L
.65114 .44942 L
.61336 .45545 L
.57557 .45907 L
.53779 .46103 L
.5 .46109 L
.46221 .46103 L
.42443 .45907 L
.38664 .45545 L
.34886 .44942 L
.31107 .44013 L
.27685 .42803 L
.27328 .42666 L
.2355 .40789 L
.21096 .39129 L
.19771 .38137 L
.17033 .35454 L
.15992 .34289 L
.14274 .31779 L
.12363 .28104 L
.12214 .27854 L
.11132 .24429 L
.10447 .20755 L
.10255 .1708 L
.1053 .13405 L
.11265 .0973 L
.12214 .06715 L
.12473 .06056 L
.14194 .02381 L
s
.42443 .09474 m
.46221 .08556 L
.5 .08259 L
.53779 .08556 L
.57557 .09474 L
.58331 .0973 L
.61336 .11123 L
.64749 .13405 L
.65114 .13713 L
.68296 .1708 L
.68893 .17908 L
.7049 .20755 L
.71738 .24429 L
.72174 .28104 L
.71793 .31779 L
.70488 .35454 L
.68893 .38349 L
.67983 .39129 L
.65114 .41724 L
.63067 .42803 L
.61336 .43636 L
.57557 .44765 L
.53779 .45355 L
.5 .45391 L
.46221 .45355 L
.42443 .44765 L
.38664 .43636 L
.36933 .42803 L
.34886 .41724 L
.32017 .39129 L
.31107 .38349 L
.29512 .35454 L
.28207 .31779 L
.27826 .28104 L
.28262 .24429 L
.2951 .20755 L
.31107 .17908 L
.31704 .1708 L
.34886 .13713 L
.35251 .13405 L
.38664 .11123 L
.41669 .0973 L
.42443 .09474 L
s
.46221 .16474 m
.5 .16076 L
.53779 .16474 L
.56521 .1708 L
.57557 .17756 L
.61336 .20205 L
.61948 .20755 L
.64801 .24429 L
.65114 .24886 L
.6622 .28104 L
.66566 .31779 L
.6588 .35454 L
.65114 .37304 L
.63857 .39129 L
.61336 .41751 L
.59333 .42803 L
.57557 .43626 L
.53779 .44617 L
.5 .44726 L
.46221 .44617 L
.42443 .43626 L
.40667 .42803 L
.38664 .41751 L
.36143 .39129 L
.34886 .37304 L
.3412 .35454 L
.33434 .31779 L
.3378 .28104 L
.34886 .24886 L
.35199 .24429 L
.38052 .20755 L
.38664 .20205 L
.42443 .17756 L
.43479 .1708 L
.46221 .16474 L
s
.46221 .20608 m
.5 .20127 L
.53779 .20608 L
.54529 .20755 L
.57557 .2227 L
.60233 .24429 L
.61336 .25742 L
.62619 .28104 L
.6351 .31779 L
.63157 .35454 L
.61486 .39129 L
.61336 .39394 L
.57557 .42538 L
.56991 .42803 L
.53779 .43894 L
.5 .44126 L
.46221 .43894 L
.43009 .42803 L
.42443 .42538 L
.38664 .39394 L
.38514 .39129 L
.36843 .35454 L
.3649 .31779 L
.37381 .28104 L
.38664 .25742 L
.39767 .24429 L
.42443 .2227 L
.45471 .20755 L
.46221 .20608 L
s
.46221 .23291 m
.5 .22715 L
.53779 .23291 L
.56691 .24429 L
.57557 .25281 L
.60053 .28104 L
.61336 .31046 L
.61474 .31779 L
.61427 .35454 L
.61336 .35889 L
.59697 .39129 L
.57557 .41547 L
.55073 .42803 L
.53779 .43195 L
.5 .43591 L
.46221 .43195 L
.44927 .42803 L
.42443 .41547 L
.40303 .39129 L
.38664 .35889 L
.38573 .35454 L
.38526 .31779 L
.38664 .31046 L
.39947 .28104 L
.42443 .25281 L
.43309 .24429 L
.46221 .23291 L
s
.0001 w
.04657 .02381 m
.06177 .02818 L
s
% Start of user PostScript
-2. -2. -1.9329459 -1.9801823 MAarrowhead1
% End of user PostScript
.04657 .08681 m
.0649 .08933 L
s
% Start of user PostScript
-2. -1.7142857 -1.919147 -1.70284 MAarrowhead1
% End of user PostScript
.04657 .1498 m
.06772 .14907 L
s
% Start of user PostScript
-2. -1.4285714 -1.9067103 -1.4318841 MAarrowhead1
% End of user PostScript
.04657 .2128 m
.06932 .20719 L
s
% Start of user PostScript
-2. -1.1428571 -1.8996301 -1.1682703 MAarrowhead1
% End of user PostScript
.04657 .27579 m
.06852 .26399 L
s
% Start of user PostScript
-2. -0.85714286 -1.9031449 -0.91067056 MAarrowhead1
% End of user PostScript
.04657 .33879 m
.06432 .32053 L
s
% Start of user PostScript
-2. -0.57142857 -1.9217066 -0.65424688 MAarrowhead1
% End of user PostScript
.04657 .40178 m
.05658 .37852 L
s
% Start of user PostScript
-2. -0.28571429 -1.955821 -0.39123631 MAarrowhead1
% End of user PostScript
.04657 .46478 m
.04657 .43962 L
s
% Start of user PostScript
-2. 0. -2. -0.11413441 MAarrowhead1
% End of user PostScript
.04657 .52778 m
.03655 .50451 L
s
% Start of user PostScript
-2. 0.28571429 -2.044179 0.18019226 MAarrowhead1
% End of user PostScript
.04657 .59077 m
.02881 .57251 L
s
% Start of user PostScript
-2. 0.57142857 -2.0782934 0.48861026 MAarrowhead1
% End of user PostScript
.04657 .65377 m
.02461 .64197 L
s
% Start of user PostScript
-2. 0.85714286 -2.0968551 0.80361516 MAarrowhead1
% End of user PostScript
.04657 .71676 m
.02381 .71116 L
s
% Start of user PostScript
-2. 1.1428571 -2.1003699 1.117444 MAarrowhead1
% End of user PostScript
.04657 .77976 m
.02541 .77903 L
s
% Start of user PostScript
-2. 1.4285714 -2.0932897 1.4252588 MAarrowhead1
% End of user PostScript
.04657 .84276 m
.02823 .84528 L
s
% Start of user PostScript
-2. 1.7142857 -2.080853 1.7257314 MAarrowhead1
% End of user PostScript
.04657 .90575 m
.03136 .91012 L
s
% Start of user PostScript
-2. 2. -2.0670541 2.0198177 MAarrowhead1
% End of user PostScript
.11134 .02381 m
.13027 .032 L
s
% Start of user PostScript
-1.7142857 -2. -1.6307919 -1.9628445 MAarrowhead1
% End of user PostScript
.11134 .08681 m
.13556 .09345 L
s
% Start of user PostScript
-1.7142857 -1.7142857 -1.6074481 -1.684147 MAarrowhead1
% End of user PostScript
.11134 .1498 m
.14117 .15268 L
s
% Start of user PostScript
-1.7142857 -1.4285714 -1.5827371 -1.415522 MAarrowhead1
% End of user PostScript
.11134 .2128 m
.14564 .20883 L
s
% Start of user PostScript
-1.7142857 -1.1428571 -1.5630177 -1.1608351 MAarrowhead1
% End of user PostScript
.11134 .27579 m
.14654 .26183 L
s
% Start of user PostScript
-1.7142857 -0.85714286 -1.5590229 -0.9204662 MAarrowhead1
% End of user PostScript
.11134 .33879 m
.14124 .31331 L
s
% Start of user PostScript
-1.7142857 -0.57142857 -1.5823924 -0.6869748 MAarrowhead1
% End of user PostScript
.11134 .40178 m
.12876 .36679 L
s
% Start of user PostScript
-1.7142857 -0.28571429 -1.6374639 -0.44443668 MAarrowhead1
% End of user PostScript
.11134 .46478 m
.11134 .42606 L
s
% Start of user PostScript
-1.7142857 0. -1.7142857 -0.175616 MAarrowhead1
% End of user PostScript
.11134 .52778 m
.09392 .49278 L
s
% Start of user PostScript
-1.7142857 0.28571429 -1.7911075 0.12699189 MAarrowhead1
% End of user PostScript
.11134 .59077 m
.08144 .5653 L
s
% Start of user PostScript
-1.7142857 0.57142857 -1.8461791 0.45588234 MAarrowhead1
% End of user PostScript
.11134 .65377 m
.07614 .63981 L
s
% Start of user PostScript
-1.7142857 0.85714286 -1.8695486 0.79381951 MAarrowhead1
% End of user PostScript
.11134 .71676 m
.07705 .7128 L
s
% Start of user PostScript
-1.7142857 1.1428571 -1.8655537 1.1248792 MAarrowhead1
% End of user PostScript
.11134 .77976 m
.08152 .78264 L
s
% Start of user PostScript
-1.7142857 1.4285714 -1.8458344 1.4416209 MAarrowhead1
% End of user PostScript
.11134 .84276 m
.08712 .8494 L
s
% Start of user PostScript
-1.7142857 1.7142857 -1.8211233 1.7444244 MAarrowhead1
% End of user PostScript
.11134 .90575 m
.09241 .91394 L
s
% Start of user PostScript
-1.7142857 2. -1.7977795 2.0371555 MAarrowhead1
% End of user PostScript
.17612 .02381 m
.19899 .03793 L
s
% Start of user PostScript
-1.4285714 -2. -1.3276852 -1.9359589 MAarrowhead1
% End of user PostScript
.17612 .08681 m
.20756 .10075 L
s
% Start of user PostScript
-1.4285714 -1.7142857 -1.289895 -1.6510616 MAarrowhead1
% End of user PostScript
.17612 .1498 m
.21817 .16043 L
s
% Start of user PostScript
-1.4285714 -1.4285714 -1.2430923 -1.3803441 MAarrowhead1
% End of user PostScript
.17612 .2128 m
.22898 .21456 L
s
% Start of user PostScript
-1.4285714 -1.1428571 -1.1954179 -1.1348463 MAarrowhead1
% End of user PostScript
.17612 .27579 m
.23522 .26134 L
s
% Start of user PostScript
-1.4285714 -0.85714286 -1.1678924 -0.92268259 MAarrowhead1
% End of user PostScript
.17612 .33879 m
.22992 .30268 L
s
% Start of user PostScript
-1.4285714 -0.57142857 -1.1912832 -0.73518016 MAarrowhead1
% End of user PostScript
.17612 .40178 m
.20883 .34614 L
s
% Start of user PostScript
-1.4285714 -0.28571429 -1.2842878 -0.53809929 MAarrowhead1
% End of user PostScript
.17612 .46478 m
.17612 .40119 L
s
% Start of user PostScript
-1.4285714 0. -1.4285714 -0.28841284 MAarrowhead1
% End of user PostScript
.17612 .52778 m
.14341 .47213 L
s
% Start of user PostScript
-1.4285714 0.28571429 -1.572855 0.033329281 MAarrowhead1
% End of user PostScript
.17612 .59077 m
.12232 .55467 L
s
% Start of user PostScript
-1.4285714 0.57142857 -1.6658597 0.40767698 MAarrowhead1
% End of user PostScript
.17612 .65377 m
.11702 .63932 L
s
% Start of user PostScript
-1.4285714 0.85714286 -1.6892505 0.79160313 MAarrowhead1
% End of user PostScript
.17612 .71676 m
.12326 .71853 L
s
% Start of user PostScript
-1.4285714 1.1428571 -1.6617249 1.150868 MAarrowhead1
% End of user PostScript
.17612 .77976 m
.13407 .79039 L
s
% Start of user PostScript
-1.4285714 1.4285714 -1.6140506 1.4767988 MAarrowhead1
% End of user PostScript
.17612 .84276 m
.14468 .8567 L
s
% Start of user PostScript
-1.4285714 1.7142857 -1.5672479 1.7775098 MAarrowhead1
% End of user PostScript
.17612 .90575 m
.15325 .91987 L
s
% Start of user PostScript
-1.4285714 2. -1.5294576 2.0640411 MAarrowhead1
% End of user PostScript
.24089 .02381 m
.26706 .04659 L
s
% Start of user PostScript
-1.1428571 -2. -1.0274576 -1.8966831 MAarrowhead1
% End of user PostScript
.24089 .08681 m
.28003 .11299 L
s
% Start of user PostScript
-1.1428571 -1.7142857 -0.97024261 -1.5955149 MAarrowhead1
% End of user PostScript
.24089 .1498 m
.29904 .17618 L
s
% Start of user PostScript
-1.1428571 -1.4285714 -0.88637454 -1.3089419 MAarrowhead1
% End of user PostScript
.24089 .2128 m
.32349 .23047 L
s
% Start of user PostScript
-1.1428571 -1.1428571 -0.778531 -1.0626849 MAarrowhead1
% End of user PostScript
.24089 .27579 m
.34544 .26809 L
s
% Start of user PostScript
-1.1428571 -0.85714286 -0.68171897 -0.89207977 MAarrowhead1
% End of user PostScript
.24089 .33879 m
.34607 .28783 L
s
% Start of user PostScript
-1.1428571 -0.57142857 -0.67897146 -0.80255137 MAarrowhead1
% End of user PostScript
.24089 .40178 m
.30858 .30679 L
s
% Start of user PostScript
-1.1428571 -0.28571429 -0.84431699 -0.71655314 MAarrowhead1
% End of user PostScript
.24089 .46478 m
.24089 .3512 L
s
% Start of user PostScript
-1.1428571 0. -1.1428571 -0.51515076 MAarrowhead1
% End of user PostScript
.24089 .52778 m
.17321 .43278 L
s
% Start of user PostScript
-1.1428571 0.28571429 -1.4413973 -0.14512457 MAarrowhead1
% End of user PostScript
.24089 .59077 m
.13572 .53981 L
s
% Start of user PostScript
-1.1428571 0.57142857 -1.6067428 0.34030577 MAarrowhead1
% End of user PostScript
.24089 .65377 m
.13635 .64606 L
s
% Start of user PostScript
-1.1428571 0.85714286 -1.6039953 0.82220594 MAarrowhead1
% End of user PostScript
.24089 .71676 m
.1583 .73444 L
s
% Start of user PostScript
-1.1428571 1.1428571 -1.5071833 1.2230294 MAarrowhead1
% End of user PostScript
.24089 .77976 m
.18275 .80614 L
s
% Start of user PostScript
-1.1428571 1.4285714 -1.3993397 1.548201 MAarrowhead1
% End of user PostScript
.24089 .84276 m
.20176 .86894 L
s
% Start of user PostScript
-1.1428571 1.7142857 -1.3154717 1.8330566 MAarrowhead1
% End of user PostScript
.24089 .90575 m
.21473 .92853 L
s
% Start of user PostScript
-1.1428571 2. -1.2582567 2.1033169 MAarrowhead1
% End of user PostScript
.30567 .02381 m
.33283 .05809 L
s
% Start of user PostScript
-0.85714286 -2. -0.73734869 -1.8445327 MAarrowhead1
% End of user PostScript
.30567 .08681 m
.35034 .13187 L
s
% Start of user PostScript
-0.85714286 -1.7142857 -0.66013534 -1.5098952 MAarrowhead1
% End of user PostScript
.30567 .1498 m
.38129 .20602 L
s
% Start of user PostScript
-0.85714286 -1.4285714 -0.52358859 -1.1736017 MAarrowhead1
% End of user PostScript
.30567 .2128 m
.43313 .27111 L
s
% Start of user PostScript
-0.85714286 -1.1428571 -0.29496859 -0.87839349 MAarrowhead1
% End of user PostScript
.30567 .27579 m
.5014 .30179 L
s
% Start of user PostScript
-0.85714286 -0.85714286 0.0061551685 -0.73923019 MAarrowhead1
% End of user PostScript
.30567 .65377 m
.10995 .67977 L
s
% Start of user PostScript
-0.85714286 0.85714286 -1.7204409 0.97505552 MAarrowhead1
% End of user PostScript
.30567 .71676 m
.17822 .77507 L
s
% Start of user PostScript
-0.85714286 1.1428571 -1.4193171 1.4073208 MAarrowhead1
% End of user PostScript
.30567 .77976 m
.23005 .83598 L
s
% Start of user PostScript
-0.85714286 1.4285714 -1.1906971 1.6835412 MAarrowhead1
% End of user PostScript
.30567 .84276 m
.26101 .88782 L
s
% Start of user PostScript
-0.85714286 1.7142857 -1.0541504 1.9186762 MAarrowhead1
% End of user PostScript
.30567 .90575 m
.27851 .94003 L
s
% Start of user PostScript
-0.85714286 2. -0.97693703 2.1554673 MAarrowhead1
% End of user PostScript
.37045 .02381 m
.39409 .07109 L
s
% Start of user PostScript
-0.57142857 -2. -0.4671419 -1.7855407 MAarrowhead1
% End of user PostScript
.37045 .08681 m
.41321 .15675 L
s
% Start of user PostScript
-0.57142857 -1.7142857 -0.38279024 -1.397047 MAarrowhead1
% End of user PostScript
.37045 .1498 m
.45448 .25551 L
s
% Start of user PostScript
-0.57142857 -1.4285714 -0.20077295 -0.9491341 MAarrowhead1
% End of user PostScript
.37045 .77976 m
.28641 .88547 L
s
% Start of user PostScript
-0.57142857 1.4285714 -0.94208419 1.9080088 MAarrowhead1
% End of user PostScript
.37045 .84276 m
.32768 .9127 L
s
% Start of user PostScript
-0.57142857 1.7142857 -0.7600669 2.0315245 MAarrowhead1
% End of user PostScript
.37045 .90575 m
.3468 .95304 L
s
% Start of user PostScript
-0.57142857 2. -0.67571524 2.2144593 MAarrowhead1
% End of user PostScript
.43522 .02381 m
.44935 .0821 L
s
% Start of user PostScript
-0.28571429 -2. -0.22339812 -1.7356064 MAarrowhead1
% End of user PostScript
.43522 .08681 m
.46277 .18086 L
s
% Start of user PostScript
-0.28571429 -1.7142857 -0.16420121 -1.2877101 MAarrowhead1
% End of user PostScript
.43522 .1498 m
.49712 .31569 L
s
% Start of user PostScript
-0.28571429 -1.4285714 -0.012697335 -0.67620913 MAarrowhead1
% End of user PostScript
.43522 .77976 m
.37333 .94564 L
s
% Start of user PostScript
-0.28571429 1.4285714 -0.55873124 2.1809337 MAarrowhead1
% End of user PostScript
.43522 .84276 m
.40767 .93681 L
s
% Start of user PostScript
-0.28571429 1.7142857 -0.40722736 2.1408613 MAarrowhead1
% End of user PostScript
.43522 .90575 m
.4211 .96405 L
s
% Start of user PostScript
-0.28571429 2. -0.34803046 2.2643936 MAarrowhead1
% End of user PostScript
.5 .02381 m
.5 .08653 L
s
% Start of user PostScript
0. -2. 0. -1.7155556 MAarrowhead1
% End of user PostScript
.5 .08681 m
.5 .19137 L
s
% Start of user PostScript
0. -1.7142857 0. -1.2400392 MAarrowhead1
% End of user PostScript
.5 .1498 m
.5 .34623 L
s
% Start of user PostScript
0. -1.4285714 0. -0.53766957 MAarrowhead1
% End of user PostScript
.5 .77976 m
.5 .97619 L
s
% Start of user PostScript
0. 1.4285714 0. 2.3194733 MAarrowhead1
% End of user PostScript
.5 .84276 m
.5 .94732 L
s
% Start of user PostScript
0. 1.7142857 0. 2.1885322 MAarrowhead1
% End of user PostScript
.5 .90575 m
.5 .96847 L
s
% Start of user PostScript
0. 2. 0. 2.2844444 MAarrowhead1
% End of user PostScript
.56478 .02381 m
.55065 .0821 L
s
% Start of user PostScript
0.28571429 -2. 0.22339812 -1.7356064 MAarrowhead1
% End of user PostScript
.56478 .08681 m
.53723 .18086 L
s
% Start of user PostScript
0.28571429 -1.7142857 0.16420121 -1.2877101 MAarrowhead1
% End of user PostScript
.56478 .1498 m
.50288 .31569 L
s
% Start of user PostScript
0.28571429 -1.4285714 0.012697335 -0.67620913 MAarrowhead1
% End of user PostScript
.56478 .77976 m
.62667 .94564 L
s
% Start of user PostScript
0.28571429 1.4285714 0.55873124 2.1809337 MAarrowhead1
% End of user PostScript
.56478 .84276 m
.59233 .93681 L
s
% Start of user PostScript
0.28571429 1.7142857 0.40722736 2.1408613 MAarrowhead1
% End of user PostScript
.56478 .90575 m
.5789 .96405 L
s
% Start of user PostScript
0.28571429 2. 0.34803046 2.2643936 MAarrowhead1
% End of user PostScript
.62955 .02381 m
.60591 .07109 L
s
% Start of user PostScript
0.57142857 -2. 0.4671419 -1.7855407 MAarrowhead1
% End of user PostScript
.62955 .08681 m
.58679 .15675 L
s
% Start of user PostScript
0.57142857 -1.7142857 0.38279024 -1.397047 MAarrowhead1
% End of user PostScript
.62955 .1498 m
.54552 .25551 L
s
% Start of user PostScript
0.57142857 -1.4285714 0.20077295 -0.9491341 MAarrowhead1
% End of user PostScript
.62955 .77976 m
.71359 .88547 L
s
% Start of user PostScript
0.57142857 1.4285714 0.94208419 1.9080088 MAarrowhead1
% End of user PostScript
.62955 .84276 m
.67232 .9127 L
s
% Start of user PostScript
0.57142857 1.7142857 0.7600669 2.0315245 MAarrowhead1
% End of user PostScript
.62955 .90575 m
.6532 .95304 L
s
% Start of user PostScript
0.57142857 2. 0.67571524 2.2144593 MAarrowhead1
% End of user PostScript
.69433 .02381 m
.66717 .05809 L
s
% Start of user PostScript
0.85714286 -2. 0.73734869 -1.8445327 MAarrowhead1
% End of user PostScript
.69433 .08681 m
.64966 .13187 L
s
% Start of user PostScript
0.85714286 -1.7142857 0.66013534 -1.5098952 MAarrowhead1
% End of user PostScript
.69433 .1498 m
.61871 .20602 L
s
% Start of user PostScript
0.85714286 -1.4285714 0.52358859 -1.1736017 MAarrowhead1
% End of user PostScript
.69433 .2128 m
.56687 .27111 L
s
% Start of user PostScript
0.85714286 -1.1428571 0.29496859 -0.87839349 MAarrowhead1
% End of user PostScript
.69433 .27579 m
.4986 .30179 L
s
% Start of user PostScript
0.85714286 -0.85714286 -0.0061551685 -0.73923019 MAarrowhead1
% End of user PostScript
.69433 .65377 m
.89005 .67977 L
s
% Start of user PostScript
0.85714286 0.85714286 1.7204409 0.97505552 MAarrowhead1
% End of user PostScript
.69433 .71676 m
.82178 .77507 L
s
% Start of user PostScript
0.85714286 1.1428571 1.4193171 1.4073208 MAarrowhead1
% End of user PostScript
.69433 .77976 m
.76995 .83598 L
s
% Start of user PostScript
0.85714286 1.4285714 1.1906971 1.6835412 MAarrowhead1
% End of user PostScript
.69433 .84276 m
.73899 .88782 L
s
% Start of user PostScript
0.85714286 1.7142857 1.0541504 1.9186762 MAarrowhead1
% End of user PostScript
.69433 .90575 m
.72149 .94003 L
s
% Start of user PostScript
0.85714286 2. 0.97693703 2.1554673 MAarrowhead1
% End of user PostScript
.75911 .02381 m
.73294 .04659 L
s
% Start of user PostScript
1.1428571 -2. 1.0274576 -1.8966831 MAarrowhead1
% End of user PostScript
.75911 .08681 m
.71997 .11299 L
s
% Start of user PostScript
1.1428571 -1.7142857 0.97024261 -1.5955149 MAarrowhead1
% End of user PostScript
.75911 .1498 m
.70096 .17618 L
s
% Start of user PostScript
1.1428571 -1.4285714 0.88637454 -1.3089419 MAarrowhead1
% End of user PostScript
.75911 .2128 m
.67651 .23047 L
s
% Start of user PostScript
1.1428571 -1.1428571 0.778531 -1.0626849 MAarrowhead1
% End of user PostScript
.75911 .27579 m
.65456 .26809 L
s
% Start of user PostScript
1.1428571 -0.85714286 0.68171897 -0.89207977 MAarrowhead1
% End of user PostScript
.75911 .33879 m
.65393 .28783 L
s
% Start of user PostScript
1.1428571 -0.57142857 0.67897146 -0.80255137 MAarrowhead1
% End of user PostScript
.75911 .40178 m
.69142 .30679 L
s
% Start of user PostScript
1.1428571 -0.28571429 0.84431699 -0.71655314 MAarrowhead1
% End of user PostScript
.75911 .46478 m
.75911 .3512 L
s
% Start of user PostScript
1.1428571 0. 1.1428571 -0.51515076 MAarrowhead1
% End of user PostScript
.75911 .52778 m
.82679 .43278 L
s
% Start of user PostScript
1.1428571 0.28571429 1.4413973 -0.14512457 MAarrowhead1
% End of user PostScript
.75911 .59077 m
.86428 .53981 L
s
% Start of user PostScript
1.1428571 0.57142857 1.6067428 0.34030577 MAarrowhead1
% End of user PostScript
.75911 .65377 m
.86365 .64606 L
s
% Start of user PostScript
1.1428571 0.85714286 1.6039953 0.82220594 MAarrowhead1
% End of user PostScript
.75911 .71676 m
.8417 .73444 L
s
% Start of user PostScript
1.1428571 1.1428571 1.5071833 1.2230294 MAarrowhead1
% End of user PostScript
.75911 .77976 m
.81725 .80614 L
s
% Start of user PostScript
1.1428571 1.4285714 1.3993397 1.548201 MAarrowhead1
% End of user PostScript
.75911 .84276 m
.79824 .86894 L
s
% Start of user PostScript
1.1428571 1.7142857 1.3154717 1.8330566 MAarrowhead1
% End of user PostScript
.75911 .90575 m
.78527 .92853 L
s
% Start of user PostScript
1.1428571 2. 1.2582567 2.1033169 MAarrowhead1
% End of user PostScript
.82388 .02381 m
.80101 .03793 L
s
% Start of user PostScript
1.4285714 -2. 1.3276852 -1.9359589 MAarrowhead1
% End of user PostScript
.82388 .08681 m
.79244 .10075 L
s
% Start of user PostScript
1.4285714 -1.7142857 1.289895 -1.6510616 MAarrowhead1
% End of user PostScript
.82388 .1498 m
.78183 .16043 L
s
% Start of user PostScript
1.4285714 -1.4285714 1.2430923 -1.3803441 MAarrowhead1
% End of user PostScript
.82388 .2128 m
.77102 .21456 L
s
% Start of user PostScript
1.4285714 -1.1428571 1.1954179 -1.1348463 MAarrowhead1
% End of user PostScript
.82388 .27579 m
.76478 .26134 L
s
% Start of user PostScript
1.4285714 -0.85714286 1.1678924 -0.92268259 MAarrowhead1
% End of user PostScript
.82388 .33879 m
.77008 .30268 L
s
% Start of user PostScript
1.4285714 -0.57142857 1.1912832 -0.73518016 MAarrowhead1
% End of user PostScript
.82388 .40178 m
.79117 .34614 L
s
% Start of user PostScript
1.4285714 -0.28571429 1.2842878 -0.53809929 MAarrowhead1
% End of user PostScript
.82388 .46478 m
.82388 .40119 L
s
% Start of user PostScript
1.4285714 0. 1.4285714 -0.28841284 MAarrowhead1
% End of user PostScript
.82388 .52778 m
.85659 .47213 L
s
% Start of user PostScript
1.4285714 0.28571429 1.572855 0.033329281 MAarrowhead1
% End of user PostScript
.82388 .59077 m
.87768 .55467 L
s
% Start of user PostScript
1.4285714 0.57142857 1.6658597 0.40767698 MAarrowhead1
% End of user PostScript
.82388 .65377 m
.88298 .63932 L
s
% Start of user PostScript
1.4285714 0.85714286 1.6892505 0.79160313 MAarrowhead1
% End of user PostScript
.82388 .71676 m
.87674 .71853 L
s
% Start of user PostScript
1.4285714 1.1428571 1.6617249 1.150868 MAarrowhead1
% End of user PostScript
.82388 .77976 m
.86593 .79039 L
s
% Start of user PostScript
1.4285714 1.4285714 1.6140506 1.4767988 MAarrowhead1
% End of user PostScript
.82388 .84276 m
.85532 .8567 L
s
% Start of user PostScript
1.4285714 1.7142857 1.5672479 1.7775098 MAarrowhead1
% End of user PostScript
.82388 .90575 m
.84675 .91987 L
s
% Start of user PostScript
1.4285714 2. 1.5294576 2.0640411 MAarrowhead1
% End of user PostScript
.88866 .02381 m
.86973 .032 L
s
% Start of user PostScript
1.7142857 -2. 1.6307919 -1.9628445 MAarrowhead1
% End of user PostScript
.88866 .08681 m
.86444 .09345 L
s
% Start of user PostScript
1.7142857 -1.7142857 1.6074481 -1.684147 MAarrowhead1
% End of user PostScript
.88866 .1498 m
.85883 .15268 L
s
% Start of user PostScript
1.7142857 -1.4285714 1.5827371 -1.415522 MAarrowhead1
% End of user PostScript
.88866 .2128 m
.85436 .20883 L
s
% Start of user PostScript
1.7142857 -1.1428571 1.5630177 -1.1608351 MAarrowhead1
% End of user PostScript
.88866 .27579 m
.85346 .26183 L
s
% Start of user PostScript
1.7142857 -0.85714286 1.5590229 -0.9204662 MAarrowhead1
% End of user PostScript
.88866 .33879 m
.85876 .31331 L
s
% Start of user PostScript
1.7142857 -0.57142857 1.5823924 -0.6869748 MAarrowhead1
% End of user PostScript
.88866 .40178 m
.87124 .36679 L
s
% Start of user PostScript
1.7142857 -0.28571429 1.6374639 -0.44443668 MAarrowhead1
% End of user PostScript
.88866 .46478 m
.88866 .42606 L
s
% Start of user PostScript
1.7142857 0. 1.7142857 -0.175616 MAarrowhead1
% End of user PostScript
.88866 .52778 m
.90608 .49278 L
s
% Start of user PostScript
1.7142857 0.28571429 1.7911075 0.12699189 MAarrowhead1
% End of user PostScript
.88866 .59077 m
.91856 .5653 L
s
% Start of user PostScript
1.7142857 0.57142857 1.8461791 0.45588234 MAarrowhead1
% End of user PostScript
.88866 .65377 m
.92386 .63981 L
s
% Start of user PostScript
1.7142857 0.85714286 1.8695486 0.79381951 MAarrowhead1
% End of user PostScript
.88866 .71676 m
.92295 .7128 L
s
% Start of user PostScript
1.7142857 1.1428571 1.8655537 1.1248792 MAarrowhead1
% End of user PostScript
.88866 .77976 m
.91848 .78264 L
s
% Start of user PostScript
1.7142857 1.4285714 1.8458344 1.4416209 MAarrowhead1
% End of user PostScript
.88866 .84276 m
.91288 .8494 L
s
% Start of user PostScript
1.7142857 1.7142857 1.8211233 1.7444244 MAarrowhead1
% End of user PostScript
.88866 .90575 m
.90759 .91394 L
s
% Start of user PostScript
1.7142857 2. 1.7977795 2.0371555 MAarrowhead1
% End of user PostScript
.95343 .02381 m
.93823 .02818 L
s
% Start of user PostScript
2. -2. 1.9329459 -1.9801823 MAarrowhead1
% End of user PostScript
.95343 .08681 m
.9351 .08933 L
s
% Start of user PostScript
2. -1.7142857 1.919147 -1.70284 MAarrowhead1
% End of user PostScript
.95343 .1498 m
.93228 .14907 L
s
% Start of user PostScript
2. -1.4285714 1.9067103 -1.4318841 MAarrowhead1
% End of user PostScript
.95343 .2128 m
.93068 .20719 L
s
% Start of user PostScript
2. -1.1428571 1.8996301 -1.1682703 MAarrowhead1
% End of user PostScript
.95343 .27579 m
.93148 .26399 L
s
% Start of user PostScript
2. -0.85714286 1.9031449 -0.91067056 MAarrowhead1
% End of user PostScript
.95343 .33879 m
.93568 .32053 L
s
% Start of user PostScript
2. -0.57142857 1.9217066 -0.65424688 MAarrowhead1
% End of user PostScript
.95343 .40178 m
.94342 .37852 L
s
% Start of user PostScript
2. -0.28571429 1.955821 -0.39123631 MAarrowhead1
% End of user PostScript
.95343 .46478 m
.95343 .43962 L
s
% Start of user PostScript
2. 0. 2. -0.11413441 MAarrowhead1
% End of user PostScript
.95343 .52778 m
.96345 .50451 L
s
% Start of user PostScript
2. 0.28571429 2.044179 0.18019226 MAarrowhead1
% End of user PostScript
.95343 .59077 m
.97119 .57251 L
s
% Start of user PostScript
2. 0.57142857 2.0782934 0.48861026 MAarrowhead1
% End of user PostScript
.95343 .65377 m
.97539 .64197 L
s
% Start of user PostScript
2. 0.85714286 2.0968551 0.80361516 MAarrowhead1
% End of user PostScript
.95343 .71676 m
.97619 .71116 L
s
% Start of user PostScript
2. 1.1428571 2.1003699 1.117444 MAarrowhead1
% End of user PostScript
.95343 .77976 m
.97459 .77903 L
s
% Start of user PostScript
2. 1.4285714 2.0932897 1.4252588 MAarrowhead1
% End of user PostScript
.95343 .84276 m
.97177 .84528 L
s
% Start of user PostScript
2. 1.7142857 2.080853 1.7257314 MAarrowhead1
% End of user PostScript
.95343 .90575 m
.96864 .91012 L
s
% Start of user PostScript
2. 2. 2.0670541 2.0198177 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:P3oool00`3ookl0M0000000
00040000000307Boo`3oool0oooo05<0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`1@0?ooo`050?noM000000000000000001d_ol0EP3oool00`3o_g@000000000000300000003001d
_`3oool0oooo05<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`0?0?ooo`00:`3o
ool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo05L0oooo00<0W4Q809cOo`3oool0D`3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooeP0oooo00<0W4Q809cOo`3oool0E`3oool00`2oM000
001d0;ooo`020?ooo`030=nLM02Lgol0oooo0100oooo000/0?ooo`030?noM00004P0W=oo05/0oooo
00<0W4Q809cOo`3oool0DP3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo05L0oooo
00<0W4Q809cOo`3oool0F03oool00`3o_g@0001809cOo`0D0?ooo`00;@3oool00`3ogi`0B00004RL
g`1J0?ooo`0309a8B02Lgol0oooo0580oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`1G0?ooo`0309a8B02Lgol0oooo05T0oooo00<0omnL04P00018W=l04`3oool00280oooo00<0W4P0
0000000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0oooo04`0oooo00<0W4P0
0000000000000`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo0580oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1G0?ooo`0309a8B02Lgol0oooo05/0oooo00<0W4P0
04RLg`3oool04@3oool00300oooo00<0W4Qd0;ooo`3oool0E`3oool00`2LB4P0W=oo0?ooo`1B0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0E`3oool00`2LB4P0W=oo0?ooo`1L0?oo
o`0309a8M02oool0oooo0100oooo000[0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3o
ool0E`3oool00`2LB4P0W=oo0?ooo`1B0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3o
ool0E`3oool00`2LB4P0W=oo0?ooo`1G0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3o
ool0403oool002/0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo05D0oooo00D0gia80000
0000B9`0W4Q809cOo`1D0?ooo`0609a8001d_ol0oooo0?oOW01807@0_oooE@3oool01@3OW4P00000
0018W02LB4P0W=oo05P0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo0140oooo000/0?oo
o`050?noM000000000000000B02Lgol0F03oool00`3OW4P0001809cOo`1D0?ooo`050?oo_`1d0000
00000000B02Lgol0F03oool00`3OW4P0001809cOo`1I0?ooo`050?noM000000000000000B02Lgol0
4P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool001L0ooooo`00002I00000040
oooo000G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
oiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`002@3oool00`3ookl0M0000000
00040000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3o
ool000X0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`050?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`4000000@3oool000/0oooo00<0okmd0000
B02Lgol02@3oool00`000000oooo0?ooo`0>0?ooo`<000006@3oool400000?l0oooo=`3oool30000
01T0oooo0`00000A0?ooo`4000000@3oool000`0oooo00<0omnL04P00018W=l0203oool3000000d0
oooo1P00000G0?ooo`D000001`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?oo
o`0000005P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0503oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01P3oool5
000001H0oooo1P00000>0?ooo`<000000@3oool000030?ooo`2LB000000000@0000000<004RL0?oo
o`3oool0103oool00`2LB000B9cO0?ooo`060?ooo`030000003oool0oooo00d0oooo2000000D0?oo
o`L000001P3oool00`000000oooo0?ooo`0<0?ooo`D000005P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0503oool5000000d0oooo00<000000?oo
o`3oool01@3oool6000001@0oooo2000000@0?ooo`4000000@3oool000l0oooo00<0W4Qd0;ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`X000004P3oool9000000<0oooo00<000000?ooo`3o
ool03`3oool4000001H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`80
00005P3oool400000100oooo00<000000?ooo`3oool00P3oool8000001<0oooo2P00000?0?ooo`40
00000@3oool000X0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`030000
003oool0oooo02h0oooo1@0000020?ooo`030000003oool0oooo00h0oooo1P00000F0?ooo`040000
003oool0oooo000001D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0000000G0?ooo`H0
00003`3oool010000000oooo0?ooo`3oool500000300oooo0@0000010?ooo`002P3oool01`3o_g@0
001d0;ooo`3oool0okmd0000B02Lgol01P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0140oooo1@00000F0?ooo`@000005@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0C0?ooo`<000005`3oool5
00000180oooo00<000000?ooo`3oool0=@3oool100000040oooo000;0?ooo`050?noM00000000000
0000B02Lgol01`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01<0oooo1000000E
0?ooo`@000005P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`D000005@3oool4000001@0oooo00<00000
0?ooo`3oool0=@3oool100000040oooo000G0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool05`3oool2000001<0oooo1P00000F0?ooo`040000003oool0oooo000001D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000001D0oooo1`00
000C0?ooo`800000603oool00`000000oooo0?ooo`0d0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0^0?ooo`D000005@3oool010000000oooo00000000
000E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04`3oool3000001H0oooo1@00
000_0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0340oooo0`00000F0?ooo`@000005@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01<0oooo1000000E0?ooo`@00000<P3oool00`000000oooo0?ooo`0c
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?oo
o`800000503oool5000001D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?oo
o`D000004`3oool2000003D0oooo00<000000?ooo`3oool0<`3oool100000040oooo000G0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0B`3oool4000001H0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0C0?ooo`D00000C03oool00`000000oooo0?ooo`0b0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1<0?ooo`@00000
5@3oool00`000000oooo0000000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000001D0oooo1000001=0?ooo`03
0000003oool0oooo0380oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo04h0oooo0`00000E0?ooo`<000005@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool3000001H0oooo0`00001?0?ooo`030000
003oool0oooo0340oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo0500oooo0P00000C0?ooo`@000005@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool5000001<0oooo0P00001A0?ooo`030000003o
ool0oooo0340oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool04P3oool4000001@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo1000000D0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0<03oool100000040oooo000G0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0J03oool3000001D0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo1000001Y0?ooo`030000003oool0oooo
0300oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06P0
oooo0`00000C0?ooo`D000004`3oool00`000000oooo0?ooo`0B0?ooo`D000004P3oool3000006/0
oooo00<000000?ooo`3oool0;`3oool100000040oooo000G0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0JP3oool2000001<0oooo1@00000C0?ooo`030000003oool0oooo0180oooo
1000000C0?ooo`<00000J`3oool00`000000oooo0?ooo`0_0?ooo`4000000@3oool001L0oooo0P00
000_0?ooo`030000003oool0oooo06/0oooo0P00000C0?ooo`@000004@3oool500000180oooo1000
000C0?ooo`800000K@3oool00`000000oooo0?ooo`0]0?ooo`8000000@3oool001L0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0140oooo1000000A
0?ooo`D000004P3oool3000001@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0^
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`220?oo
o`<000004@3oool4000001<0oooo0`0000230?ooo`030000003oool0oooo02h0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0880oooo0`00000B0?ooo`<0
00004`3oool2000008D0oooo00<000000?ooo`3oool0;@3oool100000040oooo000G0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0P`3oool200000180oooo0`00000C0?ooo`800000
Q@3oool00`000000oooo0?ooo`0]0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`230?ooo`8000004P3oool3000001<0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`0]0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool03`3oool2
000001/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0:0?ooo`l000003@3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo01X0oooo0P00000A0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool03`3oool4000001T0oooo0`0000290?ooo`T000001`3oool00`00
0000oooo0?ooo`050?ooo`X00000R03oool4000001T0oooo1000000A0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool03`3oool7000001@0oooo1P00000D0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo1000000@0?ooo`030000003oool0oooo00l0
oooo100000050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool2000001<0
oooo1`00000D0?ooo`L000004@3oool100000040oooo000G0?ooo`030000003oool0oooo00l0oooo
2@00000C0?ooo`L00000503oool200000080oooo0`00000C0?ooo`800000603oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000000`00000D0?ooo`030000
003oool0oooo01<0oooo100000000`3oool000000?ooo`0G0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool05P3oool2000001<0oooo0P0000030?ooo`800000503oool6000001@0oooo
2@00000A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool03`3oool5000001L0oooo2@00
000D0?ooo`H00000503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0503oool4000001P0oooo00<000000?ooo`3oool05`3oool4000001H0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo1P00
000D0?ooo`P00000603oool500000140oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0080oooo1@00000D0?ooo`H00000503oool2000001L0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool0oooo0`00000B0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool05@3oool2000001@0oooo1@00000E0?ooo`D00000103o
ool00`000000oooo0?ooo`0[0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0K0?ooo`L000005@3oool01@000000oooo0?ooo`3oool0000001<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`<000001P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool3000000l0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`000000
5@3oool7000001d0oooo00<000000?ooo`3oool0:`3oool100000040oooo000G0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool07@3oool6000001D0oooo00<000000?ooo`0000000P00
000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool2000000T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo0P00
000<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool200000080oooo00<0
00000?ooo`3oool04`3oool6000001l0oooo00<000000?ooo`3oool0:`3oool100000040oooo000G
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08@3oool3000001D0oooo1@00000C
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool2000000`0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo0P000009
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool5000001D0oooo0`00000S
0?ooo`030000003oool0oooo02/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo03X0oooo1P00000C0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool2000000h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00`0oooo0P0000070?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool04@3oool5000003d0oooo00<000000?ooo`3oool0:P3oool100000040oooo000G0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0>P3oool6000001@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`800000403oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool2000000@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0B0?ooo`H00000?03oool00`000000oooo0?ooo`0Z0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0l0?ooo`D00000
503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo008000004`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool200000080oooo
00<000000?ooo`3oool04`3oool2000001@0oooo1@00000n0?ooo`030000003oool0oooo02X0oooo
0@0000010?ooo`005`3oool2000002/0oooo00<000000?ooo`3oool0?P3oool4000001@0oooo00<0
00000?ooo`3oool0503oool2000001D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01<0oooo0P00000E0?ooo`030000003oool0oooo01<0oooo1000
00100?ooo`030000003oool0oooo02T0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0440oooo0P00000D0?ooo`040000003oool0oooo00000100oooo0P00
00000`3oool000000?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0C0?ooo`040000003oool0000000000100oooo00<000000?ooo`000000
5@3oool2000004<0oooo00<000000?ooo`3oool0:P3oool100000040oooo000G0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0F@3oool4000000h0oooo00D000000?ooo`3oool0oooo
0000000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000003P3oool3000005`0oooo00<000000?ooo`3o
ool0:@3oool100000040oooo000G0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
F@3oool4000000`0oooo0P0000050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
0`3oool2000000`0oooo1000001K0?ooo`030000003oool0oooo02T0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05P0oooo1P00000:0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo1P00001J0?ooo`030000003oool0oooo02T0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05T0oooo1@0000080?ooo`8000002@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`H00000F`3oool0
0`000000oooo0?ooo`0Y0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1K0?ooo`@000001@3oool2000000`0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0:0?ooo`800000103oool5000005d0oooo00<000000?ooo`3oool0:@3oool10000
0040oooo000G0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0GP3oool2000000@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0
oooo00@000000?ooo`3oool0oooo0`00001P0?ooo`030000003oool0oooo02P0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0600oooo00@000000?ooo`00
00000000403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo1000001R0?oo
o`030000003oool0oooo02P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0X0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0180oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000D0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0:03oool100000040oooo000G0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0D0?ooo`<0
0000403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03P3oool3000001H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0X0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo01<0oooo1@00000@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0=0?ooo`H000005@3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo02P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool05@3oool500000100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo1@00000G0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool09`3oool100000040oooo000G0?ooo`030000003oool0
oooo0100oooo1000000C0?ooo`030000003oool0oooo00@0oooo0P00001G0?ooo`030000003oool0
oooo01L0oooo1000000@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0>0?ooo`@000006@3oool00`000000oooo0?ooo`1E0?ooo`8000001P3oool0
0`000000oooo0?ooo`0A0?ooo`@000004P3oool100000040oooo000G0?ooo`030000003oool0oooo
0100oooo2@00000>0?ooo`030000003oool0oooo00@0oooo1000001D0?ooo`030000003oool0oooo
01T0oooo0`00000@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0>0?ooo`<000006`3oool00`000000oooo0?ooo`1B0?ooo`@000001P3oool00`00
0000oooo0?ooo`0<0?ooo`T000004P3oool100000040oooo000G0?ooo`030000003oool0oooo0100
oooo1`00000@0?ooo`030000003oool0oooo00/000003`3oool3000000L0oooo00<000000?ooo`3o
ool03P3oool2000001P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo0P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool3000000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01H0oooo0P00000@0?ooo`030000003oool0oooo00D0oooo0`00000?0?ooo`/0
00000P3oool00`000000oooo0?ooo`0>0?ooo`L000004P3oool100000040oooo000G0?ooo`030000
003oool0oooo0100oooo1@00000B0?ooo`030000003oool0oooo00@0oooo2@00000@0?ooo`@00000
0`3oool300000100oooo0P00000G0?ooo`800000203oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00`0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool2000000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`800000
5`3oool200000100oooo0`0000030?ooo`@00000403oool9000000H0oooo00<000000?ooo`3oool0
403oool500000180oooo0@0000010?ooo`005`3oool200000140oooo0P00000E0?ooo`030000003o
ool0oooo00@0oooo1@00000H0?ooo`P00000403oool2000001L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3o
ool200000100oooo2000000H0?ooo`D000001P3oool00`000000oooo0?ooo`0C0?ooo`8000004@3o
ool200000040oooo000G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool08`3oool8
00000100oooo0`00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool3
00000100oooo2000000U0?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0oooo2P00000A0?ooo`800000503oool20000
0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00D0oooo0`00000;0?ooo`L00000303oool3000000L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00800000503oool200000140oooo2P00000U0?oo
o`030000003oool0oooo02L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0440oooo0`0000030?ooo`030000003oool0oooo00d0oooo0P00000F0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool5000000<0oooo200000030?ooo`04
0000003oool0oooo0?ooo`P00000103oool5000000@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0D0?ooo`8000003`3oool010000000oooo0?ooo`3oool3000004<0oooo00<00000
0?ooo`3oool09P3oool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0A03oool6000000d0oooo0`00000F0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00`3oool7000000/0oooo00<000000?ooo`3oool02@3oool8000000D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0D0?ooo`<000003@3oool3000000030?ooo`0000000000
04H0oooo00<000000?ooo`3oool09P3oool100000040oooo000G0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0AP3oool5000000/0oooo00D000000?ooo`3oool0oooo0000000F0?oo
o`030000003oool0oooo01@0oooo2@00000>0?ooo`030000003oool0oooo00d0oooo2@00000F0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`D00000B03oool0
0`000000oooo0?ooo`0V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`150?ooo`L000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04@3oool4000000D0oooo0`00000<0?ooo`D000003@3oool30000
00D0oooo1000000C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`H00000B03oool00`000000oooo0?ooo`0V0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`150?ooo`T000001P3oool00`000000
oooo0?ooo`050?ooo`800000503oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?oo
o`0000001@3oool3000000`0oooo1@00000=0?ooo`<000001@3oool01@000000oooo0?ooo`3oool0
00000140oooo00<000000?ooo`3oool04P3oool2000000L0oooo00<000000?ooo`3oool0103oool9
000004L0oooo00<000000?ooo`3oool09P3oool100000040oooo000G0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0BP3oool5000000@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`030000003oool0oooo
00<0oooo0P00000<0?ooo`@000003P3oool2000000D0oooo00<000000?ooo`3oool00`3oool20000
00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo1@00001<0?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool02P3oool2000001<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo0P00000=0?ooo`<000003P3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool09P3oool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool2000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`<000003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
0P00000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool03P3oool200000140oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo0`00
000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0?0?ooo`8000003`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02H0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo0P00000<
0?ooo`030000003oool0oooo0140oooo0P00000E0?ooo`030000003oool0oooo00X0oooo0P000005
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo008000003`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool03@3oool200000080oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool09P3oool10000
0040oooo000G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0D0?ooo`8000000P3oool00`000000oooo0?ooo`0;0?ooo`8000004@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool2000000d0
oooo00<000000?ooo`3oool00P00000E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool09`3oool100000040oooo000G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0F0?ooo`@000002`3oool200000180oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo0P00000;0?ooo`@00000
5`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool05`3o
ool5000000T0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000090?ooo`D0
0000603oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
5P3oool6000000L0oooo0P0000040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool2000000H0oooo1`00000H0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
9`3oool100000040oooo000G0?ooo`800000:03oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo01T0oooo1@0000040?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo0P0000040?ooo`D000006P3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo02H0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool06`3oool400000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo3`00000;0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04000001d0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0W0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01l0oooo0`00000;0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`000000200000070?ooo`030000003oool0oooo
00D0oooo2P0000000`3oool000000?ooo`0?0?ooo`030000003oool0oooo00T0oooo0`00000P0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool09`3oool100000040oooo000G0?ooo`03
0000003oool0oooo0100oooo2P00000=0?ooo`030000003oool0oooo00H0oooo100000110?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`80
0000403oool00`000000oooo0?ooo`0?0?ooo`8000003`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0?`3oool4000000P0oooo00<000000?ooo`3o
ool02`3oool9000001<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0@0?ooo`T00000
3P3oool00`000000oooo0?ooo`060?ooo`T000006@3oool200000240oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0P0000000`3oool00000
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`0000000000303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool2000001T0
oooo2@0000080?ooo`030000003oool0oooo00`0oooo2000000C0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0403oool700000100oooo00<000000?ooo`3oool03@00000=0?ooo`/00000
0`3oool6000000L0oooo0`00000B0?ooo`030000003oool0oooo0080oooo0P00000K0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`8000002@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo0P0000040?ooo`030000003oool0oooo0100
oooo0`0000070?ooo`H000000`3oool;000000d0oooo3@0000020?ooo`030000003oool0oooo00h0
oooo1`00000B0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool4000001<0oooo
00<000000?ooo`3oool01@3oool5000001X0oooo300000070?ooo`D000003@3oool00`000000oooo
0?ooo`040?ooo`8000006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
0P0000060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo
0P0000060?ooo`030000003oool0oooo00/0oooo1@0000070?ooo``000006P3oool5000000L0oooo
00<000000?ooo`3oool04@3oool3000001@0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0A0?ooo`8000005@3oool00`000000oooo0?ooo`050?ooo`800000803oool7000000h0oooo1000
00090?ooo`030000003oool0oooo00H0oooo0P00000F0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00P3oool2000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0503oool2000000P0oooo00<000000?ooo`3oool01P3oool5000000h0oooo1`00
000P0?ooo`8000001`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo0`00000F
0?ooo`D000000`3oool00`000000oooo0?ooo`090?ooo`8000004`3oool00`000000oooo0?ooo`0C
0?ooo`040000003oool00000000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`0D0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`040000003oool0oooo0?ooo`@000005`3oool3000002T0oooo
00<000000?ooo`3oool0:03oool100000040oooo000G0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0A@3oool5000000@0oooo0P0000060?ooo`800000403oool00`000000oooo0?oo
o`0D0?ooo`8000003@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02`3oool2000001H0oooo00<000000?ooo`3oool03P3oool2000000H0oooo0P00
00040?ooo`D00000A`3oool00`000000oooo0?ooo`0X0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`180?ooo`030000003oool0000000L000001P3oool2
000000d0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000001H0oooo00<000000?ooo`3oool02`3oool2000000H0oooo200000000`3oool00000
0?ooo`190?ooo`030000003oool0oooo02P0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00`3oool7000000H0oooo0`00
000:0?ooo`030000003oool0oooo0180oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0203oool7000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`800000503oool00`000000oooo0?ooo`080?ooo`<000001@3oool7000000H0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0Y0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00<0oooo2@000007
0?ooo`8000001`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`08000000<0oooo00@000000?ooo`3oool0oooo2000
00030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`X000001@3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo02T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool00`3oool5000000d0oooo0P000004
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`D000002`3oool00`000000oooo0?ooo`090?ooo`H000002@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool2000000d0oooo1@000005
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0:@3oool100000040oooo000G0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?oo
o`80000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo0P0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool01000
0000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B
0?ooo`040000003oool00000000001X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0Y0?ooo`4000000@3oool000X0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`04
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0J
0?ooo`8000004`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool000000?ooo`8000001@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool300000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`800000703o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo02T0oooo0@0000010?ooo`003@3oool0
0`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0J0?ooo`040000003oool00000000000l0oooo0P00000=0?ooo`@000001`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool4000000d0oooo0P00000?0?ooo`80000000<0oooo0000003oool06`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo02X0oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`07
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0080oooo0`00000;0?ooo`030000003oool0oooo00`0oooo1@000008
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`05
0?ooo`H000003P3oool00`000000oooo0?ooo`090?ooo`<00000103oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0:P3oool100000040oooo000=0?oo
o`0309a8B02Lgol0oooo00L0oooo0`00000Z0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`0;0?oo
o`L00000203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01@3oool8000000d0oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02P0oooo0`0000010?oo
o`0000<0oooo09a800000000100000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo00L0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool02@3oool2000000D0oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`3oool5000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo1P0000030?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool2000000X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo02X0oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`070?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00/0oooo0P0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0103oool3000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo100000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P00000=0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0[0?ooo`4000000@3oool000d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0=0?ooo`8000003P3oool00`000000oooo0?ooo`050?ooo`<000001`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool3000000L0oooo
00<000000?ooo`3oool0303oool2000000l0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo02/0oooo0@0000010?ooo`002P3oool01@3OW4P000000018
W02LB4P0W=oo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool010000000oooo00000000000;0?ooo`03
0000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`<000002@3oool00`000000oooo0?ooo`090?ooo`80
000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0:`3oool100000040oooo000<0?ooo`030=nLB00004P0W=oo00P0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`<00000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0[0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`8000000`3oool2000001D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo0P00
00030?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0/0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`@000006`3oool:00000140oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo1@00000F
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D
0?ooo`D000002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool03`3oool:000001/0oooo100000080?ooo`030000003oool0oooo02`0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`<000004P3oool010000000oooo0?ooo`3oool8
000001`0oooo2@00000B0?ooo`030000003oool0oooo00l0oooo0P0000060?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool4000001D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo1000000<0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool300000140oooo00<000000?ooo`3oool0403oool9
000001`0oooo200000030?ooo`030000003oool0oooo0100oooo0P00000J0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool04`3oool6000001@0oooo00<000000?ooo`3oool01P00000M0?oo
o`P00000503oool00`000000oooo0?ooo`0?0?ooo`H0000000<0oooo0000003oool03P3oool00`00
0000oooo0?ooo`0:0?ooo`L00000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04P3oool7000000`0oooo00<000000?ooo`3oool03@3oool80000
0140oooo00<000000?ooo`3oool04P3oool8000001`0oooo1P0000030?ooo`030000003oool0oooo
0180oooo1@00000F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0403oool8000001D0
oooo00<000000?ooo`3oool01@00000J0?ooo`@000000P3oool4000001H0oooo00<000000?ooo`3o
ool03`3oool9000000d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`06000001<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140
oooo1P0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo00/0oooo2@00000B0?ooo`03
0000003oool0oooo01@0oooo100000020?ooo`@000006@3oool600000080oooo00<000000?ooo`3o
ool04`3oool7000001<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0@0?ooo`L00000
5P3oool3000000040?ooo`0000000000000001L0oooo100000060?ooo`800000603oool00`000000
oooo0?ooo`030?oooa@000003P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0
oooo0`00000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0@0?ooo`<000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0
oooo500000050?ooo`030000003oool0oooo01H0oooo0P0000060?ooo`@000005`3oool200000080
oooo0`00000F0?ooo`H000004`3oool100000040oooo000G0?ooo`030000003oool0oooo0140oooo
1000000G0?ooo`8000000`3oool00`000000oooo0?ooo`0C0?ooo`@00000703oool>000000`0oooo
0`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`03000000d0oooo3P00000L0?ooo`@00000503oool00`000000oooo0?ooo`020?ooo`800000
5`3oool4000001<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0@0?ooo`@000005P3o
ool200000080oooo00<000000?ooo`3oool04`3oool3000001P0oooo200000070?ooo`030000003o
ool0oooo00P0oooo1000000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`080?ooo`@000002P3oool00`000000oooo0?ooo`050?ooo`P00000603o
ool3000001D0oooo00<000000?ooo`3oool00P00000F0?ooo`80000000<0oooo0000003oool04@3o
ool100000040oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo200000000`3oool000000?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001`00000>0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
01@0oooo200000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo2000000F0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0;`3oool100000040oooo000G0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0
oooo2@0000090?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool9000000H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0300
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`T0000000<0oooo0000003oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`09000000d0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0300oooo0@0000010?ooo`005`3oool200000380oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool00000008000002@3o
ool00`000000oooo0?ooo`060?ooo`P000007P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0703oool8000000P0oooo00<000000?ooo`3oool01`3o
ool200000080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0300oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool04P3oool6000000X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`P000005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool8000000H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`D000005@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0340oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool03`3oool7000000`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0=0?ooo`P00000303oool2000000030?ooo`000000oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo00000000000<0?ooo`P000003P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00X0oooo1P00000B0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0<P3oool100000040oooo000G0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0@0?ooo`D00000303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01H0oooo200000040?ooo`H0000000@0oooo0000003oool0oooo1P000004
0?ooo`P000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo1@00000B
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0<P3oool100000040oooo000G0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0?0?oo
o`H00000303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo300000000`3o
ool0000000000009000001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`H000004@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03<0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool03@3oool200000080oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0280oooo4000000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo000000020?ooo`8000003`3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo03<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0280oooo0P00000D0?ooo`030000003oool0oooo00/0oooo0P0000060?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`H00000
00@0oooo0000003oool0oooo1P00000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`8000003@3oool00`000000oooo0?ooo`0B0?ooo`80
0000903oool00`000000oooo0?ooo`0d0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0P0?ooo`<000005@3oool00`000000oooo0?ooo`090?ooo`800000
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
9P3oool3000000030?ooo`000000oooo00<00000:@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool2000000/0oooo00<000000?ooo`3oool0
4`3oool300000280oooo00<000000?ooo`3oool0=03oool100000040oooo000G0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0703oool5000001H0oooo00<000000?ooo`3oool01`3o
ool2000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02P0oooo10000000103oool0000000000000000Y0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`8000002@3oool00`000000oooo
0?ooo`0D0?ooo`@000007`3oool00`000000oooo0?ooo`0e0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0J0?ooo`H00000603oool00`000000oooo0?oo
o`040?ooo`@000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0:@3oool3000000030?ooo`000000000002/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo100000060?ooo`030000003o
ool0oooo01D0oooo1P00000M0?ooo`030000003oool0oooo03D0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01X0oooo1@00000H0?ooo`030000003oool0
oooo0080oooo0P0000000`3oool000000000000;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`<0000000<0oooo000000000000:`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool2
000000030?ooo`000000000000@0oooo00<000000?ooo`3oool05P3oool4000001d0oooo00<00000
0?ooo`3oool0=P3oool100000040oooo000G0?ooo`030000003oool0oooo03@0oooo0`00000K0?oo
o`D000006@3oool00`000000oooo0?ooo`02000000030?ooo`0000000000008000002`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool20000
00030?ooo`000000oooo02/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo100000000`3oool00000000000020?ooo`030000003oool0oooo
01L0oooo1@00000K0?ooo`<00000=P3oool100000040oooo000G0?ooo`030000003oool0oooo0380
oooo100000000`3oool000000?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000006P3oool30000
0080oooo1000000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo100000020?ooo`<000006P3oool01@00
0000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`0000000`00000d0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`D000000`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo0P0000030?ooo`D00000303oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`D000000`3oool2000001h0oooo00<000000?ooo`3oool05@3oool01000
0000oooo0?ooo`3oool5000001P0oooo00<000000?ooo`3oool05`3oool100000040oooo000G0?oo
o`030000003oool0oooo01D0oooo0P00000H0?ooo`D00000103oool00`000000oooo0?ooo`0C0?oo
o`8000007@3oool200000080oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00/0oooo0`0000030?ooo`030000003oool0oooo008000007@3oool2000001D0oooo00<00000
0?ooo`3oool00P3oool5000001P0oooo0P00000G0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0503oool3000001T0oooo0`0000060?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06`3oool2000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo1@00
000/0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool2000001d0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`<000006@3oool3000001H0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0C0?ooo`<000006@3oool4000000L0oooo00<00000
0?ooo`3oool03P3oool2000001`0oooo0P0000060?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo1@00
000/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0?0?ooo`040000003oool0oooo000000H0oooo0P00000L0?ooo`800000403oool00`000000oooo
0?ooo`050?ooo`@000006@3oool3000001D0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0A0?ooo`D00000603oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool06P3oool2000000T0oooo00<000000?ooo`0000004@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool5000002`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`0000002@3oool2000001`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000001P0oooo1@00000C0?ooo`4000000@3oool001L0oooo
0P00000A0?ooo`D00000603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
0P00000K0?ooo`8000002`3oool200000180oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02X0oooo0`00000]0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`8000002`3oool2000001/0oooo
0P00000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool500000140oooo
0P0000010?ooo`005`3oool00`000000oooo0?ooo`0A0?ooo`@000005`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool2000000d0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0:P3oool3000002d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool2000001/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo1000
000C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000G
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool2000001X0oooo0P00000>
0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02X0oooo0`00000]0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000h0oooo0P00000J
0?ooo`8000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`0000004`3oool100000040oooo000G0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0603oool200000100oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool3000002d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?oo
o`000000403oool2000001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool100000040oooo000G0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0;`3oool010000000oooo0?ooo`00000C0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`0n
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0o0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0@03oool100000040oooo000G0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03P3oool2000001/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6@3oool200000100oooo00<000000?ooo`3oool0@03oool100000040oooo000G0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0303oool2000000d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0P00000>0?ooo`030000003o
ool0oooo0440oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00X0oooo0`00000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`<00000303oool00`000000oooo0?ooo`120?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`080?ooo`<000003@3oool20000
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool2000000d0oooo1000000:0?ooo`030000003oool0oooo
04<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00H0
oooo1000000=0?ooo`<000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`<000003@3oool4000000P0
oooo00<000000?ooo`3oool0A03oool100000040oooo000G0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0103oool5000000d0oooo0`0000090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
0`00000=0?ooo`D000001P3oool00`000000oooo0?ooo`150?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`040?ooo`<000003P3oool3000000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool3000000h0oooo0`0000060?ooo`030000003oool0oooo04H0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000=0?ooo`@00000203oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`05
0?ooo`@000003P3oool00`000000oooo000000050?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0<@3oool100000040oooo000G0?ooo`030000003oool0oooo0300oooo0P00000F0?oo
o`050000003oool0oooo0?ooo`000000403oool5000000H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool5
00000100oooo00D000000?ooo`3oool0oooo0000000F0?ooo`800000<P3oool100000040oooo000G
0?ooo`030000003oool0oooo02l0oooo0P00000H0?ooo`040000003oool0oooo00000100oooo1@00
00060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00@0oooo1@00000@0?ooo`040000003oool0oooo000001L0oooo
0`00000a0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0;P3oool3000001T0oooo0P00
000C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`8000006@3oool200000340oooo0@0000010?ooo`005`3oool2000002l0oooo0`00000I
0?ooo`8000004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04@3oool2000001T0oooo0`00000_0?ooo`8000000@3oool001L0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0F0?ooo`@000006@3oool00`000000oooo0000000B0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0000001T0oooo1000000H0?ooo`030000003oool0oooo01@0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0C0?ooo`8000005`3oool4000001T0oooo00D000000?ooo`3o
ool0oooo0000000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000603oool5000001L0oooo0P00000E
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?oo
o`<00000603oool00`000000oooo0?ooo`030?ooo`8000003`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool2000000D0oooo00<000000?oo
o`3oool05P3oool3000001P0oooo0`00000D0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool04P3oool2000001T0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0000001T0oooo0P00000D
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool3000001P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`070?ooo`800000303oool01@000000oooo0?ooo`3oool0
000001T0oooo0P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`8000002@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo0`00
000C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0403oool4000001P0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool00000703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool05P3oool400000180oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0@0?ooo`<00000603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo0P00
00090?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0000000T0oooo0P00000=0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05P3oool500000140oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0?
0?ooo`@00000603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool200000200oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0N
0?ooo`800000203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05P3oool300000180oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0@0?oo
o`<000005`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01@3oool200000240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?oo
o`8000001P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00@0oooo0P0000080?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07`3oool2000000L0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`0000004P3oool100000040oooo000G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo0P0000050?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00<0oooo0P00000C0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`130?ooo`8000005P3oool200000080oooo00<000000?ooo`3oool08`3o
ool2000000h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo0P00000U0?ooo`030000003oool0oooo008000005@3oool2000004H0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`130?ooo`<000005`3oool3000002L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`<000005`3oool3000004D0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`130?ooo`<000006@3oool2000002L0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0080oooo0P00000:0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool09@3oool2000001P0oooo100000150?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0@`3oool3000001T0oooo00@000000?ooo`00000000009P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo02@0oooo0P0000000`3oool000000?ooo`0G0?ooo`@00000A@3oool10000
0040oooo000G0?ooo`030000003oool0oooo0480oooo1000000I0?ooo`040000003oool0oooo0?oo
o`8000009@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo0P0000030?oo
o`030000003oool0oooo01H0oooo100000150?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0@P3oool5000001P0oooo00<000000?ooo`3oool00`3oool2000002@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P00000h0?ooo`80
0000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool08P3oool2000000D0oooo00<000000?ooo`3oool05@3oool6000004@0oooo0@0000010?ooo`00
5`3oool2000004<0oooo1@00000H0?ooo`030000003oool0oooo00D0oooo0P00000S0?ooo`800000
3@3oool2000000X0oooo0P0000040?ooo`800000=03oool2000000@0oooo0P00000:0?ooo`800000
3@3oool2000002<0oooo0P0000070?ooo`030000003oool0oooo01D0oooo1P0000130?ooo`800000
0@3oool001L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00L0oooo0P00000S0?ooo`8000003@3oool2000000X0oooo00<000000?ooo`3oool00`3o
ool200000300oooo0P0000050?ooo`030000003oool0oooo00P0oooo0P00000=0?ooo`8000008`3o
ool2000000T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`140?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool02@3oool2000002<0oooo0P00000=0?ooo`8000002@3oool0
0`000000oooo0?ooo`040?ooo`800000;03oool2000000H0oooo00<000000?ooo`3oool01`3oool2
000000d0oooo0P00000S0?ooo`8000002`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0:P3oool100000040oooo000G0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00/0oooo0P00000S0?ooo`<00000303oool3000000L0oooo0`0000050?ooo`<000009P3oool30000
00D0oooo0`0000070?ooo`<00000303oool300000280oooo0`00000=0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0:@3oool2000001T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0=0?ooo`<000008`3oool2000000d0oooo0P0000080?ooo`<000001@3oool200000280
oooo0P0000050?ooo`<00000203oool2000000d0oooo0P00000R0?ooo`<00000403oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo0P00000/0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0:@3oool3000001L0oooo0P00000J0?ooo`030000003oool0oooo0100oooo
0P00000S0?ooo`8000003@3oool3000000P0oooo100000030?ooo`T00000403oool9000000<0oooo
100000080?ooo`<000003@3oool200000280oooo0P00000C0?ooo`030000003oool0oooo01P0oooo
0P00000G0?ooo`<00000:`3oool100000040oooo000G0?ooo`030000003oool0oooo02T0oooo0`00
000G0?ooo`<000006@3oool00`000000oooo0?ooo`0B0?ooo`<000008P3oool3000000d0oooo0`00
00090?ooo`<000002@3oool@000000T0oooo0`0000090?ooo`<000003@3oool300000240oooo0`00
000E0?ooo`030000003oool0oooo01L0oooo0`00000G0?ooo`<00000:`3oool100000040oooo000G
0?ooo`030000003oool0oooo02T0oooo0`00000H0?ooo`<00000603oool00`000000oooo0?ooo`0E
0?ooo`<000008P3oool3000000d0oooo100000080?ooo`T00000403oool9000000P0oooo1000000=
0?ooo`<000008@3oool3000001P0oooo00<000000?ooo`3oool05P3oool3000001P0oooo0`00000[
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?oo
o`@00000603oool4000001L0oooo00<000000?ooo`3oool0603oool300000280oooo0`00000>0?oo
o`@000003@3oool@000000d0oooo1000000>0?ooo`<000008@3oool3000001/0oooo00<000000?oo
o`3oool05@3oool4000001L0oooo1000000H0?ooo`030000003oool0oooo0100oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo1@00000G0?ooo`H0
00005@3oool00`000000oooo0?ooo`0K0?ooo`@000008@3oool4000000h0oooo1000000R0?ooo`@0
00003P3oool400000200oooo1000000N0?ooo`030000003oool0oooo01<0oooo1P00000G0?ooo`D0
00005`3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
3`3oool2000001L0oooo1@00000G0?ooo`L00000503oool00`000000oooo0?ooo`0O0?ooo`@00000
8@3oool3000000l0oooo2@00000@0?ooo`T000003`3oool300000200oooo1000000R0?ooo`030000
003oool0oooo0180oooo1`00000G0?ooo`D000005P3oool200000180oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0?0?ooo`<00000603oool00`000000oooo0?ooo`0G0?ooo`H000005@3o
ool00`000000oooo0?ooo`0S0?ooo`@00000803oool5000001<0oooo4000000C0?ooo`D000007`3o
ool4000002H0oooo00<000000?ooo`3oool04`3oool6000001T0oooo00<000000?ooo`3oool05P3o
ool300000140oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0?0?ooo`<00000603oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool00000008000005P3oool00`000000oooo0?ooo`0W
0?ooo`H000007`3oool8000002H0oooo2000000O0?ooo`D00000:P3oool00`000000oooo0?ooo`0D
0?ooo`<0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0F0?ooo`<000004@3oool1
00000040oooo000G0?ooo`030000003oool0oooo00l0oooo0`00000H0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02d0oooo2000000O0?ooo`/00000403oool;000001l0oooo2000000_0?ooo`030000003oool0oooo
01<0oooo00H000000?ooo`3oool000000?ooo`00000I0?ooo`030000003oool0oooo01H0oooo0`00
000A0?ooo`4000000@3oool000/0oooo00D0okmd000000000000000007Boo`070?ooo`030000003o
ool0oooo00h0oooo1000000H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03D0oooo1`00000S0?oooa0000008`3o
ool7000003L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool05@3oool400000140oooo0@0000010?ooo`002`3oool0
1P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`H0oooo00<000000?ooo`3oool03P3oool5000001L0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0?03oool8000004H0oooo2000000n0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo
1@00000@0?ooo`4000000@3oool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`050?ooo`030000003oool0oooo00h0oooo1@00000G0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0ooooAP00
00160?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01D0oooo1@00000@0?ooo`4000000@3oool000X0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0403oool100000040oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool01@3oool300000100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool300000040oooo000:0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0680oooo;P00001T0?ooo`030000003oool0oooo04d0oooo0@0000010?ooo`00
2P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00D0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`1F0?ooo`/00000;P3oool;000005P0oooo00<000000?ooo`3oool0
CP3oool100000040oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo1P3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0CP3oool8000004@0
oooo2000001@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=`3oool100000040
oooo000;0?ooo`050?oo_`1d000000000000B02Lgol01`3oool00`000000oooo0?ooo`0g0?ooo`80
00005P3oool00`000000oooo0?ooo`150?ooo`P000008P3oool?000002<0oooo200000170?ooo`03
0000003oool0oooo01@0oooo0P00000i0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
=`3oool3000001H0oooo00<000000?ooo`3oool0?03oool8000001l0oooo2`00000?0?ooo``00000
7`3oool8000003h0oooo00<000000?ooo`3oool0503oool2000003X0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0h0?ooo`<000005P3oool00`000000oooo0?ooo`0f0?ooo`D000007`3o
ool8000002H0oooo2000000O0?ooo`D00000>03oool00`000000oooo0?ooo`0D0?ooo`<00000>P3o
ool100000040oooo000G0?ooo`030000003oool0oooo03P0oooo1000000E0?ooo`030000003oool0
oooo0380oooo1000000O0?ooo`D000004`3oool?000001@0oooo1@00000O0?ooo`@00000=03oool0
0`000000oooo0?ooo`0C0?ooo`<00000>`3oool100000040oooo000G0?ooo`030000003oool0oooo
03P0oooo1@00000E0?ooo`030000003oool0oooo02d0oooo1000000P0?ooo`<000003`3oool90000
00l0oooo2P00000?0?ooo`<00000803oool4000002l0oooo00<000000?ooo`3oool04`3oool40000
03/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`H000005@3oool00`000000
oooo0?ooo`0X0?ooo`@000008@3oool3000000h0oooo1000000R0?ooo`@000003P3oool300000240
oooo1000000Z0?ooo`030000003oool0oooo01<0oooo1@00000k0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0>@3oool4000001L0oooo00<000000?ooo`3oool08`3oool400000240oooo
1000000=0?ooo`@00000103ooolR000000@0oooo1000000=0?ooo`@000008@3oool3000002H0oooo
00<000000?ooo`3oool05@3oool3000003`0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo01<0oooo0P0000000`3oool000000?ooo`0F0?ooo`030000003o
ool0oooo0200oooo0`00000R0?ooo`<000003@3oool4000000H0oooo0P00000R0?ooo`8000001P3o
ool4000000d0oooo0`00000Q0?ooo`<000008`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0000001H0oooo00<000000?ooo`3oool08`3oool100000040oooo000G0?ooo`030000003oool0
oooo02<0oooo0P00000G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool2
00000280oooo0`00000=0?ooo`<000001`3oool3000000/0oooo3`00000<0?ooo`<000001`3oool3
000000d0oooo0`00000Q0?ooo`800000803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01D0oooo0P00000U0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool08`3oool20000
01P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0I0?ooo`<000008P3oool20000
00h0oooo0P0000070?ooo`<000001@3oool9000000l0oooo2P0000050?ooo`<000001`3oool20000
00h0oooo0P00000Q0?ooo`<00000703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01H0oooo0P00000U0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0903oool2000001L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`<000008`3oool2000000d0
oooo0`0000070?ooo`8000001P3oool200000280oooo0P0000060?ooo`8000001`3oool3000000d0
oooo0P00000R0?ooo`<000006@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0
oooo0P00000V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0903oool3000001L0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`<00000903oool2000000d0oooo
0P0000080?ooo`8000001P3oool2000002H0oooo0P0000060?ooo`800000203oool2000000d0oooo
0P00000S0?ooo`@00000503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo
0`00000V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0E0?ooo`@000005P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo0P00
000U0?ooo`8000003@3oool2000000P0oooo0P0000060?ooo`800000:P3oool2000000H0oooo0P00
00080?ooo`8000003@3oool2000002D0oooo0P00000A0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0503oool4000001L0oooo00<000000?ooo`3oool0303oool100000040oooo000G
0?ooo`030000003oool0oooo00`0oooo0P00000F0?ooo`@000005`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00`0oooo0P00000U0?ooo`8000003@3oool2000000T0oooo00<00000
0?ooo`3oool0103oool2000002h0oooo0P0000060?ooo`030000003oool0oooo00L0oooo0P00000=
0?ooo`8000009@3oool2000000h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0E
0?ooo`@000005P3oool2000000h0oooo0@0000010?ooo`005`3oool2000000d0oooo0P00000G0?oo
o`@000005P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo0P00000U0?oo
o`8000003@3oool2000000T0oooo0P0000050?ooo`800000<P3oool2000000D0oooo0P0000090?oo
o`8000003@3oool2000002D0oooo0P00000<0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0503oool4000001L0oooo0P00000=0?ooo`8000000@3oool001L0oooo00<000000?ooo`3o
ool0303oool3000001H0oooo0`00000H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool01`3oool2000002D0oooo0P00000=0?ooo`8000002P3oool00`000000oooo0?ooo`030?ooo`80
0000=P3oool2000000D0oooo00<000000?ooo`3oool0203oool2000000d0oooo0P00000U0?ooo`80
00002@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo0`00000F0?ooo`<0
00003P3oool100000040oooo000G0?ooo`030000003oool0oooo00`0oooo1000000E0?ooo`030000
003oool0000001T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`800000
9P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool2000003X0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0T0?ooo`8000001P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`0000005@3oool3000000l0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0=0?ooo`@000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool00P3oool2000002L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0U0?ooo`800000103oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool4000000l0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0=0?ooo`@000005`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01L0oooo00@000000?ooo`0000000000:03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo02H0oooo0P0000000`3oool000000?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05@3oool4000000l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0=
0?ooo`D000005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0P000004
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`D000003`3oool100000040oooo000G0?oo
o`030000003oool0oooo00d0oooo0`00000I0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05@3oool2000000030?ooo`000000oooo02H0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0U0?ooo`040000003oool00000000001L0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0G0?ooo`<000003`3oool100000040oooo000G0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01@0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`8000003`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool2000002D0oooo00D00000
0?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool1
00000040oooo000G0?ooo`030000003oool0oooo05L0oooo0P00000Y0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01P3oool2000000H0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`040?ooo`800000203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02L0oooo0P00001I0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`1F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0E03oool2000002X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0X0?ooo`800000EP3oool100000040oooo
000G0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0D`3oool100000040oooo000G
0?ooo`030000003oool0oooo03@0oooo1000000I0?ooo`800000:`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02T0oooo0P00000I0?ooo`@00000=P3oool100000040oooo000G0?oo
o`030000003oool0oooo03D0oooo2000000C0?ooo`030000003oool0oooo02T0oooo0P00000A0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool8000003L0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0f0?ooo`H000004P3oool2000002/0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0Z0?ooo`8000004@3oool6000003T0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0g0?ooo`D000004@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0>0?ooo`D00000
>P3oool100000040oooo000G0?ooo`030000003oool0oooo03T0oooo0P0000000`3oool000000000
000>0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00`0oooo1@00000k0?ooo`4000000@3oool001L0oooo0P00000k
0?ooo`040000003oool0oooo0?ooo`8000002`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`8000000P3o
ool00`000000oooo0?ooo`0j0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0;P3oool2
00000100oooo0P0000080?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo0P00000?0?ooo`800000<@3oool1
00000040oooo000G0?ooo`030000003oool0oooo02l0oooo1@00000>0?ooo`<00000103oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`020?ooo`<000003@3oool500000380oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0`0?ooo`L000003P3oool2000000030?ooo`000000oooo02h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0^0?ooo`040000003oool00000000000h0oooo1P00000c0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0<@3oool500000140oooo0P00000^0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool200000100oooo1@00000d0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`@00000
403oool00`000000oooo0?ooo`02000002`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Z0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`@000004`3oool00`000000oooo
0?ooo`0N0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool07`3oool200000180oooo0P00
00000`3oool000000?ooo`0=0?ooo`030000003oool0oooo00<0oooo0P00000Y0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0:03oool2000000D0oooo00<000000?ooo`3oool02`3o
ool500000180oooo0P00000Q0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool07`3oool4
00000140oooo00<000000?ooo`3oool00P00000;0?ooo`030000003oool0oooo00H0oooo0P00000W
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09@3oool2000000P0oooo00<00000
0?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000140oooo1000000Q0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?ooo`D00000503oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0`00000S0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool08P3oool3000000/0oooo00<000000?ooo`3oool01P3oool2
000001@0oooo1@00000G0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`090?ooo`8000005P3oool5000001@0oooo0P0000060?ooo`030000003oool0oooo
00d0oooo0P00000Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07`3oool20000
00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`D000005P3oool20000
00/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`090?ooo`@000005@3oool3000001L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`8000007`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo0P00000B0?ooo`040000003oool0oooo0?oo
o`8000005`3oool3000001D0oooo1000000;0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool02P3oool5000001<0oooo1000000G0?ooo`80000000<0oooo0000003oool0503oool2000001`0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`8000005@3oool00`000000
oooo0000000H0?ooo`@000004`3oool5000000`0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0;0?ooo`D000004`3oool010000000oooo0?ooo`00000H0?ooo`8000005`3oool2000001X0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`8000005`3oool2000001P0
oooo00@000000?ooo`3oool000004P3oool6000000d0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0<0?ooo`<00000603oool2000001H0oooo00<000000?ooo`000000603oool2000001P0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`800000603oool00`000000
oooo0000000F0?ooo`8000005`3oool4000000h0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0<0?ooo`@000006@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`80
0000603oool2000001D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`80
0000603oool2000000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`@0
00003P3oool100000040oooo000G0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0
00006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05`3oool2000001<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`80
00006@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`00000?0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0m0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0l0?ooo`4000000@3oool001L0oooo0P00000l0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03X0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo03/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
03X0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03T0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03P0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03D0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03D0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03<0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo03<0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0L0?oo
o`@00000303oool:000003T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0g0?oo
o`X00000303oool4000001h0oooo0@0000010?ooo`005`3oool2000000P0oooo0P00000D0?ooo`P0
0000203oool9000000D0oooo0P00000a0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0;P3oool3000000D0oooo2@0000080?ooo`P00000503oool2000000P0oooo0P0000010?ooo`00
5`3oool00`000000oooo0?ooo`080?ooo`D000004@3oool6000000/0oooo1`0000000`3oool00000
0000000400000340oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0^0?ooo`L00000
00<0oooo0000000000001@00000:0?ooo`H000004P3oool5000000X0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`090?ooo`L000003`3oool6000000/0oooo3@00000a0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0;P3oool>000000/0oooo1@00000@0?ooo`L000002`3o
ool100000040oooo000G0?ooo`030000003oool0oooo00X0oooo1@00000B0?ooo`8000000P3oool2
000000P0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000000B000002@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0R0?oooa@0000000<0oooo0000000000000`3o
ool00`000000oooo0?ooo`060?ooo`80000000@0oooo00000000000000004@3oool6000000`0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`D000004P3oool00`000000oooo0?oo
o`020?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`D0000000<0oooo0000000000000P00
00080?ooo`h000005P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo3P00
00080?ooo`@0000000<0oooo0000000000000`0000090?ooo`030000003oool0oooo00<0oooo0P00
00030?ooo`030000003oool0oooo0140oooo1@00000=0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0303oool200000080oooo00<000000?ooo`3oool05P3oool2000000<0oooo00<00000
0?ooo`3oool02P3oool2000000D0oooo0`00000C0?ooo`P000003P3oool00`000000oooo0?ooo`05
0?ooo`@000003@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool4000000L0oooo00<000000?ooo`3oool0303oool8000001<0oooo0`000005
0?ooo`800000303oool010000000oooo0?ooo`3oool2000001P0oooo00<000000?ooo`0000000P00
000>0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03h0oooo2000000A0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`P00000@03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo03L0oooo2@00000H0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0F0?ooo`P00000>P3oool00`000000oooo0?ooo`0]0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0`0?ooo`L0
0000203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo2000000b0?ooo`03
0000003oool0oooo02d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02T0oooo1`00000?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3@3oool7000002/0oooo00<000000?ooo`3oool0;@3oool100000040oooo000G0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool08`3oool7000001H0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0D0?ooo`L000009@3oool00`000000oooo0?ooo`0/0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0K0?ooo`P000007@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01/0oooo1`00000N0?ooo`030000003oool0
oooo02`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01@0oooo1`00000U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08P3oool70000
01L0oooo00<000000?ooo`3oool0;03oool100000040oooo000G0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00P3oool2000000X0oooo1`00000/0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0:@3oool8000000X0oooo0P0000040?ooo`030000003oool0oooo02/0
oooo0@0000010?ooo`002P3oool00`3o_g@000000000000300000003001d_`3oool0oooo00@0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0400000080oooo2000000c0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0<@3oool7000000<0oooo100000020?ooo`030000
003oool0oooo02/0oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003o
ool0oooo02/0oooo2@00000l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>@3o
ool:000002d0oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0
oooo02T0oooo2P00000m0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool9
000002`0oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo
02X0oooo00@000000?ooo`3oool0oooo1@00000m0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0>`3oool5000000<0oooo00<000000?ooo`3oool0:P3oool100000040oooo000=0?oo
o`0309a8B02Lgol0oooo00L0oooo0`00000Z0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo0P00000d0?oo
o`8000003@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0X0?ooo`<000000@3oool000d0oooo00<0W4Q809cOo`3o
ool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo0`00000^0?ooo`<0
00003P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0Z0?ooo`4000000@3oool000d0oooo00<0W4Q809cOo`3oool0
1`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0@0?ooo`8000003`3oool3000002P0oooo0`00000?0?ooo`800000
4P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
:P3oool100000040oooo000:0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00l0oooo0`00000R0?ooo`<000004@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0Y0?ooo`4000000@3oool000`0oooo00<0gia80000B02Lgol0203oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo1000000J0?ooo`@000004`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0Y0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D
0?ooo`D00000403oool5000001H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0:@3oool100000040oooo000G0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool5000000D0oooo1P00000J0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo02T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`80
00007@3oool5000001h0oooo0P00000D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0Y0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:03o
ool100000040oooo000G0?ooo`030000003oool0oooo00H0oooo2P00000A0?ooo`@000000`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool2
000003P0oooo0P00000F0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0B03oool0
10000000oooo0?ooo`3oool400000140oooo2P0000080?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool01`3oool9000000`0oooo2@0000030?ooo`030000003oool0oooo00/0oooo0P00000l
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool2000003@0oooo0P00000G
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool2000000d0oooo00@00000
0?ooo`3oool0oooo2@00000<0?ooo`T000002@3oool100000040oooo000G0?ooo`030000003oool0
oooo00T0oooo1P00000?0?ooo`T0000000<0oooo0000003oool0203oool6000003`0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`800000<03oool2000001P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`H000002@3oool00`000000oooo00000008
000000h0oooo1`00000;0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool02`3oool60000
00l0oooo1@0000020?ooo`@00000103ooolF000001P0oooo0`00000D0?ooo`040000003oool0oooo
0?ooo`800000703oool00`000000oooo0?ooo`0H0?ooo`800000;03oool2000001X0oooo00<00000
0?ooo`3oool06P3oool2000000<0oooo00<000000?ooo`3oool04P3oool3000001P0oooo5P000004
0?ooo`@000000P3oool5000000l0oooo1P00000=0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool03@3oool2000001@0oooo0P0000020?ooo`030000003oool0oooo00L0oooo1`00000P0?oo
o`D00000603oool3000001l0oooo00<000000?ooo`3oool06@3oool2000002P0oooo0P00000K0?oo
o`030000003oool0oooo01d0oooo0`00000H0?ooo`D00000803oool7000000T0oooo00<000000?oo
o`3oool00P00000D0?ooo`8000003`3oool100000040oooo000G0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool02`3oool3000001/0oooo1@00000L0?ooo`8000008P3oool00`000000
oooo0?ooo`0J0?ooo`P00000603oool8000001`0oooo00<000000?ooo`3oool0803oool2000001`0
oooo1@00000K0?ooo`<000003@3oool00`000000oooo0?ooo`0W0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo
1000000O0?ooo`8000000P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo
200000080?ooo`P000008`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00800000
7`3oool4000000T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0W0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`<00000103o
ool500000200oooo0`0000040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:03o
ool8000002X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`<00000803o
ool5000000@0oooo0`00000K0?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`005`3oool2
000002P0oooo00<000000?ooo`3oool05`3oool9000002<0oooo0P0000080?ooo`030000003oool0
oooo0240oooo0P00001H0?ooo`8000008`3oool00`000000oooo0?ooo`060?ooo`8000008`3oool9
000001T0oooo00<000000?ooo`3oool09P3oool200000040oooo000G0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool05@3oool8000002@0oooo0P00000:0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00T0oooo0P00000T0?ooo`P000005`3oool00`000000oooo0?ooo`0W0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`X000008P3oool2000000d0
oooo00<000000?ooo`3oool08`3oool200000580oooo0P00000U0?ooo`030000003oool0oooo00/0
oooo0P00000R0?ooo`X000005@3oool00`000000oooo0?ooo`0W0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0l0?ooo`<000003`3oool00`000000oooo
0?ooo`0U0?ooo`800000CP3oool2000002H0oooo00<000000?ooo`3oool03P3oool3000003h0oooo
00<000000?ooo`3oool09`3oool100000040oooo000G0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0>P3oool2000001<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04@3oool2000003`0oooo00<0
00000?ooo`3oool09`3oool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0>@3oool2000001D0oooo00<000000?ooo`3oool09`3oool2000004P0oooo0P00000X
0?ooo`030000003oool0oooo01@0oooo0P00000k0?ooo`030000003oool0oooo02H0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03L0oooo0P00000H0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01L0oooo0P00000i0?ooo`030000003oool0oooo02H0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03@0oooo0`00000J0?ooo`03
0000003oool0oooo02T0oooo0P0000120?ooo`800000:P3oool00`000000oooo0?ooo`0I0?ooo`<0
0000=P3oool00`000000oooo0?ooo`0V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0b0?ooo`8000007P3oool00`000000oooo0?ooo`0Z0?ooo`800000
?P3oool2000002/0oooo00<000000?ooo`3oool07@3oool2000003@0oooo00<000000?ooo`3oool0
9P3oool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0<03o
ool200000240oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0803oool200000380oooo00<000000?ooo`3oool09P3o
ool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;@3oool3
000002<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool08P3oool3000002l0oooo00<000000?ooo`3oool09P3oool1
00000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:`3oool20000
02L0oooo00<000000?ooo`3oool0;03oool2000003H0oooo0P00000]0?ooo`030000003oool0oooo
02H0oooo0P00000]0?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo0P00000Z0?ooo`030000003oool0oooo02d0
oooo0`00000`0?ooo`<00000;`3oool00`000000oooo0?ooo`0X0?ooo`800000:`3oool00`000000
oooo0?ooo`0V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0S0?ooo`040000003oool0oooo0?ooo`800000;@3oool00`000000oooo0?ooo`0_0?ooo`H0
0000903oool600000340oooo00<000000?ooo`3oool0:`3oool2000000<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0Q0?ooo`H00000<03oool00`000000oooo0?ooo`0d0?ooo`H00000
603oool6000003H0oooo00<000000?ooo`3oool0;P3oool6000002<0oooo00<000000?ooo`3oool0
9P3oool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803o
ool5000003<0oooo00<000000?ooo`3oool0>@3oool8000000P0oooo2000000k0?ooo`030000003o
ool0oooo0340oooo1@00000R0?ooo`030000003oool0oooo02H0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo1P00000d0?ooo`030000003oool0
oooo0400oooo200000120?ooo`030000003oool0oooo0340oooo1`00000P0?ooo`030000003oool0
oooo02L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01`0oooo2@00000d0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0<P3oool90000
01h0oooo00<000000?ooo`3oool09`3oool100000040oooo000G0?ooo`8000003`3oool2000001L0
oooo00<000000?ooo`3oool06`3oool5000003X0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0h0?ooo`D000007@3oool00`000000oooo0?ooo`0E0?ooo`8000003`3oool200000040
oooo000G0?ooo`030000003oool0oooo00X0oooo1P00000E0?ooo`<00000G03oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo05/0oooo0`00000E0?ooo`H00000303oool100000040oooo
000G0?ooo`030000003oool0oooo00L0oooo2P00000B0?ooo`P00000603oool2000001T0oooo0P00
000I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0G0?ooo`8000006@3oool2000001P0oooo2000000B0?ooo`X000002@3oool100000040oooo000G
0?ooo`030000003oool0oooo00T0oooo1`00000@0?ooo`P000004`3oool010000000oooo0?ooo`3o
ool4000001T0oooo0P00000I0?ooo`8000003@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`8000006@3o
ool2000001T0oooo100000030?ooo`030000003oool0oooo0140oooo2000000@0?ooo`L000002`3o
ool100000040oooo000G0?ooo`030000003oool0oooo00d0oooo0`00000>0?ooo`X000004@3oool6
000001/0oooo0P00000J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0H0?ooo`8000006`3oool600000140oooo2P00000>0?ooo`<000003`3oool1
00000040oooo000G0?ooo`030000003oool0oooo0280oooo1P00000?0?ooo`D00000703oool20000
01/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01T0oooo0P00000K0?ooo`H000003`3oool6000002@0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo2000000I0?ooo`8000006`3oool2000001@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04P3oool2000001/0oooo0P00000I0?ooo`P00000303oool00`000000
oooo0?ooo`0X0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`080?ooo`X000005`3oool2000001`0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01X0oooo0P00000G0?ooo`X000002P3oool00`000000oooo
0?ooo`0X0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00<000007@3oool00`000000oooo0?ooo`0G0?ooo`050000003o
ool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3o
ool06`3oool300000080oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0X0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Q0?ooo`D00000
7P3oool2000001/0oooo00<000000?ooo`000000703oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0000000K0?ooo`800000
7P3oool5000002<0oooo00<000000?ooo`3oool0:03oool100000040oooo000G0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0803oool4000001l0oooo00<000000?ooo`3oool0703o
ool2000001`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01X0oooo0P00000N0?ooo`030000003oool0oooo01`0oooo1@00000R0?ooo`030000003o
ool0oooo02P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo01l0oooo1P00000M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`0000006`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0000000O0?ooo`030000003oool0oooo01X0oooo1`00000Q0?ooo`030000003oool0
oooo02P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01`0oooo2000000K0?ooo`8000007`3oool010000000oooo0?ooo`3oool2000001P0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo0P000003
0?ooo`030000003oool0oooo01d0oooo0P00000J0?ooo`T000007P3oool00`000000oooo0?ooo`0Y
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0K0?oo
o`D000007P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0703oool5000001d0oooo00<000000?ooo`3oool0:@3oool100000040oooo000G0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00H0oooo0P00000E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0C0?ooo`800000203oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0:@3oool100000040oooo000G0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0>`3oool200000200oooo00<000000?ooo`3oool0
2@3oool200000180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0100oooo0P00000;0?ooo`030000003oool0oooo01h0oooo0P00000m0?ooo`030000
003oool0oooo02T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0:@3oool100000040oooo000G0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00d0oooo0P00000>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0<0?ooo`8000003`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0:P3oool100000040oooo000G0?ooo`800000:`3oool00`00
0000oooo0?ooo`0f0?ooo`8000008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00X0oooo0P00000B0?ooo`030000003oool0oooo0200oooo0P00000h0?ooo`030000003oool0oooo
02T0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0B0?ooo`8000002`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool2000001D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0000000e0?ooo`030000003oool0oooo02X0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0380oooo
0`00000S0?ooo`030000003oool0oooo01D0oooo0P0000080?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`800000603oool00`000000oooo
0?ooo`0Q0?ooo`<00000=03oool00`000000oooo0?ooo`0Z0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0a0?ooo`@000008`3oool00`000000oooo0?oo
o`0G0?ooo`8000001P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool00`3oool2000001X0oooo00<000000?ooo`3oool08@3oool4000003<0oooo00<0
00000?ooo`3oool0:P3oool100000040oooo000G0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0;`3oool600000240oooo00<000000?ooo`3oool06P3oool2000000@0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo0?ooo`8000007@3o
ool00`000000oooo0?ooo`0O0?ooo`H00000<@3oool00`000000oooo0?ooo`0[0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0^0?ooo`D000008P3oool0
0`000000oooo0?ooo`0M0?ooo`80000000<0oooo0000003oool0803oool00`000000oooo0?ooo`0P
0?ooo`<00000803oool00`000000oooo0?ooo`0P0?ooo`D00000<03oool00`000000oooo0?ooo`0[
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0]0?oo
o`@000008`3oool00`000000oooo0?ooo`0P0?ooo`<00000803oool00`000000oooo0?ooo`0N0?oo
o`<000008`3oool00`000000oooo0?ooo`0Q0?ooo`@00000;`3oool00`000000oooo0?ooo`0[0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0/0?ooo`80
00009@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000<00000703oool00`000000
oooo0?ooo`0K0?ooo`<000000P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0
oooo0P00000^0?ooo`030000003oool0oooo02/0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0?0?ooo`8000006P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0103oool4000001P0oooo00<000000?ooo`3oool05`3oool4000000H0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01T0oooo
0P00000A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool03@3oool4000001H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool4000001@0oooo00<000000?ooo`3oool04`3oool4000000X0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000
5`3oool4000000l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0:0?ooo`L00000503o
ool3000000050?ooo`00000000000?ooo`0000005`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`@00000
403oool00`000000oooo0?ooo`0?0?ooo`@000001@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0000000@00000503oool8000000`0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`080?ooo`T000004P3oool6000000<0oooo00<000000?ooo`3oool03`3oool010000000oooo0?oo
o`3oool2000001T0oooo0P00000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool9000000L0oooo00<000000?ooo`3oool01P3oool9000000T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`8000006@3oool2000000<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0600000180oooo2P00000:0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0303oool500000100oooo200000030?ooo`030000003oool0oooo00h0oooo1@00
000J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0A0?oooa0000004`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0603oool5000000l0oooo00@000000?ooo`3oool0oooo2000000@0?ooo`D00000
3`3oool100000040oooo000G0?ooo`030000003oool0oooo0200oooo2@0000040?ooo`030000003o
ool0oooo00`0oooo1000000J0?ooo`8000006P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01P0oooo0P00000J0?ooo`@000003P3oool010000000oooo0?ooo`3oool:00000280oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo1`00
000H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01H0oooo1`00000<0?ooo`030000003oool0oooo02d0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo1P00000E
0?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3oool000005P3oool6000000/0oooo00<000000?ooo`3oool0
;@3oool100000040oooo000G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0203o
ool3000001P0oooo1@00000K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool4000001T0oooo0`0000090?ooo`030000003oool0oooo02h0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0240oooo1@00000K0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool4000002@0oooo00<000000?ooo`3oool0;P3oool1
00000040oooo000G0?ooo`800000;`3oool00`000000oooo0?ooo`0P0?ooo`L000006@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo1P00000S0?ooo`030000003oool0oooo
02d0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0200
oooo1@00000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool500000240
oooo00<000000?ooo`3oool0;`3oool100000040oooo000G0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool07P3oool4000001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0000000F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`0I0?ooo`@00000803oool00`000000oooo0?ooo`0_0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0M0?ooo`8000006P3oool010000000oooo0?oo
o`0000050?ooo`@000005@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`@000001@3oool010000000oooo
0?ooo`00000J0?ooo`8000007P3oool00`000000oooo0?ooo`0`0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0h0?ooo`@000001P3oool5000001@0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04P3oool5000000H0oooo1000000i0?ooo`030000003oool0oooo0300oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03L0oooo1000
00050?ooo`D00000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`D000001@3oool4000003P0oooo00<0
00000?ooo`3oool0<@3oool100000040oooo000G0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0=P3oool6000000@0oooo0`00000E0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo0`000004
0?ooo`H00000=`3oool00`000000oooo0?ooo`0a0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0e0?ooo`D00000103oool3000001H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0503oool3000000@0oooo1@00000f0?ooo`030000003oool0oooo0380oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03@0oooo100000060?ooo`80
00005P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0D0?ooo`8000001P3oool4000003D0oooo00<000000?ooo`3o
ool0<P3oool100000040oooo000G0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
<`3oool2000000L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00D0oooo0P00000d0?ooo`030000003oool0oooo03<0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<`3o
ool100000040oooo000G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0d0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0000001D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0000004l0oooo00<000000?ooo`3oool0=@3oool100000040
oooo00090?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0103oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo04h0oooo0`00000D0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04P3oool3000004l0oooo00<000000?ooo`3oool0=@3oool100000040oooo
000:0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0C03oool5000001<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`D00000C@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`002`3oool00`3o_g@0001809cOo`09
0?ooo`030000003oool0oooo00l0oooo0`00000G0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0C03oool4000001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B
0?ooo`@00000C@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo0`00000A
0?ooo`4000000@3oool000`0oooo00<0omnL04P00018W=l0203oool00`000000oooo0?ooo`0>0?oo
o`@000005@3oool3000000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0o0?oo
o`@00000503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo0`0000120?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool4000001@0oooo1@00000@0?oo
o`4000000@3oool000h0oooo00<0W4P004RLg`3oool01P3oool3000000`0oooo1`00000C0?ooo`D0
00002`3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01`3oool3000000h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo0`0000090?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo00000002000000P0
oooo00<000000?ooo`3oool02P3oool5000001<0oooo1`00000<0?ooo`<000000@3oool000l0oooo
00<0W4Qd0;ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`T000004P3oool6000001@0oooo
1@00000J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool2000000h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo
0P00000:0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool5000001<0oooo
1`00000B0?ooo`T00000303oool100000040oooo000:0?ooo`030=nLB01d_ol0oooo0080oooo00<0
_g@007Boo`3oool01@3oool00`000000oooo0?ooo`090?ooo`D000005@3oool900000180oooo1@00
000F0?ooo`030000003oool0oooo008000006@3oool00`000000oooo0?ooo`080?ooo`8000003`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3o
ool2000000X0oooo00<000000?ooo`3oool05`3oool200000080oooo00<000000?ooo`3oool04`3o
ool600000180oooo2@00000E0?ooo`D000002`3oool100000040oooo000:0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`060?ooo`030000003oool0oooo0280oooo1@00000F0?ooo`L00000
503oool4000001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool4000001@0oooo1`00000F0?ooo`D00000
903oool100000040oooo000;0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo
0?ooo`0l0?ooo`H000005P3oool4000001X0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo0`0000070?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`<000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool4000001H0oooo
1P00000n0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0>`3oool3000001T0oooo1P00
000H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`D000001@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00`3oool5000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01H0oooo1P00000I0?ooo`<00000?@3oool100000040oooo000G
0?ooo`030000003oool0oooo05H0oooo1P00000F0?ooo`030000003oool0000001`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`@000001@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool4000000T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0000001H0oooo1P00001H
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0E@3oool5000001L0oooo0`00000L0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool4000000D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo1000000:0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool3000001P0oooo1@00001G0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0E@3oool3000001T0oooo1000000K0?ooo`03
0000003oool0oooo00<0oooo0`00000:0?ooo`<000001P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool3000000X0oooo0`0000050?ooo`03
0000003oool0oooo01T0oooo1000000I0?ooo`<00000E`3oool100000040oooo000G0?ooo`030000
003oool0oooo05@0oooo0P00000J0?ooo`H000006@3oool00`000000oooo0?ooo`040?ooo`D00000
203oool3000000H0oooo00<000000?ooo`3oool05`3oool5000001X0oooo00<000000?ooo`3oool0
103oool3000000P0oooo1@0000060?ooo`030000003oool0oooo01L0oooo1@00000K0?ooo`800000
EP3oool100000040oooo000G0?ooo`030000003oool0oooo0700oooo1@00000J0?ooo`030000003o
ool0oooo00@0oooo100000090?ooo`8000001P3oool00`000000oooo0?ooo`0H0?ooo`D000006`3o
ool00`000000oooo0?ooo`040?ooo`8000002@3oool4000000H0oooo00<000000?ooo`3oool0603o
ool500000780oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1_0?ooo`@000006@3oool0
0`000000oooo000000070?ooo`@000002@3oool2000000H0oooo00<000000?ooo`3oool0603oool4
000001`0oooo00<000000?ooo`3oool0103oool2000000T0oooo100000070?ooo`030000003oool0
000001T0oooo0`00001b0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0K`3oool30000
01X0oooo0`0000060?ooo`@000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01T0oooo0`00000L0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool30000
00L0oooo0`00000J0?ooo`<00000L@3oool100000040oooo000G0?ooo`030000003oool0oooo06h0
oooo0`00000J0?ooo`D000001@3oool3000001<0oooo00<000000?ooo`3oool06@3oool3000001`0
oooo00<000000?ooo`3oool04@3oool3000000@0oooo1@00000K0?ooo`800000L@3oool100000040
oooo000G0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool06P3oool4000000H0oooo
0P00000C0?ooo`030000003oool0oooo01X0oooo0`00000M0?ooo`030000003oool0oooo0140oooo
0P0000050?ooo`D00000703oool00`000000oooo0?ooo`1^0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0R`3oool3000000L0oooo0P00000A0?ooo`<00000703oool2000001h0oooo0`00
000A0?ooo`8000001P3oool4000008d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`2;
0?ooo`800000203oool00`000000oooo0?ooo`0@0?ooo`D000006`3oool00`000000oooo0?ooo`0J
0?ooo`D000004P3oool00`000000oooo0?ooo`050?ooo`<00000S@3oool100000040oooo000G0?oo
o`030000003oool0oooo08X0oooo0`00000K0?ooo`@000006P3oool5000001/0oooo1000000K0?oo
o`800000S@3oool100000040oooo000G0?ooo`800000R`3oool2000001`0oooo1000000J0?ooo`D0
00006`3oool4000001`0oooo0P00002;0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0K0?ooo`<000006`3oool4000001d0oooo0`00000M0?ooo`030000
003oool0oooo08X0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`2X0?ooo`<000006`3o
ool5000001`0oooo0`00002Z0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0Z03oool2
000001`0oooo1@00000M0?ooo`800000ZP3oool100000040oooo000G0?ooo`030000003oool0oooo
0:P0oooo0P00000L0?ooo`@000007P3oool200000:X0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo01`0oooo0`00000O0?ooo`030000003oool0oooo0:P0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`370?ooo`<00000bP3oool100000040oooo
000G0?ooo`030000003oool0oooo0<L0oooo0`00003:0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0a`3oool200000</0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo0<T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`380?ooo`03
0000003oool0oooo0<T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
oiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`3o0?oooiD0oooo0@0000010?ooo`005`3oool200000140oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`0?0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool10000
0040oooo000G0?ooool00000V@0000010?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-2.45528, -2.34095, 0.0162276, \
0.0166862}}]
}, Closed]],

Cell[TextData[{
  "Notice that the local variable ",
  StyleBox["Efield", "InlineInput"],
  " is not defined outside the module."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Efield\)], "Input"],

Cell[BoxData[
    \(Efield\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Write a function f[x,y] using Module that returns ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%n x\^k\/\(k!\)\)]],
  " where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the largest integer less than or equal to ",
  StyleBox["y",
    FontSlant->"Italic"],
  ".  Of course, your function should only respond to positive ",
  StyleBox["y",
    FontSlant->"Italic"],
  ".  Verify that the function works properly and that the local variables \
are protected properly."
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["With", "Subsubsection",
  CellTags->"With"],

Cell[TextData[{
  ButtonBox["With",
    ButtonStyle->"RefGuideLink"],
  " is another scoping command designed to assign values to local constants.  \
The basic syntax is ",
  StyleBox["With[{x=x0,y=y0,\[CenterEllipsis]},expr]", "InlineInput"],
  " ",
  StyleBox["where the expression ",
    FontFamily->"Times New Roman"],
  StyleBox["expr", "InlineInput",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["is evaluated using local constants ", "MR",
    FontFamily->"Times New Roman"],
  StyleBox["x", "MR",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", ", "MR",
    FontFamily->"Times New Roman"],
  StyleBox["y", "MR",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", ... assigned local values ", "MR",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_0\)\(,\)\)\)],
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)],
    FontFamily->"Times New Roman"],
  StyleBox[", ... ",
    FontFamily->"Times New Roman"],
  ".  The principal distinction between ",
  StyleBox["With", "InlineInput"],
  " and ",
  StyleBox["Module", "InlineInput"],
  " is that ",
  StyleBox["With", "InlineInput"],
  " employs ",
  StyleBox["local constants",
    FontSlant->"Italic"],
  " that are evaluated only once, whereas ",
  StyleBox["Module", "InlineInput"],
  " employs ",
  StyleBox["local variables",
    FontSlant->"Italic"],
  " whose values may change many times as the body of the module is \
evaluated.  Thus, code written with ",
  StyleBox["With", "InlineInput"],
  " is sometimes more transparent to the reader than equivalent code based \
upon ",
  StyleBox["Module", "InlineInput"],
  ".  The local constants do not escape the scope of ",
  StyleBox["With", "InlineInput"],
  " and may have the same names as external global symbols.  The expression \
evaluated by ",
  StyleBox["With", "InlineInput"],
  " may itself be a ",
  StyleBox["Module", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[
    \(a\  = \ "\<stuff\>"; \ b = "\<more stuff\>"; \ 
    c = "\<yet more stuff\>";\)], "Input"],

Cell[BoxData[
    \(ff[x_]\  := \ 
      With[{a = 2, b = 3, c = 4}, \ a\ x\^2 + b\ x\  + \ c]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff[x]\)], "Input"],

Cell[BoxData[
    \(4 + 3\ x + 2\ x\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}\)], "Input"],

Cell[BoxData[
    \({"stuff", "more stuff", "yet more stuff"}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Note that you cannot reassign a local constant within ",
  StyleBox["With", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[
    \(gg[x_]\  := \ 
      With[{a = 2, b = 3, c = 4}, \ a = 12; b = \(-12\); c = "\<junk\>"; 
        a\ x\^2 + b\ x\  + \ c]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg[y]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Set::"setraw"\), \(\(:\)\(\ \)\), "\<\"Cannot assign to raw \
object \\!\\(2\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Set::setraw\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Set::"setraw"\), \(\(:\)\(\ \)\), "\<\"Cannot assign to raw \
object \\!\\(3\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Set::setraw\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Set::"setraw"\), \(\(:\)\(\ \)\), "\<\"Cannot assign to raw \
object \\!\\(4\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Set::setraw\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(Set :: \\\"setraw\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(4 + 3\ y + 2\ y\^2\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Note that ",
  StyleBox["With", "InlineInput"],
  " protects local constants by appending ",
  StyleBox["$", "InlineInput"],
  " to the corresponding symbols, a method similar to that used by ",
  StyleBox["Module", "InlineInput"],
  ".  Verify by using ",
  StyleBox["Trace[ff[x]]", "InlineInput"],
  "."
}], "Text"],

Cell[TextData[{
  "Plot the function ",
  Cell[BoxData[
      \(TraditionalForm\`\((Sin[x\  + \ y]/\((x + y)\))\)\^2\)]],
  " using With to assign the value ",
  Cell[BoxData[
      \(TraditionalForm\`y = \[Pi]\)]],
  ".  Verify that ",
  StyleBox["y",
    FontSlant->"Italic"],
  " can be assigned a value that is not changed by your assignment within \
With."
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Block", "Subsubsection",
  CellTags->"Block"],

Cell[TextData[{
  "Another type of scoping command is ",
  ButtonBox["Block",
    ButtonStyle->"RefGuideLink"],
  ".  The principal difference between ",
  StyleBox["Block", "InlineInput"],
  " and ",
  StyleBox["Module", "InlineInput"],
  " is that ",
  StyleBox["Block", "InlineInput"],
  " treats the values assigned to symbols as local but treats their names as \
global, whereas ",
  StyleBox["Module", "InlineInput"],
  " treats the names of local variables as local.  The basic syntax is either \
",
  StyleBox["Block[{x,y,...}, expr]", "InlineInput"],
  " or ",
  StyleBox["Block[{", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x = x\_0\)], "InlineInput"], "InlineInput"],
  StyleBox[",", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`y = y\_0\)], "InlineInput"], "InlineInput"],
  StyleBox[",...},expr]", "InlineInput"],
  " where ",
  StyleBox["{x,y,...}", "InlineInput"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "are assigned local values during the evaluation of the expression ",
  StyleBox["expr", "InlineInput"],
  ", and may change during that evaluation, but their names exist outside the \
scope of ",
  StyleBox["Block", "InlineInput"],
  ".  If initial values ",
  StyleBox["{", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\_0\)], "InlineInput"], "InlineInput"],
  StyleBox[",", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`y\_0\)], "InlineInput"], "InlineInput"],
  StyleBox[",...}", "InlineInput"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "are supplied, these are used as local starting values.  Note that \
commands, such as ",
  StyleBox["Table", "InlineInput"],
  " and ",
  StyleBox["Do", "InlineInput"],
  ", implicitly use ",
  StyleBox["Block", "InlineInput"],
  " for handling iterators.  "
}], "Text"],

Cell[BoxData[
    \(Clear[f, x]\)], "Input"],

Cell[BoxData[
    \(f[x_] := 
      Block[{a = 2, b = 3, c = 4}, \ a\ x\^2 + b\ x\  + \ c]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}\)], "Input"],

Cell[BoxData[
    \({"stuff", "more stuff", "yet more stuff"}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x]\)], "Input"],

Cell[BoxData[
    \(4 + 3\ x + 2\ x\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}\)], "Input"],

Cell[BoxData[
    \({"stuff", "more stuff", "yet more stuff"}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Notice that ",
  StyleBox["Block", "InlineInput"],
  " has not changed the values of the global variables.  Similarly, ",
  StyleBox["Table", "InlineInput"],
  " can use an iterator whose name has been assigned a global value without \
interference with that value."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[a\^2, {a, 0, 4}]\)], "Input"],

Cell[BoxData[
    \({0, 1, 4, 9, 16}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\)], "Input"],

Cell[BoxData[
    \("stuff"\)], "Output"]
}, Closed]],

Cell[TextData[{
  "However, ",
  StyleBox["Block", "InlineInput"],
  " does not always prevent confusion between local and global symbols.  \
Compare the following versions of a function which adds reciprocal powers of \
its argument."
}], "Text"],

Cell[BoxData[
    \(f[x_] := Module[{i}, Sum[1\/x\^i, {i, 0, 5}]]\)], "Input"],

Cell[BoxData[
    \(g[x_] := Block[{i}, Sum[1\/x\^i, {i, 0, 5}]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[2], f[x], f[i]}\)], "Input"],

Cell[BoxData[
    \({63\/32, 1 + 1\/x\^5 + 1\/x\^4 + 1\/x\^3 + 1\/x\^2 + 1\/x, 
      1 + 1\/i\^5 + 1\/i\^4 + 1\/i\^3 + 1\/i\^2 + 1\/i}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({g[2], g[x], g[i]}\)], "Input"],

Cell[BoxData[
    RowBox[{\(Power::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\^0\\) encountered. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\
\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({1\/2, 1 + 1\/x\^5 + 1\/x\^4 + 1\/x\^3 + 1\/x\^2 + 1\/x, 
      Indeterminate}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "The version using ",
  StyleBox["Block", "InlineInput"],
  " fails because the local variable conflicts with the argument of the \
function.  Normally one should use ",
  StyleBox["Module", "InlineInput"],
  " instead of ",
  StyleBox["Block", "InlineInput"],
  ", but there are circumstances where ",
  StyleBox["Block", "InlineInput"],
  " can be useful.  For example, if one needs to temporarily modify a system \
parameter within a small section of code, ",
  StyleBox["Block", "InlineInput"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is helpful but ",
  StyleBox["Module", "InlineInput"],
  " does not work because it appends extra stuff to the name of the local \
variables.  Bahder suggests the following example."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[0] = 1;\)\), "\n", 
    \(\(f[n_] := n\ f[n - 1];\)\)}], "Input"],

Cell[BoxData[
    \(blockFactorial[n_] := 
      Block[{$RecursionLimit = n + 3}, \ f[n]]\)], "Input"],

Cell[BoxData[
    \(moduleFactorial[n_] := 
      Module[{$RecursionLimit = n + 3}, \ f[n]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(blockFactorial[280]\)], "Input"],

Cell[BoxData[
    \(167722777994521853160085596424816909961541626534432242162291441665330104\
951381765521757796289008661549376554670808935097251174020947867974304499659925\
918550478633350704981975370539488820962625657803155049347444823310804256805524\
909715970621113493074470581392199438348464270814752346757803031862414953643544\
732202479813341827378961464965690571682052631724229322685452070652306446657920\
521862865039783751144138273095992874774212646014655759122298169234041732019773\
378783792109329300988876034817392640000000000000000000000000000000000000000000\
00000000000000000000000000\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(moduleFactorial[280]\)], "Input"],

Cell[BoxData[
    RowBox[{\($RecursionLimit::"reclim"\), \(\(:\)\(\ \)\), "\<\"Recursion \
depth of \\!\\(256\\) exceeded. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"$RecursionLimit::reclim\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(415884773572898676057465131862361483607482037154131021064513888064310967\
112206335713850366178233953700076253129400011175883083250920819786085389786247\
556720012922688191148103030739180351948922221324832212137596740663366294759096\
330539446115423863014654861213807126300883692335455632344300893073538472851104\
007370215710797387298276517229175017495525406242692574024214650957992344318292\
389101294313454437219106727254120667091125353319974610916461281326807082506678\
55644402384896000000000000000000000000000000000000000000000000000000000000000\
\ Hold[f[27 - 1]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Nevertheless, ",
  StyleBox["Module", "InlineInput"],
  " or ",
  StyleBox["With", "InlineInput"],
  " is preferred under most circumstances."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Conditional functions", "Subsection",
  CellTags->"conditional functions"],

Cell[CellGroupData[{

Cell["If, Which, and Switch", "Subsubsection"],

Cell[TextData[{
  "A ",
  StyleBox["conditional",
    FontSlant->"Italic"],
  " ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is a command whose actions depend upon conditions.  We have already \
explored how conditions can be applied to definitions or to rules using the \
condition operator (",
  StyleBox["/;", "InlineInput"],
  ").  More sophisticated conditional branching can be implemented using the \
",
  StyleBox["If", "InlineInput"],
  ", ",
  StyleBox["Which", "InlineInput"],
  ", or ",
  StyleBox["Switch", "InlineInput"],
  " functions. "
}], "Text"],

Cell[TextData[{
  "The basic syntax for the ",
  ButtonBox["If",
    ButtonStyle->"RefGuideLink"],
  " function is ",
  StyleBox["If[condition,t,f]", "InlineInput"],
  ", where the expression ",
  StyleBox["t", "InlineInput"],
  " is returned if the ",
  StyleBox["condition", "InlineInput"],
  " is true or the expression ",
  StyleBox["f", "InlineInput"],
  " is returned if the condition is false.  However, the entire command is \
returned unevaluated if the condition is indefinite."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[step];\)\), "\n", 
    \(step[x_]\  := \ If[x > 0, 1, 0]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({step[\(-1\)], step[0], step[2], step[x], \ 
      step[x - 1] /. x \[Rule] 2}\)], "Input"],

Cell[BoxData[
    \({0, 0, 1, If[x > 0, 1, 0], 1}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Although this version of the step function is more compact than the \
earlier version using three conditional definitions, the value for ",
  StyleBox["step[0]", "InlineInput"],
  " is not what we prefer; a better version based upon ",
  StyleBox["Which", "InlineInput"],
  " is given below.  Also note that the result for an argument which yields \
an ambiguous condition remains unevaluated.  An alternative form which always \
returns something is ",
  StyleBox["If[condition,t,f,u]", "InlineInput"],
  ", where the expression ",
  StyleBox["u", "InlineInput"],
  " is return if the status of the condition is uncertain."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f[x_]\  := \ If[x > 0, 1, 0, 0]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[\(-1\)], f[0], f[2], f[x], \ f[x - 1] /. x \[Rule] 2}\)], "Input"],

Cell[BoxData[
    \({0, 0, 1, 0, 0}\)], "Output"]
}, Closed]],

Cell[TextData[
"We chose a different name because this variant isn't really a well-defined \
step function \[LongDash] the interpretation of unknown variables remains \
problematical."], "Text"],

Cell[TextData[{
  "A more flexible conditional function is the ",
  ButtonBox["Which",
    ButtonStyle->"RefGuideLink"],
  " command with basic syntax ",
  StyleBox["Which[test1,expr1,test2,expr2,\[CenterEllipsis]]", 
    "InlineInput"],
  ".  Each test is evaluated in turn and the expression corresponding to the \
first true case is returned.  With this command we can construct a step \
function that returns the desired value at the transition point but does not \
produce unreliable results for uncertain input.  A default value can be given \
simply by choosing ",
  StyleBox["True", "InlineInput"],
  " as the final test in the sequence.  However, if a test is encountered \
that cannot be evaluated as either ",
  StyleBox["True", "InlineInput"],
  " or ",
  StyleBox["False", "InlineInput"],
  ", the statement is returned unevaluated."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[step];\)\), "\n", 
    \(step[x_]\  := \ 
      Which[x > 0, 1, x \[Equal] 0, \ 1\/2, \ x < 0, \ 0]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({step[\(-1\)], step[0], step[2], step[x], \ 
      step[x - 1] /. x \[Rule] 2}\)], "Input"],

Cell[BoxData[
    \({0, 1\/2, 1, Which[x > 0, 1, x \[Equal] 0, 1\/2, x < 0, 0], 
      1}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Finally, an even more sophisticated conditional is ",
  ButtonBox["Switch",
    ButtonStyle->"RefGuideLink"],
  " which combines pattern testing with conditional evaluation.  The basic \
syntax is ",
  StyleBox["Switch[expr,form1,value1,form2,value2,\[CenterEllipsis]]", 
    "InlineInput"],
  ".  The input expression ",
  StyleBox["expr", "InlineInput"],
  " is compared with each pattern ",
  StyleBox["form", "InlineInput"],
  " until a match is found and the corresponding ",
  StyleBox["value", "InlineInput"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`value\)]],
  " is returned.  Note that a default value can be given simply by ending \
with a blank pattern.  The following example comes from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Book.  ",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(switchfunction[x_] := 
      Switch[x, \n_Integer, FactorInteger[x], \n_Rational, N[x], \n_Real, 
        Rationalize[x], \n_Complex, Im[x], \n_Symbol, 
        1 + x\^2, \n_, "\<The Head is \>" <> 
          ToString[Head[x]] <> "\<.\>"]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(switchfunction /@ {12, 1\/3, 9.1, 
        2 + 7\ I, \[Pi], "\<xxx yyy\>"}\)], "Input",
  CellTags->"Switch"],

Cell[BoxData[
    \({{{2, 2}, {3, 1}}, 0.3333333333333333`, 91\/10, 7, 1 + \[Pi]\^2, 
      "The Head is String."}\)], "Output",
  CellTags->"Switch"]
}, Closed]],

Cell[TextData[{
  "Write a function whose values are ",
  Cell[BoxData[
      \(TraditionalForm\`1 - \[LeftBracketingBar]x\[RightBracketingBar]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[LessEqual] 1\)]],
  " or 0 for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[GreaterEqual] 1\)]],
  ".  Make several variations using conditioned arguments, If, or Which."
}], "Exercise"],

Cell["\<\
Use If or Which to write a function that gives the gravitational acceleration \
for a uniform sphere.  (Refer to the earlier version of this problem for \
details.)\
\>", "Exercise"],

Cell[TextData[{
  "Finite-difference methods for differential equations represent the \
solution on a uniform grid ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\) = x\_i + dx\)]],
  " with spacing dx as a vector ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_i]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, n\)]],
  " and approximate the second derivative by \n\t",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(f\^\[DoublePrime]\)[
              x\_i] = \(f[x\_\(i + 1\)]\  - \ 2  f[x\_i] + f[x\_\(i - \
1\)]\)\/dx\^2\),
          "DisplayFormula"], TraditionalForm]]],
  " \nThus, the second derivative can be constructed by matrix \
multiplication, ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\[DoublePrime] = A . f\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " is an operator acting on the solution vector.  Use Table and Switch to \
write a function A[n_,dx_] that constructs the desired matrix."
}], "Exercise",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Use Switch to write a function that in a single statement defines the area of \
simple geometric figures, including triangle, rectangle, parallelogram, \
trapezoid, etc.  Compare with the earlier version using multiple definitions.\
\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Boole and Piecewise: new in Version 5.1", "Subsubsection"],

Cell[TextData[{
  "Two new conditional functions were introduced in Version 5.1.  ",
  ButtonBox["Boole",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[expr]", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "returns 1 if the logical ",
  StyleBox["expr", "InlineInput"],
  " evaluates to 1 if true or 0 if false.  This simple function is equivalent \
to ",
  StyleBox["If[expr,", "InlineInput"],
  StyleBox["1,0", "InlineInput"],
  StyleBox["]", "InlineInput"],
  " but is handy nonetheless.  A more sophisticated conditional function is \
",
  ButtonBox["Piecewise",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput"],
  StyleBox["{{", "InlineInput"],
  StyleBox["val1,cond1", "InlineInput"],
  StyleBox["},{", "InlineInput"],
  StyleBox["val2,cond2", "InlineInput"],
  StyleBox["}\[CenterEllipsis]},", "InlineInput"],
  StyleBox["val]", "InlineInput"],
  " which returns the first value for which the corresponding condition is \
true.  If none of the conditions evaluate to ",
  StyleBox["True", "InlineInput"],
  ", the final value is returned; if omitted, the default final value is 0.  \
If any of the conditions are indeterminate, the result is only partially \
evaluated.  ",
  StyleBox["Piecewise", "InlineInput"],
  " can be nested and can be used in integrals, differential equations, and \
in most applications suitable for conventional functions. "
}], "Text"],

Cell[TextData[{
  "For example, we can now define spherical Bessel functions by providing an \
explicit formula for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " that interprets the removable singularity at the origin."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[sbessj];\)\), "\[IndentingNewLine]", 
    \(\(sbessj[0, z_] = 
        Piecewise[{{1, z \[Equal] 0}}, 
          Sin[z]\/z];\)\), "\[IndentingNewLine]", 
    \(\(sbessj[n_, z_] = \@\(\[Pi]\/2\)\ \(z\^\(\(-1\)/2\)\) 
          BesselJ[n + 1\/2, z];\)\)}], "Input"],

Cell["This version behaves well numerically.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[Table[sbessj[n, x], {n, 0, 3}]], {x, \(-10\), 
          10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.193476 0.409845 [
[.02381 .18098 -9 -9 ]
[.02381 .18098 9 0 ]
[.2619 .18098 -6 -9 ]
[.2619 .18098 6 0 ]
[.7381 .18098 -3 -9 ]
[.7381 .18098 3 0 ]
[.97619 .18098 -6 -9 ]
[.97619 .18098 6 0 ]
[.4875 .02954 -24 -4.5 ]
[.4875 .02954 0 4.5 ]
[.4875 .11151 -24 -4.5 ]
[.4875 .11151 0 4.5 ]
[.4875 .27544 -18 -4.5 ]
[.4875 .27544 0 4.5 ]
[.4875 .35741 -18 -4.5 ]
[.4875 .35741 0 4.5 ]
[.4875 .43938 -18 -4.5 ]
[.4875 .43938 0 4.5 ]
[.4875 .52135 -18 -4.5 ]
[.4875 .52135 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .19348 m
.02381 .19973 L
s
[(-10)] .02381 .18098 0 1 Mshowa
.2619 .19348 m
.2619 .19973 L
s
[(-5)] .2619 .18098 0 1 Mshowa
.7381 .19348 m
.7381 .19973 L
s
[(5)] .7381 .18098 0 1 Mshowa
.97619 .19348 m
.97619 .19973 L
s
[(10)] .97619 .18098 0 1 Mshowa
.125 Mabswid
.07143 .19348 m
.07143 .19723 L
s
.11905 .19348 m
.11905 .19723 L
s
.16667 .19348 m
.16667 .19723 L
s
.21429 .19348 m
.21429 .19723 L
s
.30952 .19348 m
.30952 .19723 L
s
.35714 .19348 m
.35714 .19723 L
s
.40476 .19348 m
.40476 .19723 L
s
.45238 .19348 m
.45238 .19723 L
s
.54762 .19348 m
.54762 .19723 L
s
.59524 .19348 m
.59524 .19723 L
s
.64286 .19348 m
.64286 .19723 L
s
.69048 .19348 m
.69048 .19723 L
s
.78571 .19348 m
.78571 .19723 L
s
.83333 .19348 m
.83333 .19723 L
s
.88095 .19348 m
.88095 .19723 L
s
.92857 .19348 m
.92857 .19723 L
s
.25 Mabswid
0 .19348 m
1 .19348 L
s
.5 .02954 m
.50625 .02954 L
s
[(-0.4)] .4875 .02954 1 0 Mshowa
.5 .11151 m
.50625 .11151 L
s
[(-0.2)] .4875 .11151 1 0 Mshowa
.5 .27544 m
.50625 .27544 L
s
[(0.2)] .4875 .27544 1 0 Mshowa
.5 .35741 m
.50625 .35741 L
s
[(0.4)] .4875 .35741 1 0 Mshowa
.5 .43938 m
.50625 .43938 L
s
[(0.6)] .4875 .43938 1 0 Mshowa
.5 .52135 m
.50625 .52135 L
s
[(0.8)] .4875 .52135 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .05003 m
.50375 .05003 L
s
.5 .07052 m
.50375 .07052 L
s
.5 .09101 m
.50375 .09101 L
s
.5 .132 m
.50375 .132 L
s
.5 .15249 m
.50375 .15249 L
s
.5 .17298 m
.50375 .17298 L
s
.5 .21397 m
.50375 .21397 L
s
.5 .23446 m
.50375 .23446 L
s
.5 .25495 m
.50375 .25495 L
s
.5 .29594 m
.50375 .29594 L
s
.5 .31643 m
.50375 .31643 L
s
.5 .33692 m
.50375 .33692 L
s
.5 .37791 m
.50375 .37791 L
s
.5 .3984 m
.50375 .3984 L
s
.5 .41889 m
.50375 .41889 L
s
.5 .45988 m
.50375 .45988 L
s
.5 .48037 m
.50375 .48037 L
s
.5 .50086 m
.50375 .50086 L
s
.5 .54184 m
.50375 .54184 L
s
.5 .56234 m
.50375 .56234 L
s
.5 .58283 m
.50375 .58283 L
s
.5 .00905 m
.50375 .00905 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .17118 m
.06244 .20391 L
.08255 .22208 L
.0932 .23051 L
.10458 .23792 L
.11009 .24076 L
.11531 .24293 L
.11999 .24442 L
.12263 .24506 L
.12507 .24552 L
.12616 .24568 L
.12734 .24583 L
.12846 .24593 L
.12947 .24601 L
.13067 .24606 L
.13196 .24609 L
.13319 .24608 L
.13433 .24603 L
.13561 .24595 L
.13682 .24583 L
.13791 .2457 L
.13908 .24552 L
.14172 .24501 L
.14415 .24438 L
.14885 .24278 L
.15389 .24047 L
.16298 .23479 L
.17378 .22563 L
.18364 .21523 L
.22348 .16111 L
.2417 .13627 L
.25208 .12417 L
.26181 .11495 L
.26645 .11145 L
.27133 .10847 L
.27389 .10722 L
.27668 .10611 L
.27922 .10533 L
.28045 .10504 L
.28159 .10482 L
.2829 .10463 L
.28359 .10456 L
.28433 .1045 L
.28556 .10445 L
.28626 .10444 L
.28691 .10446 L
.28813 .10453 L
.28924 .10465 L
.29053 .10485 L
.29175 .1051 L
Mistroke
.29444 .10587 L
.29694 .10685 L
.29968 .10824 L
.3026 .11008 L
.30797 .11443 L
.31291 .11957 L
.32405 .13518 L
.33387 .15351 L
.34423 .17729 L
.38225 .29627 L
.42273 .44571 L
.44141 .50745 L
.46169 .56052 L
.46706 .57141 L
.47275 .58132 L
.47803 .58893 L
.48297 .59464 L
.48758 .59869 L
.49018 .60042 L
.49255 .60165 L
.49374 .60214 L
.49501 .60257 L
.49574 .60277 L
.4964 .60293 L
.49769 .60316 L
.49839 .60324 L
.49903 .60329 L
.49974 .60332 L
.50048 .60331 L
.50173 .60323 L
.50244 .60314 L
.50311 .60303 L
.50436 .60275 L
.5057 .60234 L
.5081 .60135 L
.51068 .59989 L
.51354 .59782 L
.51864 .59293 L
.52343 .58698 L
.53235 .57251 L
.54198 .55226 L
.562 .49696 L
.58309 .42481 L
.62117 .28404 L
.64239 .21414 L
.66169 .16315 L
.67132 .14331 L
.68175 .12636 L
.68654 .12021 L
.69161 .11483 L
Mistroke
.69628 .11089 L
.70071 .10803 L
.70306 .10685 L
.70563 .10584 L
.70676 .10549 L
.70796 .10517 L
.70909 .10492 L
.71013 .10474 L
.71144 .10457 L
.71213 .10451 L
.71286 .10447 L
.71409 .10444 L
.71479 .10446 L
.71544 .10449 L
.71666 .10458 L
.71777 .10472 L
.71905 .10494 L
.72026 .1052 L
.72247 .10582 L
.72481 .10667 L
.72903 .10866 L
.73356 .11146 L
.73856 .11526 L
.75792 .1358 L
.77878 .16438 L
.79845 .19244 L
.80884 .20619 L
.81994 .21922 L
.83071 .22974 L
.84049 .23718 L
.8452 .23999 L
.85032 .24244 L
.85266 .24335 L
.85514 .24418 L
.85727 .24477 L
.85959 .24528 L
.8609 .24552 L
.86212 .2457 L
.86338 .24585 L
.86453 .24596 L
.86565 .24603 L
.86671 .24607 L
.86783 .24609 L
.86904 .24607 L
.87026 .24602 L
.87096 .24598 L
.87161 .24593 L
.87292 .2458 L
.87432 .24561 L
.87686 .24517 L
Mistroke
.87918 .24464 L
.88369 .24329 L
.88859 .24136 L
.8975 .23672 L
.91732 .22218 L
.93835 .20317 L
.97617 .17119 L
.97619 .17118 L
Mfstroke
.02381 .16132 m
.03279 .15639 L
.04262 .15229 L
.04758 .15081 L
.0503 .15017 L
.05288 .14969 L
.05528 .14935 L
.05664 .1492 L
.05789 .1491 L
.05894 .14904 L
.0601 .14899 L
.06131 .14897 L
.06244 .14897 L
.0631 .14899 L
.06379 .14901 L
.06504 .14908 L
.06581 .14914 L
.06653 .1492 L
.06788 .14935 L
.07036 .14971 L
.07305 .15023 L
.0781 .15161 L
.08274 .15331 L
.09336 .15874 L
.10458 .16666 L
.12422 .18495 L
.14255 .20523 L
.16119 .22629 L
.18146 .24614 L
.18681 .25038 L
.19249 .25427 L
.19776 .25727 L
.2027 .25949 L
.2073 .26101 L
.20989 .26162 L
.21226 .26202 L
.21354 .26218 L
.21472 .26228 L
.21602 .26234 L
.21675 .26236 L
.21741 .26236 L
.2181 .26234 L
.21874 .26232 L
.21945 .26228 L
.22019 .26222 L
.22144 .26209 L
.22282 .26189 L
.22532 .26138 L
.22803 .26062 L
.23298 .25865 L
Mistroke
.2378 .25603 L
.24227 .25296 L
.25239 .24379 L
.26316 .23076 L
.28461 .1961 L
.3048 .1559 L
.3434 .07575 L
.36338 .0425 L
.37343 .02999 L
.3791 .02445 L
.38445 .02031 L
.38936 .01748 L
.39213 .01632 L
.39345 .01587 L
.39469 .01552 L
.39581 .01525 L
.39684 .01505 L
.39798 .01489 L
.39921 .01477 L
.40032 .01472 L
.40154 .01472 L
.40282 .01479 L
.404 .01492 L
.40531 .01513 L
.40673 .01544 L
.40931 .01623 L
.41182 .01727 L
.41413 .01847 L
.41938 .02204 L
.42493 .02709 L
.43439 .03864 L
.44454 .05493 L
.46287 .09329 L
.5042 .20551 L
.52487 .2629 L
.54401 .30928 L
.56257 .34385 L
.57195 .35645 L
.57729 .36204 L
.58231 .36619 L
.58699 .3691 L
.58965 .37033 L
.59212 .3712 L
.59347 .37156 L
.59474 .37183 L
.59588 .37202 L
.59712 .37216 L
.59776 .3722 L
.59847 .37223 L
.59921 .37224 L
Mistroke
.5999 .37223 L
.60114 .37216 L
.60183 .37209 L
.60247 .37201 L
.60361 .37182 L
.60482 .37156 L
.607 .37094 L
.6096 .36994 L
.61195 .36881 L
.61659 .36592 L
.62096 .36245 L
.63074 .35218 L
.64106 .33795 L
.65953 .30559 L
.69753 .2262 L
.71869 .18486 L
.73797 .15467 L
.74755 .14323 L
.7526 .13826 L
.75797 .13382 L
.76264 .13065 L
.7678 .12794 L
.77006 .127 L
.7725 .12617 L
.77479 .12554 L
.7769 .12511 L
.77818 .12491 L
.77939 .12477 L
.78047 .12468 L
.78164 .12461 L
.78293 .12459 L
.78357 .1246 L
.78428 .12462 L
.78554 .12469 L
.78671 .1248 L
.78789 .12495 L
.78901 .12512 L
.79111 .12555 L
.79337 .12613 L
.79584 .12692 L
.80104 .12909 L
.80658 .13211 L
.81654 .13917 L
.83801 .1598 L
.8582 .18257 L
.87663 .20288 L
.88708 .21312 L
.89682 .22139 L
.90729 .2286 L
.91681 .23346 L
Mistroke
.92205 .23539 L
.927 .23673 L
.92971 .23726 L
.93222 .23762 L
.93353 .23776 L
.93498 .23787 L
.9357 .23791 L
.93648 .23795 L
.93722 .23797 L
.9379 .23798 L
.93914 .23798 L
.9403 .23795 L
.94135 .2379 L
.94249 .23782 L
.94373 .23771 L
.94504 .23756 L
.94739 .23722 L
.95159 .23635 L
.9562 .23505 L
.96119 .23324 L
.96654 .23088 L
.97619 .22563 L
Mfstroke
.02381 .22542 m
.06244 .19757 L
.08255 .17864 L
.10458 .15872 L
.11448 .15107 L
.12507 .14434 L
.1302 .14172 L
.13506 .13969 L
.13942 .13824 L
.14189 .13759 L
.14415 .13711 L
.1465 .13672 L
.14779 .13656 L
.14903 .13644 L
.15016 .13636 L
.15121 .13631 L
.15236 .13628 L
.15359 .13628 L
.15429 .1363 L
.15494 .13633 L
.15565 .13636 L
.1564 .13642 L
.15766 .13654 L
.15904 .13671 L
.1616 .13714 L
.16399 .13768 L
.1693 .13936 L
.17414 .14146 L
.18502 .14812 L
.19493 .15646 L
.2041 .16592 L
.22486 .1925 L
.26413 .25205 L
.28382 .27972 L
.30188 .30006 L
.31131 .30807 L
.3161 .31136 L
.32123 .31426 L
.32639 .31652 L
.32869 .31731 L
.33119 .31801 L
.33272 .31836 L
.33412 .31863 L
.33544 .31884 L
.3369 .31901 L
.3382 .31912 L
.33942 .31919 L
.3407 .31921 L
.34142 .31921 L
.34208 .31919 L
Mistroke
.34338 .31913 L
.34459 .31903 L
.34568 .31891 L
.34686 .31875 L
.34952 .31826 L
.35195 .31765 L
.35641 .31616 L
.36111 .31408 L
.371 .30809 L
.38184 .29926 L
.42232 .25334 L
.441 .23102 L
.46128 .2107 L
.47234 .20247 L
.4772 .19964 L
.48256 .1971 L
.48499 .19617 L
.4876 .19532 L
.48986 .19471 L
.49233 .19418 L
.49361 .19397 L
.49497 .19378 L
.49572 .1937 L
.49641 .19363 L
.4971 .19358 L
.49774 .19354 L
.49897 .19349 L
.49961 .19348 L
.50029 .19348 L
.50144 .1935 L
.5027 .19356 L
.504 .19367 L
.5052 .1938 L
.50652 .19399 L
.50793 .19423 L
.51028 .19475 L
.51288 .19547 L
.51768 .1972 L
.52218 .19931 L
.53224 .20559 L
.54309 .21457 L
.58419 .2614 L
.6047 .28565 L
.61469 .29601 L
.62379 .30411 L
.63325 .31092 L
.63759 .31341 L
.64219 .31559 L
.64452 .31651 L
.6471 .31737 L
Mistroke
.64946 .31802 L
.65162 .31849 L
.65284 .31871 L
.65417 .3189 L
.6549 .31898 L
.65558 .31905 L
.65626 .31911 L
.65691 .31915 L
.65817 .3192 L
.65931 .31921 L
.66054 .31919 L
.66123 .31916 L
.66186 .31912 L
.66313 .31901 L
.66432 .31887 L
.66657 .3185 L
.66898 .31797 L
.67161 .31721 L
.67633 .31541 L
.6807 .31324 L
.69073 .30651 L
.70137 .29686 L
.72086 .27356 L
.73914 .24711 L
.77785 .1887 L
.7979 .16372 L
.80799 .15379 L
.81366 .14912 L
.81901 .14535 L
.82394 .14244 L
.82929 .13991 L
.83165 .13901 L
.83415 .1382 L
.8365 .13756 L
.83863 .1371 L
.84112 .13669 L
.84249 .13652 L
.84379 .1364 L
.84499 .13633 L
.8461 .13629 L
.84732 .13628 L
.84861 .1363 L
.84936 .13633 L
.85004 .13637 L
.85079 .13643 L
.85158 .1365 L
.85292 .13665 L
.85438 .13685 L
.85707 .13736 L
.85959 .13797 L
Mistroke
.86462 .13957 L
.87008 .14185 L
.88 .14735 L
.89857 .16137 L
.93942 .19925 L
.97619 .22542 L
Mfstroke
.02381 .20966 m
.04262 .22398 L
.0522 .23022 L
.06244 .23575 L
.0679 .23811 L
.07286 .23988 L
.07784 .24126 L
.08008 .24174 L
.08255 .24218 L
.08522 .24253 L
.08668 .24267 L
.08738 .24272 L
.08805 .24277 L
.08932 .24282 L
.09049 .24285 L
.09174 .24286 L
.09246 .24285 L
.09312 .24283 L
.09384 .2428 L
.09461 .24276 L
.09603 .24265 L
.0974 .24251 L
.09866 .24235 L
.10154 .24188 L
.10458 .24122 L
.10954 .23977 L
.11406 .23804 L
.12422 .23283 L
.13363 .22641 L
.14255 .21904 L
.18088 .17726 L
.20027 .15367 L
.22166 .12956 L
.23141 .12005 L
.24192 .11121 L
.25177 .10449 L
.26093 .09971 L
.26556 .09786 L
.2705 .09632 L
.27332 .09565 L
.27599 .09514 L
.27838 .0948 L
.27973 .09465 L
.28097 .09455 L
.28219 .09447 L
.28349 .09442 L
.28472 .0944 L
.28585 .0944 L
.28717 .09444 L
.28791 .09447 L
Mistroke
.2886 .09451 L
.28987 .09461 L
.29122 .09474 L
.29415 .09513 L
.29691 .09564 L
.30207 .09692 L
.30674 .09845 L
.31186 .10051 L
.32219 .10575 L
.34067 .1181 L
.38115 .15104 L
.39982 .16522 L
.42011 .17775 L
.43117 .18299 L
.44139 .18679 L
.45116 .1895 L
.45609 .19056 L
.46152 .19149 L
.46646 .19215 L
.47164 .19267 L
.47607 .19299 L
.47858 .19312 L
.48091 .19323 L
.48363 .19332 L
.4862 .19338 L
.48851 .19342 L
.48981 .19344 L
.49101 .19345 L
.4923 .19346 L
.4935 .19347 L
.49482 .19347 L
.49556 .19347 L
.49624 .19347 L
.49695 .19347 L
.4976 .19348 L
.49832 .19348 L
.49908 .19348 L
.50036 .19348 L
.50109 .19348 L
.50178 .19348 L
.50295 .19348 L
.5042 .19348 L
.50539 .19348 L
.50646 .19349 L
.50773 .19349 L
.5091 .1935 L
.5104 .19352 L
.51159 .19353 L
.51398 .19357 L
.51534 .19361 L
Mistroke
.51662 .19364 L
.51918 .19373 L
.52194 .19385 L
.52689 .19417 L
.5316 .19459 L
.53582 .19509 L
.54043 .19577 L
.55076 .19791 L
.56012 .20066 L
.57093 .20486 L
.5811 .20985 L
.61967 .23657 L
.63923 .25279 L
.66069 .26987 L
.67056 .27675 L
.68113 .28304 L
.68625 .28559 L
.69111 .28768 L
.6958 .28937 L
.7002 .29065 L
.70479 .29164 L
.70723 .29202 L
.70849 .29218 L
.70986 .29232 L
.71122 .29243 L
.71247 .2925 L
.71317 .29253 L
.7138 .29254 L
.71453 .29255 L
.71522 .29255 L
.71644 .29253 L
.71757 .29249 L
.71881 .29242 L
.72012 .29231 L
.72231 .29206 L
.72466 .2917 L
.7289 .29078 L
.73394 .28927 L
.73855 .28747 L
.74843 .28235 L
.75759 .27611 L
.77833 .2574 L
.81753 .21162 L
.83756 .18803 L
.84809 .17682 L
.85919 .16638 L
.86917 .15848 L
.87446 .15494 L
.88011 .15168 L
.88532 .14917 L
Mistroke
.89006 .14732 L
.89482 .14588 L
.89699 .14537 L
.89933 .14491 L
.9017 .14455 L
.90277 .14442 L
.90394 .14431 L
.90464 .14425 L
.90529 .1442 L
.90659 .14414 L
.90776 .1441 L
.90901 .14409 L
.90971 .1441 L
.91035 .14412 L
.91105 .14414 L
.91179 .14418 L
.91303 .14426 L
.9144 .14438 L
.91693 .14469 L
.91929 .14509 L
.92394 .14614 L
.92819 .14741 L
.93773 .15128 L
.94729 .15642 L
.95615 .16212 L
.97619 .17729 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003of@3oool0
0`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000
oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool200000=D0oooo003I
0?ooo`030000003oool0oooo0=@0oooo002^0?ooo`800000:@3oool00`000000oooo0?ooo`3D0?oo
o`00Z`3oool8000002H0oooo00<000000?ooo`3oool0e03oool00:T0oooo0P0000080?ooo`800000
903oool00`000000oooo0?ooo`3D0?ooo`00Y`3oool2000000`0oooo00<000000?ooo`3oool00P3o
ool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3oool01@3ogi`0B000
000000000000M;oo00L0oooo00<000000?ooo`3oool0e03oool00:H0oooo00<000000?ooo`3oool0
3@3oool02P000000oooo0?ooo`3oool0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000
000007Bo00P0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`3D0?ooo`00Y@3oool0
0`000000oooo0?ooo`0?0?ooo`80000000<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0>
0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool0e03oool00:@0oooo00<000000?oo
o`3oool04P3oool00`000000B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia80000
000000000`0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo0=@0oooo002S0?ooo`03
0000003oool0oooo00X0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3OW4P00000
00<0oooo00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;ooo`3oool0_g@007Boo`P0oooo0`00
003D0?ooo`00XP3oool00`000000oooo0?ooo`0D0?ooo`030=nLB018W=l000000080oooo00<0okmd
001d_`3oool02`3oool01@3OW4P007Bo0?ooo`2oM000M;oo00P0oooo00<000000?ooo`3oool0e03o
ool00:40oooo00<000000?ooo`3oool05@3oool00`3o_g@0B9cO000000020?ooo`030=nLB018W=l0
oooo00`0oooo00@0W4P004RLg`2oM000M;oo203oool00`000000oooo0?ooo`3D0?ooo`00X03oool0
0`000000oooo0?ooo`0G0?ooo`0609a8001d_ol000000?oOW01807@0_ooo3@3oool0103ogi`0B018
04Q8001d_ol80?ooo`030000003oool0oooo0=@0oooo002O0?ooo`030000003oool0oooo01P0oooo
00D0oono07@000000000000009cOo`0?0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3o
ool0e03oool009h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0=@0oooo002M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`3D0?ooo`00W@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0e03oool009`0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0=@0oooo002L0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool05P3oool200000=D0oooo002K0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3D0?ooo`00V`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0e03oool009X0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0=@0oooo002J0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3D0?oo
o`00V@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0e03oool009T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0=@0oooo002H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3D0?ooo`00V03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0180oooo0P00003E0?ooo`00U`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0e03oool009L0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0=@0oooo002F0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3D0?ooo`00U@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0e03oool009D0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0=@0oooo002D0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3D0?oo
o`00U03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0e03oool009<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0=@0oooo002C0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool03P3o
ool200000=D0oooo002B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3D0?ooo`00MP3oool=000000l0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0=@0oooo001d0?ooo`8000003@3oool4000000X0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=@0
oooo001b0?ooo`8000004`3oool3000000L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0=@0oooo001`0?ooo`800000603oool2000000@0oooo00<0
00000?ooo`3oool09`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l0
0`3oool00`000000M000000000040000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0
e03oool006h0oooo0P00000:0?ooo`P000002P3oool200000080oooo00<000000?ooo`3oool09`3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool00`000000
001d0;ooo`020?ooo`030=nLM02Lgol0oooo00H0oooo00<000000?ooo`3oool0E@3oool8000007L0
oooo001]0?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`8000002P3oool2000002T0oooo
00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`040000003o_g@0001809cOo`X0
oooo00<000000?ooo`3oool0DP3oool3000000P0oooo00<000000?ooo`3oool0M03oool006/0oooo
0P00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool2000002P0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`050000003oool0omnL04P00018
W=l02@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00X0oooo0P00001d0?ooo`00
JP3oool00`000000oooo0?ooo`080?ooo`8000003P3oool2000000L0oooo00@000000?ooo`3oool0
00007P3oool00`2LB000000000000003000000050018W03oool0oooo0=nLB018W=l00`3oool00`3o
_g@007Bo0?ooo`0;0?ooo`050000003oool0oooo09a80018W=l0203oool300000540oooo00<00000
0?ooo`3oool0303oool200000780oooo001Y0?ooo`030000003oool0oooo00L0oooo0P00000B0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool02`3oool01P000000oooo0?ooo`3oool0W4Qd0;ooo`L0oooo
00<000000?ooo`3oool0C`3oool200000140oooo0P00001`0?ooo`00J03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`800000903oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0
gia807Boo`0000000P3oool00`2oM000M;oo0?ooo`060?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1]0?ooo`00I`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo0280oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@000000?oo
o`3o_g@0001809cOo`070?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1/0?ooo`00IP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0Q0?ooo`050?oo_`1d00000000
0000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00P0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06/0oooo001U0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0000000:0?ooo`800000=@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0;0?ooo`800000G@3oool006@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`070?ooo`/00000F03oool006<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`040?ooo`8000002`3oool2000005H0oooo001R0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0000000>0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01d0oooo
00@000000?ooo`3oool0oooo0P00000?0?ooo`800000E03oool00640oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`070?ooo`800000B@3oool00`000000oooo0?ooo`0O0?ooo`<00000
4`3oool00`000000oooo0?ooo`1A0?ooo`00A03oool2000001X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000003`3oool200000300oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01l0oooo
0P00000E0?ooo`030000003oool0oooo00d0oooo0P0000110?ooo`00?P3oool6000000030?ooo`00
0000000000<000005@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01l0oooo00@0
00000?ooo`3oool000005@3oool2000000P0oooo1@0000000`3oool0000000000004000003`0oooo
000m0?ooo`030000003oool0oooo00X0oooo0P00000B0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool0
0P3oool3000000`0oooo0P00000j0?ooo`00>P3oool3000000l0oooo0P00000?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00@000000?ooo`00000000004@3oool2000003P0oooo000h0?ooo`800000503o
ool2000000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0503oool2000001D0oooo0P0000080?ooo`/000008`3o
ool003L0oooo00<000000?ooo`3oool05P3oool2000000T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool2
000002`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0
oooo000001H0oooo0P0000030?ooo`@000002P3oool4000001l0oooo000H0?ooo`/000004P3oool2
000001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05@3oool300000180oooo0P00000M0?ooo`005@3oool30000
00/0oooo0P00000?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0103oool20000
04D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00h0oooo0P0000060?ooo`030000003oool0oooo01<0oooo1000000D0?ooo`8000006`3oool000X0
oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`050000000307Boo`3oool0oooo00X0
oooo0`00000;0?ooo`030000003oool0oooo01h0oooo0P0000020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03P3oool01@2oM0000000000000000000M;oo00/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01T0oooo00D0_g@00000
00000000000007Boo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0@0?ooo`800000103oool00`000000oooo0?ooo`0C0?ooo`8000001@3oool0
0`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?oo
o`030?ooo`003@3oool0102LB4P0W=oo0?ooo`3oool2000000070?ooo`2LB7@0_ooo0?ooo`3ookl0
M01d0;ooo`0>0?ooo`8000001`3oool2000002<0oooo0P00000;0?ooo`030000003oool0oooo00h0
oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0C0?ooo`800000:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool06@3oool01`2oM00007Bo0000003oool0omnL04P0001d_ol0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo0P0000060?ooo`0309a8
B02Lgol0oooo00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`003@3oool0102LB4P0
W=oo0000000000020?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03`3oool20000
00@0oooo00<000000?ooo`3oool08`3oool2000000/0oooo00<000000?ooo`3oool04`3oool00`3o
_g@007Bo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0K0?ooo`050000003oool0oooo0?noM000M;l0303oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`07
0?ooo`8000005P3oool00`000000oooo0?ooo`030?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd
001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`030?ooo`003@3oool2000000@0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`0A0?ooo`80000000<0oooo0000003oool09@3oool00`00
0000oooo000000090?ooo`030000003oool0oooo01@0oooo00<0okmd001d_`3oool0203oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06`3oool01P00
0000oooo0?ooo`3oool0okmd001d_`d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00T0oooo0P00000<0?ooo`030000003oool0oooo01@0oooo0P00
00030?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`030?ooo`0000<0oooo09a800000000100000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0
oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0C0?ooo`8000009@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01`3oool00`2LB00000000000
0003000000030018W03oool0oooo00D0oooo00<0W4P007Boo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01D0oooo0P00000V0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0K0?ooo`060000003oool0oooo0?ooo`2LB000
M;oo3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01P3oool2000000l0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`2LB4P0W=oo
00@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`030?ooo`003@3oool00`2LB4P0
W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool04P3oool010000000
oooo0?ooo`00000S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0@0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06P3oool00`00
0000M000000000020000000304RLg`3oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0E0?ooo`040000003oool0W4Q809cOo`@0oooo00<0gia804RLg`3oool00P3oool0
0`3o_g@007Bo0?ooo`030?ooo`003@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo00<0oono07@0M02oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01P0oooo0P00000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0J0?ooo`040000003ookl0M01d0;oooa<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0E0?ooo`80000000<0W=oo0?ooo`3oool00P3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00<0oooo000:0?ooo`050=nLB000000004RL0000002Lgol01@3oool0
1P2LB000M;oo0?ooo`3ogi`0B01d0;oooa00oooo0P0000060?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000001@0oooo00<0oono07@0M02o
ool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool08@3oool01@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3oool06P3oool01000
0000oono07@0M02ooolC0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`00000F0?ooo`8000004`3oool01@3OW4P000000018W02LB4P0000000<0oooo
00P000000?ooo`2LB000M;oo0?ooo`3ogi`0B01d0;ooo`@0oooo000<0?ooo`030=nLB00004P00000
00D0oooo00D0oono07@000000000001809cOo`0@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0000001D0oooo00<0oono
07@0000000000P0000000`0007@0_ooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool06P3oool200000240oooo00@000000?ooo`3oool0oooo0P0000120?ooo`030000003o
ool0oooo01T0oooo00@000000?ooo`3ookl0M0000`0000000`0007@0_ooo0?ooo`0?0?ooo`040000
003oool0oooo000001P0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`0B0?ooo`06
0=nLB00004P0W=oo0000003oool000000P3oool01@3ookl0M0000000000004P0W=oo00D0oooo000?
0?ooo`8000005`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool02@3oool200000280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0K
0?ooo`8000007`3oool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0H0?ooo`8000006P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01D0oooo0P00000<0?ooo`004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`8000008P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo0P00000N0?ooo`040000003oool0
oooo00000480oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`0000006P3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo000000/0oooo000B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000008@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo0P00000L0?ooo`040000003o
ool0oooo00000440oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0000001P0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0100
oooo0P00000?0?ooo`004`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`00
0000803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0200oooo0`00000I0?ooo`04
0000003oool0oooo00000440oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?oo
o`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`00503oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo02<0oooo0P00000H0?ooo`030000003oool00000
0440oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo
0?ooo`0000005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`005@3oool2000000`0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool09@3oool3000001D0oooo00<000000?ooo`000000@03oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0140oooo000G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool09`3oool3000001<0oooo0P0000100?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0H0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`00
603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo1`00000<0?ooo`800000
@03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00030?ooool00000[@00
00010?ooo`003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0P00000<
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?
0?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo1@00
00000`3oool000000?ooo`0B0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool2000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`050000
003oool0oooo0?ooo`0000000P3oool2000000/0oooo00<000000?ooo`3oool02@3oool000d0oooo
00<000000?ooo`3oool02`3oool2000000050?ooo`000000oooo0?ooo`000000503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool010000000
oooo0?ooo`00000C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo100000090?ooo`@000004@3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000403oool0
1@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool00P3oool2000000d0oooo00<0
00000?ooo`3oool02@3oool000d0oooo00<000000?ooo`3oool0303oool200000200oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02P3oool4000002@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06@3oool2000000d0oooo00<00000
0?ooo`3oool02@3oool001/0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0<@3oool2000000X0oooo0P000009
0?ooo`8000003P3oool200000280oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P00000G0?ooo`006P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo0P00000<0?ooo`8000002`3oool00`00
0000oooo0?ooo`0=0?ooo`8000007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo000H0?ooo`8000001P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo0000
00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0;03oool2000000h0oooo0P00000<0?ooo`030000003oool0oooo
00h0oooo0P00000M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool000d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`0000003@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`000000303oool200000100oooo0P00000K0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000001/0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo000>0?oo
o`030000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`0000003P3oool00`000000oooo0?ooo`0?0?ooo`800000603oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04`3oool2000001d0oooo00<000000?oo
o`3oool03P3oool2000000/0oooo0P00000B0?ooo`003`3oool2000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0@0?ooo`<000003`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01@0oooo0P00000N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0?0?ooo`004@3oool300000100oooo00<000000?ooo`3oool0
6P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool04@3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo0100oooo0P00000E0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0000001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo000A0?ooo`8000004P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`00
0000oooo0?ooo`0200000140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0C0?oo
o`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0A0?ooo`8000004@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0C0?ooo`8000003@3oool000h0oooo0P0000050?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool2000000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000A
0?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo0P00000N
0?ooo`8000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo000=0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool200000180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool2
000000030?ooo`000000000001X0oooo00<000000?ooo`3oool02@3oool001L0oooo0P00000A0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000P
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01@0oooo0P00000;0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?ooo`800000303oool001T0oooo0P00000@0?oo
o`030000003oool0oooo00/0oooo0P00000?0?ooo`8000008P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?oo
o`040000003oool00000000001H0oooo0P00000>0?ooo`006`3oool2000000l0oooo0P00000:0?oo
o`030000003oool0oooo00l0oooo0P00000S0?ooo`040000003oool0oooo000002/0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01D0oooo0P0000070?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool06@3oool2000000@0oooo0P00000B0?ooo`800000403oool001d0oooo0P00000?0?oo
o`8000001P3oool200000140oooo00@000000?ooo`3oool000008P3oool00`000000oooo0000000/
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`06
0?ooo`@000002P3oool400000180oooo000O0?ooo`8000003`3oool010000000oooo0?ooo`3oool2
00000140oooo0P0000040?ooo`030000003oool0oooo0200oooo0P00000/0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0503oool2000000d0oooo2P00000F0?ooo`008@3oool40000
00/0oooo1000000@0?ooo`<000001`3oool00`000000oooo0?ooo`0O0?ooo`800000;03oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000G
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`8000004P3oool2000002l0oooo000U0?ooo`/000000`3oool2000000d0oooo0P00000;0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool3000000d0oooo0P00000a
0?ooo`00=@3oool=000000h0oooo00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0
000002`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`<000005P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool=
000003<0oooo001A0?ooo`8000006@3oool2000000D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo0P00000F0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1J0?ooo`00D`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool005@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000001<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0
oooo001E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool2000000L0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0G03oool005H0oooo0`00000?0?ooo`8000002`3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo05d0oooo001I0?ooo`8000002`3oool2000000h0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1N0?ooo`00F`3oool;00000140oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01P3oool2000000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo05l0oooo001g0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0H03oool007P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool03`3oool2000006<0oooo001i0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000000000@00000
00<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06<0oooo
001i0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`060?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`03
0;md000007@0_ooo0080oooo00<0giad09cOo`3oool01P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo06@0oooo001j0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`060?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0
2`3oool00`3o_g@0001809cOo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1U0?ooo`00N`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P00018W=l02@3o
ool3000000T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0100oooo0P0000000`3oool000000?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0IP3oool007/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>
0?ooo`0309a80018W=l0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool200000140oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1W0?ooo`00O03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?oo
o`<00000403oool00`000000oooo0?ooo`0<0?ooo`800000JP3oool007d0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<0okmd04RLg`3o
ool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3o
ool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo008000003@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo06X0oooo001n0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`0609a8001d_ol0oooo0?oOW018
07@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol01`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`030000003oool0oooo00/0oooo0P00
001]0?ooo`00O`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd0000000000000018
09cOo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool2000000L0oooo
00<000000?ooo`3oool02P3oool2000006l0oooo00200?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool0
203oool2000000@0oooo00<000000?ooo`3oool02@3oool200000740oooo00200?ooo`030000003o
ool0oooo0280oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool07@3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00X0
oooo4000001c0?ooo`00P@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool000000300oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0000001<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1m0?ooo`00PP3oool00`000000oooo0?oo
o`0Q0?ooo`800000<@3oool2000000h0oooo00<000000?ooo`3oool07P3oool2000001<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1n0?ooo`00P`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0N
0?ooo`8000004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07l0oooo00240?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`000000<@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01d0oooo00@000000?ooo`0000000000403oool00`000000oooo0?ooo`0;
0?ooo`800000PP3oool008D0oooo00<000000?ooo`3oool06`3oool200000080oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01d0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0PP3oool0
08H0oooo0P00000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0P`3oool008P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0
oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Q03oool008T0oooo
0P00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo0P0000270?ooo`00R`3oool00`000000oooo0?oo
o`0@0?ooo`800000203oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`8000001P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo08L0oooo002<0?ooo`030000003oool0oooo00`0oooo0`00000:
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`800000RP3oool008d0oooo1P0000050?ooo`<000003P3oool00`000000oooo0?ooo`0]0?oo
o`8000004P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo1@0000050?oo
o`@00000S03oool00980oooo1P00000A0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo1P00002@0?ooo`00
Z@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo09@0oooo002Y0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0U@3oool00:X0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`2E0?ooo`00ZP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
09H0oooo002Z0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0UP3oool00:X0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2G0?ooo`00Z`3oool00`000000oooo0?oo
o`0[0?ooo`8000005P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0U`3oool00:/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2H
0?ooo`00Z`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09T0oooo002/0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0V@3oool00:`0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2J0?ooo`00[03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo09/0oooo002/0?ooo`030000003oool0oooo00/0oooo00D0okmd000000000000000007Bo
o`050?ooo`030;md0000000007Bo00H0oooo00D0omnL04P000000000000007Boo`070?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo09/0oooo002]0?ooo`030000003oool0oooo00X0oooo00H0W4Qd0;ooo`3oool0oono
07@0M02oool40?ooo`030;md0000000007Bo00P0oooo00<0_g@007Boo`3oool01`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`2L0?ooo`00[@3oool00`000000oooo0?ooo`090?ooo`030?noM000M;l0oooo0080oooo
00<0gia804RLg`3oool03P3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09d0oooo
002]0?ooo`030000003oool0oooo00T0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0:0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool01@3oool3000001/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`800000X03oool00:h0oooo00<00000
0?ooo`3oool0203oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00H0okmd
0000M02oool0oooo0;md001d_ol80?ooo`030000003oool0oooo01`0oooo0P0000090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0X03oool00:h0oooo00<000000?ooo`3oool0203o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia8001d_`3oool0_g@0
07Boo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0:40oooo002^0?ooo`030000003oool0oooo00P0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0<0?ooo`0409a80018W=l0_g@007Boo`P0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0XP3oool00:h0oooo00<000000?ooo`3oool02@3oool01P2LB000M;oo0?oo
o`3ogi`0B01d0;ooo`d0oooo00@0omnL04P0B018B000M;oo203oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2R0?oo
o`00[`3oool00`000000oooo0?ooo`080?ooo`050?oo_`1d000000000000B02Lgol03`3oool00`3o
_g@0000007Boo`080?ooo`030000003oool0oooo0240oooo0P0000030?ooo`030000003oool0oooo
00<0oooo0`00002U0?ooo`00[`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02<0
oooo2@00002X0?ooo`00[`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0Z`3oool00;00oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0:/0oooo002`0?ooo`030000003oool0oooo02H0oooo0P00000V
0?ooo`030000003oool0oooo0:`0oooo002`0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`2/0?ooo`00/03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0[03oool00;40oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0:`0oooo002a0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2]0?ooo`00/@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0[@3oool0
0;80oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0:d0oooo002b0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`2^0?ooo`00/P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0[P3oool00;80oooo00<000000?ooo`3oool0903oool2000002@0oooo00<0
00000?ooo`3oool0[P3oool00;<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0:h0oooo002c0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`2_0?ooo`00/`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0[`3oool00;<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0:l0oooo002d0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2_0?ooo`00]03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0/03oool0
0;@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0;00oooo002e0?ooo`030000003oool0oooo0240oooo0P00000R0?ooo`030000003oool0oooo0;00
oooo002e0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`2`0?ooo`00]@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0/@3oool00;D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0;40oooo002f0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`2a0?ooo`00]P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0/P3oool00;H0oooo00D000000?ooo`3oool0
oooo0?noM0030000000307Boo`3oool0oooo00<0oooo00<0_g@000000000M;l01P3oool01@2oM000
00000000000007@0_ooo00L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2b0?oo
o`00]`3oool02@000000oooo0?ooo`2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`040?ooo`030;md0000
000007Bo00D0oooo00H0gia8001d_`3oool0oooo0?noM000M;l70?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0/P3oool00;L0oooo00@000000?ooo`3o_g@007Bo0`3oool00`3OW4P0
B9cO0?ooo`0:0?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool01P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0;80oooo002g0?ooo`040000003oool0gia804RLg`<0
oooo00<0okmd001d_`3oool02P3oool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l01`3oool3
000001h0oooo00<000000?ooo`3oool0/`3oool00;L0oooo00@000000?ooo`3OW4P0B9cO0`3oool0
0`3o_g@007Bo0?ooo`0:0?ooo`030?oOW018B9`0okmd0080000000<004RL0?ooo`3oool01P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;<0oooo002h0?ooo`030000003OW4P0B9cO
00<0oooo00<0okmd001d_`3oool02P3oool00`3ookl0M01d0;ooo`0;0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0/`3oool00;P0oooo00<000000?noM018W=l00`3oool00`3OW4P0
B9cO0?ooo`0;0?ooo`030;md0018W=l0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`2d0?ooo`00^03oool020000000oooo09a8001d_ol0oooo0?oOW01807@0_ooo303oool0
0`3ookl0M000001d_`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0]03oool0
0;T0oooo00H000000?oo_`1d000000000000B02Lgol?0?ooo`040;md0000000000000018W0L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2d0?ooo`00^@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0]03oool00;T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;D0oooo002j0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2e0?oo
o`00^P3oool00`000000oooo0?ooo`0L0?ooo`8000007@3oool00`000000oooo0?ooo`2e0?ooo`00
^P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
]P3oool00;X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0;H0oooo002k0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`2f0?ooo`00^`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0]`3oool00;/0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0;L0oooo002l0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2g0?ooo`00_03oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0]`3oool00;`0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0;P0oooo002m0?oo
o`030000003oool0oooo01T0oooo0P00000J0?ooo`030000003oool0oooo0;P0oooo002m0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2h0?ooo`00
_@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
^@3oool00;h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0;T0oooo002n0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`2i0?ooo`00_P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0^@3oool00;h0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0;X0oooo002o0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2j0?ooo`00_`3oool00`000000oooo0?oo
o`0G0?ooo`800000603oool00`000000oooo0?ooo`2j0?ooo`00_`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0^`3oool00<00oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0;/0oooo00300?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2k0?ooo`00
`03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
_03oool00<40oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0;`0oooo002j0?ooo`050?noM000000000000000001d_ol00P3oool01P000000oooo0?oo
o`2oM0000000001d_`D0oooo00D0_g@00000000000000000001d_`080?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0_03oool00;X0oooo00P0W4Qd0;ooo`3oool0oono07@0M02oool0
oooo00000080oooo00<0_g@000000000M;l0103oool00`3o_g@007Bo0?ooo`020?ooo`030;mdB02L
gol0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2m0?ooo`00^@3oool0
0`3o_g@007Bo0?ooo`020?ooo`050=nLB018W=l0oooo0?ooo`000000203oool00`3OW4P0B9cO0?oo
o`020?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`2m0?ooo`00^@3oool00`3OW4P0B9cO0?ooo`020?ooo`050?noM000M;l0oooo0?ooo`000000203o
ool00`3o_g@004RL0?ooo`020?ooo`0309a8B02Lgol0oooo00H0oooo0`00000D0?ooo`030000003o
ool0oooo0;d0oooo002i0?ooo`030=nLB018W=l0oooo0080oooo00D0okmd001d_`3oool0oooo0000
00090?ooo`050=nLB0000000000000000018W=l0203oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0;h0oooo002i0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`030?oo_`1dB9`0oooo0080oooo00<0W4Qd0;ooo`3oool01P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;h0oooo002i0?ooo`030?noM018W=l0
oooo0080oooo00<0gia804RLg`3oool00P3oool00`000000oooo0?ooo`050?ooo`030?noM018W=l0
oooo0080oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0;l0oooo002j0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0`3oool00`000000oooo0?oo
o`050?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B01d0;ooo`070?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0_`3oool00;X0oooo00D0oono07@000000000001809cOo`050?ooo`03
0000003oool0oooo00D0oooo00D0okmd000000000000001809cOo`080?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0_`3oool00<@0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0<00oooo00350?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`300?ooo`00a@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0`03oool00<D0oooo00<00000
0?ooo`3oool04@3oool200000140oooo00<000000?ooo`3oool0`@3oool00<H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0<40oooo00360?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`310?ooo`00
aP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
`P3oool00<L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0<80oooo00370?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`330?ooo`00a`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0``3oool00<P0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0<@0oooo00380?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`340?ooo`00b@3oool00`000000oooo0?oo
o`0=0?ooo`8000003@3oool00`000000oooo0?ooo`350?ooo`00b@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0a@3oool00<X0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0<H0oooo003:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`360?ooo`00
b`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
a`3oool00</0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0<P0oooo003<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`380?ooo`00c03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0b@3oool00<d0oooo00<000000?ooo`3oool02@3oool2000000T0
oooo00<000000?ooo`3oool0b@3oool00<h0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0<X0oooo003>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3:0?ooo`00c`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0b`3oool00=00oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0</0oooo003@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3<0?ooo`00
b`3oool00`3o_g@0000000000004000000L0oooo00<000000?ooo`3oool00`3oool200000<l0oooo
003>0?ooo`0409a8B02Lgol0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0<l0oooo003>0?ooo`0309a8B02Lgol0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0200000=80oooo003>0?ooo`0309a8B02Lgol0oooo00@0oooo1`00003D
0?ooo`00cP3oool00`2LB4P0W=oo0?ooo`080?ooo`030000003oool0oooo0=@0oooo003>0?ooo`03
09a8B02Lgol0oooo00P0oooo00<000000?ooo`3oool0e03oool00<h0oooo00<0W4Q809cOo`3oool0
203oool00`000000oooo0?ooo`3D0?ooo`00b`3oool01@3OW4P000000018W02LB4P0W=oo00T0oooo
00<000000?ooo`3oool0e03oool00<d0oooo00<0gia80000B02Lgol02@3oool00`000000oooo0?oo
o`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-10.663, -0.475024, \
0.0736533, 0.00855764}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[Table[D[sbessj[n, x], x], {n, 0, 3}]], {x, \(-10\), 
          10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.309022 0.674736 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.2619 .29652 -6 -9 ]
[.2619 .29652 6 0 ]
[.7381 .29652 -3 -9 ]
[.7381 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.4875 .03913 -24 -4.5 ]
[.4875 .03913 0 4.5 ]
[.4875 .17408 -24 -4.5 ]
[.4875 .17408 0 4.5 ]
[.4875 .44397 -18 -4.5 ]
[.4875 .44397 0 4.5 ]
[.4875 .57892 -18 -4.5 ]
[.4875 .57892 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-10)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .03913 m
.50625 .03913 L
s
[(-0.4)] .4875 .03913 1 0 Mshowa
.5 .17408 m
.50625 .17408 L
s
[(-0.2)] .4875 .17408 1 0 Mshowa
.5 .44397 m
.50625 .44397 L
s
[(0.2)] .4875 .44397 1 0 Mshowa
.5 .57892 m
.50625 .57892 L
s
[(0.4)] .4875 .57892 1 0 Mshowa
.125 Mabswid
.5 .07286 m
.50375 .07286 L
s
.5 .1066 m
.50375 .1066 L
s
.5 .14034 m
.50375 .14034 L
s
.5 .20781 m
.50375 .20781 L
s
.5 .24155 m
.50375 .24155 L
s
.5 .27529 m
.50375 .27529 L
s
.5 .34276 m
.50375 .34276 L
s
.5 .3765 m
.50375 .3765 L
s
.5 .41023 m
.50375 .41023 L
s
.5 .47771 m
.50375 .47771 L
s
.5 .51144 m
.50375 .51144 L
s
.5 .54518 m
.50375 .54518 L
s
.5 .00539 m
.50375 .00539 L
s
.5 .61265 m
.50375 .61265 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36197 m
.03279 .37007 L
.04262 .37682 L
.04758 .37927 L
.0503 .38032 L
.05288 .38111 L
.05528 .38167 L
.05664 .38191 L
.05789 .38208 L
.05894 .38218 L
.0601 .38226 L
.06131 .38229 L
.06244 .38229 L
.0631 .38226 L
.06379 .38222 L
.06504 .38211 L
.06581 .38202 L
.06653 .38191 L
.06788 .38167 L
.07036 .38108 L
.07305 .38021 L
.0781 .37795 L
.08274 .37515 L
.09336 .3662 L
.10458 .35317 L
.12422 .32305 L
.14255 .28966 L
.16119 .25501 L
.18146 .22232 L
.18681 .21535 L
.19249 .20893 L
.19776 .204 L
.2027 .20034 L
.2073 .19784 L
.20989 .19683 L
.21226 .19617 L
.21354 .19592 L
.21472 .19576 L
.21602 .19565 L
.21675 .19562 L
.21741 .19562 L
.2181 .19564 L
.21874 .19568 L
.21945 .19575 L
.22019 .19584 L
.22144 .19606 L
.22282 .19639 L
.22532 .19723 L
.22803 .19849 L
.23298 .20172 L
Mistroke
.2378 .20604 L
.24227 .2111 L
.25239 .2262 L
.26316 .24763 L
.28461 .3047 L
.3048 .37089 L
.3434 .50284 L
.36338 .55758 L
.37343 .57817 L
.3791 .58729 L
.38445 .59411 L
.38936 .59876 L
.39213 .60068 L
.39345 .60142 L
.39469 .602 L
.39581 .60244 L
.39684 .60276 L
.39798 .60304 L
.39921 .60323 L
.40032 .60332 L
.40154 .60331 L
.40282 .6032 L
.404 .60299 L
.40531 .60264 L
.40673 .60213 L
.40931 .60083 L
.41182 .59912 L
.41413 .59714 L
.41938 .59126 L
.42493 .58294 L
.43439 .56393 L
.44454 .5371 L
.46287 .47396 L
.5042 .28921 L
.52487 .19473 L
.54401 .11837 L
.56257 .06146 L
.57195 .04071 L
.57729 .03152 L
.58231 .02468 L
.58699 .0199 L
.58965 .01787 L
.59212 .01644 L
.59347 .01584 L
.59474 .01539 L
.59588 .01508 L
.59712 .01485 L
.59776 .01478 L
.59847 .01473 L
.59921 .01472 L
Mistroke
.5999 .01474 L
.60114 .01486 L
.60183 .01497 L
.60247 .0151 L
.60361 .01541 L
.60482 .01584 L
.607 .01686 L
.6096 .0185 L
.61195 .02037 L
.61659 .02512 L
.62096 .03084 L
.63074 .04775 L
.64106 .07118 L
.65953 .12444 L
.69753 .25516 L
.71869 .3232 L
.73797 .37291 L
.74755 .39174 L
.7526 .39992 L
.75797 .40724 L
.76264 .41245 L
.7678 .41692 L
.77006 .41846 L
.7725 .41983 L
.77479 .42086 L
.7769 .42157 L
.77818 .4219 L
.77939 .42214 L
.78047 .42229 L
.78164 .42239 L
.78293 .42242 L
.78357 .42241 L
.78428 .42238 L
.78554 .42226 L
.78671 .42208 L
.78789 .42184 L
.78901 .42155 L
.79111 .42086 L
.79337 .41989 L
.79584 .41859 L
.80104 .41502 L
.80658 .41005 L
.81654 .39843 L
.83801 .36447 L
.8582 .32697 L
.87663 .29355 L
.88708 .27668 L
.89682 .26306 L
.90729 .2512 L
.91681 .2432 L
Mistroke
.92205 .24002 L
.927 .23782 L
.92971 .23694 L
.93222 .23635 L
.93353 .23612 L
.93498 .23593 L
.9357 .23586 L
.93648 .2358 L
.93722 .23577 L
.9379 .23575 L
.93914 .23576 L
.9403 .23581 L
.94135 .23589 L
.94249 .23601 L
.94373 .2362 L
.94504 .23644 L
.94739 .23701 L
.95159 .23843 L
.9562 .24058 L
.96119 .24355 L
.96654 .24743 L
.97619 .25608 L
Mfstroke
.02381 .26173 m
.06244 .31025 L
.08255 .341 L
.0932 .35657 L
.10458 .37156 L
.11531 .38335 L
.12507 .39151 L
.12977 .39444 L
.13225 .3957 L
.13488 .39681 L
.13717 .39759 L
.13839 .39793 L
.1397 .39823 L
.1409 .39846 L
.142 .39863 L
.1431 .39875 L
.14415 .39882 L
.1454 .39886 L
.1461 .39885 L
.14674 .39883 L
.14793 .39876 L
.14918 .39862 L
.1503 .39844 L
.15135 .39824 L
.15374 .39762 L
.15632 .39671 L
.15867 .39566 L
.16396 .39254 L
.16848 .38903 L
.1734 .38435 L
.18234 .37361 L
.20212 .34066 L
.22313 .2953 L
.26088 .20746 L
.28022 .17104 L
.28552 .16314 L
.2911 .15601 L
.29633 .15051 L
.30108 .14657 L
.30344 .145 L
.30599 .1436 L
.3084 .14257 L
.31063 .14188 L
.31184 .1416 L
.31298 .14141 L
.31423 .14128 L
.31494 .14124 L
.31558 .14122 L
.31687 .14126 L
.31759 .14131 L
Mistroke
.31827 .14139 L
.31951 .14159 L
.32082 .1419 L
.32321 .14267 L
.32579 .14385 L
.33046 .14686 L
.33501 .15089 L
.33919 .15552 L
.34895 .16978 L
.35805 .18717 L
.37873 .23939 L
.41769 .36553 L
.43754 .42922 L
.448 .45902 L
.4591 .48631 L
.46897 .50599 L
.4742 .51447 L
.47984 .52197 L
.485 .52728 L
.48726 .52913 L
.48973 .5308 L
.49207 .53207 L
.49425 .53295 L
.49545 .53332 L
.49655 .53358 L
.49781 .53379 L
.499 .5339 L
.50016 .53393 L
.5014 .53388 L
.50257 .53374 L
.50364 .53354 L
.5049 .53322 L
.50626 .53277 L
.50875 .53166 L
.51134 .53012 L
.5141 .52805 L
.51905 .52323 L
.52783 .51136 L
.53752 .49357 L
.55684 .44565 L
.57769 .3809 L
.59731 .31506 L
.6188 .24662 L
.62871 .21881 L
.6393 .19293 L
.64923 .17295 L
.65839 .15862 L
.66335 .15259 L
.66862 .14759 L
.67116 .14569 L
Mistroke
.6739 .14402 L
.67546 .14323 L
.6769 .14263 L
.67826 .14216 L
.67971 .14176 L
.6804 .14161 L
.68105 .14149 L
.68227 .14133 L
.68341 .14124 L
.68465 .14122 L
.6853 .14125 L
.68602 .1413 L
.68676 .14138 L
.68746 .14148 L
.6887 .14172 L
.69004 .14206 L
.69268 .143 L
.69517 .1442 L
.69985 .14726 L
.70445 .15125 L
.70952 .15674 L
.71978 .17104 L
.7382 .20551 L
.77843 .29889 L
.79692 .33878 L
.80739 .35797 L
.81713 .3729 L
.82683 .38459 L
.83226 .38966 L
.83719 .3933 L
.8424 .39617 L
.84534 .39732 L
.84674 .39776 L
.84805 .3981 L
.84929 .39837 L
.85042 .39856 L
.85168 .39872 L
.85237 .39878 L
.85303 .39882 L
.85434 .39886 L
.85555 .39884 L
.85625 .3988 L
.85688 .39875 L
.85761 .39867 L
.85829 .39859 L
.85946 .3984 L
.86071 .39814 L
.86297 .39754 L
.86565 .3966 L
.86809 .39553 L
Mistroke
.87341 .39254 L
.87843 .3889 L
.88729 .38074 L
.89692 .36972 L
.93777 .30993 L
.97619 .26173 L
Mfstroke
.02381 .27185 m
.03279 .26161 L
.04262 .25177 L
.05288 .24348 L
.05747 .24055 L
.06244 .23796 L
.06529 .23677 L
.06792 .23586 L
.07044 .23518 L
.07172 .23489 L
.0731 .23464 L
.07435 .23446 L
.07549 .23434 L
.07663 .23425 L
.07772 .2342 L
.07898 .23419 L
.08015 .23422 L
.08143 .2343 L
.08215 .23437 L
.0828 .23444 L
.08417 .23464 L
.08561 .2349 L
.08819 .23554 L
.09097 .23644 L
.09402 .2377 L
.09948 .24066 L
.10458 .2442 L
.11503 .25377 L
.12493 .26546 L
.14349 .29305 L
.18182 .36104 L
.2012 .39252 L
.2115 .40635 L
.21691 .41255 L
.2226 .41819 L
.22765 .42236 L
.23317 .42599 L
.23559 .42726 L
.23818 .4284 L
.24061 .42925 L
.24285 .42986 L
.24405 .4301 L
.24531 .43031 L
.24658 .43047 L
.2473 .43053 L
.24798 .43057 L
.2492 .4306 L
.25031 .43058 L
.25159 .4305 L
.25281 .43037 L
Mistroke
.2539 .43021 L
.25506 .42999 L
.25715 .42948 L
.25962 .42867 L
.26187 .42774 L
.26676 .42511 L
.27192 .42143 L
.28115 .41262 L
.29109 .4002 L
.30199 .38354 L
.34246 .30579 L
.36114 .27 L
.38142 .23814 L
.38679 .23151 L
.39248 .22545 L
.39776 .22079 L
.4027 .21729 L
.40731 .21482 L
.40991 .21377 L
.41228 .21302 L
.41347 .21273 L
.41474 .21247 L
.41547 .21235 L
.41613 .21226 L
.41742 .21213 L
.41812 .21208 L
.41876 .21206 L
.41947 .21205 L
.42021 .21205 L
.42146 .21212 L
.42217 .21218 L
.42284 .21225 L
.42409 .21243 L
.42543 .21269 L
.42783 .21333 L
.43042 .21424 L
.43327 .21554 L
.43837 .21857 L
.44316 .22224 L
.45209 .23105 L
.46171 .24319 L
.50282 .31435 L
.52332 .35159 L
.53332 .36766 L
.54241 .38036 L
.55124 .39057 L
.56081 .39891 L
.56607 .40217 L
.56839 .40329 L
.57093 .40431 L
Mistroke
.57333 .40505 L
.57557 .40555 L
.57681 .40575 L
.57794 .40588 L
.57925 .40597 L
.58049 .406 L
.58173 .40597 L
.58244 .40593 L
.58308 .40587 L
.58427 .40573 L
.58552 .40552 L
.5877 .40503 L
.59008 .40428 L
.59264 .40325 L
.59537 .40188 L
.60031 .39872 L
.60993 .39015 L
.6187 .37974 L
.6378 .34994 L
.65857 .31019 L
.67797 .27122 L
.69937 .23228 L
.70912 .21755 L
.71964 .20457 L
.72447 .19973 L
.72956 .19547 L
.73424 .19233 L
.73865 .19007 L
.74106 .18913 L
.74232 .18872 L
.74366 .18835 L
.74479 .18808 L
.74603 .18784 L
.74715 .18768 L
.74821 .18756 L
.74953 .18747 L
.75078 .18745 L
.7519 .18747 L
.75313 .18755 L
.75383 .18762 L
.75446 .1877 L
.75587 .18792 L
.75718 .1882 L
.75841 .18851 L
.76065 .18921 L
.76302 .19014 L
.76724 .19229 L
.7718 .19527 L
.77678 .1993 L
.78702 .20992 L
Mistroke
.79635 .22201 L
.81728 .25542 L
.83803 .29275 L
.8572 .32612 L
.86675 .34101 L
.87702 .35508 L
.88654 .36591 L
.8956 .37398 L
.90027 .37723 L
.90537 .38005 L
.90761 .38105 L
.91001 .38194 L
.91225 .38263 L
.91431 .38312 L
.91561 .38337 L
.91699 .38358 L
.91765 .38365 L
.91837 .38373 L
.91915 .38378 L
.91988 .38382 L
.92056 .38385 L
.92129 .38386 L
.92198 .38385 L
.92263 .38383 L
.92384 .38376 L
.92513 .38364 L
.92629 .3835 L
.92753 .38329 L
.92979 .38281 L
.93247 .38206 L
.93494 .38119 L
.93967 .37906 L
.94473 .37615 L
.95385 .36938 L
.97455 .34814 L
.97619 .34619 L
Mfstroke
.02381 .37227 m
.02846 .37095 L
.03279 .36925 L
.03754 .36685 L
.04262 .36371 L
.053 .35547 L
.06244 .34606 L
.10458 .28966 L
.12534 .26024 L
.14451 .23711 L
.15414 .22792 L
.16316 .22116 L
.16769 .21849 L
.17256 .21621 L
.17534 .21518 L
.17797 .21439 L
.18034 .21384 L
.18169 .21359 L
.18292 .21341 L
.18416 .21327 L
.18548 .21316 L
.18679 .2131 L
.18754 .21309 L
.18824 .21309 L
.1895 .21313 L
.19065 .2132 L
.19129 .21325 L
.19198 .21333 L
.19324 .21349 L
.1956 .21391 L
.1981 .21452 L
.2026 .21602 L
.20774 .21839 L
.21257 .22121 L
.22357 .22969 L
.24375 .25151 L
.26226 .27637 L
.28278 .30583 L
.30188 .33159 L
.32031 .35216 L
.33062 .36107 L
.33999 .36728 L
.34484 .36976 L
.34997 .37182 L
.35435 .37312 L
.35684 .37367 L
.35917 .37407 L
.36046 .37423 L
.36186 .37438 L
.3625 .37443 L
Mistroke
.36319 .37447 L
.36441 .37453 L
.36571 .37455 L
.36693 .37454 L
.36802 .37451 L
.3692 .37444 L
.3705 .37434 L
.37193 .37418 L
.37481 .37375 L
.37748 .37321 L
.37997 .37259 L
.38499 .37099 L
.39045 .36878 L
.40036 .36365 L
.41893 .35122 L
.43835 .33658 L
.44867 .3291 L
.45977 .3219 L
.47036 .31623 L
.47499 .3142 L
.48006 .31235 L
.48487 .31095 L
.48933 .30999 L
.49181 .30959 L
.49405 .30932 L
.4953 .30921 L
.49595 .30916 L
.49664 .30912 L
.49791 .30906 L
.49908 .30903 L
.5003 .30902 L
.50099 .30903 L
.50162 .30904 L
.50279 .30909 L
.50403 .30916 L
.50514 .30925 L
.50618 .30935 L
.50855 .30964 L
.51109 .31006 L
.51343 .31054 L
.5187 .31195 L
.52762 .31531 L
.53702 .32004 L
.5751 .34677 L
.59633 .36166 L
.60637 .36727 L
.61563 .37121 L
.6203 .37266 L
.62269 .37325 L
.62525 .37376 L
Mistroke
.62659 .37398 L
.62782 .37415 L
.62906 .3743 L
.63022 .3744 L
.63092 .37445 L
.63156 .37449 L
.63227 .37452 L
.63302 .37454 L
.63368 .37455 L
.6344 .37455 L
.63569 .37452 L
.63687 .37447 L
.63798 .37439 L
.63919 .37427 L
.64049 .37411 L
.64314 .37368 L
.64556 .37314 L
.65023 .37175 L
.65464 .37 L
.66431 .36467 L
.67457 .35685 L
.69299 .33783 L
.73076 .28636 L
.75175 .25724 L
.76094 .24583 L
.77099 .23485 L
.78011 .22656 L
.78985 .21973 L
.79523 .21694 L
.80013 .21505 L
.80249 .21436 L
.80505 .21378 L
.80622 .21357 L
.80747 .21339 L
.80853 .21327 L
.80969 .21317 L
.81099 .21311 L
.81219 .21309 L
.81351 .21311 L
.81425 .21315 L
.81491 .21319 L
.81614 .2133 L
.81746 .21346 L
.81986 .21388 L
.82222 .21444 L
.82471 .21519 L
.82915 .21694 L
.83432 .21961 L
.83913 .22269 L
.85005 .23169 L
Mistroke
.87046 .25472 L
.88903 .28037 L
.90979 .3105 L
.92895 .33611 L
.94759 .356 L
.95699 .36344 L
.96198 .36658 L
.96735 .36931 L
.97197 .37109 L
.97619 .37227 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003of@3oool0
0`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000
oooo0?ooo`3D0?ooo`00f@3oool200000=D0oooo003I0?ooo`030000003oool0oooo0=@0oooo003I
0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`03
0000003oool0oooo02@0oooo1P00002Z0?ooo`00f@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00@0oooo0`00002W0?ooo`00f@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0Y03oool00=T0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:<0oooo003I0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2R0?ooo`00f@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0XP3oool00=T0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0:40oooo
002j0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`060?ooo`050?oO
W018000000000000001d_ol01`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0X@3oool00;X0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?oo
o`030;md0000000007Bo00P0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0X03oool00;T0oooo00<0okmd001d_`3o
ool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0:00oooo002i0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P00000000000030000000307Bo
o`3oool0oooo00D0oooo0`00000L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
W`3oool00;00oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo
00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;ooo`3oool0_g@007Boo`P0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo09h0oooo002i0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo0?ooo`2oM000M;oo
00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
09d0oooo002i0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102LB000
B9cO0;md001d_ol80?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`2M0?ooo`00^P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`d0oooo00@0omnL
04P0B018B000M;oo203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0W03oool00;X0oooo00D0oono07@000000000001809cOo`0?0?ooo`030?noM000
0000M;oo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo09`0oooo003I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`2K0?ooo`00f@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0V`3oool00=T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo09X0oooo003I0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2J0?ooo`00f@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0VP3oool00=T0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo09T0oooo003I0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2I0?oo
o`00f@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0V03oool00=T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo09P0oooo003I0?ooo`8000005P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo09P0oooo003I0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`2G0?ooo`00f@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0U`3oool00=T0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo09L0oooo003I0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2F0?ooo`00f@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0UP3oool00=T0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo09H0oooo003I0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2E0?oo
o`00f@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0U@3oool00=T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo09D0oooo003I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`2D0?ooo`00f@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0U03oool00=T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo09<0oooo003I0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2C0?ooo`00f@3oool200000180oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2C0?ooo`00f@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0TP3oool00=T0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0980oooo003I0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2B0?oo
o`00f@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0T@3oool00=T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0940oooo003I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2A0?ooo`00f@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0T03oool00=T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0900oooo003I0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2@0?ooo`00f@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0S`3oool00=T0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo08l0oooo003I
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2?
0?ooo`00f@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0S`3oool00=T0oooo0P00000>0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0SP3oool008L0oooo1`00001;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`020?ooo`L00000Q@3oool008D0oooo0P0000070?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`040000003o
ool0oooo0?ooo`8000001P3oool2000008<0oooo00240?ooo`030000003oool0oooo00P0oooo0P00
00180?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0000
000:0?ooo`800000P@3oool008<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=@3oool2000000d0oooo00<00000
0?ooo`3oool0OP3oool00880oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo07d0oooo00200?ooo`8000004@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0=@3oool200000100oooo00<000000?ooo`3o
ool0O03oool007l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0<`3oool200000080oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`1k0?ooo`00OP3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1j0?ooo`00OP3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1j0?ooo`00O@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1i0?ooo`00O03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo00D0okmd000000000000000007Boo`050?oo
o`030;md0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0N03oool007`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0P0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool0
0`2oM0000000001d_`040?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07L0oooo001k0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool07P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo
00/0oooo00<0okmd0000B02Lgol02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
07L0oooo001k0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P00018W=l02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo07H0oooo001j0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0503oool00`2LB000000000000003000000050018W03oool0oooo0=nLB018
W=l00`3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo00L0oooo0`0000090?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo07D0oooo001j0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
703oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07D0oooo001i0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0703oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018
W=l0oooo00X0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0M03oool007T0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0L0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3o_g@0001d
0;ooo`3oool0okmd0000B02Lgol01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
07@0oooo001h0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0703oool01@3ookl0
M0000000000004P0W=oo00d0oooo00D0okmd000000000000001809cOo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0L`3oool007L0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0L`3oool007L0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00P3oool9000006L0oooo001f0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0I03oool007H0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01@0oooo0`00000;0?ooo`800000I03oool005h0oooo1@00
000B0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0B0?ooo`<000003P3oool200000680oooo001K0?ooo`<000001@3oool2000000l0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool00000403oool00`000000oooo0?ooo`1O0?ooo`00FP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo05h0oooo001H0?ooo`800000303oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?oo
o`00E`3oool00`000000oooo0?ooo`0=0?ooo`8000002P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0G03oool005H0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
=P3oool2000000L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo05/0oooo001E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0FP3o
ool005@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool04@3oool6000001l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F@3oool0
04h0oooo2`00000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0=0?ooo`<000001P3oool2000001d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0oooo3000001;
0?ooo`00C@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00000A0?oo
o`050000003oool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`0;0?ooo`8000002`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool00000000000`0oooo0P0000190?ooo`00B`3oool2
000000D0oooo00<000000?ooo`3oool01P3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
000`0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool2000001X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo0P00
000@0?ooo`800000A`3oool004T0oooo0P0000060?ooo`030000003oool0oooo00T0oooo0P00000>
0?ooo`030000003oool000000380oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?
0?ooo`800000603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool200000080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`14
0?ooo`00B03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool200000380oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00`0oooo0P0000050?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@`3oool004H0oooo0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`120?ooo`00A@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool2000003<0oooo00<000000?ooo`3oool0
0`3oool2000001P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0@@3oool004@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@03o
ool004<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool00000<`3oool010000000oooo0?ooo`00000M0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo01X0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0
oooo000P0?ooo`X00000603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000380oooo00@000000?ooo`3o
ool000007P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000001L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0803oool5000001T0oooo000M0?ooo`<000002P3oool2000001D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo0000000c0?ooo`8000007`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
000001L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0703oool4000000@0oooo1000000E0?ooo`006`3oool20000
00l0oooo0P00000B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo01`0oooo0P00000H0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01T0oooo0P00000<0?ooo`8000004`3oool001X0oooo00<000000?ooo`3oool04@3oool2000000l0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool03P3oool2000000<0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0L0?ooo`8000006@3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`800000403oool00`000000oooo0?ooo`0@0?oo
o`006@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo000000L0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0000000R0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo0P00000I0?oo
o`040000003oool0oooo000001<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0703oool00`000000oooo000000070?ooo`030000003oool0oooo02d0oooo00@000000?oo
o`3oool000008P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`8000006P3oool2000001D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo0P00000?
0?ooo`005P3oool2000001X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0]0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000J
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool001D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07P3oool2000000P0oooo00<000000?ooo`3oool0:`3oool01@000000oooo0?ooo`3oool0
000002<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`00000I0?ooo`8000005`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0;0?ooo`00503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000002`0oooo00<0
00000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000001L0oooo00@000000?ooo`3oool0
00005P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0:0?ooo`004`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool00000
02`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01@0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo000B0?oo
o`030000003oool0oooo0240oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0O
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`050000003o
ool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo
000=0?ooo`050000003oool0oooo0?ooo`000000903oool00`000000oooo0000000=0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo
0000000V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`00000/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`0U0?ooo`800000303oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000002`0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030?noM0000000000000<00000
00D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo01/0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool01@2oM0000000000000000000M;oo02@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000:`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool01P2oM0000000000000000000M;oo000000P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`3o_g@0
000000000004000000<0oooo00D0okmd000000000000000007Boo`050?ooo`003@3oool0102LB4P0
00000?ooo`0000030?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo6`3oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`0:0000
003oool0oooo0;md0000M;l0oooo0000003ogi`0B00007Boob80oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
:`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool01`2oM00007Bo0?ooo`3oool0omnL0000001d_ol02@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`0309a8B02Lgol0
000000@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`003@3oool020000000W=oo0?oo
o`3oool000000?ooo`3o_g@007Bo0`3oool00`3OW4P0B9cO0?ooo`0J0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?noM000M;lQ0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`040000003oool0
oooo000002/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?noM000M;l02@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`0000007`3oool00`2LB4P000000?ooo`030?ooo`030?noM000
M;l0oooo0080oooo00<0gia804RLg`3oool00`3oool000d0oooo00<0W4Q809cOo`3oool00P3oool0
0`000000gia804RLg`030?ooo`030?noM000M;l0oooo01T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003o_g@007Bo0240oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo0`00000[0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
okmd001d_`X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`8000007`3o
ool00`000000W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool00`3o
ool000030?ooo`2LB000000000@0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`03
0?ooo`0300000018W=l0oooo0080oooo00<0okmd001d_`3oool0603oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`03
0?ooo`0309a800000000000000<0000000<004RL0?ooo`000000103oool00`000000W4P007Boo`0P
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000002/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`2LB000M;oo2P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool00`000000W=oo0?oo
o`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool00`3oool000d0oooo00<0W4Q8
09cOo`3oool00`3oool00`000000B9cO0?ooo`020?ooo`030?noM000M;l0oooo01P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0303oool00`000000M0000000000300000240oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000:`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`3ookl0M000000000020000000304RLg`3oool0oooo00X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0000001h0oooo00<0000009a8B02Lgol0103oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00<0oooo000=0?ooo`0309a8B02Lgol0oooo
00<0oooo00<0okmd0000003oool00P3oool00`3OW4P0B9cO0?ooo`0G0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00`0oooo00<0000007@0M02oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00P0oooo00<0oono0000002oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool00000703oool010000000oooo09a8B02Lgol40?ooo`030?noM018
W=l0oooo0080oooo00<0gia804RLg`3oool00`3oool000X0oooo00D0gia800000000B9`0W4Q809cO
o`050?ooo`0609a800000000oooo0?oOW01807@0_ooo5`3oool00`000000oooo0?ooo`090?ooo`05
0000003oool0oooo0?ooo`0000008P3oool00`000000oooo0?ooo`0=0?ooo`030?oo_`000000_ooo
0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0103oool2000002/0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<0oono0000002oool03`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000K
0?ooo`80000000<004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`@0oooo
000<0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000001809cOo`0H0?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`0=0?ooo`03
0?oo_`1d000000000080000000<0001d0000003oool07@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool2000002/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0000007@00000
00000P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3O
W4P0001809cOo`050?ooo`050?oo_`1d000000000000B02Lgol01@3oool001L0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`8000008P3oool00`000000oooo0?ooo`0A0?oo
o`040000003oool0oooo000001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0080oooo0P00000Z0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`00603oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?oo
o`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00P3oool2000002X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo000H0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool03P3oool200000240oooo00<000000?ooo`3oool04`3oool01000
0000oooo0?ooo`00000L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09P3oool0
10000000oooo0?ooo`3oool2000002X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`00000P0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02H0oooo00D0
00000?ooo`3oool0oooo0000000Z0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0D0?ooo`006P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0000001X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`040000
003oool0oooo000002X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0A0?ooo`05
0000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01D0oooo000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0000000Z0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool01@000000
oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?oo
o`00703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`00
0000603oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`00
0000:P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3o
ool000006P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01L0oooo000L0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool2000001L0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0X0?ooo`800000:@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01@0oooo0P00000K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool05`3oool001d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0W0?ooo`800000
:@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00030?ooool00000[@00
00010?ooo`003@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`8000004`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`09
0?ooo`8000001P3oool2000000H0oooo0`00000:0?ooo`030000003oool0oooo0140oooo0P00000C
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`06
0?ooo`8000002@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000100oooo00<0
00000?ooo`3oool02@3oool000d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool2000001<0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`800000203oool3000000P0oooo0P00000M
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00T0oooo000P0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool3000000T0oooo00D000000?ooo`000000oooo000000090?ooo`8000006`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
7P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo000P0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool07`3oool200000140oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0G0?ooo`800000303oool01@000000oooo0000003oool0000000/0oooo
0P00000H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool01@000000oooo
0?ooo`3oool0000001h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`00
8@3oool01@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`0000003`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo0P00000>0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool02P3oool2000001H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0H0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0L0?ooo`008P3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`040000003oool0
oooo000001P0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`008P3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0Q0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0A0?ooo`8000004@3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo
0P00000J0?ooo`030000003oool000000200oooo000S0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00d0
oooo0P00000A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool2000001/0
oooo00<000000?ooo`3oool07`3oool00280oooo00<000000?ooo`0000004@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`80
00004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`0000006P3oool200000200oooo000R0?ooo`030000003oool000000100oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool02`3oool2000001D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?oo
o`8000003P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00@000000?oo
o`3oool000006@3oool00`000000oooo0000000P0?ooo`008@3oool01@000000oooo0?ooo`3oool0
000000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000001L0oooo
00D000000?ooo`3oool0oooo0000000O0?ooo`00803oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0@0?ooo`8000002P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool001l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0K0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`040000
003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0
oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool0103oool2000001X0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo01<0oooo0P0000050?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00T0oooo000M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`050?ooo`030000003oool0000002H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool001/0
oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool200000080oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02P3oool001X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00D0oooo0P00000V0?ooo`040000003oool0oooo000001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo0P00000E0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
o`006@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`00000V0?ooo`8000007P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool2000001@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo000H0?ooo`03
0000003oool0oooo0100oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000002@0oooo0P00000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool000000180oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo000G0?ooo`030000003oool0oooo
0180oooo0P00000R0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool2000000030?ooo`000000
oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P00000?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00000_
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L
0?ooo`8000000`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`8000006P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo0P0000020?ooo`030000003oool0oooo00l0oooo000>0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool2000002@0oooo0P00000`0?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05@3oool200000180oooo000?0?ooo`040000003oool0oooo
0?ooo`8000005P3oool010000000oooo0?ooo`00000S0?ooo`800000<03oool01@000000oooo0?oo
o`3oool0000000T0oooo0P00000H0?ooo`8000001`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00D0oooo0P0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo1000000@0?ooo`00403o
ool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`800000<@3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo0180oooo0`0000090?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0203oool2000000H0oooo00<000000?ooo`3oool02`3o
ool2000001l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000003oool0oooo0080oooo
0P00000>0?ooo`003`3oool3000001H0oooo0P0000060?ooo`030000003oool0oooo01l0oooo0P00
000a0?ooo`030000003oool0000000d0oooo1000000>0?ooo`8000003@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00X0oooo0`0000030?ooo`030000003oool0oooo00P0oooo0`00
000R0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0F0?ooo`<000005`3oool00`000000oooo0?ooo`050?ooo`800000303oool000d0oooo0P000003
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0M
0?ooo`040000003oool0oooo00000300oooo0P00000B0?ooo`D00000103oool5000000l0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`D00000103oool5000002D0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo0P00
000E0?ooo`8000002P3oool00`000000oooo0?ooo`090?ooo`004`3oool200000140oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0E0?ooo`@00000503oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00@0oooo0P00000>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool010000000oooo0?ooo`3oool5000002X0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool00000
4`3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`800000303o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3o
ool200000300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000I0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`005P3o
ool4000000L0oooo0`00000?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0/0?ooo`800000<03oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0O0?ooo`040000003o
ool0oooo000001P0oooo00<000000?ooo`3oool0103oool3000000/0oooo0`00000J0?ooo`006P3o
ool7000001<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02X0oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0P0?ooo`800000
603oool00`000000oooo0?ooo`080?ooo`@000000`3oool4000001d0oooo000e0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`050000003o
ool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0303oool400000240oooo000f0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?ooo`000000
<03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0N0?ooo`040000003oool00000000001D0oooo00<000000?ooo`3o
ool0<@3oool003L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`800000
=03oool003P0oooo00<000000?ooo`3oool03P3oool2000000h0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo0P00000f0?ooo`00>@3oool2
000000d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0f0?ooo`00>`3oool30000
00L0oooo0`00000B0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool30000
00L0oooo0`00000i0?ooo`00?P3oool7000001H0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`800000@03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo1`00000l0?oo
o`00G03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0603oool2000000030?ooo`000000oooo00P0oooo0P0000120?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0CP3oool005`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo0P0000070?ooo`800000A@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04l0oooo001M0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000H00000A`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04l0oooo001N0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1@0?ooo`00G`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo0P00000K0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1A0?ooo`00H03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo00h0oooo0P00001D0?ooo`00H@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0E03oool00680oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0D`3oool2000000X0oooo0P00001G0?ooo`00H`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1E
0?ooo`8000001P3oool2000005T0oooo001T0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05P0oooo1P00001K0?oo
o`00I@3oool2000000h0oooo0P00000E0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0^@3oool006L0oooo0P00000:0?ooo`8000005`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0;T0oooo001Y0?ooo`@000000P3oool4000001X0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`2j0?ooo`00K03oool3000001h0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`2j0?ooo`00S@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0;X0oooo002=0?ooo`030000003oool0oooo02X0oooo00H0okmd000000000000000007Boo`000004
0?ooo`030;md0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`05
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0^`3oool008h0oooo00<000000?oo
o`3oool0:@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d000000@0oooo00<0_g@000000000M;l0103o
ool00`2oM00000000;ooo`020?ooo`030=nLM02Lgol0oooo00H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`2k0?ooo`00SP3oool00`000000oooo0?ooo`0X0?ooo`030?noM000M;l0
oooo0080oooo00<0gia804RLg`0000002`3oool00`000000001809cOo`0:0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0^`3oool008h0oooo00<000000?ooo`3oool0:03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0000000/0oooo00@000000?oOW0180000B9cO2@3oool3
000001D0oooo00<000000?ooo`3oool0_03oool008l0oooo00<000000?ooo`3oool09`3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0000000/0oooo00D000000?ooo`3oool0W4P004RLg`08
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0_03oool008l0oooo00<000000?oo
o`3oool09`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0000000X0oooo00<000000?oo
o`3oool00P3oool00`2LB7@0_ooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0_03oool008l0oooo00<000000?ooo`3oool09`3oool00`3o_g@0B9cO0?ooo`020?ooo`04
0=nLB018W=l0oooo000000T0oooo00<0000007Boo`3oool00P3oool00`2oM000M;oo0?ooo`060?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0_@3oool00900oooo00<000000?ooo`3o
ool09`3oool0202LB000M;oo0?ooo`3ogi`0B01d0;ooo`3oool000002@3oool01`000000001d0;oo
o`3oool0okmd0000B02Lgol01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0;d0
oooo002@0?ooo`030000003oool0oooo02L0oooo00D0oono07@000000000001809cOo`020?ooo`03
0000003oool0oooo00L0oooo00H000000?noM000000000000000B02Lgol80?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0_P3oool00900oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`2n0?ooo`00T@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;h0
oooo002A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0_`3oool00940oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`2o0?ooo`00T@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0;l0oooo002B0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0`03oool00980oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`300?ooo`00
TP3oool00`000000oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0<40oooo002C0?ooo`030000003oool0oooo02l0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0`@3oool009<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0000000@0?ooo`800000
4@3oool00`000000oooo0?ooo`310?ooo`00T`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool000000100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`320?ooo`00U03oool0
0`000000oooo0?ooo`0`0?ooo`800000403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0<80oooo002D0?ooo`030000003oool0oooo0300oooo0P00000@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0`P3oool009@0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0``3oool009@0oooo
00<000000?ooo`3oool0<03oool200000100oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`330?ooo`00U@3oool00`000000oooo0?ooo`0_0?ooo`800000403oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0<@0oooo002E0?ooo`030000003oool0oooo02h0oooo00@00000
0?ooo`3oool000003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0<@0oooo002E
0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0<D0oooo002F0?ooo`030000003oool0oooo02d0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0a@3o
ool009H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`360?ooo`00UP3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0<H0oooo002G0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0a`3oool009L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`370?ooo`00U`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool2000000X0oooo00<000000?ooo`3oool0b03oool009P0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`390?ooo`00V03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0<X0oooo002H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0bP3oool009T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3;0?ooo`00V@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<`0oooo002I0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0c@3oool009X0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3>0?ooo`00VP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00h0
oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0c`3oool009X0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0@0?ooo`8000000P3oool00`000000oooo
0000000200000=80oooo002K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3o
ool400000=D0oooo002K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`3D0?ooo`00V`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0e03oool009`0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0=@0oooo002L0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3D0?ooo`00W03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01H0oooo0P00003E0?ooo`00W@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0e03oool009d0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0=@0oooo002M0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3D0?ooo`00
WP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
e03oool009h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0=@0oooo002O0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3D0?ooo`00W`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0e03oool00:00oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0=@0oooo002P0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3D0?ooo`00X@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0e03oool00:40oooo00<00000
0?ooo`3oool05P3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3o
ool01@3ogi`0B000000000000000M;oo00L0oooo00<000000?ooo`3oool0e03oool00:80oooo00<0
00000?ooo`3oool05@3oool01P2LB7@000000?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000
M;l0203oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo0=@0oooo002R0?ooo`030000
003oool0oooo01@0oooo00<0okmd0000003oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030;md
001d_ol0oooo00L0oooo00<000000?ooo`3oool0e03oool00:<0oooo00<000000?ooo`3oool04`3o
ool00`3OW4P000000?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia80000000000000`00
00000`1d_ol0oooo0?ooo`050?ooo`<00000e03oool00:<0oooo00<000000?ooo`3oool04`3oool0
0`000000B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00H0okmd0000M02oool0oooo0;md
001d_ol80?ooo`030000003oool0oooo0=@0oooo002T0?ooo`030000003oool0oooo0180oooo00<0
000004RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0;0?ooo`050=nLB000M;l0oooo0;md001d_ol0
203oool00`000000oooo0?ooo`3D0?ooo`00Y03oool00`000000oooo0?ooo`0A0?ooo`030000003o
_g@0B9cO00<0oooo00<0gia804RLg`3oool0303oool0102LB000B9cO0;md001d_ol80?ooo`030000
003oool0oooo0=@0oooo002U0?ooo`030000003oool0oooo00l0oooo00T000000?ooo`3oool0W4P0
07Boo`3oool0omnL04P0M02oool03@3oool0103ogi`0B01804Q8001d_ol80?ooo`030000003oool0
oooo0=@0oooo002V0?ooo`030000003oool0oooo00d0oooo00T000000?ooo`3oool0oooo0?oo_`1d
000000000000B02Lgol03`3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0=@0oooo
002V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`3D0?ooo`00Y`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0e03oool00:P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0=@0oooo002Y0?ooo`<000001P3oool2000002D0oooo00<000000?ooo`3o
ool0e03oool00:/0oooo1`00000W0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`030000003o
ool0oooo0=@0oooo003I0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`030000003oool0oooo
0=@0oooo003I0?ooo`800000e@3oool00=T0oooo00<000000?ooo`3oool0e03oool00=T0oooo00<0
00000?ooo`3oool0e03oool00=T0oooo00<000000?ooo`3oool0e03oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-10.663, -0.460578, \
0.0736533, 0.00519804}}]
}, Closed]],

Cell[TextData[{
  "It also has the advantage that symbolic derivatives are evaluated \
properly.  Notice that ",
  StyleBox["Piecewise", "InlineInput"],
  " takes care of the limit ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " correctly."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Simplify[D[sbessj[n, z], z]], {n, 0, 2}] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{"\[Piecewise]", GridBox[{
                  {"0", \(z \[Equal] 0\)},
                  {\(\(z\ Cos[z] - Sin[z]\)\/z\^2\), 
                    TagBox["True",
                      "PiecewiseDefault",
                      AutoDelete->False,
                      DeletionWarning->True]}
                  },
                ColumnSpacings->1.2,
                ColumnAlignments->{Left}]}]},
          {\(\(2\ z\ Cos[z] + \((\(-2\) + z\^2)\)\ Sin[z]\)\/z\^3\)},
          {\(\(\(-z\)\ \((\(-9\) + z\^2)\)\ Cos[
                      z] + \((\(-9\) + 4\ z\^2)\)\ Sin[z]\)\/z\^4\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Piecewise[ {{0, 
          Equal[ z, 0]}}, 
          Times[ 
            Power[ z, -2], 
            Plus[ 
              Times[ z, 
                Cos[ z]], 
              Times[ -1, 
                Sin[ z]]]]], 
        Times[ 
          Power[ z, -3], 
          Plus[ 
            Times[ 2, z, 
              Cos[ z]], 
            Times[ 
              Plus[ -2, 
                Power[ z, 2]], 
              Sin[ z]]]], 
        Times[ 
          Power[ z, -4], 
          Plus[ 
            Times[ -1, z, 
              Plus[ -9, 
                Power[ z, 2]], 
              Cos[ z]], 
            Times[ 
              Plus[ -9, 
                Times[ 4, 
                  Power[ z, 2]]], 
              Sin[ z]]]]}]]], "Output"]
}, Closed]],

Cell[TextData[{
  "The gravitational field of a uniform sphere with mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is\n\t",
  Cell[BoxData[
      \(TraditionalForm\`r < 
          R\ \ \[DoubleLongRightArrow]\ \ g\  = \ \(G\ M\ r\)\/R\^2\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`r > 
          R\ \ \[DoubleLongRightArrow]\ \ g = \ \(G\ M\)\/r\^2\)]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " is the gravitational constant.  The corresponding potential is then\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\  = \ \(-\(\[Integral]\_\[Infinity]\%r g[
                s] \[DifferentialD]s\)\)\)]],
  "\nUse Piecewise to define the field and then evaluate the potential.   It \
may help to use Assuming[{R>0,r>0}, \[CenterEllipsis] ] to inform Integrate \
that it may assume that radii are positive real numbers.  ",
  "Then plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi][r]/\[Phi][R]\)]],
  " versus ",
  Cell[BoxData[
      \(TraditionalForm\`r/R\)]],
  "."
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Loop commands", "Subsection",
  CellTags->"loop commands"],

Cell[CellGroupData[{

Cell["Basic syntax", "Subsubsection"],

Cell[TextData[{
  "The ",
  ButtonBox["Do",
    ButtonStyle->"RefGuideLink"],
  " command can be used to execute a set of instructions a fixed number of \
times, whereas the ",
  ButtonBox["While",
    ButtonStyle->"RefGuideLink"],
  " or ",
  ButtonBox["For",
    ButtonStyle->"RefGuideLink"],
  " commands execute a set of instructions while a condition remains true."
}], "Text"],

Cell[TextData[{
  "The basic syntax for ",
  StyleBox["Do", "InlineInput"],
  " is ",
  StyleBox["Do[body,iterator]", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "where ",
  StyleBox["body", "InlineInput"],
  " is a sequence of commands separated by semicolons (except for the last) \
and ",
  StyleBox["iterator", "InlineInput"],
  " is a standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " iteration code.  If several iterators are included, separated by commas, \
nested loops are evaluated from the innermost iterator to the outermost.  \
Although one can often write functions more efficiently using ",
  ButtonBox["Nest",
    ButtonStyle->"RefGuideLink"],
  " or related functions, for numerical calculations using intermediate \
results it is often useful to embed a ",
  StyleBox["Do", "InlineInput"],
  " loop within a module.  "
}], "Text"],

Cell[TextData[{
  "The basic syntax for ",
  StyleBox["While", "InlineInput"],
  " is ",
  StyleBox["While[condition,body]", "InlineInput"],
  " where ",
  StyleBox["condition", "InlineInput"],
  " is tested while ",
  StyleBox["body", "InlineInput"],
  " is iterated until the condition becomes ",
  StyleBox["False", "InlineInput"],
  ".  You must make sure that the condition will eventually fail, perhaps by \
including an iteration counter in ",
  StyleBox["body", "InlineInput"],
  " and a test on that counter in ",
  StyleBox["condition", "InlineInput"],
  ".  "
}], "Text"],

Cell[TextData[{
  "Finally, the basic syntax for ",
  StyleBox["For", "InlineInput"],
  " is ",
  StyleBox["For[start,test,incr,body]", "InlineInput"],
  " where ",
  StyleBox["start", "InlineInput"],
  " is evaluated first and usually initializes a counter (and perhaps other \
variables), then ",
  StyleBox["test", "InlineInput"],
  " and ",
  StyleBox["body", "InlineInput"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "are evaluated until ",
  StyleBox["test", "InlineInput"],
  " fails.  The iteration variable is incremented by ",
  StyleBox["incr", "InlineInput"],
  ".  A trivial example is given below.  Notice that 1) ",
  StyleBox["start", "InlineInput"],
  " is evaluated first,  2) since the ",
  StyleBox["test", "InlineInput"],
  " evaluates to ",
  StyleBox["True", "InlineInput"],
  ", 3) ",
  StyleBox["body", "InlineInput"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is evaluated next, then 4) ",
  StyleBox["incr", "InlineInput"],
  " changes something and 5) ",
  StyleBox["test", "InlineInput"],
  " is evaluated again to determine whether ",
  StyleBox["body", "InlineInput"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "should be reevaluated."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(For[\((x = 20; y = 1)\), x > 0, 
      x = x - 2, \((y = y*x; Print[y])\)]\)], "Input"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(360\)], "Print"],

Cell[BoxData[
    \(5760\)], "Print"],

Cell[BoxData[
    \(80640\)], "Print"],

Cell[BoxData[
    \(967680\)], "Print"],

Cell[BoxData[
    \(9676800\)], "Print"],

Cell[BoxData[
    \(77414400\)], "Print"],

Cell[BoxData[
    \(464486400\)], "Print"],

Cell[BoxData[
    \(1857945600\)], "Print"],

Cell[BoxData[
    \(3715891200\)], "Print"]
}, Closed]],

Cell[TextData[{
  "An advantage of ",
  StyleBox["Do", "InlineInput"],
  " is that by prescribing the number of iterations in advance one can be \
confident that the loop will eventually terminate.  On the other hand, loops \
which terminate when a condition is satisfied are more flexible.  For \
example, when summing a series one can continue until convergence is \
obtained.  However, the user must make sure that the loop does eventually \
terminate.  Therefore, one usually includes a maximum number of iterations as \
part of the termination condition."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: summation using Do, While, or For", "Subsubsection"],

Cell[TextData[{
  "For example, below we use ",
  StyleBox["Do", "InlineInput"],
  ", ",
  StyleBox["While", "InlineInput"],
  ", and ",
  StyleBox["For", "InlineInput"],
  " to evaluate an approximation to the following sum with symbolic result"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(exactsum = Sum[n\^\(-2\), {n, 1, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    \(\[Pi]\^2\/6\)], "Output"]
}, Closed]],

Cell["and numerical result", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[exactsum]\)], "Input"],

Cell[BoxData[
    \(1.6449340668482262`\)], "Output"]
}, Closed]],

Cell[TextData[{
  "First, we use a ",
  StyleBox["Do", "InlineInput"],
  " loop to sum 100 terms.  Notice that we initialize the sum in the \
declaration of local variables for ",
  StyleBox["Module", "InlineInput"],
  " and return a numerical result as the final statement of the module.  The \
",
  StyleBox["Do", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "loop by itself accumulates the sum, but does not print the final result.  \
By placing the loop within a module, we both protect the local variable and \
ensure that the final result is displayed.  It is good practice to always \
encapsulate loop commands within a scoping command."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Module[{sum = 0}, Do[sum = sum + 1\/x\^2, {x, 1, 100}]; 
      N[sum]]\)], "Input"],

Cell[BoxData[
    \(1.6349839001848927`\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Alternatively, ",
  StyleBox["While", "InlineInput"],
  " expresses that range in terms of a condition upon the loop counter."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Module[{sum = 0, x = 1}, 
      While[x \[LessEqual] 100, sum = sum + 1\/x\^2; x = x + 1]; 
      N[sum]]\)], "Input"],

Cell[BoxData[
    \(1.6349839001848927`\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Finally, ",
  StyleBox["For", "InlineInput"],
  " includes the initialization but is otherwise similar to ",
  StyleBox["While", "InlineInput"],
  " (although the components differ in order)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(For[{sum = 0, x = 1}, x \[LessEqual] 100, x = x + 1, 
      sum = sum + 1\/x\^2]; N[sum]\)], "Input"],

Cell[BoxData[
    \(1.6349839001848927`\)], "Output"]
}, Closed]],

Cell["\<\
a) Write and test factorial functions using Do, For, and While loops.  
b) Evaluate 257! using these functions.  Note that the recursion limit \
encountered for the recursive factorial function does not affect loops.  
c) Compare the speeds of these three versions of the function.\
\>", "Exercise"],

Cell[TextData[{
  "Use a For loop to determine the minimum ",
  StyleBox["nmax",
    FontSlant->"Italic"],
  " needed to reduce the difference between ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%nmax n\^\(-2\)\)]],
  " and the limiting value ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\^2\/6\)]],
  "to less than 0.001.  Check using Sum.  [Important: the sum approaches the \
limit from below and the counter is incremented before leaving the loop.]"
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fancy incrementation operators", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides many of the incrementation operators that appeal to C \
programmers, but perhaps to few others.  For example, we can increment ",
  StyleBox["x", "InlineInput"],
  " within a ",
  StyleBox["For", "InlineInput"],
  " loop either using the assignment statement ",
  StyleBox["x=x+1", "InlineInput"],
  " or the incrementation operator ",
  StyleBox["++x", "InlineInput"],
  ".",
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "Although one never needs these somewhat cryptic constructions, they are \
listed below for completeness.  "
}], "Text"],

Cell[BoxData[
    StyleBox[GridBox[{
          {
            StyleBox[\(Incrementation\ Operators\),
              FontFamily->"Times New Roman",
              FontWeight->"Bold",
              Background->RGBColor[0.500008, 0.996109, 0.996109]]},
          {
            StyleBox[GridBox[{
                  {
                    StyleBox["incrementation",
                      "Text"], 
                    StyleBox[\(new\ value\),
                      "Text"], 
                    StyleBox[\(return\ value\),
                      "Text"]},
                  {\(x++\), \(x \[Rule] x + 1\), 
                    StyleBox[\(old\ value\),
                      "Text"]},
                  {\(++x\), \(x \[Rule] x + 1\), 
                    StyleBox[\(new\ value\),
                      "Text"]},
                  {\(x--\), \(x \[Rule] x - 1\), 
                    StyleBox[\(old\ value\),
                      "Text"]},
                  {\(--x\), \(x \[Rule] x + 1\), 
                    StyleBox[\(new\ value\),
                      "Text"]},
                  {\(x += dx\), \(x \[Rule] x + dx\), 
                    StyleBox[\(new\ value\),
                      "Text"]},
                  {\(x -= dx\), \(x \[Rule] x - dx\), 
                    StyleBox[\(new\ value\),
                      "Text"]},
                  {\(x *= c\), \(x \[Rule] x*c\), 
                    StyleBox[\(new\ value\),
                      "Text"]},
                  {\(x /= c\), \(x \[Rule] x/c\), 
                    StyleBox[\(new\ value\),
                      "Text"]}
                  },
                ColumnAlignments->{Left},
                GridFrame->True,
                RowLines->{True, False}],
              "Input",
              Background->RGBColor[0.500008, 0.996109, 0.996109]]}
          }],
      Background->RGBColor[0.500008, 0.996109, 0.996109]]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Note that in some cases the old value of the loop counter is printed even \
though the counter is updated; in other words, in some cases the counter is \
printed before updating.  Thus,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = 1; \ \(x++\)\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Closed]],

Cell["\<\
prints the value before incrementing, and then stores the new value\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Closed]],

Cell["whereas", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = 1; \ \(++x\)\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Closed]],

Cell["\<\
increments before printing.  These two forms usually behave the same way \
within loops that do not print their counters, but one should be aware of the \
difference between them.\
\>", "Text"],

Cell[TextData[{
  "As an example, the ",
  StyleBox["For", "InlineInput"],
  " loop at the end of the preceding section is rewritten below using \
incrementation operators in place of assignment statements.  The results are \
the same, of course, but we have saved a few characters at the expense of \
readability."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(For[{sum = 0, x = 1}, x \[LessEqual] 100, \(++x\), sum += 1\/x\^2]; 
    N[sum]\)], "Input"],

Cell[BoxData[
    \(1.6349839001848927`\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Documenting functions", "Subsection",
  CellTags->"documentation"],

Cell[TextData[{
  "Several types of documentation are available.  The most obvious are the \
text cells that we have been using to present this course!  This type of \
documentation describes the notebook and its contents in general, but not the \
specifics of a function.  A function or module should be contained within a \
single input cell.  Comments which explain the steps within that cell can be \
included using the special notation ",
  StyleBox["(* comment text *)", "InlineInput"],
  ", where everything between ",
  StyleBox["(*", "InlineInput"],
  " and ",
  StyleBox["*)", "InlineInput"],
  " is treated as a comment and is not evaluated."
}], "Text"],

Cell[TextData[{
  "Another important type of documentation is a ",
  StyleBox["usage message",
    FontSlant->"Italic"],
  ".  When we type"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?BesselJ\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"BesselJ[n, z] gives the Bessel function of the first kind \
J(n, z).\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"BesselJ",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3312796112-2879332"]
}, Closed]],

Cell[TextData[{
  "we receive a usage message that provides a brief explanation of the \
function and its arguments.  This is especially important when the function \
definitions are not immediately accessible to the user; perhaps they are \
buried in some package.  In any case, it is good practice to provide usage \
messages for your functions if only to remind yourself what they do a few \
weeks later.  It is also advisable to provide usage messages for any options \
that you give your functions.  The basic syntax for a usage message is ",
  StyleBox["f::usage", "InlineInput"],
  StyleBox[" = ", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["\"text\"", "InlineInput"],
  ".  Recall, for example, our version of the spherical Bessel function."
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear[sbessj];\)\(\n\)
    \)\), "\n", 
    \(\(sbessj::usage\  = \ "\<sbessj[n,z] computes the spherical Bessel \
function of the first kind (based on BesselJ) and is regular at the origin \
for integer order n.\>";\)\), "\n", 
    \(\(\(sbessy::usage\  = \ "\<sbessy[n,z] computes the spherical Bessel \
function of the second kind (based on BesselY) and is irregular at the origin \
for integer order n.\>";\)\(\n\)
    \)\), "\n", 
    \(\(sbessj[0, z_] = 
        Piecewise[{{1, z \[Equal] 0}}, 
          Sin[z]\/z];\)\), "\[IndentingNewLine]", 
    \(\(sbessj[n_, z_] = \@\(\[Pi]\/2\)\ \(z\^\(\(-1\)/2\)\) 
          BesselJ[n + 1\/2, z];\)\), "\n", 
    \(\(sbessy[n_, 
          z_]\  := \ \@\(\[Pi]\/2\)\ z\^\(\(-1\)/2\)\ BesselY[n + 1\/2, 
            z];\)\)}], "Input",
  CellTags->"sbess"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?sbess*\)\)], "Input"],

Cell[BoxData[GridBox[{
        {
          StyleBox["Global`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["sbessj",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3317812152-6582644", "Global`sbessj"},
                  ButtonFrame->"None",
                  ButtonNote->"Global`"], 
                ButtonBox[
                  StyleBox["sbessy",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3317812152-6582644", "Global`sbessy"},
                  ButtonFrame->"None",
                  ButtonNote->"Global`"], "", "", "", "", "", "", "", "", "", 
                "", "", "", ""}
              },
            RowMinHeight->1.05]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell[TextData[{
  "Usage messages are a special case of a more general messaging function \
that can be used to report errors or warnings.  To create a message \
associated with a ",
  StyleBox["symbol", "InlineInput"],
  ", assign a string to ",
  StyleBox["symbol::tag", "InlineInput"],
  " where ",
  StyleBox["tag", "InlineInput"],
  " identifies the particular message.  A message is printed when the \
function ",
  ButtonBox["Message",
    ButtonStyle->"RefGuideLink"],
  "[",
  StyleBox["symbol::tag,parameters", "InlineInput"],
  "] is evaluated.  A message string can include one or more parameter slots, \
numbered ",
  StyleBox["`1`", "InlineInput"],
  ", ",
  StyleBox["`2`", "InlineInput"],
  ", etc., which are filled sequentially.  Note the back-quotes in the \
parameter numbering."
}], "Text"],

Cell["\<\
Our previous versions of factorial functions remained unevaluated if given \
improper input.  In the following version we include messages that inform the \
user of the nature of improper input.\
\>", "Text"],

Cell[BoxData[{
    \(\(factorial::usage = "\<factorial[n] returns n! for nonnegative \
integers and error messages otherwise\>";\)\), "\n", 
    \(\(factorial::noninteger = "\<`1` is not an integer\>";\)\), "\n", 
    \(\(\(factorial::negative = "\<negative argument `1` not allowed\>";\)\(\n\
\)
    \)\t\t\t\), "\n", 
    \(factorial[n_] := \ 
      Which[\n\tNot[IntegerQ[n]], \ Message[factorial::noninteger, n], \n\t
        n < 0, \ Message[factorial::negative, n], \n\t
        True, \ \(n!\)\ ]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?factorial\)\)], "Input"],

Cell[BoxData[
    \("factorial[n] returns n! for nonnegative integers and error messages \
otherwise"\)], "Print",
  CellTags->"Info3312796154-7655491"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial[\(-2\)]\)], "Input"],

Cell[BoxData[
    \(factorial::"negative" \(\(:\)\(\ \)\) 
      "negative argument \!\(-2\) not allowed"\)], "Message"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial[\[Pi]]\)], "Input"],

Cell[BoxData[
    \(factorial::"noninteger" \(\(:\)\(\ \)\) 
      "\!\(\[Pi]\) is not an integer"\)], "Message"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(factorial[10]\)], "Input"],

Cell[BoxData[
    \(3628800\)], "Output"]
}, Closed]],

Cell["\<\
Messages are usually placed in packages that contain well-developed functions \
which are intended to be used in many applications.  It is often important to \
ensure that such functions do not return unpredictable results for improper \
input and it is then very helpful to the user, who might even be yourself, to \
provide diagnostic information.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiled functions", "Section",
  CellTags->"compiled functions"],

Cell[TextData[{
  "Unlike traditional ",
  StyleBox["compiled",
    FontSlant->"Italic"],
  " languages which translate instructions directly into machine code that \
performs simple operations, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is an ",
  StyleBox["interpreted",
    FontSlant->"Italic"],
  " language which evaluates instructions by applying rules to symbols that \
match patterns.  Consequently, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code is sometimes rather slow compared with, say, Fortran or C code for \
the same function.  Fortunately, there is a mechanism in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for recovering some of the economy of compiled languages by using ",
  ButtonBox["Compile",
    ButtonStyle->"RefGuideLink"],
  " to produce machine code that operates upon numbers rather than symbols.  \
Thus, ",
  StyleBox["Compile[{", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\_1, x\_2, \[CenterEllipsis]\)], "InlineInput"], 
    "InlineInput"],
  StyleBox["},body]", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "produces a pure function of type ",
  StyleBox["CompiledFunction[{", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\_1, x\_2, \[CenterEllipsis]\)], "InlineInput"], 
    "InlineInput"],
  StyleBox["},", "InlineInput"],
  StyleBox["-", "InlineInput",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["CompiledCode-", "InlineInput",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "]",
  " assuming that all arguments are real numbers."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[f, x];\)\), "\n", 
    \(f = \ Compile[{x}, \ x\^2\ Exp[\(-x\^2\)]\ ]\)}], "Input"],

Cell[BoxData[
    TagBox[\(CompiledFunction[{x}, 
        Block[{$$647}, $$647 = x\^2; $$647\ \[ExponentialE]\^\(-$$647\)], 
        "-CompiledCode-"]\),
      False,
      Editable->False]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(Table[f[x], {x, 0. , 10. , 0.0001}];\)]\)], "Input"],

Cell[BoxData[
    \({0.23399999999999999`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[g, x];\)\), "\n", 
    \(\(g[x_]\  := \ x\^2\ Exp[\(-x\^2\)];\)\), "\n", 
    \(Timing[\(Table[g[x], {x, 0. , 10. , 0.0001}];\)]\)}], "Input"],

Cell[BoxData[
    \({0.609`\ Second, Null}\)], "Output"]
}, Closed]],

Cell["\<\
Thus, for this simple function compilation improves the speed by about a \
factor of 3.  The ratio depends upon the function and the machine, but \
compilation is often quite helpful for complicated functions that are \
expected to be used only with numeric data of particular types.\
\>", "Text"],

Cell[TextData[{
  "When the arguments are not real numbers, it is necessary to specify their \
types explicitly using the syntax ",
  StyleBox["Compile[{", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`{x\_1, t\_1}, \ {x\_2, t\_2}, \[CenterEllipsis]\)], 
    "InlineInput"], "InlineInput"],
  StyleBox["},body]", "InlineInput"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i\)]],
  " indicates the type and may be ",
  StyleBox["_Real", "InlineInput"],
  ",  ",
  StyleBox["_Integer", "InlineInput"],
  ",  ",
  StyleBox["_Complex", "InlineInput"],
  ", or ",
  StyleBox["True|False", "InlineInput"],
  ".  Refer to ",
  ButtonBox["Compile",
    ButtonStyle->"RefGuideLink"],
  " for other variations that apply to more complicated arguments."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Mandelbrot set", "Section",
  CellTags->"Mandelbrot"],

Cell["\<\
An elementary example of procedural programming is provided by the classic \
Mandelbrot set, which was often the subject of the first program written by a \
proud new PC owner back in the early 1980's.  Here we develop such a program \
using many of the concepts presented in this notebook, adding refinements as \
we go.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["The algorithm consists of the iteration", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(TraditionalForm\`z \[RightArrow] z\^2 + c\)], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", " ", "=", " ", 
          RowBox[{
            StyleBox["cx",
              FontSlant->"Italic"], " ", "+", " ", 
            RowBox[{"I", " ", 
              StyleBox["cy",
                FontSlant->"Italic"]}]}]}], TraditionalForm]]],
  " is a complex number with real part ",
  Cell[BoxData[
      FormBox[
        StyleBox["cx",
          FontSlant->"Italic"], TraditionalForm]]],
  " and imaginary part ",
  Cell[BoxData[
      FormBox[
        StyleBox["cy",
          FontSlant->"Italic"], TraditionalForm]]],
  " and where the starting value is ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 = 0\)]],
  ".  Either ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " will find itself trapped near the origin or, after some number of \
iterations, it will escape to infinity.  The Mandelbrot set consists of all \
points ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " for which the iteration beginning with ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 = 0\)]],
  " produces a sequence that is trapped.  Pretty pictures are created by \
applying a coloring or altitude algorithm to display the rate at which points \
outside the Mandelbrot set flee the scene."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Therefore, we require a function of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox["cx",
              FontSlant->"Italic"], ",", 
            StyleBox["cy",
              FontSlant->"Italic"]}], ")"}], TraditionalForm]]],
  ".  Since it will be necessary to terminate the iteration after a finite \
number of steps for points which either escape very slowly or simply orbit \
the origin, it is convenient to specify the maximum number of iterations as a \
third argument.  The value returned by the function will be either the number \
of iterations needed to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] > 2\)]],
  ", which one can show is threshold for certain escape, or the maximum \
number of iterations permitted.  We use ",
  StyleBox["Module", "InlineInput"],
  " to isolate the local variables of no external importance and use ",
  StyleBox["While", "InlineInput"],
  " to perform the iteration while testing the magnitude of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ".  We use ",
  StyleBox["Return", "InlineInput"],
  " to clearly identify the result of the function.  Those familiar with any \
standard procedural programing language, such as Fortran or C or Pascal, \
should immediately recognize this algorithm.  "
}], "Text"],

Cell[BoxData[
    \(\(\(\(Clear[mandelbrotRate];\)\n
    mandelbrotRate[cx_, cy_, lim_]\  := \ 
      Module[{c, z, ct = 0}, c = cx\  + \ I\ cy; z\  = \ c; 
        While[\((Abs[z] < 2.0)\)\  && \ \((ct \[LessEqual] lim)\), 
          ct = ct + 1; z\  = \ z*z + \ c;]; 
        Return[ct]\ ]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "The escape rate can now be displayed in the form of a ",
  StyleBox["DensityPlot", "InlineInput"],
  " using a coloring function that assigns each point a hue.  Below we \
evaluate the hue using the logarithm of the escape rate."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DensityPlot[
        Log[1 + mandelbrotRate[x, y, 50]], {x, \(-2\), 0.6}, {y, \(-1.2\), 
          1.2}, PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        AspectRatio \[Rule] Automatic, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92308 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.758876 0.369822 0.461538 0.369822 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.20414 -0.0125 -12 -9 ]
[.20414 -0.0125 12 0 ]
[.38905 -0.0125 -6 -9 ]
[.38905 -0.0125 6 0 ]
[.57396 -0.0125 -12 -9 ]
[.57396 -0.0125 12 0 ]
[.75888 -0.0125 -3 -9 ]
[.75888 -0.0125 3 0 ]
[.94379 -0.0125 -9 -9 ]
[.94379 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09172 -12 -4.5 ]
[-0.0125 .09172 0 4.5 ]
[-0.0125 .27663 -24 -4.5 ]
[-0.0125 .27663 0 4.5 ]
[-0.0125 .46154 -6 -4.5 ]
[-0.0125 .46154 0 4.5 ]
[-0.0125 .64645 -18 -4.5 ]
[-0.0125 .64645 0 4.5 ]
[-0.0125 .83136 -6 -4.5 ]
[-0.0125 .83136 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .92308 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .92308 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2)] .01923 -0.0125 0 1 Mshowa
.20414 0 m
.20414 .00625 L
s
[(-1.5)] .20414 -0.0125 0 1 Mshowa
.38905 0 m
.38905 .00625 L
s
[(-1)] .38905 -0.0125 0 1 Mshowa
.57396 0 m
.57396 .00625 L
s
[(-0.5)] .57396 -0.0125 0 1 Mshowa
.75888 0 m
.75888 .00625 L
s
[(0)] .75888 -0.0125 0 1 Mshowa
.94379 0 m
.94379 .00625 L
s
[(0.5)] .94379 -0.0125 0 1 Mshowa
.125 Mabswid
.05621 0 m
.05621 .00375 L
s
.0932 0 m
.0932 .00375 L
s
.13018 0 m
.13018 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.24112 0 m
.24112 .00375 L
s
.27811 0 m
.27811 .00375 L
s
.31509 0 m
.31509 .00375 L
s
.35207 0 m
.35207 .00375 L
s
.42604 0 m
.42604 .00375 L
s
.46302 0 m
.46302 .00375 L
s
.5 0 m
.5 .00375 L
s
.53698 0 m
.53698 .00375 L
s
.61095 0 m
.61095 .00375 L
s
.64793 0 m
.64793 .00375 L
s
.68491 0 m
.68491 .00375 L
s
.72189 0 m
.72189 .00375 L
s
.79586 0 m
.79586 .00375 L
s
.83284 0 m
.83284 .00375 L
s
.86982 0 m
.86982 .00375 L
s
.9068 0 m
.9068 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09172 m
.00625 .09172 L
s
[(-1)] -0.0125 .09172 1 0 Mshowa
0 .27663 m
.00625 .27663 L
s
[(-0.5)] -0.0125 .27663 1 0 Mshowa
0 .46154 m
.00625 .46154 L
s
[(0)] -0.0125 .46154 1 0 Mshowa
0 .64645 m
.00625 .64645 L
s
[(0.5)] -0.0125 .64645 1 0 Mshowa
0 .83136 m
.00625 .83136 L
s
[(1)] -0.0125 .83136 1 0 Mshowa
.125 Mabswid
0 .1287 m
.00375 .1287 L
s
0 .16568 m
.00375 .16568 L
s
0 .20266 m
.00375 .20266 L
s
0 .23964 m
.00375 .23964 L
s
0 .31361 m
.00375 .31361 L
s
0 .35059 m
.00375 .35059 L
s
0 .38757 m
.00375 .38757 L
s
0 .42456 m
.00375 .42456 L
s
0 .49852 m
.00375 .49852 L
s
0 .5355 m
.00375 .5355 L
s
0 .57249 m
.00375 .57249 L
s
0 .60947 m
.00375 .60947 L
s
0 .68343 m
.00375 .68343 L
s
0 .72041 m
.00375 .72041 L
s
0 .7574 m
.00375 .7574 L
s
0 .79438 m
.00375 .79438 L
s
0 .05473 m
.00375 .05473 L
s
0 .01775 m
.00375 .01775 L
s
0 .86834 m
.00375 .86834 L
s
0 .90533 m
.00375 .90533 L
s
.25 Mabswid
0 0 m
0 .92308 L
s
.01923 .91683 m
.01923 .92308 L
s
.20414 .91683 m
.20414 .92308 L
s
.38905 .91683 m
.38905 .92308 L
s
.57396 .91683 m
.57396 .92308 L
s
.75888 .91683 m
.75888 .92308 L
s
.94379 .91683 m
.94379 .92308 L
s
.125 Mabswid
.05621 .91933 m
.05621 .92308 L
s
.0932 .91933 m
.0932 .92308 L
s
.13018 .91933 m
.13018 .92308 L
s
.16716 .91933 m
.16716 .92308 L
s
.24112 .91933 m
.24112 .92308 L
s
.27811 .91933 m
.27811 .92308 L
s
.31509 .91933 m
.31509 .92308 L
s
.35207 .91933 m
.35207 .92308 L
s
.42604 .91933 m
.42604 .92308 L
s
.46302 .91933 m
.46302 .92308 L
s
.5 .91933 m
.5 .92308 L
s
.53698 .91933 m
.53698 .92308 L
s
.61095 .91933 m
.61095 .92308 L
s
.64793 .91933 m
.64793 .92308 L
s
.68491 .91933 m
.68491 .92308 L
s
.72189 .91933 m
.72189 .92308 L
s
.79586 .91933 m
.79586 .92308 L
s
.83284 .91933 m
.83284 .92308 L
s
.86982 .91933 m
.86982 .92308 L
s
.9068 .91933 m
.9068 .92308 L
s
.98077 .91933 m
.98077 .92308 L
s
.25 Mabswid
0 .92308 m
1 .92308 L
s
.99375 .09172 m
1 .09172 L
s
.99375 .27663 m
1 .27663 L
s
.99375 .46154 m
1 .46154 L
s
.99375 .64645 m
1 .64645 L
s
.99375 .83136 m
1 .83136 L
s
.125 Mabswid
.99625 .1287 m
1 .1287 L
s
.99625 .16568 m
1 .16568 L
s
.99625 .20266 m
1 .20266 L
s
.99625 .23964 m
1 .23964 L
s
.99625 .31361 m
1 .31361 L
s
.99625 .35059 m
1 .35059 L
s
.99625 .38757 m
1 .38757 L
s
.99625 .42456 m
1 .42456 L
s
.99625 .49852 m
1 .49852 L
s
.99625 .5355 m
1 .5355 L
s
.99625 .57249 m
1 .57249 L
s
.99625 .60947 m
1 .60947 L
s
.99625 .68343 m
1 .68343 L
s
.99625 .72041 m
1 .72041 L
s
.99625 .7574 m
1 .7574 L
s
.99625 .79438 m
1 .79438 L
s
.99625 .05473 m
1 .05473 L
s
.99625 .01775 m
1 .01775 L
s
.99625 .86834 m
1 .86834 L
s
.99625 .90533 m
1 .90533 L
s
.25 Mabswid
1 0 m
1 .92308 L
s
0 0 m
1 0 L
1 .92308 L
0 .92308 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01775 translate
.96154 .88758 scale
300 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FFB800FFB800FFB800FF71
00FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FFB800D7FF00A9FF4D00FF00FFB8
00FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FFB800FFF400A9FF00A9FF00FFF4
00FFB800FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB8005BFF005BFF00D7FF
00FFB800FFB800FFB800FFB800FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FFB800FFB800A9FFFF00000080FF
00D7FF00FFF400FFF400FFF400FFF400FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FFB800FFF400D7FF0080FFC200FF
00A9FF00A9FF00A9FF0080FF005BFF00FFB800FF7100FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FFB800FFB800FFF400D7FF00A9FFFF00D5
001AFF005BFF3500FF003AFF00FFF400FFB800FF7100FF7100FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF7100FF7100FF7100FF7100FF7100FFB800FFF400FFF400D7FF00A9FF005BFF
B100FF1C00FF0080FF00A9FF00FFF400FFB800FFB800FF7100FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFF400D7FF00D7FF0080FF005BFF
8C00FF001AFF0080FF00D7FF00FFF400FFB800FFB800FF7100FF7100FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FF7100FF7100FF7100FF7100FF7100FFB800FFF400FFF400D7FF00A9FF001AFF1C00FF
FF00BC0100FF001AFF00D7FF00FFF400FFF400FFB800FF7100FF7100FF7100FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF71
00FF7100FF7100FF7100FF7100FFB800FFF400D7FF6300FF0080FF005BFF3500FFFF00C9
FF0000FF00FE7800FF00A9FF00D7FF00D7FF00FFB800FF7100FF7100FF7100FF7100FF71
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF71
00FF7100FF7100FF7100FFB800FFB800A9FF005BFF4D00FF001AFF0100FF4D00FFFF0000
FF0000FF001F0100FF005BFF005BFF4D00FF00FFF400FFB800FF7100FF7100FF7100FF71
00FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF71
00FF7100FFB800FFB800FFB800FFF4005BFF3500FFFF000FFF00E3FF00F0FF0000FF0000
FF0000FF0000C200FF001AFFC200FF005BFF00D7FF00FFB800FF7100FF7100FF7100FF71
00FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FFB8
00FFB800FFB800FFB800FFF400D7FF00A9FF005BFFFF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF006FF200FFFF00E300D7FF00FFF400FFB800FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB800FFB8
00FFB800FFB800FFF400FFF400D7FF00A9FF005BFF3500FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00006300FF0080FF00D7FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB8
00FFB800FFF400FFF400FFF400D7FF00A9FF6300FFD300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00006300FF1C00FF00D7FF00FFF400FFF400FFB800FFB800FFB8
00FF7100FF7100FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A54FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFF4
00FFF400FFF400FFF400D7FF00D7FF00A9FF003AFF8C00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000B100FF0080FF00D7FF00D7FF00FFF400FFF400FFB800FFB8
00FFB800FFB800FFB800FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A54FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF7100FF7100FF7100FFB800FFF400FFF400FFF400FFF400FFF400FFF400FFF4
00FFF400FFF400D7FF00A9FF00A9FF0080FF005BFF9F00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000B100FF0080FF00A9FF00D7FF00D7FF00FFF400FFF400FFB8
00FFB800FFB800FFB800FFB800FFB800FFB800FFB800FF7100FF1A00FF1A00FF1A54FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FF7100FF7100FF7100FFB800D7FF005BFF00D7FF00A9FF3500FF005BFF00D7FF00D7FF
00D7FF00A9FF0080FF0080FF0080FF005BFF003AFF0100FFFF00C9FF0000FF0000FF0000
FF0000FF0000FF0000FF00F0001AFF005BFF0080FF00A9FF00A9FF0100FF00D7FF00FFF4
00FFF400FFB800FFB800FFB800FFF400D7FF0080FF00FFB800FF7100FF1A00FF1A00FF1A
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF71
00FF7100FF7100FFB800FFB800D7FFFF0038001AFF1C00FFFF0000005BFF00A9FF00A9FF
0080FF001AFFFF00001C00FF001AFFFF00F01C00FF3500FF7800FFFF0000FF0000FF0000
FF0000FF0000FF00E36300FF1C00FF0100FF7800FF005BFF005BFF3500FF0100FF00D7FF
00D7FF00FFF400FFF400FFF400FFF400A9FF7800FF00FFF400FFB800FF7100FF1A00FF1A
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF71
00FF7100FFB800FFB800FFF400D7FF005BFF4D00FFFF00F03500FF0100FF4D00FF005BFF
005BFFD300FFFF0000FF000F8C00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF008EFF0000FF00004D00FFFF0049FF00000080FF
00A9FF00D7FF00D7FF00D7FF00A9FF003AFFFF00F000D7FF00FFB800FF7100FF1A00FF1A
00FF1A54FF0054FF0054FF00
FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFB800FFF400D7FFF200FF6300FFFF00A5FF0000B100FFFF0000001AFF
001AFF4D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000005BFF
0080FF0080FFD300FF0100FF005BFF003AFFFF00840080FF9F00FF00FF7100FF7100FF1A
00FF1A54FF0054FF0054FF00
FF0000FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFB800FFB800FFB800FFF400D7FF0080FF001AFFFF00F0FF0000FF0000FF00004D00FF
FF0000FF00C9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FFF0065
003AFF003AFF4D00FFB100FF4D00FF3500FFFF00FE001AFF00D7FF00FF7100FF7100FF1A
00FF1A00FF1A54FF0054FF00
FF0000FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFB800FFB800FFF400FFF400D7FF00A9FF1C00FFFF00FEFF0000FF0000FF0000D300FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3500FF4D00FFFF0000FF0000FF0038FF00001C00FFFF007900FFF400FFB800FF7100FF71
00FF1A00FF1A54FF0054FF00
FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB8
00FFB800FFB800FFF400D7FF00D7FF0080FF0100FFC200FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A5FF0000FF0000FF00009F00FF005BFF00A9FF00FFF400FFB800FF7100FF71
00FF1A00FF1A54FF0054FF00
FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFB8
00FFB800FFF400D7FF00D7FF00A9FF0080FF003AFF3500FFF200FFFF000FFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0053FF0000FF0000FF0000FF00F0C200FF00D7FF00FFB800FFB800FF7100FF71
00FF1A00FF1A00FF1A54FF00
FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB8
00FFF400FFF400A9FF003AFF0100FF003AFFFF00E38C00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00001C00FF0080FF00FFF400FFB800FFB800FF7100FF71
00FF1A00FF1A00FF1A54FF00
FF0000FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFF4
00FFF4003AFF0100FFC200FF4D00FF1C00FFFF00E3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00D51C00FF005BFF00A9FF00FFF400FFF400FFB800FF7100FF71
00FF7100FF1A00FF1A54FF00
FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FFB800FFB800FFB800FFB800FFB800FFB800FFB800FF7100FF71
00FF7100FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFB800FFF400FFF4
00D7FF00A9FFFF00C9FF0000FF0049FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000001AFF0080FF00D7FF00FFF400FFB800FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FFB800A9FF00D7FF00FFF400FFB800FFB800FFB800FFB800FFB800FFB8
00FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFF400FFF400FFF400FFF400D7FF
00D7FF00A9FF001AFFD300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000001AFF00D7FF00D7FF00FFF400FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FF7100FFB800FFB800D7FF003AFF0080FF00FFF400FFF400FFF400FFF400FFF400FFF4
00FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400D7FF
00D7FF0080FF003AFF3500FFFF00D5FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00E3003AFF0080FF00A9FF005BFF00FFF400FF71
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF71
00FF7100FFB800FFB800D7FF001AFF0080FF00D7FF00D7FF00FFF400FFF400FFF400D7FF
00D7FF1C00FF00D7FF00D7FF00FFF400FFF400FFF400FFF400FFF400D7FF00D7FF00D7FF
00A9FF003AFF8C00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00003500FFD300FF003AFFFF000000D7FF00FFB8
00FF7100FF1A00FF1A00FF1A
FF0000FF000054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF71
00FF7100FFB800FFB8003AFF1C00FF005BFF00A9FF00A9FF00A9FF00D7FF00D7FF00A9FF
005BFF1C00FF0080FF00A9FF00D7FF00D7FF00FFF400D7FF00D7FF00D7FF00D7FF00A9FF
005BFFFF0065FF0000FF0079FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00847800FF0100FF00FFB8
00FF7100FF1A00FF1A00FF1A
FF0000FF000054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFB800D7FF005BFF9F00FF4D00FF003AFF0100FF005BFF00A9FF0080FF
003AFFC200FF001AFF0080FF0080FF005BFF00A9FF00A9FF00A9FF00A9FF00A9FF0080FF
005BFF1C00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C93500FF00FFF400FFB8
00FF7100FF1A00FF1A00FF1A
FF0000F2FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFF400D7FF00A9FF005BFF001AFFFF0000E300FF0100FF001AFF005BFF
001AFF1C00FFFF00003500FF001AFF4D00FF005BFF00A9FF00A9FF00A9FF0080FF0080FF
003AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5003AFF00D7FF00FFF400FFB8
00FF7100FF1A00FF1A00FF1A
FF0000F2FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFF400FFF400A9FF0080FF005BFF3500FFFF005CF200FF7800FF4D00FF
1C00FFFF00FEFF0000FF00003500FFC200FF0100FF003AFF0080FF0080FF0080FF005BFF
0100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00007800FF0080FF00D7FF00FFB800FFB8
00FF7100FF1A00FF1A00FF1A
FF0000F2FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFF400FFF400FFF400A9FF00A9FF001AFFF200FFFF0000FF0000FF00C9E300FF
FF0000FF0038FF0000FF006FFF0027FF00009F00FFFF00D5003AFF005BFF005BFF003AFF
0100FFFF00FEFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003500FF005BFF00A9FF00FFB800FFB8
00FF7100FF1A00FF1A00FF1A
FF000054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFF400FFF400FFF400D7FF00A9FF0080FF0100FF7800FFFF0000FF0000FF000FFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C9001AFF001AFF001AFF
4D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003500FFFF000000FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFF400FFF400FFF400A9FF0080FF005BFF001AFF6300FFFF00E3FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000C200FF0100FF0100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F200FF003AFF00FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFF4
00D7FF00D7FF00D7FF0080FF7800FF3500FF9F00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004D00FF3500FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008E0080FF00FFF400FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFF4001AFF00D7FF
00D7FF00A9FF00A9FF005BFF001AFFFF0040FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00537800FF
FF0027FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003500FF00FFF400FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFF400D7FF005BFF003AFF
0080FF00A9FF0080FF005BFF0100FF8C00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000B100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F000A9FF00FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFF400FFF400D7FF0080FF7800FF
003AFF003AFF0100FF001AFF3500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000005BFF00FFF400FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF1A00FF1A00FF1A00FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FFB8
00FFB800FFB800FFB800FFB800FFB800FFF400FFF400FFF400FFF400A9FF0080FF003AFF
FF00994D00FFFF00B09F00FF7800FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000100FF00D7FF00FFF400FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF1A00FF7100FF7100FF7100FF7100FFB800FFB800FFF400D7FF00FFF400FFF4
00FFB800FFB800FFB800FFB800FFF400FFF400FFF400FFF400A9FF00A9FF005BFF001AFF
8C00FFFF0000FF0000FF0000E300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000B100FF0080FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF7100FF7100FF7100FFB800FFB800FFB800FFF400FFF4005BFF00FFF400FFF4
00D7FF00D7FF0080FF00D7FF00D7FF00D7FF00A9FF0080FF003AFF005BFF0100FF6300FF
FF006FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000005BFF00D7FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FFB800FF7100FFF400FFF400FFF400D7FF00A9FF0080FFFF00C90080FF00A9FF
0080FF0080FF001AFF005BFF005BFF0080FF003AFF001AFF4D00FFC200FFFF00E3FF0084
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00C9005BFF00A9FF00D7FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FFB800FF7100FFF400FFF400FFF400D7FF00A9FF0080FFFF00C90080FF00A9FF
0080FF0080FF001AFF005BFF005BFF0080FF003AFF001AFF4D00FFC200FFFF00E3FF0084
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00C9005BFF00A9FF00D7FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF7100FF7100FF7100FFB800FFB800FFB800FFF400FFF4005BFF00FFF400FFF4
00D7FF00D7FF0080FF00D7FF00D7FF00D7FF00A9FF0080FF003AFF005BFF0100FF6300FF
FF006FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000005BFF00D7FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF1A00FF7100FF7100FF7100FF7100FFB800FFB800FFF400D7FF00FFF400FFF4
00FFB800FFB800FFB800FFB800FFF400FFF400FFF400FFF400A9FF00A9FF005BFF001AFF
8C00FFFF0000FF0000FF0000E300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000B100FF0080FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF1A00FF1A00FF1A00FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FFB8
00FFB800FFB800FFB800FFB800FFB800FFF400FFF400FFF400FFF400A9FF0080FF003AFF
FF00994D00FFFF00B09F00FF7800FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000100FF00D7FF00FFF400FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFF400FFF400D7FF0080FF7800FF
003AFF003AFF0100FF001AFF3500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000005BFF00FFF400FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFF400D7FF005BFF003AFF
0080FF00A9FF0080FF005BFF0100FF8C00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000B100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F000A9FF00FFB800FF7100FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFF4001AFF00D7FF
00D7FF00A9FF00A9FF005BFF001AFFFF0040FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00537800FF
FF0027FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003500FF00FFF400FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFF4
00D7FF00D7FF00D7FF0080FF7800FF3500FF9F00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004D00FF3500FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008E0080FF00FFF400FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFF400FFF400FFF400A9FF0080FF005BFF001AFF6300FFFF00E3FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000C200FF0100FF0100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F200FF003AFF00FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF000054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFF400FFF400FFF400D7FF00A9FF0080FF0100FF7800FFFF0000FF0000FF000FFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C9001AFF001AFF001AFF
4D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003500FFFF000000FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF0000F2FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFF400FFF400FFF400A9FF00A9FF001AFFF200FFFF0000FF0000FF00C9E300FF
FF0000FF0038FF0000FF006FFF0027FF00009F00FFFF00D5003AFF005BFF005BFF003AFF
0100FFFF00FEFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003500FF005BFF00A9FF00FFB800FFB8
00FF7100FF1A00FF1A00FF1A
FF0000F2FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFF400FFF400A9FF0080FF005BFF3500FFFF005CF200FF7800FF4D00FF
1C00FFFF00FEFF0000FF00003500FFC200FF0100FF003AFF0080FF0080FF0080FF005BFF
0100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00007800FF0080FF00D7FF00FFB800FFB8
00FF7100FF1A00FF1A00FF1A
FF0000F2FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFF400D7FF00A9FF005BFF001AFFFF0000E300FF0100FF001AFF005BFF
001AFF1C00FFFF00003500FF001AFF4D00FF005BFF00A9FF00A9FF00A9FF0080FF0080FF
003AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5003AFF00D7FF00FFF400FFB8
00FF7100FF1A00FF1A00FF1A
FF0000FF000054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFB800D7FF005BFF9F00FF4D00FF003AFF0100FF005BFF00A9FF0080FF
003AFFC200FF001AFF0080FF0080FF005BFF00A9FF00A9FF00A9FF00A9FF00A9FF0080FF
005BFF1C00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C93500FF00FFF400FFB8
00FF7100FF1A00FF1A00FF1A
FF0000FF000054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF71
00FF7100FFB800FFB8003AFF1C00FF005BFF00A9FF00A9FF00A9FF00D7FF00D7FF00A9FF
005BFF1C00FF0080FF00A9FF00D7FF00D7FF00FFF400D7FF00D7FF00D7FF00D7FF00A9FF
005BFFFF0065FF0000FF0079FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00847800FF0100FF00FFB8
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF71
00FF7100FFB800FFB800D7FF001AFF0080FF00D7FF00D7FF00FFF400FFF400FFF400D7FF
00D7FF1C00FF00D7FF00D7FF00FFF400FFF400FFF400FFF400FFF400D7FF00D7FF00D7FF
00A9FF003AFF8C00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00003500FFD300FF003AFFFF000000D7FF00FFB8
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FF7100FFB800FFB800D7FF003AFF0080FF00FFF400FFF400FFF400FFF400FFF400FFF4
00FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400FFF400D7FF
00D7FF0080FF003AFF3500FFFF00D5FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00E3003AFF0080FF00A9FF005BFF00FFF400FF71
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FFB800A9FF00D7FF00FFF400FFB800FFB800FFB800FFB800FFB800FFB8
00FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFF400FFF400FFF400FFF400D7FF
00D7FF00A9FF001AFFD300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000001AFF00D7FF00D7FF00FFF400FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FFB800FFB800FFB800FFB800FFB800FFB800FFB800FF7100FF71
00FF7100FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFB800FFF400FFF4
00D7FF00A9FFFF00C9FF0000FF0049FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000001AFF0080FF00D7FF00FFF400FFB800FFB800FF71
00FF7100FF1A00FF1A00FF1A
FF0000FF0000FF0000F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFF4
00FFF4003AFF0100FFC200FF4D00FF1C00FFFF00E3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00D51C00FF005BFF00A9FF00FFF400FFF400FFB800FF7100FF71
00FF7100FF1A00FF1A54FF00
FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB8
00FFF400FFF400A9FF003AFF0100FF003AFFFF00E38C00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00001C00FF0080FF00FFF400FFB800FFB800FF7100FF71
00FF1A00FF1A00FF1A54FF00
FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFB8
00FFB800FFF400D7FF00D7FF00A9FF0080FF003AFF3500FFF200FFFF000FFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0053FF0000FF0000FF0000FF00F0C200FF00D7FF00FFB800FFB800FF7100FF71
00FF1A00FF1A00FF1A54FF00
FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB800FFB8
00FFB800FFB800FFF400D7FF00D7FF0080FF0100FFC200FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A5FF0000FF0000FF00009F00FF005BFF00A9FF00FFF400FFB800FF7100FF71
00FF1A00FF1A54FF0054FF00
FF0000FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFB800FFB800FFF400FFF400D7FF00A9FF1C00FFFF00FEFF0000FF0000FF0000D300FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3500FF4D00FFFF0000FF0000FF0038FF00001C00FFFF007900FFF400FFB800FF7100FF71
00FF1A00FF1A54FF0054FF00
FF0000FF0000FF0000FF0000F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FF7100FFB8
00FFB800FFB800FFB800FFF400D7FF0080FF001AFFFF00F0FF0000FF0000FF00004D00FF
FF0000FF00C9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001FFF0065
003AFF003AFF4D00FFB100FF4D00FF3500FFFF00FE001AFF00D7FF00FF7100FF7100FF1A
00FF1A00FF1A54FF0054FF00
FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FF7100FF71
00FFB800FFB800FFB800FFF400D7FFF200FF6300FFFF00A5FF0000B100FFFF0000001AFF
001AFF4D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000005BFF
0080FF0080FFD300FF0100FF005BFF003AFFFF00840080FF9F00FF00FF7100FF7100FF1A
00FF1A54FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FF71
00FF7100FFB800FFB800FFF400D7FF005BFF4D00FFFF00F03500FF0100FF4D00FF005BFF
005BFFD300FFFF0000FF000F8C00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF008EFF0000FF00004D00FFFF0049FF00000080FF
00A9FF00D7FF00D7FF00D7FF00A9FF003AFFFF00F000D7FF00FFB800FF7100FF1A00FF1A
00FF1A54FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF71
00FF7100FF7100FFB800FFB800D7FFFF0038001AFF1C00FFFF0000005BFF00A9FF00A9FF
0080FF001AFFFF00001C00FF001AFFFF00F01C00FF3500FF7800FFFF0000FF0000FF0000
FF0000FF0000FF00E36300FF1C00FF0100FF7800FF005BFF005BFF3500FF0100FF00D7FF
00D7FF00FFF400FFF400FFF400FFF400A9FF7800FF00FFF400FFB800FF7100FF1A00FF1A
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FF7100FF7100FF7100FFB800D7FF005BFF00D7FF00A9FF3500FF005BFF00D7FF00D7FF
00D7FF00A9FF0080FF0080FF0080FF005BFF003AFF0100FFFF00C9FF0000FF0000FF0000
FF0000FF0000FF0000FF00F0001AFF005BFF0080FF00A9FF00A9FF0100FF00D7FF00FFF4
00FFF400FFB800FFB800FFB800FFF400D7FF0080FF00FFB800FF7100FF1A00FF1A00FF1A
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF7100FF7100FF7100FFB800FFF400FFF400FFF400FFF400FFF400FFF400FFF4
00FFF400FFF400D7FF00A9FF00A9FF0080FF005BFF9F00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000B100FF0080FF00A9FF00D7FF00D7FF00FFF400FFF400FFB8
00FFB800FFB800FFB800FFB800FFB800FFB800FFB800FF7100FF1A00FF1A00FF1A54FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB800FFF4
00FFF400FFF400FFF400D7FF00D7FF00A9FF003AFF8C00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000B100FF0080FF00D7FF00D7FF00FFF400FFF400FFB800FFB8
00FFB800FFB800FFB800FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A54FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB800FFB800FFB800FFB8
00FFB800FFF400FFF400FFF400D7FF00A9FF6300FFD300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00006300FF1C00FF00D7FF00FFF400FFF400FFB800FFB800FFB8
00FF7100FF7100FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A54FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB800FFB8
00FFB800FFB800FFF400FFF400D7FF00A9FF005BFF3500FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00006300FF0080FF00D7FF00FFF400FFB800FFB800FF7100FF71
00FF7100FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FFB8
00FFB800FFB800FFB800FFF400D7FF00A9FF005BFFFF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF006FF200FFFF00E300D7FF00FFF400FFB800FF7100FF7100FF71
00FF7100FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF71
00FF7100FFB800FFB800FFB800FFF4005BFF3500FFFF000FFF00E3FF00F0FF0000FF0000
FF0000FF0000C200FF001AFFC200FF005BFF00D7FF00FFB800FF7100FF7100FF7100FF71
00FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF71
00FF7100FF7100FF7100FFB800FFB800A9FF005BFF4D00FF001AFF0100FF4D00FFFF0000
FF0000FF001F0100FF005BFF005BFF4D00FF00FFF400FFB800FF7100FF7100FF7100FF71
00FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF71
00FF7100FF7100FF7100FF7100FFB800FFF400D7FF6300FF0080FF005BFF3500FFFF00C9
FF0000FF00FE7800FF00A9FF00D7FF00D7FF00FFB800FF7100FF7100FF7100FF7100FF71
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF71
00FF7100FF7100FF7100FF7100FF7100FFB800FFF400FFF400D7FF00A9FF001AFF1C00FF
FF00BC0100FF001AFF00D7FF00FFF400FFF400FFB800FF7100FF7100FF7100FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF7100FF7100FF7100FF7100FF7100FFB800FFB800FFF400D7FF00D7FF0080FF005BFF
8C00FF001AFF0080FF00D7FF00FFF400FFB800FFB800FF7100FF7100FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF7100FF7100FF7100FF7100FF7100FFB800FFF400FFF400D7FF00A9FF005BFF
B100FF1C00FF0080FF00A9FF00FFF400FFB800FFB800FF7100FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FFB800FFB800FFF400D7FF00A9FFFF00D5
001AFF005BFF3500FF003AFF00FFF400FFB800FF7100FF7100FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF7100FF7100FF7100FF7100FF7100FFB800FFF400D7FF0080FFC200FF
00A9FF00A9FF00A9FF0080FF005BFF00FFB800FF7100FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF7100FF7100FF7100FF7100FFB800FFB800A9FFFF00000080FF
00D7FF00FFF400FFF400FFF400FFF400FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FF7100FFB800FFB8005BFF005BFF00D7FF
00FFB800FFB800FFB800FFB800FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF7100FFB800FFF400A9FF00A9FF00FFF4
00FFB800FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FFB800D7FF00A9FF4D00FF00FFB8
00FF7100FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FFB800FFB800FFB800FF71
00FF7100FF7100FF1A00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF1A00FF7100FF1A
00FF1A00FF1A00FF1A00FF1A00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0000FF1A00FF1A00FF1A00FF1A00FF1A
00FF1A54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00
54FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF0054FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00F2FF00
F2FF00F2FF00F2FF00F2FF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001SR000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00<03oool00`3ookl0M000000000040000000307Boo`3oool0oooo03H0oooo00<0okmd0000
000000000`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00D0oooo00D0_g@00000
00000000000007Boo`0i0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0=`3oool0
1@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool01@2oM00000000000
00000000M;oo03H0oooo00D0okmd000000000000000007Boo`0j0?ooo`050?noM000000000000000
001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md0000000000000000001d_ol0303oool0
0340oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`0j0?ooo`0309a8B02Lgol0oooo
00D0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0>`3o
ool00`2LB4P0W=oo0?ooo`0j0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM000
0000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0e0?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo>@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@00000
0000M;l0103oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol02`3oool00380oooo00<0okmd
0000B02Lgol0?P3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo03X0oooo00<0W4Q8
09cOo`3oool0>@3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0okmd
001d_`3oool0<`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo03L0oooo00<0okmd
001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo00X0oooo000c0?oo
o`030?oOW0180000B9cO03d0oooo00<0W4Q809cOo`3oool04@3oool00`3o_g@007Bo0?ooo`0j0?oo
o`0309a8B02Lgol0oooo03T0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?oo
o`030?noM000M;l0oooo03<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0g0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`0:0?oo
o`00:03oool00`2LB000000000000003000000030018W03oool0oooo00@0oooo00<0W4P004RLg`3o
ool0;`3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cOo`3o
ool04@3oool00`2LB000M;oo0?ooo`0^0?ooo`0309a800000000000000<0000000<004RL0?ooo`3o
ool00`3oool00`2LB4P0W=oo0?ooo`0`0?ooo`0309a800000000000000<0000000D004RL0?ooo`3o
ool0gia804RLg`030?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool0<`3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03L0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`0?0?ooo`0309a8001d_ol0oooo00X0oooo000f0?ooo`0309a8M02oool0oooo03X0
oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M000000000020000000304RLg`3oool0oooo03X0
oooo00<0W4Q809cOo`3oool0>@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0c0?ooo`030=nLB018W=l0oooo0080
oooo00<0okmd001d_`3oool0=`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0:0?ooo`00<@3oool00`3OW4P0M;oo
0?ooo`020?ooo`030;md001d_ol0oooo03X0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M01d
0;ooo`0o0?ooo`0309a8B02Lgol0oooo03T0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0:0?ooo`030?oo_`1d07@0_ooo03P0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0g0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01d
0;ooo`0?0?ooo`00<@3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0>03oool01@3OW4P0
00000018W02LB4P0W=oo00d0oooo00<0oono07@0M02oool0?03oool01@3OW4P000000018W02LB4P0
W=oo03/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo_`1d07@0_ooo03T0oooo
00H0W4P007Boo`3oool0omnL04P0M02oooli0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3o
ool00`3ookl0M01d0;ooo`0?0?ooo`00<P3oool01@3o_g@000000000000004P0W=oo03/0oooo00<0
gia80000B02Lgol03@3oool00`3ookl0M00000000002000000030000M02oool0oooo03T0oooo00<0
gia80000B02Lgol0>`3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0oono07@000000000
0P0000000`0007@0_ooo0?ooo`0d0?ooo`050?oo_`1d000000000000B02Lgol0>P3oool01@3ookl0
M0000000000004P0W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`0:0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00:03ooooo000008P000000@3oool0
02P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0103oool100000040oooo000X0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01<0
oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`3o0?oooh@0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`3o0?oooh@0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`3o
0?oooh@0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`3o0?oooh@0oooo0@0000010?oo
o`00:03oool300000?l0ooooP`3oool200000040oooo000X0?ooo`030000003oool0oooo00D0oooo
?03o00100?;o0;P0E?l0A03bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3o
ooll0?l00400l_l0^01Do`140?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`05
0?oooc`0o`00@03bo`2h05Co04@0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo>03o000l0?;o08P0E?l05P00oaXZ05Co03`0l_l01P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo>03o000l0?;o08P0E?l05P00oaXZ05Co03`0l_l01P3oool100000040
oooo000X0?ooo`030000003oool0oooo00D0oooo>03o000l0?;o08P0E?l05P00oaXZ05Co03`0l_l0
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo>03o000l0?;o08P0E?l05P00
oaXZ05Co03`0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo=@3o000h
0?;o07`0E?l07P00oaX4003oLAH00?lJ8P1Do`0e0?;o00H0oooo0@0000010?ooo`00:03oool00`00
0000oooo0?ooo`050?ooocD0o`00>03bo`1l05Co01h00?lJ1000og4F003o6R80E?l0=@3bo`060?oo
o`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooole0?l003P0l_l0O01Do`0N003o6P@0
0?ma5P00oaXR05Co03D0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo
=@3o000`0?;o07`0E?l06`00oaX4003oL@/00?nh2`00og4G003o6Qh0E?l0;@3bo`060?ooo`400000
0@3oool002P0oooo00<000000?ooo`3oool01@3ooole0?l00300l_l0O01Do`0K003o6P@00?ma2`00
okP;003oLAL00?lJ7P1Do`0]0?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`05
0?ooocD0o`00<03bo`1l05Co01/00?lJ1000og4;003o^0/00?ma5`00oaXN05Co02d0l_l01P3oool1
00000040oooo000X0?ooo`<000001@3ooole0?l00300l_l0O01Do`0K003o6P@00?ma2`00okP;003o
LAL00?lJ7P1Do`0]0?;o00D0oooo0P0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooc40
o`00<@3bo`1d05Co02800?lJ1000og44003o^0<00=Oo1000ZOl404d0o`@00?nh2`00og4J003o6Qh0
E?l09P3bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooola0?l00340l_l0
M01Do`0R003o6P@00?ma1000okP3003Go`@00:Wo101=0?l4003o^0/00?ma6P00oaXN05Co02H0l_l0
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo<@3o000a0?;o07@0E?l08P00
oaX4003oL@@00?nh0`00eol4002Yo`@0C@3o1000okP;003oLAX00?lJ7P1Do`0V0?;o00H0oooo0@00
00010?ooo`00:03oool00`000000oooo0?ooo`050?oooc40o`00:@3bo`1h05Co02800?lJ2000og44
003o^0<00?od2000ZOl4003om0<00?nh3000og4J003o6Qh0E?l08P3bo`060?ooo`4000000@3oool0
02P0oooo00<000000?ooo`3oool01@3ooola0?l002T0l_l0N01Do`0R003o6PP00?ma1000okP3003o
m0P00:Wo1000oo@3003o^0`00?ma6P00oaXN05Co0280l_l01P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo<@3o000Y0?;o07P0E?l08P00oaX8003oL@@00?nh0`00oo@8002Yo`@0
0?od0`00okP<003oLAX00?lJ7P1Do`0R0?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo
0?ooo`050?oooc40o`00:@3bo`1h05Co02800?lJ2000og44003o^0<00?od2000ZOl4003om0<00?nh
3000og4J003o6Qh0E?l08P3bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3o
ool]0?l002T0l_l0M@1Do`0U003o6P`00?ma1`00okP8001Ko`@00=Oo3`00okP3003oLAh00?lJ6`1D
o`0N0?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooobd0o`00:@3bo`1e
05Co02D00?lJ3000og47003o^0P005_o1000eol?003o^0<00?ma7P00oaXK05Co01h0l_l01P3oool1
00000040oooo000X0?ooo`030000003oool0oooo00D0oooo;@3o000Y0?;o07D0E?l09@00oaX<003o
L@L00?nh2000Fol4003Go`l00?nh0`00og4N003o6Q/0E?l07P3bo`060?ooo`4000000@3oool001`0
oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo:@3o000V0?;o07@0E?l0:P00oaX?003oL@L00?nh1000ZOl40?l000@0083o0`00eol?003om0@0
0?ma7P00oaXN05Co01L0l_l01P3oool100000040oooo000O0?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool01@3ooolY0?l002H0l_l0M01Do`0Z003o6Pl00?ma1`00okP4002Yo`@0o`00
1000P?l3003Go`l00?od1000og4N003o6Qh0E?l05`3bo`060?ooo`4000000@3oool001l0oooo00<0
W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`050?ooobT0o`009P3bo`1d05Co02X00?lJ3`00
og47003o^0@00:Wo103o00040020o`<00=Oo3`00oo@4003oLAh00?lJ7P1Do`0G0?;o00H0oooo0@00
00010?ooo`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo00D0oooo:@3o000R
0?;o07D0E?l0:@00oaXC003oL@@00?nh0`00oo@4003Go`@0083o10320?l;002Yo`@0083o0`00Fol4
003o^0@00?ma7P00oaXN05Co01<0l_l01P3oool100000040oooo000C0?ooo`0309a8000000000000
00<0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`060?ooo`@00000103ooolY0?l0
0280l_l0M@1Do`0Y003o6Q<00?ma1000okP3003om0@00=Oo1000P?l40<80o`/00:Wo1000P?l3001K
o`@00?nh1000og4N003o6Qh0E?l04`3bo`040?ooo`<000000@3oool001l0oooo00<0W4Q809cOo`3o
ool01P3oool00`000000oooo0?ooo`050?ooobT0o`008P3bo`1e05Co02T00?lJ4`00og44003o^0<0
0?od1000eol40020o`@0`P3o2`00ZOl40020o`<005_o1000okP4003oLAh00?lJ7P1Do`0C0?;o00H0
oooo0@0000010?ooo`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo00D0oooo
:@3o000R0?;o07D0E?l0:@00oaXC003oL@@00?nh0`00oo@4003Go`@0083o10320?l;002Yo`@0083o
0`00Fol4003o^0@00?ma7P00oaXN05Co01<0l_l01P3oool100000040oooo000L0?ooo`050=nLB000
000004RL09a8B02Lgol01`3oool00`000000oooo0?ooo`050?ooobD0o`008P3bo`1e05Co02d00?lJ
3`00og48003o^0<00?od1000eol4002Yo`@0o`3E0`006_l4001Ko`@0=@3o1000>_l3003om0@00?nh
2000og4N003o6Qh0E?l03`3bo`060?ooo`4000000@3oool001h0oooo00<0gia80000B02Lgol01`3o
ool00`000000oooo0?ooo`050?ooobD0o`008P3bo`1e05Co02d00?lJ3`00og48003o^0<00?od1000
eol4002Yo`@0o`3E0`006_l4001Ko`@0=@3o1000>_l3003om0@00?nh2000og4N003o6Qh0E?l03`3b
o`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolU0?l00280l_l0M@1Do`0]
003o6Pl00?ma2000okP3003om0@00=Oo1000ZOl40?l0e@<001[o1000Fol403D0o`@003[o0`00oo@4
003o^0P00?ma7P00oaXN05Co00l0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo9@3o000O0?;o0700E?l0<@00oaXC003oL@@00?nh1`00oo@4003Go`@00:Wo1000Fol30;40
o`@0703o1000P?l4002Yo`<00?od2000okP4003oLB400?lJ7`1Do`0;0?;o00H0oooo0@0000010?oo
o`00:03oool00`000000oooo0?ooo`050?ooobD0o`007`3bo`1`05Co03400?lJ4`00og44003o^0L0
0?od1000eol4002Yo`@005_o0`2a0?l401`0o`@0083o1000ZOl3003om0P00?nh1000og4Q003o6Ql0
E?l02`3bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolU0?l001l0l_l0
L01Do`0a003o6Q<00?ma1000okP7003om0@00=Oo1000ZOl4001Ko`<0/@3o100L0?l40020o`@00:Wo
0`00oo@8003o^0@00?ma8@00oaXO05Co00/0l_l01P3oool100000040oooo000X0?ooo`030000003o
ool0oooo00D0oooo9@3o000O0?;o0700E?l0<@00oaXC003oL@@00?nh1`00oo@4003Go`@00:Wo1000
Fol30;40o`@0703o1000P?l4002Yo`<00?od2000okP4003oLB400?lJ7`1Do`0;0?;o00H0oooo0@00
00010?ooo`00:03oool00`000000oooo0?ooo`050?ooob80o`007P3bo`1a05Co03000?lJ4`00og48
003o^0@00?od1`00eol40020o`@005_o0`2<0?l4000Jo`@0083o1000eol3003om0P00?nh1`00og4R
003o6Qh0E?l0203bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolR0?l0
01h0l_l0L@1Do`0`003o6Q<00?ma2000okP4003om0L00=Oo1000P?l4001Ko`<0S03o10006_l40020
o`@00=Oo0`00oo@8003o^0L00?ma8P00oaXN05Co00P0l_l01P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo8P3o000N0?;o0740E?l0<000oaXC003oL@P00?nh1000oo@7003Go`@0
083o1000Fol308`0o`@001[o1000P?l4003Go`<00?od2000okP7003oLB800?lJ7P1Do`080?;o00H0
oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooob80o`006P3bo`1a05Co03400?lJ
5P00og44003o^0P00?od0`00eol4002Yo`@001[o100L0?l30?l0_0@00@3o10006_l4003Go`L00?od
1000okP;003oLB800?lJ7P1Do`040?;o00H0oooo0@0000010?ooo`00:03oool3000000D0oooo8P3o
000J0?;o0740E?l0<@00oaXF003oL@@00?nh2000oo@3003Go`@00:Wo10006_l401`0o`<0o`2l1001
0?l4000Jo`@00=Oo1`00oo@4003o^0/00?ma8P00oaXN05Co00@0l_l01@3oool200000040oooo000X
0?ooo`030000003oool0oooo00D0oooo8P3o000J0?;o0740E?l0<@00oaXF003oL@@00?nh2000oo@3
003Go`@00:Wo10006_l401`0o`<0o`2l10010?l4000Jo`@00=Oo1`00oo@4003o^0/00?ma8P00oaXN
05Co00@0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo8P3o000J0?;o
0740E?l0<@00oaXF003oL@@00?nh2000oo@3003Go`@00:Wo10006_l401`0o`<0o`2l10010?l4000J
o`@00=Oo1`00oo@4003o^0/00?ma8P00oaXN05Co00@0l_l01P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo7P3o000J0?;o0740E?l0<@00oaXF003oL@@00?nh1000oo@4003Go`@0
H`3o0`00P?l4001Ko`@0=@3o103o0<T30?l000@0o`3n101h0?l4002Yo`L00=Oo1000okPC003oLAX0
0?lJ8P1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolN0?l001X0l_l0
L@1Do`0a003o6QH00?ma1000okP4003om0@00=Oo101S0?l30020o`@005_o100e0?l40?l0b@<0o`00
103o0?h407P0o`@00:Wo1`00eol4003o^1<00?ma6P00oaXR05Co00H0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?oooah0o`006P3bo`1a05Co03400?lJ5P00og44003o^0@00?od1000
eol406<0o`<0083o1000Fol403D0o`@0o`390`3o00040?l0oP@0N03o1000ZOl7003Go`@00?nh4`00
og4J003o6R80E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo7P3o000G
0?;o0700E?l0<@00oaXG003oL@L00?nh1000ZOl4001Ko`@0C@3o0`006_l40040o`@0C@3o1`3o0004
0?l07`@00@3o1`00Fol404d0o`@00?od1000okPB003oLA/00?lJ7P1Do`060?ooo`4000000@3oool0
02P0oooo00<000000?ooo`3oool01@3ooolN0?l001L0l_l0L01Do`0a003o6QL00?ma1`00okP4002Y
o`@005_o101=0?l3000Jo`@00@3o101=0?l70?l000@0o`0O10010?l7001Ko`@0C@3o1000oo@4003o
^1800?ma6`00oaXN05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooah0
o`005`3bo`1`05Co03400?lJ5`00og47003o^0@00:Wo1000Fol404d0o`<001[o10010?l404d0o`L0
o`00103o01l40040o`L005_o101=0?l4003om0@00?nh4P00og4K003o6Qh0E?l01P3oool100000040
oooo000X0?ooo`030000003oool0oooo00D0oooo7P3o000G0?;o0700E?l0<@00oaXG003oL@L00?nh
1000ZOl4001Ko`@0C@3o0`006_l40040o`@0C@3o1`3o00040?l07`@00@3o1`00Fol404d0o`@00?od
1000okPB003oLA/00?lJ7P1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3o
oolJ0?l001L0l_l0L@1Do`0`003o6Q<00?ma2`00okP4003om0@005_o100e0?l40?l03`<0o`3S103o
0?0?0?l000@0`P3o10006_l30<80o`@005_o1000eol4003o^1H00?ma6P00oaXK05Co00H0oooo0@00
00010?ooo`00:03oool00`000000oooo0?ooo`050?oooaX0o`005`3bo`1a05Co03000?lJ4`00og4;
003o^0@00?od1000Fol403D0o`@0o`0?0`3o0><40?l0l0l0o`0010320?l4000Jo`<0`P3o1000Fol4
003Go`@00?nh5P00og4J003o6Q/0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo6P3o000G0?;o0740E?l0<000oaXC003oL@/00?nh1000oo@4001Ko`@0=@3o103o00l30?l0
h`@0o`3`3`3o00040<80o`@001[o0`320?l4001Ko`@00=Oo1000okPF003oLAX00?lJ6`1Do`060?oo
o`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolJ0?l001<0l_l0L@1Do`0a003o6Pl0
0?ma3`00okP3003om0@00=Oo1000ZOl4001Ko`@0o`2I6P3o00040?l0K`<0lP3o103o0><4003Go`@0
0?od0`00okPK003oLA800?lJ6`1Do`060?ooo`4000000@3oool002P0oooo0`0000050?oooaX0o`00
4`3bo`1a05Co03400?lJ3`00og4?003o^0<00?od1000eol4002Yo`@005_o103o09TJ0?l000@0o`1_
0`3b0?l40?l0h`@00=Oo1000oo@3003o^1/00?ma4P00oaXK05Co00D0oooo0P0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?oooaX0o`004`3bo`1a05Co03400?lJ3`00og4?003o^0<00?od1000
eol4002Yo`@005_o103o09TJ0?l000@0o`1_0`3b0?l40?l0h`@00=Oo1000oo@3003o^1/00?ma4P00
oaXK05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaX0o`003`3bo`1a
05Co03400?lJ2`00og4C003o^0L00?od1000eol4002Yo`@005_o100e0?lN0?l000<0H`3o1000P?l4
003Go`@00?od1`00okPJ003oLA<00?lJ5`1Do`060?ooo`4000000@3oool002P0oooo00<000000?oo
o`3oool01@3ooolJ0?l000l0l_l0L@1Do`0a003o6P/00?ma4`00okP7003om0@00=Oo1000ZOl4001K
o`@0=@3o7P3o000306<0o`@0083o1000eol4003om0L00?nh6P00og4C003o6QL0E?l01P3oool10000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo6P3o000?0?;o0740E?l0<@00oaX;003oLA<0
0?nh1`00oo@4003Go`@00:Wo1000Fol403D0oah0o`000`1S0?l40020o`@00=Oo1000oo@7003o^1X0
0?ma4`00oaXG05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaX0o`00
3`3bo`1a05Co03400?lJ2`00og4C003o^0L00?od1000eol4002Yo`@005_o100e0?lN0?l000<0H`3o
1000P?l4003Go`@00?od1`00okPJ003oLA<00?lJ5`1Do`060?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3ooolF0?l001<0l_l0J@1Do`0a003o6P`00?ma5P00okP;003om0@00=Oo1000
ZOl406<0o`@0d`3o7P3o000306<0o`@0703o1000eol7003om0`00?nh5P00og4?003o6QL0E?l01P3o
ool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo5P3o000C0?;o06T0E?l0<@00oaX<
003oLAH00?nh2`00oo@4003Go`@00:Wo101S0?l40=<0oah0o`000`1S0?l401`0o`@00=Oo1`00oo@<
003o^1H00?ma3`00oaXG05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oo
oaH0o`004`3bo`1Y05Co03400?lJ3000og4F003o^0/00?od1000eol4002Yo`@0H`3o103C0?lN0?l0
00<0H`3o100L0?l4003Go`L00?od3000okPF003oL@l00?lJ5`1Do`060?ooo`4000000@3oool002P0
oooo00<000000?ooo`3oool01@3ooolF0?l000l0l_l0JP1Do`0a003o6P/00?ma4`00okP?003om0L0
0=Oo1000ZOl4000jo`@0S03o7P3o00030;40o`@0083o2000eol7003om1<00?nh3`00og4?003o6Q<0
E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo5P3o000?0?;o06X0E?l0
<@00oaX;003oLA<00?nh3`00oo@7003Go`@00:Wo1000>_l408`0oah0o`000`2a0?l40020o`P00=Oo
1`00oo@C003o^0l00?ma3`00oaXC05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?oo
o`050?oooaH0o`003`3bo`1Z05Co03400?lJ2`00og4C003o^0l00?od1`00eol4002Yo`@003[o102<
0?lN0?l000<0/@3o1000P?l8003Go`L00?od4`00okP?003oL@l00?lJ4`1Do`060?ooo`4000000@3o
ool002P0oooo00<000000?ooo`3oool01@3ooolF0?l000l0l_l0JP1Do`0a003o6P/00?ma4`00okP?
003om0L00=Oo1000ZOl4000jo`@0S03o7P3o00030;40o`@0083o2000eol7003om1<00?nh3`00og4?
003o6Q<0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo5P3o000<0?;o
06T0E?l0;@00oaX;003oL@@00?nh8P00oo@4003Go`L00:Wo1000P?l4001Ko`@0W`3o7P3o00030;40
o`@0083o1000ZOl7003Go`P00?od7P00okP4003oL@/00?lJ4`1Do`060?ooo`4000000@3oool002P0
oooo00<000000?ooo`3oool01@3ooolF0?l000`0l_l0J@1Do`0]003o6P/00?ma1000okPR003om0@0
0=Oo1`00ZOl40020o`@005_o102O0?lN0?l000<0/@3o1000P?l4002Yo`L00=Oo2000oo@N003o^0@0
0?ma2`00oaXC05Co00H0oooo0@0000010?ooo`00:03oool3000000D0oooo5P3o000<0?;o06T0E?l0
;@00oaX;003oL@@00?nh8P00oo@4003Go`L00:Wo1000P?l4001Ko`@0W`3o7P3o00030;40o`@0083o
1000ZOl7003Go`P00?od7P00okP4003oL@/00?lJ4`1Do`050?ooo`8000000@3oool002P0oooo00<0
00000?ooo`3oool01@3ooolC0?l000l0l_l0I@1Do`0Z003o6Pl00?ma0`00okP4003Go`@005_o1000
eol3002Yo`@0=@3o1000Fol;003Go`@00:Wo2`00P?l4001Ko`@003[o10010?l30?l0bAL0o`00103o
0?03000Jo`@005_o1000P?l7002Yo`@00@3o1000eol7003om0`00?nh0`00oo@4003Go`@0083o1000
okP3003oL@`00?lJ3`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC
0?l000l0l_l0I@1Do`0Z003o6Pl00?ma0`00okP4003Go`@005_o1000eol3002Yo`@0=@3o1000Fol;
003Go`@00:Wo2`00P?l4001Ko`@003[o10010?l30?l0bAL0o`00103o0?03000Jo`@005_o1000P?l7
002Yo`@00@3o1000eol7003om0`00?nh0`00oo@4003Go`@0083o1000okP3003oL@`00?lJ3`1Do`06
0?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC0?l000l0l_l0I@1Do`0Z003o
6Pl00?ma0`00okP4003Go`@005_o1000eol3002Yo`@0=@3o1000Fol;003Go`@00:Wo2`00P?l4001K
o`@003[o10010?l30?l0bAL0o`00103o0?03000Jo`@005_o1000P?l7002Yo`@00@3o1000eol7003o
m0`00?nh0`00oo@4003Go`@0083o1000okP3003oL@`00?lJ3`1Do`060?ooo`4000000@3oool002P0
oooo00<000000?ooo`3oool01@3ooolC0?l000l0l_l0I@1Do`0Z003o6Pl00?ma0`00okP4003Go`@0
05_o1000eol3002Yo`@0=@3o1000Fol;003Go`@00:Wo2`00P?l4001Ko`@003[o10010?l30?l0bAL0
o`00103o0?03000Jo`@005_o1000P?l7002Yo`@00@3o1000eol7003om0`00?nh0`00oo@4003Go`@0
083o1000okP3003oL@`00?lJ3`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3ooolC0?l000/0l_l0I@1Do`0V003o6Q<00?ma1`00okP4003Go`@0o`0h10006_l301`0o`@0o`00
1000Fol7002Yo`@0083o10006_l40?l000<0703o10006_l40?l0l0@0703o100e0?l307P0oa<0o`00
103o0><406<0o`<0703o10010?l407P0o`L005_o100e0?l40040o`L00=Oo3`00oo@4002Yo`@0N03o
1000oo@3003o^0@00?ma2000oaX?05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?oo
o`050?oooa<0o`002`3bo`1U05Co02H00?lJ4`00og47003o^0@00=Oo103o03P4000Jo`<0703o103o
0004001Ko`L00:Wo1000P?l4000Jo`@0o`000`0L0?l4000Jo`@0o`3`100L0?l403D0o`<0N03o4`3o
00040?l0h`@0H`3o0`0L0?l40040o`@0N03o1`00Fol403D0o`@00@3o1`00eol?003om0@00:Wo101h
0?l4003om0<00?nh1000og48003o6Pl0E?l01P3oool100000040oooo000X0?ooo`030000003oool0
oooo00D0oooo4`3o000;0?;o06D0E?l09P00oaXC003oL@L00?nh1000eol40?l0>0@001[o0`0L0?l4
0?l000@005_o1`00ZOl40020o`@001[o103o000301`0o`@001[o103o0?0401`0o`@0=@3o0`1h0?lC
0?l000@0o`3S101S0?l301`0o`@00@3o101h0?l7001Ko`@0=@3o10010?l7003Go`l00?od1000ZOl4
07P0o`@00?od0`00okP4003oL@P00?lJ3`1Do`060?ooo`4000000@3oool002P0oooo00<000000?oo
o`3oool01@3ooolC0?l000/0l_l0HP1Do`0R003o6QH00?ma2000okP3003om0@00=Oo1000Fol404d0
o`<0o`3`100e0?l40040o`@0C@3o1`00Fol40=<0o`@0o`000`3o00l408`0obd0o`00103o08h80?l0
00<0C@3o103o04T40?l000@0083o0`00ZOl<003Go`<00:Wo1000>_l40?l0l0@00=Oo0`00okP4003o
L@`00?lJ2`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC0?l000/0
l_l0HP1Do`0R003o6QH00?ma2000okP3003om0@00=Oo1000Fol404d0o`<0o`3`100e0?l40040o`@0
C@3o1`00Fol40=<0o`@0o`000`3o00l408`0obd0o`00103o08h80?l000<0C@3o103o04T40?l000@0
083o0`00ZOl<003Go`<00:Wo1000>_l40?l0l0@00=Oo0`00okP4003oL@`00?lJ2`1Do`060?ooo`40
00000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC0?l000/0l_l0HP1Do`0R003o6QH00?ma
2000okP3003om0@00=Oo1000Fol404d0o`<0o`3`100e0?l40040o`@0C@3o1`00Fol40=<0o`@0o`00
0`3o00l408`0obd0o`00103o08h80?l000<0C@3o103o04T40?l000@0083o0`00ZOl<003Go`<00:Wo
1000>_l40?l0l0@00=Oo0`00okP4003oL@`00?lJ2`1Do`060?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3ooolC0?l000/0l_l0HP1Do`0R003o6QH00?ma2000okP3003om0@00=Oo1000
Fol404d0o`<0o`3`100e0?l40040o`@0C@3o1`00Fol40=<0o`@0o`000`3o00l408`0obd0o`00103o
08h80?l000<0C@3o103o04T40?l000@0083o0`00ZOl<003Go`<00:Wo1000>_l40?l0l0@00=Oo0`00
okP4003oL@`00?lJ2`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool?
0?l000/0l_l0HP1Do`0N003o6QX00?ma3000okP3003om0@00=Oo103b0?l406<0o`<0o`2U103o0004
0;40o`@0o`001`006_l404d0odl0o`001000Fol70020o`@0d`3o10010?l3001Ko`@003[o103o08@4
0020o`<0W`3o2000og48003o6P/0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo3`3o000;0?;o0680E?l07P00oaXJ003oL@`00?nh0`00oo@4003Go`@0lP3o101S0?l30?l0
Y@@0o`00102a0?l40?l000L001[o101=0?m?0?l000@005_o1`00P?l40=<0o`@00@3o0`00Fol4000j
o`@0o`241000P?l309l0o`P00?ma2000oaX;05Co00H0oooo0@0000010?ooo`00:03oool3000000D0
oooo3`3o000;0?;o0680E?l07P00oaXJ003oL@`00?nh0`00oo@4003Go`@0lP3o101S0?l30?l0Y@@0
o`00102a0?l40?l000L001[o101=0?m?0?l000@005_o1`00P?l40=<0o`@00@3o0`00Fol4000jo`@0
o`241000P?l309l0o`P00?ma2000oaX;05Co00D0oooo0P0000010?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`l0o`001`3bo`1R05Co01L00?lJ8P00og4?003o^0<00?od1000eol40020o`@001[o
0`3o0?0<0?l000<0C@3o103o00040?l0bD/0o`00103o01l40?l0I@L003[o101=0?l40;40o`<0C@3o
100e0?l40?l0oP@001[o0`00eol8003oL@/00?lJ201Do`060?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool?0?l000L0l_l0HP1Do`0G003o6R800?ma3`00okP3003om0@00=Oo1000
P?l4000Jo`<0o`3`303o000304d0o`@0o`00103o0<U;0?l000@0o`0O103o06D7000jo`@0C@3o102a
0?l304d0o`@0=@3o103o0?h4000Jo`<00=Oo2000og4;003o6PP0E?l01P3oool100000040oooo000X
0?ooo`030000003oool0oooo00D0oooo3`3o00070?;o0680E?l05`00oaXR003oL@l00?nh0`00oo@4
003Go`@0083o10006_l30?l0l0`0o`000`1=0?l40?l000@0o`39B`3o00040?l07`@0o`1U1`00>_l4
04d0o`@0/@3o0`1=0?l403D0o`@0o`3n10006_l3003Go`P00?ma2`00oaX805Co00H0oooo0@000001
0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`l0o`001`3bo`1R05Co01L00?lJ8P00og4?003o
^0<00?od1000eol40020o`@001[o0`3o0?0<0?l000<0C@3o103o00040?l0bD/0o`00103o01l40?l0
I@L003[o101=0?l40;40o`<0C@3o100e0?l40?l0oP@001[o0`00eol8003oL@/00?lJ201Do`060?oo
o`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool?0?l000L0l_l0F`1Do`0F003o6RX0
0?ma2`00okP7003om0@00=Oo1000ZOl401`0o`<0o`3n303o00030=<0oe/0o`000`0e0?l404d0o`P0
o`000`3o03P40?l000@0703o103o07T3003om0@00?nh2000og47003o6PP0E?l01P3oool100000040
oooo000X0?ooo`030000003oool0oooo00D0oooo3`3o00070?;o05/0E?l05P00oaXZ003oL@/00?nh
1`00oo@4003Go`@00:Wo100L0?l30?l0oP`0o`000`3C0?mK0?l000<0=@3o101=0?l80?l000<0o`0h
103o000401`0o`@0o`1i0`00oo@4003o^0P00?ma1`00oaX805Co00H0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`l0o`001`3bo`1K05Co01H00?lJ:P00og4;003o^0L00?od1000
eol4002Yo`@0703o0`3o0?h<0?l000<0d`3oF`3o000303D0o`@0C@3o203o00030?l0>0@0o`00100L
0?l40?l0N@<00?od1000okP8003oL@L00?lJ201Do`060?ooo`4000000@3oool002P0oooo00<00000
0?ooo`3oool01@3oool;0?l000P0l_l0FP1Do`0C003o6Rd00?ma3`00okP4003om0L00=Oo1000P?l4
0040o`<0`P3oK@3o00040?l0Y@/0o`00102O0?l4001Ko`@00:Wo0`00oo@4003o^0P00?ma1`00oaX8
05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`/0o`00203bo`1J05Co
01<00?lJ;@00og4?003o^0@00?od1`00eol40020o`@00@3o0`320?m]0?l000@0o`2U2`3o000409l0
o`@005_o1000ZOl3003om0@00?nh2000og47003o6PP0E?l01P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo2`3o00080?;o05X0E?l04`00oaX]003oL@l00?nh1000oo@7003Go`@0
083o10010?l30<80ofd0o`00103o0:D;0?l000@0W`3o1000Fol4002Yo`<00?od1000okP8003oL@L0
0?lJ201Do`060?ooo`4000000@3oool000/0oooo00D0okmd000000000000000007Boo`050?ooo`03
0;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`060?ooo`030000003oool0oooo
00D0oooo2`3o00080?;o0580E?l04`00oaXa003oL@l00?nh1000oo@7003Go`@00:Wo1000P?l4000j
o`<0=@3o103b0?l40?l03fD0o`00103o05<;0?l000@0o`3`10320?l4003Go`L00?nh2000og4;003o
6P@0E?l01P3oool100000040oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool0
0`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`050?ooo`030000
003oool0oooo00D0oooo2`3o00080?;o0580E?l04`00oaXa003oL@l00?nh1000oo@7003Go`@00:Wo
1000P?l4000jo`<0=@3o103b0?l40?l03fD0o`00103o05<;0?l000@0o`3`10320?l4003Go`L00?nh
2000og4;003o6P@0E?l01P3oool100000040oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0
gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo00D0oooo2`3o
00080?;o0580E?l04`00oaXa003oL@l00?nh1000oo@7003Go`@00:Wo1000P?l4000jo`<0=@3o103b
0?l40?l03fD0o`00103o05<;0?l000@0o`3`10320?l4003Go`L00?nh2000og4;003o6P@0E?l01P3o
ool100000040oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool0
0`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo00D0oooo2`3o00080?;o0580E?l04`00oaXa
003oL@l00?nh1000oo@7003Go`@00:Wo1000P?l4000jo`<0=@3o103b0?l40?l03fD0o`00103o05<;
0?l000@0o`3`10320?l4003Go`L00?nh2000og4;003o6P@0E?l01P3oool100000040oooo00000`3o
ool0W4P000000004000000050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0?
0?ooo`0309a8001d_ol0oooo00@0oooo100000040?ooo`/0o`00203bo`1?05Co00l00?lJ<@00og4B
003o^0P00?od1000ZOl3000jo`@00@3o1000>_l40?l0h`<0S03oO03o000401`0o`@0083o1000oo@7
003o^0P00?ma2`00oaX405Co00@0oooo0`0000010?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo2`3o00080?;o04l0E?l03`00oaXa003oLA800?nh2000oo@4002Y
o`<003[o10010?l4000jo`@0o`3S0`2<0?ml0?l000@0703o1000P?l4003om0L00?nh2000og4;003o
6P@0E?l01P3oool100000040oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3o
ool02P3oool00`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo00D0oooo2`3o00080?;o04l0
E?l03`00oaXa003oLA800?nh2000oo@4002Yo`<003[o10010?l4000jo`@0o`3S0`2<0?ml0?l000@0
703o1000P?l4003om0L00?nh2000og4;003o6P@0E?l01P3oool100000040oooo000;0?ooo`0609a8
001d_ol0oooo0?oOW01807@0_ooo2`3oool00`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo
00D0oooo2`3o00040?;o04/0E?l03`00oaXe003oLA<00?nh1`00oo@4000jo`@00@3o0`320?l404d0
o`@0703o103o0>=h0?l000@0o`3E0`0L0?l4001Ko`@00:Wo1`00oo@4003o^0`00?ma1`00oaX405Co
00H0oooo0@0000010?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0oono07@0
000000000P0000000`0007@0_ooo0?ooo`040?ooo`030000003oool0oooo00D0oooo2`3o00040?;o
04/0E?l03`00oaXe003oLA<00?nh1`00oo@4000jo`@00@3o0`320?l404d0o`@0703o103o0>=h0?l0
00@0o`3E0`0L0?l4001Ko`@00:Wo1`00oo@4003o^0`00?ma1`00oaX405Co00H0oooo0@0000010?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`/0o`00103bo`1;05Co00l00?lJ=@00og4C003o^0L0
0?od1000>_l40040o`<0`P3o101=0?l401`0o`@0o`3SN03o00040?l0e@<0703o1000Fol4002Yo`L0
0?od1000okP<003oL@L00?lJ101Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3oool;0?l000@0l_l0B`1Do`0?003o6SD00?ma4`00okP7003om0@003[o10010?l30<80o`@0C@3o
100L0?l40?l0hgP0o`00103o0=D301`0o`@005_o1000ZOl7003om0@00?nh3000og47003o6P@0E?l0
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o00080?;o0400E?l04`00
oaX3003oLA/00?nh5P00og4G003o^0L00?od1000eol4002Yo`@0o`390`3o00040?l0BHL0o`001000
6_l40020o`@00=Oo0`00oo@8003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<00000
0?ooo`3oool01@3oool70?l000P0l_l0@01Do`0C003o6P<00?ma6`00okPF003oLAL00?nh1`00oo@4
003Go`@00:Wo103o0<T30?l000@0o`19Q`3o0004000Jo`@0083o1000eol3003om0P00?nh2000og4;
003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`L0o`00203bo`1005Co
01<00?lJ0`00og4K003o^1H00?ma5`00okP7003om0@00=Oo1000ZOl40?l0b@<0o`00103o04V70?l0
00@001[o1000P?l4003Go`<00?od2000okP8003oL@/00?lJ1P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo1`3o00040?;o03`0E?l04`00oaX8003oL@<00?nh1000ZOl4003Go`@0
0?od<@00okP?003om0L00=Oo1000ZOl4000Jo`<0d`3oS`3o0004000Jo`L00=Oo1000oo@4003o^0P0
0?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool70?l000@0l_l0
?01Do`0C003o6PP00?ma0`00okP4002Yo`@00=Oo1000oo@a003o^0l00?od1`00eol4002Yo`@001[o
0`3C0?n?0?l000@001[o1`00eol4003om0@00?nh2000og4;003o6PH0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0l05Co01<00?lJ2000og43003o^0@00:Wo1000
eol4003om3400?nh3`00oo@7003Go`@00:Wo10006_l30=<0ohl0o`0010006_l7003Go`@00?od1000
okP8003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o0004
0?;o03`0E?l04`00oaX8003oL@<00?nh1000ZOl4003Go`@00?od<@00okP?003om0L00=Oo1000ZOl4
000Jo`<0d`3oS`3o0004000Jo`L00=Oo1000oo@4003o^0P00?ma2`00oaX60?ooo`4000000@3oool0
02P0oooo0`0000050?ooo`L0o`00103bo`0a05Co01X00?lJ2000og47003o^0@00=Oo1000>_l40020
od000?od1`00eol40020o`@003[o0`0e0?l40?l0eHL0o`00103o0><4000jo`@0083o0`00ZOl4001K
o`@00?od2000og4;003o6PD0oooo0P0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`L0
o`00103bo`0a05Co01X00?lJ2000og47003o^0@00=Oo1000>_l40020od000?od1`00eol40020o`@0
03[o0`0e0?l40?l0eHL0o`00103o0><4000jo`@0083o0`00ZOl4001Ko`@00?od2000og4;003o6PH0
oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0a05Co01X00?lJ
2000og47003o^0@00=Oo1000>_l40020od000?od1`00eol40020o`@003[o0`0e0?l40?l0eHL0o`00
103o0><4000jo`@0083o0`00ZOl4001Ko`@00?od2000og4;003o6PH0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0V05Co02800?lJ2`00og47003o^0@00=Oo1000
6_l40020o`L00=Oo2`00oo@8003Go`@0703o1`00eolC003om0/00=Oo1000ZOl4000jo`@0S03oTP3o
000403D0o`@0d`3o0`00>_l40?l000@00=Oo1000okP4003oL@/00?lJ1P3oool100000040oooo000X
0?ooo`030000003oool0oooo00D0oooo1`3o00040?;o02H0E?l08P00oaX;003oL@L00?nh1000eol4
000Jo`@0083o1`00eol;003om0P00=Oo100L0?l7003Goa<00?od2`00eol4002Yo`@003[o102<0?nB
0?l000@0=@3o103C0?l3000jo`@0o`001000eol4003o^0@00?ma2`00oaX60?ooo`4000000@3oool0
02P0oooo00<000000?ooo`3oool01@3oool70?l000@0l_l09P1Do`0R003o6P/00?ma1`00okP4003G
o`@001[o1000P?l7003Go`/00?od2000eol401`0o`L00=Oo4`00oo@;003Go`@00:Wo1000>_l408`0
oi80o`00100e0?l40=<0o`<003[o103o0004003Go`@00?nh1000og4;003o6PH0oooo0@0000010?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0V05Co02800?lJ2`00og47003o^0@0
0=Oo10006_l40020o`L00=Oo2`00oo@8003Go`@0703o1`00eolC003om0/00=Oo1000ZOl4000jo`@0
S03oTP3o000403D0o`@0d`3o0`00>_l40?l000@00=Oo1000okP4003oL@/00?lJ1P3oool100000040
oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o000R05Co02800?lJ4`00og47003o^0@003[o
100L0?l4001Ko`/00:Wo1`00eol4002Yo`@005_o100L0?l30020o`@00:Wo2000eol4003om0l00=Oo
0`00ZOl4001Ko`@0o`1U103o00030?l0NIL0o`000`3o08@407P0o`@00@3o1000okP4003oL@/00?lJ
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o000R05Co02800?lJ4`00
og47003o^0@003[o100L0?l4001Ko`/00:Wo1`00eol4002Yo`@005_o100L0?l30020o`@00:Wo2000
eol4003om0l00=Oo0`00ZOl4001Ko`@0o`1U103o00030?l0NIL0o`000`3o08@407P0o`@00@3o1000
okP4003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o000R
05Co02800?lJ4`00og47003o^0@003[o100L0?l4001Ko`/00:Wo1`00eol4002Yo`@005_o100L0?l3
0020o`@00:Wo2000eol4003om0l00=Oo0`00ZOl4001Ko`@0o`1U103o00030?l0NIL0o`000`3o08@4
07P0o`@00@3o1000okP4003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo1`3o000K05Co02D00?lJ4`00og4;003o^0@00=Oo1000Fol409l0o`<0C@3o1000>_l40040
o`@005_o0`00ZOl40020o`@003[o10320?l3000Jo`P0083o1000FolC002Yo`<0083o1000Fol401`0
oih0o`000`3o0<T403D0o`@00?od1000okP4003oL@/00?lJ1P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo1`3o000K05Co02D00?lJ4`00og4;003o^0@00=Oo1000Fol409l0o`<0
C@3o1000>_l40040o`@005_o0`00ZOl40020o`@003[o10320?l3000Jo`P0083o1000FolC002Yo`<0
083o1000Fol401`0oih0o`000`3o0<T403D0o`@00?od1000okP4003oL@/00?lJ1P3oool100000040
oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o000K05Co02D00?lJ4`00og4;003o^0@00=Oo
1000Fol409l0o`<0C@3o1000>_l40040o`@005_o0`00ZOl40020o`@003[o10320?l3000Jo`P0083o
1000FolC002Yo`<0083o1000Fol401`0oih0o`000`3o0<T403D0o`@00?od1000okP4003oL@/00?lJ
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o000K05Co02D00?lJ4`00
og4;003o^0@00=Oo1000Fol409l0o`<0C@3o1000>_l40040o`@005_o0`00ZOl40020o`@003[o1032
0?l3000Jo`P0083o1000FolC002Yo`<0083o1000Fol401`0oih0o`000`3o0<T403D0o`@00?od1000
okP4003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o0003
0?;o01<0E?l0:P00oaXF003oL@P00?nh0`00oo@4003Go`@00:Wo1000Fol3000Jo`@0o`00103S0?l4
0040o`<001[o1000Fol4000Jo`@0703o0`3o000403D0o`@001[o101=0?l4001Ko`/00:Wo1`00P?l4
000joih0o`00103o0=D3000jo`@00=Oo1000oo@4003o^0@00?ma2`00oaX60?ooo`4000000@3oool0
02P0oooo0`0000050?ooo`@0o`000`3bo`0C05Co02X00?lJ5P00og48003o^0<00?od1000eol4002Y
o`@005_o0`006_l40?l000@0h`3o10010?l3000Jo`@005_o10006_l401`0o`<0o`00100e0?l4000J
o`@0C@3o1000Fol;002Yo`L0083o1000>_nN0?l000@0o`3E0`00>_l4003Go`@00?od1000okP4003o
L@/00?lJ1@3oool200000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o00030?;o01<0
E?l0:P00oaXF003oL@P00?nh0`00oo@4003Go`@00:Wo1000Fol3000Jo`@0o`00103S0?l40040o`<0
01[o1000Fol4000Jo`@0703o0`3o000403D0o`@001[o101=0?l4001Ko`/00:Wo1`00P?l4000joih0
o`00103o0=D3000jo`@00=Oo1000oo@4003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo
00<000000?ooo`3oool01@3oool40?l000<0l_l03`1Do`0Z003o6QX00?ma2000okP7003om0@00:Wo
1000P?l3001Ko`@0=@3o103o05`40?80o`<0N03o101=0?l401`0o`@0o`3n1`3o000403D0o`@0`P3o
10010?l3000jo``0083o0`00Fol40040oih0o`00101h0?l30020o`@00=Oo2000okP4003oL@/00?lJ
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o00030?;o00l0E?l0:P00
oaXJ003oL@P00?nh1`00oo@4002Yo`@0083o0`00Fol403D0o`@0o`1L103b0?l307P0o`@0C@3o100L
0?l40?l0oPL0o`00100e0?l40<80o`@00@3o0`00>_l<0020o`<005_o10010?nN0?l000@0N03o0`00
P?l4003Go`P00?nh1000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`05
0?ooo`@0o`000`3bo`0?05Co02X00?lJ6P00og48003o^0L00?od1000ZOl40020o`<005_o100e0?l4
0?l0G0@0lP3o0`1h0?l404d0o`@0703o103o0?h70?l000@0=@3o10320?l40040o`<003[o3000P?l3
001Ko`@00@3oWP3o000407P0o`<0083o1000eol8003o^0@00?ma2`00oaX60?ooo`4000000@3oool0
02P0oooo00<000000?ooo`3oool01@3oool40?l000<0l_l0301Do`0Y003o6Qh00?ma1000okP;003o
m0P00:Wo0`006_l40?80o`P0o`000`3o0<T40><0o`@0o`00103o03P30?l000@0o`1_103o02L40?l0
00@0W`3o0`3o0=D4000jo`P005_o0`00>_l40040o`@0o`3nVP3o000403D0o`<005_o1000ZOl8003o
^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000<0
l_l0301Do`0Y003o6Qh00?ma1000okP;003om0P00:Wo0`006_l40?80o`P0o`000`3o0<T40><0o`@0
o`00103o03P30?l000@0o`1_103o02L40?l000@0W`3o0`3o0=D4000jo`P005_o0`00>_l40040o`@0
o`3nVP3o000403D0o`<005_o1000ZOl8003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo
00<000000?ooo`3oool01@3oool40?l000<0l_l0301Do`0Y003o6Qh00?ma1000okP;003om0P00:Wo
0`006_l40?80o`P0o`000`3o0<T40><0o`@0o`00103o03P30?l000@0o`1_103o02L40?l000@0W`3o
0`3o0=D4000jo`P005_o0`00>_l40040o`@0o`3nVP3o000403D0o`<005_o1000ZOl8003o^0@00?ma
2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000<0l_l0301D
o`0Y003o6Qh00?ma1000okP;003om0P00:Wo0`006_l40?80o`P0o`000`3o0<T40><0o`@0o`00103o
03P30?l000@0o`1_103o02L40?l000@0W`3o0`3o0=D4000jo`P005_o0`00>_l40040o`@0o`3nVP3o
000403D0o`<005_o1000ZOl8003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<00000
0?ooo`3oool01@3oool40?l000/0E?l0:@00oaXN003oL@@00?nh2`00oo@4003Go`@00:Wo1000P?l3
0040o`@0N03o203o00030?l03b80o`00103o0<T;000Jo`@0C@3oXP3o000303D0o`@0o`001000okP8
003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000;05Co
02T00?lJ7P00og44003o^0/00?od1000eol4002Yo`@0083o0`010?l407P0o`P0o`000`3o00lR0?l0
00@0o`392`006_l404d0oj80o`000`0e0?l40?l000@00?nh2000og4;003o6PH0oooo0@0000010?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`@0o`002`1Do`0Y003o6Qh00?ma1000okP;003om0@0
0=Oo1000ZOl40020o`<00@3o101h0?l80?l000<0o`0?8P3o00040?l0b@/001[o101=0?nR0?l000<0
=@3o103o0004003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3oool40?l000L0E?l0;@00oaXN003oL@@00?nh2`00oo@4002Yo`@0083o1000Fol3000Jo`@0H`3o
103o0><]0?l000@0`P3o1`010?nV0?l000<0lP3o1000>_l4003o^0P00?ma2`00oaX60?ooo`400000
0@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000L0E?l0;@00oaXN003oL@@00?nh2`00
oo@4002Yo`@0083o1000Fol3000Jo`@0H`3o103o0><]0?l000@0`P3o1`010?nV0?l000<0lP3o1000
>_l4003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo0`0000050?ooo`@0o`001`1Do`0]
003o6Qh00?ma1000okP;003om0@00:Wo1000P?l4001Ko`<001[o101S0?l40?l0hbd0o`0010320?l7
0040ojH0o`000`3b0?l4000jo`@00?nh2000og4;003o6PD0oooo0P0000010?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`@0o`001`1Do`0]003o6Qh00?ma1000okP;003om0@00:Wo1000P?l4001K
o`<001[o101S0?l40?l0hbd0o`0010320?l70040ojH0o`000`3b0?l4000jo`@00?nh2000og4;003o
6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`001`1Do`0Z003o6Qh0
0?ma0`00okP4003om0/00=Oo1000P?l407P0o`@0=@3o0`2O0?li0?l000@0C@3o0`0e0?nR0?l000@0
o`2>0`00P?l4003om0@00?nh2000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`@0o`001`1Do`0Z003o6Qh00?ma0`00okP4003om0/00=Oo1000P?l407P0o`@0=@3o
0`2O0?li0?l000@0C@3o0`0e0?nR0?l000@0o`2>0`00P?l4003om0@00?nh2000og4;003o6PH0oooo
0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`001`1Do`0Z003o6Qh00?ma0`00
okP4003om0/00=Oo1000P?l407P0o`@0=@3o0`2O0?li0?l000@0C@3o0`0e0?nR0?l000@0o`2>0`00
P?l4003om0@00?nh2000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`05
0?ooo`@0o`000`1Do`0Z003o6QX00?ma1000okP4003om0<001[o2000eol7002Yo`@005_o10006_l4
0?l0@3`0o`00103o05<307P0o`@0o`0WXP3o000303D0o`@00?od1000okP8003oL@/00?lJ1P3oool1
00000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000305Co02X00?lJ6P00og44003o
^0@00?od0`006_l8003Go`L00:Wo1000Fol4000Jo`@0o`10?03o00040?l0D`<0N03o103o02NR0?l0
00<0=@3o1000oo@4003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3o
ool01@3oool40?l000<0E?l0:P00oaXJ003oL@@00?nh1000oo@3000Jo`P00=Oo1`00ZOl4001Ko`@0
01[o103o040l0?l000@0o`1C0`1h0?l40?l09j80o`000`0e0?l4003om0@00?nh2000og4;003o6PH0
oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`000`1Do`0Z003o6QX00?ma
1000okP4003om0<001[o2000eol7002Yo`@005_o10006_l40?l0@3`0o`00103o05<307P0o`@0o`0W
XP3o000303D0o`@00?od1000okP8003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003o
ool0oooo00D0oooo103o000305Co02H00?lJ2`00og4C003o^0@00?od1000eol3001Ko`@003[o1000
P?l4002Yo`<0083o1000Fol40040o`@0S03o@03o00030;40oj80o`00103o0?03002Yo`@00?nh3000
og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`000`1Do`0V
003o6P/00?ma4`00okP4003om0@00=Oo0`00Fol4000jo`@0083o1000ZOl30020o`@005_o10010?l4
08`0od00o`000`2a0?nR0?l000@0o`3`0`00ZOl4003o^0`00?ma2`00oaX60?ooo`4000000@3oool0
02P0oooo00<000000?ooo`3oool01@3oool40?l000<0E?l09P00oaX;003oLA<00?nh1000oo@4003G
o`<005_o1000>_l40020o`@00:Wo0`00P?l4001Ko`@00@3o102<0?m00?l000<0/@3oXP3o00040?l0
l0<00:Wo1000okP<003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0
oooo103o000U003o6P@00?ma6P00okP8003om0@00=Oo0`00P?l407P0o`P003[o0`010?l4000Jo`@0
=@3oA03o00030?l0SZ80o`001000Fol3003om0@00?nh3000og4;003o6PH0oooo0@0000010?ooo`00
:03oool00`000000oooo0?ooo`050?ooo`@0o`009@00oaX4003oLAX00?nh2000oo@4003Go`<0083o
101h0?l8000jo`<00@3o10006_l403D0od@0o`000`3o08jR0?l000@005_o0`00oo@4003o^0`00?ma
2`00oaX60?ooo`4000000@3oool002P0oooo0`0000050?ooo`@0o`009@00oaX4003oLAX00?nh2000
oo@4003Go`<0083o101h0?l8000jo`<00@3o10006_l403D0od@0o`000`3o08jR0?l000@005_o0`00
oo@4003o^0`00?ma2`00oaX50?ooo`8000000@3oool002P0oooo00<000000?ooo`3oool01@3oool4
0?l002D00?lJ1000og4J003o^0P00?od1000eol30020o`@0N03o2000>_l30040o`@001[o100e0?m4
0?l000<0o`2>XP3o0004001Ko`<00?od1000okP<003oL@/00?lJ1P3oool100000040oooo000X0?oo
o`030000003oool0oooo00D0oooo103o000;003o6P@00?ma4P00oaX4003oLAL00?nh3`00oo@4002Y
o`<0083o1000>_l40?l0V@@0C@3o0`3o0;0409l0o`@0N03oi@3o00040040o`@00=Oo0`00oo@4003o
^0`00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000/0
0?lJ1000og4B003o6P@00?ma5`00okP?003om0@00:Wo0`00P?l4000jo`@0o`2I101=0?l30?l0/0@0
W`3o101h0?oU0?l000@00@3o1000eol3003om0@00?nh3000og4;003o6PH0oooo0@0000010?ooo`00
:03oool00`000000oooo0?ooo`050?ooo`@0o`002`00oaX4003oLA800?lJ1000og4G003o^0l00?od
1000ZOl30020o`@003[o103o09T404d0o`<0o`2`102O0?l407P0onD0o`0010010?l4003Go`<00?od
1000okP<003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o
0003003o6Pl00?ma2000okP4003om0<00=Oo2000oo@?003o^0l00?od2000ZOl3001Ko`@001[o102<
0?l;0?l000@0h`3oh@3o00040;40o`@0083o1000oo@7003o^0`00?ma2`00oaX60?ooo`4000000@3o
ool002P0oooo00<000000?ooo`3oool01@3oool40?l000<00?lJ3`00og48003o^0@00?od0`00eol8
003om0l00?nh3`00oo@8002Yo`<005_o10006_l408`0o`/0o`00103S0?oQ0?l000@0/@3o1000P?l4
003om0L00?nh3000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oo
o`@0o`000`00oaX?003oL@P00?nh1000oo@3003Go`P00?od3`00okP?003om0P00:Wo0`00Fol4000J
o`@0S03o2`3o00040><0on40o`00102a0?l40020o`@00?od1`00okP<003oL@/00?lJ1P3oool10000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000;003oL@/00?nh2000oo@3001Ko`P0
0?od2000eol30020o``00=Oo0`00ZOl40020o`@003[o1000Fol30040o`@0H`3o103o06o`0?l000@0
05_o1000eol4003om0L00?nh3000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`@0o`002`00og4;003o^0P00?od0`00Fol8003om0P00=Oo0`00P?l<003Go`<00:Wo
1000P?l4000jo`@005_o0`010?l406<0o`@0o`1_l03o0004001Ko`@00=Oo1000oo@7003o^0`00?ma
2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000/00?ma2`00
okP8003om0<005_o2000oo@8003Go`<0083o3000eol3002Yo`@0083o1000>_l4001Ko`<00@3o101S
0?l40?l0Ko00o`001000Fol4003Go`@00?od1`00okP<003oL@/00?lJ1P3oool100000040oooo000M
0?ooo`050?noM000000000000000001d_ol01P3oool00`000000oooo0?ooo`050?ooo`@0o`002`00
og4;003o^0P00?od0`00Fol8003om0P00=Oo0`00P?l<003Go`<00:Wo1000P?l4000jo`@005_o0`01
0?l406<0o`@0o`1_l03o0004001Ko`@00=Oo1000oo@7003o^0`00?ma2`00oaX60?ooo`4000000@3o
ool001d0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool50?ooo`030000003oool0oooo00D0oooo
103o0003003o^0@00?ma2`00oo@4003Go`@00:Wo1000P?l30?l0b@@0083o1000ZOl80020o`<001[o
2000Fol40020o`<003[o10006_l404d0o`@0`P3o0`3o0><40?l0Q>d0o`00103o0<T3001Ko`@00:Wo
1000eol4003om0L00?nh3000og4;003o6PH0oooo0@0000010?ooo`00703oool00`3o_g@007Bo0?oo
o`020?ooo`030=nLB018W=l0oooo00@0oooo00<000000?ooo`3oool01@3oool40?l000<00?nh1000
og4;003om0@00=Oo1000ZOl40020o`<0o`391000P?l4002Yo`P0083o0`006_l8001Ko`@0083o0`00
>_l4000Jo`@0C@3o10320?l30?l0h`@0o`24k@3o00040?l0b@<005_o1000ZOl4003Go`@00?od1`00
okP<003oL@/00?lJ1P3oool100000040oooo000L0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool0103oool00`000000oooo0?ooo`050?ooo`@0o`000`00okP4003oL@/00?od1000eol4
002Yo`@0083o0`3o0<T40020o`@00:Wo2000P?l3000Jo`P005_o1000P?l3000jo`@001[o101=0?l4
0<80o`<0o`3S103o08C]0?l000@0o`390`00Fol4002Yo`@00=Oo1000oo@7003o^0`00?ma2`00oaX6
0?ooo`4000000@3oool001`0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?oo
o`@00000103oool40?l000<00?nh1000og4;003om0@00=Oo1000ZOl40020o`<0o`391000P?l4002Y
o`P0083o0`006_l8001Ko`@0083o0`00>_l4000Jo`@0C@3o10320?l30?l0h`@0o`24k@3o00040?l0
b@<005_o1000ZOl4003Go`@00?od1`00okP<003oL@/00?lJ103oool300000040oooo000L0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`050?ooo`@0
o`000`00okP4003oL@/00?od1000eol4002Yo`@0083o0`3o0<T40020o`@00:Wo2000P?l3000Jo`P0
05_o1000P?l3000jo`@001[o101=0?l40<80o`<0o`3S103o08C]0?l000@0o`390`00Fol4002Yo`@0
0=Oo1000oo@7003o^0`00?ma2`00oaX60?ooo`4000000@3oool001`0oooo00<0okmd04RLg`3oool0
0P3oool00`3OW4P0B9cO0?ooo`040?ooo`030000003oool0oooo00D0oooo103o0003003o^0@00?ma
2`00oo@4003Go`@00:Wo1000P?l30?l0b@@0083o1000ZOl80020o`<001[o2000Fol40020o`<003[o
10006_l404d0o`@0`P3o0`3o0><40?l0Q>d0o`00103o0<T3001Ko`@00:Wo1000eol4003om0L00?nh
3000og4;003o6PH0oooo0@0000010?ooo`007@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`D0
oooo00<000000?ooo`3oool01@3oool40?l000<00?nh1000og4;003om0@00=Oo1000ZOl40020o`<0
o`391000P?l4002Yo`P0083o0`006_l8001Ko`@0083o0`00>_l4000Jo`@0C@3o10320?l30?l0h`@0
o`24k@3o00040?l0b@<005_o1000ZOl4003Go`@00?od1`00okP<003oL@/00?lJ1P3oool100000040
oooo000M0?ooo`050?oo_`1d000000000000B02Lgol01P3oool00`000000oooo0?ooo`050?ooo`@0
o`002`00og4;003o^0P00?od0`00Fol8003om0P00=Oo0`00P?l<003Go`<00:Wo1000P?l4000jo`@0
05_o0`010?l406<0o`@0o`1_l03o0004001Ko`@00=Oo1000oo@7003o^0`00?ma2`00oaX60?ooo`40
00000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000/00?ma2`00okP8003om0<005_o
2000oo@8003Go`<0083o3000eol3002Yo`@0083o1000>_l4001Ko`<00@3o101S0?l40?l0Ko00o`00
1000Fol4003Go`@00?od1`00okP<003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003o
ool0oooo00D0oooo103o000;003oL@/00?nh2000oo@3001Ko`P00?od2000eol30020o``00=Oo0`00
ZOl40020o`@003[o1000Fol30040o`@0H`3o103o06o`0?l000@005_o1000eol4003om0L00?nh3000
og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`000`00oaX?
003oL@P00?nh1000oo@3003Go`P00?od3`00okP?003om0P00:Wo0`00Fol4000Jo`@0S03o2`3o0004
0><0on40o`00102a0?l40020o`@00?od1`00okP<003oL@/00?lJ1P3oool100000040oooo000X0?oo
o`030000003oool0oooo00D0oooo103o0003003o6Pl00?ma2000okP4003om0<00=Oo2000oo@?003o
^0l00?od2000ZOl3001Ko`@001[o102<0?l;0?l000@0h`3oh@3o00040;40o`@0083o1000oo@7003o
^0`00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000<0
0?lJ3`00og48003o^0@00?od0`00eol8003om0l00?nh3`00oo@8002Yo`<005_o10006_l408`0o`/0
o`00103S0?oQ0?l000@0/@3o1000P?l4003om0L00?nh3000og4;003o6PH0oooo0@0000010?ooo`00
:03oool00`000000oooo0?ooo`050?ooo`@0o`000`00oaX?003oL@P00?nh1000oo@3003Go`P00?od
3`00okP?003om0P00:Wo0`00Fol4000Jo`@0S03o2`3o00040><0on40o`00102a0?l40020o`@00?od
1`00okP<003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o
000;003o6P@00?ma4P00oaX4003oLAL00?nh3`00oo@4002Yo`<0083o1000>_l40?l0V@@0C@3o0`3o
0;0409l0o`@0N03oi@3o00040040o`@00=Oo0`00oo@4003o^0`00?ma2`00oaX60?ooo`4000000@3o
ool002P0oooo00<000000?ooo`3oool01@3oool40?l000/00?lJ1000og4B003o6P@00?ma5`00okP?
003om0@00:Wo0`00P?l4000jo`@0o`2I101=0?l30?l0/0@0W`3o101h0?oU0?l000@00@3o1000eol3
003om0@00?nh3000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oo
o`@0o`002`00oaX4003oLA800?lJ1000og4G003o^0l00?od1000ZOl30020o`@003[o103o09T404d0
o`<0o`2`102O0?l407P0onD0o`0010010?l4003Go`<00?od1000okP<003oL@/00?lJ1P3oool10000
0040oooo000X0?ooo`<000001@3oool40?l002D00?lJ1000og4J003o^0P00?od1000eol30020o`@0
N03o2000>_l30040o`@001[o100e0?m40?l000<0o`2>XP3o0004001Ko`<00?od1000okP<003oL@/0
0?lJ1@3oool200000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000U003o6P@00?ma
6P00okP8003om0@00=Oo0`00P?l407P0o`P003[o0`010?l4000Jo`@0=@3oA03o00030?l0SZ80o`00
1000Fol3003om0@00?nh3000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?oo
o`050?ooo`@0o`009@00oaX4003oLAX00?nh2000oo@4003Go`<0083o101h0?l8000jo`<00@3o1000
6_l403D0od@0o`000`3o08jR0?l000@005_o0`00oo@4003o^0`00?ma2`00oaX60?ooo`4000000@3o
ool002P0oooo00<000000?ooo`3oool01@3oool40?l002D00?lJ1000og4J003o^0P00?od1000eol3
0020o`@0N03o2000>_l30040o`@001[o100e0?m40?l000<0o`2>XP3o0004001Ko`<00?od1000okP<
003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000305Co
02H00?lJ2`00og4C003o^0@00?od1000eol3001Ko`@003[o1000P?l4002Yo`<0083o1000Fol40040
o`@0S03o@03o00030;40oj80o`00103o0?03002Yo`@00?nh3000og4;003o6PH0oooo0@0000010?oo
o`00:03oool00`000000oooo0?ooo`050?ooo`@0o`000`1Do`0V003o6P/00?ma4`00okP4003om0@0
0=Oo0`00Fol4000jo`@0083o1000ZOl30020o`@005_o10010?l408`0od00o`000`2a0?nR0?l000@0
o`3`0`00ZOl4003o^0`00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3oool40?l000<0E?l09P00oaX;003oLA<00?nh1000oo@4003Go`<005_o1000>_l40020o`@00:Wo
0`00P?l4001Ko`@00@3o102<0?m00?l000<0/@3oXP3o00040?l0l0<00:Wo1000okP<003oL@/00?lJ
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000305Co02X00?lJ6P00
og44003o^0@00?od0`006_l8003Go`L00:Wo1000Fol4000Jo`@0o`10?03o00040?l0D`<0N03o103o
02NR0?l000<0=@3o1000oo@4003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<00000
0?ooo`3oool01@3oool40?l000<0E?l0:P00oaXJ003oL@@00?nh1000oo@3000Jo`P00=Oo1`00ZOl4
001Ko`@001[o103o040l0?l000@0o`1C0`1h0?l40?l09j80o`000`0e0?l4003om0@00?nh2000og4;
003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`000`1Do`0Z003o
6QX00?ma1000okP4003om0<001[o2000eol7002Yo`@005_o10006_l40?l0@3`0o`00103o05<307P0
o`@0o`0WXP3o000303D0o`@00?od1000okP8003oL@/00?lJ1P3oool100000040oooo000X0?ooo`03
0000003oool0oooo00D0oooo103o000305Co02X00?lJ6P00og44003o^0@00?od0`006_l8003Go`L0
0:Wo1000Fol4000Jo`@0o`10?03o00040?l0D`<0N03o103o02NR0?l000<0=@3o1000oo@4003o^0P0
0?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000L0E?l0
:P00oaXN003oL@<00?nh1000oo@;003Go`@0083o101h0?l403D0o`<0W`3o>@3o000404d0o`<0=@3o
XP3o00040?l0SP<0083o1000oo@4003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool40?l000L0E?l0:P00oaXN003oL@<00?nh1000oo@;003Go`@0083o101h
0?l403D0o`<0W`3o>@3o000404d0o`<0=@3oXP3o00040?l0SP<0083o1000oo@4003o^0P00?ma2`00
oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000L0E?l0:P00oaXN
003oL@<00?nh1000oo@;003Go`@0083o101h0?l403D0o`<0W`3o>@3o000404d0o`<0=@3oXP3o0004
0?l0SP<0083o1000oo@4003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?oo
o`3oool01@3oool40?l000L0E?l0;@00oaXN003oL@@00?nh2`00oo@4002Yo`@0083o1000Fol3000J
o`@0H`3o103o0><]0?l000@0`P3o1`010?nV0?l000<0lP3o1000>_l4003o^0P00?ma2`00oaX60?oo
o`4000000@3oool002P0oooo0`0000050?ooo`@0o`001`1Do`0]003o6Qh00?ma1000okP;003om0@0
0:Wo1000P?l4001Ko`<001[o101S0?l40?l0hbd0o`0010320?l70040ojH0o`000`3b0?l4000jo`@0
0?nh2000og4;003o6PD0oooo0P0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`00
1`1Do`0]003o6Qh00?ma1000okP;003om0@00:Wo1000P?l4001Ko`<001[o101S0?l40?l0hbd0o`00
10320?l70040ojH0o`000`3b0?l4000jo`@00?nh2000og4;003o6PH0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?ooo`@0o`002`1Do`0Y003o6Qh00?ma1000okP;003om0@00=Oo1000
ZOl40020o`<00@3o101h0?l80?l000<0o`0?8P3o00040?l0b@/001[o101=0?nR0?l000<0=@3o103o
0004003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool4
0?l000/0E?l0:@00oaXN003oL@@00?nh2`00oo@4003Go`@00:Wo1000P?l30040o`@0N03o203o0003
0?l03b80o`00103o0<T;000Jo`@0C@3oXP3o000303D0o`@0o`001000okP8003oL@/00?lJ1P3oool1
00000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o000;05Co02T00?lJ7P00og44003o
^0/00?od1000eol4002Yo`@0083o0`010?l407P0o`P0o`000`3o00lR0?l000@0o`392`006_l404d0
oj80o`000`0e0?l40?l000@00?nh2000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000
oooo0?ooo`050?ooo`@0o`002`1Do`0Y003o6Qh00?ma1000okP;003om0@00=Oo1000ZOl40020o`<0
0@3o101h0?l80?l000<0o`0?8P3o00040?l0b@/001[o101=0?nR0?l000<0=@3o103o0004003o^0P0
0?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000<0l_l0
301Do`0Y003o6Qh00?ma1000okP;003om0P00:Wo0`006_l40?80o`P0o`000`3o0<T40><0o`@0o`00
103o03P30?l000@0o`1_103o02L40?l000@0W`3o0`3o0=D4000jo`P005_o0`00>_l40040o`@0o`3n
VP3o000403D0o`<005_o1000ZOl8003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool40?l000<0l_l0301Do`0Y003o6Qh00?ma1000okP;003om0P00:Wo0`00
6_l40?80o`P0o`000`3o0<T40><0o`@0o`00103o03P30?l000@0o`1_103o02L40?l000@0W`3o0`3o
0=D4000jo`P005_o0`00>_l40040o`@0o`3nVP3o000403D0o`<005_o1000ZOl8003o^0@00?ma2`00
oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool40?l000<0l_l0301Do`0Y
003o6Qh00?ma1000okP;003om0P00:Wo0`006_l40?80o`P0o`000`3o0<T40><0o`@0o`00103o03P3
0?l000@0o`1_103o02L40?l000@0W`3o0`3o0=D4000jo`P005_o0`00>_l40040o`@0o`3nVP3o0004
03D0o`<005_o1000ZOl8003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?oo
o`3oool01@3oool40?l000<0l_l03`1Do`0Z003o6QX00?ma2000okP7003om0@00:Wo1000P?l3001K
o`@0=@3o103o05`40?80o`<0N03o101=0?l401`0o`@0o`3n1`3o000403D0o`@0`P3o10010?l3000j
o``0083o0`00Fol40040oih0o`00101h0?l30020o`@00=Oo2000okP4003oL@/00?lJ1P3oool10000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo103o00030?;o00l0E?l0:P00oaXJ003oL@P0
0?nh1`00oo@4002Yo`@0083o0`00Fol403D0o`@0o`1L103b0?l307P0o`@0C@3o100L0?l40?l0oPL0
o`00100e0?l40<80o`@00@3o0`00>_l<0020o`<005_o10010?nN0?l000@0N03o0`00P?l4003Go`P0
0?nh1000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`@0o`00
0`3bo`0?05Co02X00?lJ6P00og48003o^0L00?od1000ZOl40020o`<005_o100e0?l40?l0G0@0lP3o
0`1h0?l404d0o`@0703o103o0?h70?l000@0=@3o10320?l40040o`<003[o3000P?l3001Ko`@00@3o
WP3o000407P0o`<0083o1000eol8003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool40?l000<0l_l03`1Do`0Z003o6QX00?ma2000okP7003om0@00:Wo1000
P?l3001Ko`@0=@3o103o05`40?80o`<0N03o101=0?l401`0o`@0o`3n1`3o000403D0o`@0`P3o1001
0?l3000jo``0083o0`00Fol40040oih0o`00101h0?l30020o`@00=Oo2000okP4003oL@/00?lJ1P3o
ool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo103o00030?;o01<0E?l0:P00oaXF
003oL@P00?nh0`00oo@4003Go`@00:Wo1000Fol3000Jo`@0o`00103S0?l40040o`<001[o1000Fol4
000Jo`@0703o0`3o000403D0o`@001[o101=0?l4001Ko`/00:Wo1`00P?l4000joih0o`00103o0=D3
000jo`@00=Oo1000oo@4003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo0`0000050?oo
o`@0o`000`3bo`0C05Co02X00?lJ5P00og48003o^0<00?od1000eol4002Yo`@005_o0`006_l40?l0
00@0h`3o10010?l3000Jo`@005_o10006_l401`0o`<0o`00100e0?l4000Jo`@0C@3o1000Fol;002Y
o`L0083o1000>_nN0?l000@0o`3E0`00>_l4003Go`@00?od1000okP4003oL@/00?lJ1@3oool20000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo103o00030?;o01<0E?l0:P00oaXF003oL@P0
0?nh0`00oo@4003Go`@00:Wo1000Fol3000Jo`@0o`00103S0?l40040o`<001[o1000Fol4000Jo`@0
703o0`3o000403D0o`@001[o101=0?l4001Ko`/00:Wo1`00P?l4000joih0o`00103o0=D3000jo`@0
0=Oo1000oo@4003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3oool70?l001/0E?l09@00oaXC003oL@/00?nh1000eol4001Ko`@0W`3o0`1=0?l4000jo`@00@3o
1000Fol3002Yo`@0083o1000>_l40<80o`<001[o2000P?l4001Koa<00:Wo0`00P?l4001Ko`@0703o
WP3o00030?l0b@@0=@3o1000oo@4003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool70?l001/0E?l09@00oaXC003oL@/00?nh1000eol4001Ko`@0W`3o0`1=
0?l4000jo`@00@3o1000Fol3002Yo`@0083o1000>_l40<80o`<001[o2000P?l4001Koa<00:Wo0`00
P?l4001Ko`@0703oWP3o00030?l0b@@0=@3o1000oo@4003o^0@00?ma2`00oaX60?ooo`4000000@3o
ool002P0oooo00<000000?ooo`3oool01@3oool70?l001/0E?l09@00oaXC003oL@/00?nh1000eol4
001Ko`@0W`3o0`1=0?l4000jo`@00@3o1000Fol3002Yo`@0083o1000>_l40<80o`<001[o2000P?l4
001Koa<00:Wo0`00P?l4001Ko`@0703oWP3o00030?l0b@@0=@3o1000oo@4003o^0@00?ma2`00oaX6
0?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool70?l001/0E?l09@00oaXC003o
L@/00?nh1000eol4001Ko`@0W`3o0`1=0?l4000jo`@00@3o1000Fol3002Yo`@0083o1000>_l40<80
o`<001[o2000P?l4001Koa<00:Wo0`00P?l4001Ko`@0703oWP3o00030?l0b@@0=@3o1000oo@4003o
^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool70?l00280
E?l08P00oaXC003oL@L00?nh1000>_l401`0o`@005_o2`00ZOl7003Go`@00:Wo1000Fol401`0o`<0
083o1000ZOl8003Go`@00?od3`00eol3002Yo`@005_o103o06D40?l000<0o`1iU`3o00030?l0Q0@0
N03o10010?l4003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3oool70?l00280E?l08P00oaXC003oL@L00?nh1000>_l401`0o`@005_o2`00ZOl7003Go`@00:Wo
1000Fol401`0o`<0083o1000ZOl8003Go`@00?od3`00eol3002Yo`@005_o103o06D40?l000<0o`1i
U`3o00030?l0Q0@0N03o10010?l4003o^0@00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool70?l00280E?l08P00oaXC003oL@L00?nh1000>_l401`0o`@005_o2`00
ZOl7003Go`@00:Wo1000Fol401`0o`<0083o1000ZOl8003Go`@00?od3`00eol3002Yo`@005_o103o
06D40?l000<0o`1iU`3o00030?l0Q0@0N03o10010?l4003o^0@00?ma2`00oaX60?ooo`4000000@3o
ool002P0oooo00<000000?ooo`3oool01@3oool70?l000@0l_l09P1Do`0R003o6P/00?ma1`00okP4
003Go`@001[o1000P?l7003Go`/00?od2000eol401`0o`L00=Oo4`00oo@;003Go`@00:Wo1000>_l4
08`0oi80o`00100e0?l40=<0o`<003[o103o0004003Go`@00?nh1000og4;003o6PH0oooo0@000001
0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0V05Co02800?lJ2`00og47003o
^0@00=Oo10006_l40020o`L00=Oo2`00oo@8003Go`@0703o1`00eolC003om0/00=Oo1000ZOl4000j
o`@0S03oTP3o000403D0o`@0d`3o0`00>_l40?l000@00=Oo1000okP4003oL@/00?lJ1P3oool10000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o00040?;o02H0E?l08P00oaX;003oL@L0
0?nh1000eol4000Jo`@0083o1`00eol;003om0P00=Oo100L0?l7003Goa<00?od2`00eol4002Yo`@0
03[o102<0?nB0?l000@0=@3o103C0?l3000jo`@0o`001000eol4003o^0@00?ma2`00oaX60?ooo`40
00000@3oool002P0oooo00<000000?ooo`3oool01@3oool70?l000@0l_l09P1Do`0R003o6P/00?ma
1`00okP4003Go`@001[o1000P?l7003Go`/00?od2000eol401`0o`L00=Oo4`00oo@;003Go`@00:Wo
1000>_l408`0oi80o`00100e0?l40=<0o`<003[o103o0004003Go`@00?nh1000og4;003o6PH0oooo
0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0a05Co01X00?lJ2000
og47003o^0@00=Oo1000>_l40020od000?od1`00eol40020o`@003[o0`0e0?l40?l0eHL0o`00103o
0><4000jo`@0083o0`00ZOl4001Ko`@00?od2000og4;003o6PH0oooo0@0000010?ooo`00:03oool0
0`000000oooo0?ooo`050?ooo`L0o`00103bo`0a05Co01X00?lJ2000og47003o^0@00=Oo1000>_l4
0020od000?od1`00eol40020o`@003[o0`0e0?l40?l0eHL0o`00103o0><4000jo`@0083o0`00ZOl4
001Ko`@00?od2000og4;003o6PH0oooo0@0000010?ooo`00:03oool3000000D0oooo1`3o00040?;o
0340E?l06P00oaX8003oL@L00?nh1000eol4000jo`@0083o@000oo@7003Go`@0083o1000>_l303D0
o`@0o`3EQ`3o00040?l0h`@003[o1000P?l3002Yo`@005_o1000oo@8003oL@/00?lJ1@3oool20000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o00040?;o03`0E?l04`00oaX8003oL@<0
0?nh1000ZOl4003Go`@00?od<@00okP?003om0L00=Oo1000ZOl4000Jo`<0d`3oS`3o0004000Jo`L0
0=Oo1000oo@4003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3oool70?l000@0l_l0?01Do`0C003o6PP00?ma0`00okP4002Yo`@00=Oo1000oo@a003o^0l00?od
1`00eol4002Yo`@001[o0`3C0?n?0?l000@001[o1`00eol4003om0@00?nh2000og4;003o6PH0oooo
0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`L0o`00103bo`0l05Co01<00?lJ2000
og43003o^0@00:Wo1000eol4003om3400?nh3`00oo@7003Go`@00:Wo10006_l30=<0ohl0o`001000
6_l7003Go`@00?od1000okP8003oL@/00?lJ1P3oool100000040oooo000X0?ooo`030000003oool0
oooo00D0oooo1`3o00080?;o0400E?l04`00oaX3003oLA/00?nh5P00og4G003o^0L00?od1000eol4
002Yo`@0o`390`3o00040?l0BHL0o`0010006_l40020o`@00=Oo0`00oo@8003o^0P00?ma2`00oaX6
0?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool70?l000P0l_l0@01Do`0C003o
6P<00?ma6`00okPF003oLAL00?nh1`00oo@4003Go`@00:Wo103o0<T30?l000@0o`19Q`3o0004000J
o`@0083o1000eol3003om0P00?nh2000og4;003o6PH0oooo0@0000010?ooo`00:03oool00`000000
oooo0?ooo`050?ooo`L0o`00203bo`1005Co01<00?lJ0`00og4K003o^1H00?ma5`00okP7003om0@0
0=Oo1000ZOl40?l0b@<0o`00103o04V70?l000@001[o1000P?l4003Go`<00?od2000okP8003oL@/0
0?lJ1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo1`3o00080?;o0400E?l0
4`00oaX3003oLA/00?nh5P00og4G003o^0L00?od1000eol4002Yo`@0o`390`3o00040?l0BHL0o`00
10006_l40020o`@00=Oo0`00oo@8003o^0P00?ma2`00oaX60?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3oool;0?l000@0l_l0B`1Do`0?003o6SD00?ma4`00okP7003om0@003[o1001
0?l30<80o`@0C@3o100L0?l40?l0hgP0o`00103o0=D301`0o`@005_o1000ZOl7003om0@00?nh3000
og47003o6P@0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo2`3o0004
0?;o04/0E?l03`00oaXe003oLA<00?nh1`00oo@4000jo`@00@3o0`320?l404d0o`@0703o103o0>=h
0?l000@0o`3E0`0L0?l4001Ko`@00:Wo1`00oo@4003o^0`00?ma1`00oaX405Co00H0oooo0@000001
0?ooo`002`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool0
1@2oM0000000000000000000M;oo00H0oooo00<000000?ooo`3oool01@3oool;0?l000@0l_l0B`1D
o`0?003o6SD00?ma4`00okP7003om0@003[o10010?l30<80o`@0C@3o100L0?l40?l0hgP0o`00103o
0=D301`0o`@005_o1000ZOl7003om0@00?nh3000og47003o6P@0E?l01P3oool100000040oooo000;
0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`070;md
0000M;l0oooo0?ooo`3ogi`0B00007Boo`050?ooo`030000003oool0oooo00D0oooo2`3o00080?;o
04l0E?l03`00oaXa003oLA800?nh2000oo@4002Yo`<003[o10010?l4000jo`@0o`3S0`2<0?ml0?l0
00@0703o1000P?l4003om0L00?nh2000og4;003o6P@0E?l01P3oool100000040oooo000:0?ooo`03
0?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03`3oool00`3o_g@007Bo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo2`3o00080?;o04l0E?l03`00oaXa003oLA800?nh2000oo@4002Yo`<0
03[o10010?l4000jo`@0o`3S0`2<0?ml0?l000@0703o1000P?l4003om0L00?nh2000og4;003o6P@0
E?l01P3oool100000040oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
3`3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo00D0oooo2`3o00080?;o04l0E?l0
3`00oaXa003oLA800?nh2000oo@4002Yo`<003[o10010?l4000jo`@0o`3S0`2<0?ml0?l000@0703o
1000P?l4003om0L00?nh2000og4;003o6P@0E?l01P3oool100000040oooo000:0?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`2LB000M;oo0?ooo`040?ooo`@00000103o
ool;0?l000P0l_l0C`1Do`0?003o6S400?ma4P00okP8003om0@00:Wo0`00>_l40040o`@003[o103o
0><308`0og`0o`00100L0?l40020o`@00?od1`00okP8003oL@/00?lJ101Do`040?ooo`<000000@3o
ool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1d0000
00000080000000<0B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`/0o`00203bo`1B
05Co01<00?lJ<@00og4?003o^0@00?od1`00eol4002Yo`@0083o1000>_l303D0o`@0lP3o103o00mU
0?l000@0o`1C2`3o00040?l0l0@0`P3o1000eol7003o^0P00?ma2`00oaX405Co00H0oooo0@000001
0?ooo`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0
M02oool02@3oool00`000000oooo0?ooo`050?ooo`/0o`00203bo`1B05Co01<00?lJ<@00og4?003o
^0@00?od1`00eol4002Yo`@0083o1000>_l303D0o`@0lP3o103o00mU0?l000@0o`1C2`3o00040?l0
l0@0`P3o1000eol7003o^0P00?ma2`00oaX405Co00H0oooo0@0000010?ooo`002`3oool01P2LB000
M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0M02oool02@3oool00`000000oooo0?ooo`05
0?ooo`/0o`00203bo`1B05Co01<00?lJ<@00og4?003o^0@00?od1`00eol4002Yo`@0083o1000>_l3
03D0o`@0lP3o103o00mU0?l000@0o`1C2`3o00040?l0l0@0`P3o1000eol7003o^0P00?ma2`00oaX4
05Co00H0oooo0@0000010?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0oono
07@0000000000P0000000`0007@0_ooo0?ooo`040?ooo`030000003oool0oooo00D0oooo2`3o0008
0?;o05X0E?l04`00oaX]003oL@l00?nh1000oo@7003Go`@0083o10010?l30<80ofd0o`00103o0:D;
0?l000@0W`3o1000Fol4002Yo`<00?od1000okP8003oL@L00?lJ201Do`060?ooo`4000000@3oool0
02P0oooo00<000000?ooo`3oool01@3oool;0?l000P0l_l0FP1Do`0C003o6Rd00?ma3`00okP4003o
m0L00=Oo1000P?l40040o`<0`P3oK@3o00040?l0Y@/0o`00102O0?l4001Ko`@00:Wo0`00oo@4003o
^0P00?ma1`00oaX805Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`/0
o`00203bo`1J05Co01<00?lJ;@00og4?003o^0@00?od1`00eol40020o`@00@3o0`320?m]0?l000@0
o`2U2`3o000409l0o`@005_o1000ZOl3003om0@00?nh2000og47003o6PP0E?l01P3oool100000040
oooo000X0?ooo`030000003oool0oooo00D0oooo2`3o00080?;o05X0E?l04`00oaX]003oL@l00?nh
1000oo@7003Go`@0083o10010?l30<80ofd0o`00103o0:D;0?l000@0W`3o1000Fol4002Yo`<00?od
1000okP8003oL@L00?lJ201Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3o
ool?0?l000L0l_l0F`1Do`0F003o6RX00?ma2`00okP7003om0@00=Oo1000ZOl401`0o`<0o`3n303o
00030=<0oe/0o`000`0e0?l404d0o`P0o`000`3o03P40?l000@0703o103o07T3003om0@00?nh2000
og47003o6PP0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo3`3o0007
0?;o05/0E?l05P00oaXZ003oL@/00?nh1`00oo@4003Go`@00:Wo100L0?l30?l0oP`0o`000`3C0?mK
0?l000<0=@3o101=0?l80?l000<0o`0h103o000401`0o`@0o`1i0`00oo@4003o^0P00?ma1`00oaX8
05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`l0o`001`3bo`1K05Co
01H00?lJ:P00og4;003o^0L00?od1000eol4002Yo`@0703o0`3o0?h<0?l000<0d`3oF`3o000303D0
o`@0C@3o203o00030?l0>0@0o`00100L0?l40?l0N@<00?od1000okP8003oL@L00?lJ201Do`060?oo
o`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool?0?l000L0l_l0HP1Do`0G003o6R80
0?ma3`00okP3003om0@00=Oo1000P?l4000Jo`<0o`3`303o000304d0o`@0o`00103o0<U;0?l000@0
o`0O103o06D7000jo`@0C@3o102a0?l304d0o`@0=@3o103o0?h4000Jo`<00=Oo2000og4;003o6PP0
E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo3`3o00070?;o0680E?l0
5`00oaXR003oL@l00?nh0`00oo@4003Go`@0083o10006_l30?l0l0`0o`000`1=0?l40?l000@0o`39
B`3o00040?l07`@0o`1U1`00>_l404d0o`@0/@3o0`1=0?l403D0o`@0o`3n10006_l3003Go`P00?ma
2`00oaX805Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`l0o`001`3b
o`1R05Co01L00?lJ8P00og4?003o^0<00?od1000eol40020o`@001[o0`3o0?0<0?l000<0C@3o103o
00040?l0bD/0o`00103o01l40?l0I@L003[o101=0?l40;40o`<0C@3o100e0?l40?l0oP@001[o0`00
eol8003oL@/00?lJ201Do`060?ooo`4000000@3oool002P0oooo0`0000050?ooo`l0o`001`3bo`1R
05Co01L00?lJ8P00og4?003o^0<00?od1000eol40020o`@001[o0`3o0?0<0?l000<0C@3o103o0004
0?l0bD/0o`00103o01l40?l0I@L003[o101=0?l40;40o`<0C@3o100e0?l40?l0oP@001[o0`00eol8
003oL@/00?lJ201Do`050?ooo`8000000@3oool002P0oooo00<000000?ooo`3oool01@3oool?0?l0
00/0l_l0HP1Do`0N003o6QX00?ma3000okP3003om0@00=Oo103b0?l406<0o`<0o`2U103o00040;40
o`@0o`001`006_l404d0odl0o`001000Fol70020o`@0d`3o10010?l3001Ko`@003[o103o08@40020
o`<0W`3o2000og48003o6P/0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0
oooo3`3o000;0?;o0680E?l07P00oaXJ003oL@`00?nh0`00oo@4003Go`@0lP3o101S0?l30?l0Y@@0
o`00102a0?l40?l000L001[o101=0?m?0?l000@005_o1`00P?l40=<0o`@00@3o0`00Fol4000jo`@0
o`241000P?l309l0o`P00?ma2000oaX;05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo
0?ooo`050?ooo`l0o`002`3bo`1R05Co01h00?lJ6P00og4<003o^0<00?od1000eol40?80o`@0H`3o
0`3o0:D40?l000@0/@3o103o0007000Jo`@0C@3oC`3o0004001Ko`L0083o103C0?l40040o`<005_o
1000>_l40?l0Q0@0083o0`2O0?l8003oL@P00?lJ2`1Do`060?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3ooolC0?l000/0l_l0HP1Do`0R003o6QH00?ma2000okP3003om0@00=Oo1000
Fol404d0o`<0o`3`100e0?l40040o`@0C@3o1`00Fol40=<0o`@0o`000`3o00l408`0obd0o`00103o
08h80?l000<0C@3o103o04T40?l000@0083o0`00ZOl<003Go`<00:Wo1000>_l40?l0l0@00=Oo0`00
okP4003oL@`00?lJ2`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC
0?l000/0l_l0HP1Do`0R003o6QH00?ma2000okP3003om0@00=Oo1000Fol404d0o`<0o`3`100e0?l4
0040o`@0C@3o1`00Fol40=<0o`@0o`000`3o00l408`0obd0o`00103o08h80?l000<0C@3o103o04T4
0?l000@0083o0`00ZOl<003Go`<00:Wo1000>_l40?l0l0@00=Oo0`00okP4003oL@`00?lJ2`1Do`06
0?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC0?l000/0l_l0HP1Do`0R003o
6QH00?ma2000okP3003om0@00=Oo1000Fol404d0o`<0o`3`100e0?l40040o`@0C@3o1`00Fol40=<0
o`@0o`000`3o00l408`0obd0o`00103o08h80?l000<0C@3o103o04T40?l000@0083o0`00ZOl<003G
o`<00:Wo1000>_l40?l0l0@00=Oo0`00okP4003oL@`00?lJ2`1Do`060?ooo`4000000@3oool002P0
oooo00<000000?ooo`3oool01@3ooolC0?l000/0l_l0HP1Do`0R003o6QH00?ma2000okP3003om0@0
0=Oo1000Fol404d0o`<0o`3`100e0?l40040o`@0C@3o1`00Fol40=<0o`@0o`000`3o00l408`0obd0
o`00103o08h80?l000<0C@3o103o04T40?l000@0083o0`00ZOl<003Go`<00:Wo1000>_l40?l0l0@0
0=Oo0`00okP4003oL@`00?lJ2`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3ooolC0?l000/0l_l0I@1Do`0V003o6Q<00?ma1`00okP4003Go`@0o`0h10006_l301`0o`@0o`00
1000Fol7002Yo`@0083o10006_l40?l000<0703o10006_l40?l0l0@0703o100e0?l307P0oa<0o`00
103o0><406<0o`<0703o10010?l407P0o`L005_o100e0?l40040o`L00=Oo3`00oo@4002Yo`@0N03o
1000oo@3003o^0@00?ma2000oaX?05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?oo
o`050?oooa<0o`002`3bo`1U05Co02H00?lJ4`00og47003o^0@00=Oo103o03P4000Jo`<0703o103o
0004001Ko`L00:Wo1000P?l4000Jo`@0o`000`0L0?l4000Jo`@0o`3`100L0?l403D0o`<0N03o4`3o
00040?l0h`@0H`3o0`0L0?l40040o`@0N03o1`00Fol403D0o`@00@3o1`00eol?003om0@00:Wo101h
0?l4003om0<00?nh1000og48003o6Pl0E?l01P3oool100000040oooo000X0?ooo`030000003oool0
oooo00D0oooo4`3o000;0?;o06D0E?l09P00oaXC003oL@L00?nh1000eol40?l0>0@001[o0`0L0?l4
0?l000@005_o1`00ZOl40020o`@001[o103o000301`0o`@001[o103o0?0401`0o`@0=@3o0`1h0?lC
0?l000@0o`3S101S0?l301`0o`@00@3o101h0?l7001Ko`@0=@3o10010?l7003Go`l00?od1000ZOl4
07P0o`@00?od0`00okP4003oL@P00?lJ3`1Do`060?ooo`4000000@3oool002P0oooo00<000000?oo
o`3oool01@3ooolC0?l000l0l_l0I@1Do`0Z003o6Pl00?ma0`00okP4003Go`@005_o1000eol3002Y
o`@0=@3o1000Fol;003Go`@00:Wo2`00P?l4001Ko`@003[o10010?l30?l0bAL0o`00103o0?03000J
o`@005_o1000P?l7002Yo`@00@3o1000eol7003om0`00?nh0`00oo@4003Go`@0083o1000okP3003o
L@`00?lJ3`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC0?l000l0
l_l0I@1Do`0Z003o6Pl00?ma0`00okP4003Go`@005_o1000eol3002Yo`@0=@3o1000Fol;003Go`@0
0:Wo2`00P?l4001Ko`@003[o10010?l30?l0bAL0o`00103o0?03000Jo`@005_o1000P?l7002Yo`@0
0@3o1000eol7003om0`00?nh0`00oo@4003Go`@0083o1000okP3003oL@`00?lJ3`1Do`060?ooo`40
00000@3oool002P0oooo00<000000?ooo`3oool01@3ooolC0?l000l0l_l0I@1Do`0Z003o6Pl00?ma
0`00okP4003Go`@005_o1000eol3002Yo`@0=@3o1000Fol;003Go`@00:Wo2`00P?l4001Ko`@003[o
10010?l30?l0bAL0o`00103o0?03000Jo`@005_o1000P?l7002Yo`@00@3o1000eol7003om0`00?nh
0`00oo@4003Go`@0083o1000okP3003oL@`00?lJ3`1Do`060?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3ooolF0?l000`0l_l0J@1Do`0]003o6P/00?ma1000okPR003om0@00=Oo1`00
ZOl40020o`@005_o102O0?lN0?l000<0/@3o1000P?l4002Yo`L00=Oo2000oo@N003o^0@00?ma2`00
oaXC05Co00H0oooo0@0000010?ooo`00:03oool3000000D0oooo5P3o000<0?;o06T0E?l0;@00oaX;
003oL@@00?nh8P00oo@4003Go`L00:Wo1000P?l4001Ko`@0W`3o7P3o00030;40o`@0083o1000ZOl7
003Go`P00?od7P00okP4003oL@/00?lJ4`1Do`050?ooo`8000000@3oool002P0oooo00<000000?oo
o`3oool01@3ooolF0?l000`0l_l0J@1Do`0]003o6P/00?ma1000okPR003om0@00=Oo1`00ZOl40020
o`@005_o102O0?lN0?l000<0/@3o1000P?l4002Yo`L00=Oo2000oo@N003o^0@00?ma2`00oaXC05Co
00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaH0o`00303bo`1Y05Co02d0
0?lJ2`00og44003o^2800?od1000eol7002Yo`@0083o1000Fol409l0oah0o`000`2a0?l40020o`@0
0:Wo1`00eol8003om1h00?nh1000og4;003o6Q<0E?l01P3oool100000040oooo000X0?ooo`030000
003oool0oooo00D0oooo5P3o000?0?;o06X0E?l0<@00oaX;003oLA<00?nh3`00oo@7003Go`@00:Wo
1000>_l408`0oah0o`000`2a0?l40020o`P00=Oo1`00oo@C003o^0l00?ma3`00oaXC05Co00H0oooo
0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaH0o`003`3bo`1Z05Co03400?lJ2`00
og4C003o^0l00?od1`00eol4002Yo`@003[o102<0?lN0?l000<0/@3o1000P?l8003Go`L00?od4`00
okP?003oL@l00?lJ4`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolF
0?l000l0l_l0JP1Do`0a003o6P/00?ma4`00okP?003om0L00=Oo1000ZOl4000jo`@0S03o7P3o0003
0;40o`@0083o2000eol7003om1<00?nh3`00og4?003o6Q<0E?l01P3oool100000040oooo000X0?oo
o`030000003oool0oooo00D0oooo5P3o000C0?;o06T0E?l0<@00oaX<003oLAH00?nh2`00oo@4003G
o`@00:Wo101S0?l40=<0oah0o`000`1S0?l401`0o`@00=Oo1`00oo@<003o^1H00?ma3`00oaXG05Co
00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaH0o`004`3bo`1Y05Co0340
0?lJ3000og4F003o^0/00?od1000eol4002Yo`@0H`3o103C0?lN0?l000<0H`3o100L0?l4003Go`L0
0?od3000okPF003oL@l00?lJ5`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3ooolF0?l001<0l_l0J@1Do`0a003o6P`00?ma5P00okP;003om0@00=Oo1000ZOl406<0o`@0d`3o
7P3o000306<0o`@0703o1000eol7003om0`00?nh5P00og4?003o6QL0E?l01P3oool100000040oooo
000X0?ooo`030000003oool0oooo00D0oooo5P3o000C0?;o06T0E?l0<@00oaX<003oLAH00?nh2`00
oo@4003Go`@00:Wo101S0?l40=<0oah0o`000`1S0?l401`0o`@00=Oo1`00oo@<003o^1H00?ma3`00
oaXG05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaX0o`003`3bo`1a
05Co03400?lJ2`00og4C003o^0L00?od1000eol4002Yo`@005_o100e0?lN0?l000<0H`3o1000P?l4
003Go`@00?od1`00okPJ003oLA<00?lJ5`1Do`060?ooo`4000000@3oool002P0oooo00<000000?oo
o`3oool01@3ooolJ0?l000l0l_l0L@1Do`0a003o6P/00?ma4`00okP7003om0@00=Oo1000ZOl4001K
o`@0=@3o7P3o000306<0o`@0083o1000eol4003om0L00?nh6P00og4C003o6QL0E?l01P3oool10000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo6P3o000?0?;o0740E?l0<@00oaX;003oLA<0
0?nh1`00oo@4003Go`@00:Wo1000Fol403D0oah0o`000`1S0?l40020o`@00=Oo1000oo@7003o^1X0
0?ma4`00oaXG05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaX0o`00
4`3bo`1a05Co03400?lJ3`00og4?003o^0<00?od1000eol4002Yo`@005_o103o09TJ0?l000@0o`1_
0`3b0?l40?l0h`@00=Oo1000oo@3003o^1/00?ma4P00oaXK05Co00H0oooo0@0000010?ooo`00:03o
ool3000000D0oooo6P3o000C0?;o0740E?l0<@00oaX?003oL@l00?nh0`00oo@4003Go`@00:Wo1000
Fol40?l0VAX0o`00103o06l30?80o`@0o`3S1000eol4003om0<00?nh6`00og4B003o6Q/0E?l01@3o
ool200000040oooo000X0?ooo`030000003oool0oooo00D0oooo6P3o000C0?;o0740E?l0<@00oaX?
003oL@l00?nh0`00oo@4003Go`@00:Wo1000Fol40?l0VAX0o`00103o06l30?80o`@0o`3S1000eol4
003om0<00?nh6`00og4B003o6Q/0E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo6P3o000C0?;o0740E?l0<@00oaX?003oL@l00?nh0`00oo@4003Go`@00:Wo1000Fol40?l0
VAX0o`00103o06l30?80o`@0o`3S1000eol4003om0<00?nh6`00og4B003o6Q/0E?l01P3oool10000
0040oooo000X0?ooo`030000003oool0oooo00D0oooo6P3o000G0?;o0740E?l0<000oaXC003oL@/0
0?nh1000oo@4001Ko`@0=@3o103o00l30?l0h`@0o`3`3`3o00040<80o`@001[o0`320?l4001Ko`@0
0=Oo1000okPF003oLAX00?lJ6`1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3ooolJ0?l001L0l_l0L@1Do`0`003o6Q<00?ma2`00okP4003om0@005_o100e0?l40?l03`<0o`3S
103o0?0?0?l000@0`P3o10006_l30<80o`@005_o1000eol4003o^1H00?ma6P00oaXK05Co00H0oooo
0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooaX0o`005`3bo`1a05Co03000?lJ4`00
og4;003o^0@00?od1000Fol403D0o`@0o`0?0`3o0><40?l0l0l0o`0010320?l4000Jo`<0`P3o1000
Fol4003Go`@00?nh5P00og4J003o6Q/0E?l01P3oool100000040oooo000X0?ooo`030000003oool0
oooo00D0oooo7P3o000G0?;o0700E?l0<@00oaXG003oL@L00?nh1000ZOl4001Ko`@0C@3o0`006_l4
0040o`@0C@3o1`3o00040?l07`@00@3o1`00Fol404d0o`@00?od1000okPB003oLA/00?lJ7P1Do`06
0?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolN0?l001L0l_l0L01Do`0a003o
6QL00?ma1`00okP4002Yo`@005_o101=0?l3000Jo`@00@3o101=0?l70?l000@0o`0O10010?l7001K
o`@0C@3o1000oo@4003o^1800?ma6`00oaXN05Co00H0oooo0@0000010?ooo`00:03oool00`000000
oooo0?ooo`050?oooah0o`005`3bo`1`05Co03400?lJ5`00og47003o^0@00:Wo1000Fol404d0o`<0
01[o10010?l404d0o`L0o`00103o01l40040o`L005_o101=0?l4003om0@00?nh4P00og4K003o6Qh0
E?l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo7P3o000G0?;o0700E?l0
<@00oaXG003oL@L00?nh1000ZOl4001Ko`@0C@3o0`006_l40040o`@0C@3o1`3o00040?l07`@00@3o
1`00Fol404d0o`@00?od1000okPB003oLA/00?lJ7P1Do`060?ooo`4000000@3oool002P0oooo00<0
00000?ooo`3oool01@3ooolN0?l001X0l_l0L@1Do`0a003o6QH00?ma1000okP4003om0@00=Oo101S
0?l30020o`@005_o100e0?l40?l0b@<0o`00103o0?h407P0o`@00:Wo1`00eol4003o^1<00?ma6P00
oaXR05Co00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooah0o`006P3bo`1a
05Co03400?lJ5P00og44003o^0@00?od1000eol406<0o`<0083o1000Fol403D0o`@0o`390`3o0004
0?l0oP@0N03o1000ZOl7003Go`@00?nh4`00og4J003o6R80E?l01P3oool100000040oooo000X0?oo
o`030000003oool0oooo00D0oooo7P3o000J0?;o0740E?l0<@00oaXF003oL@@00?nh1000oo@4003G
o`@0H`3o0`00P?l4001Ko`@0=@3o103o0<T30?l000@0o`3n101h0?l4002Yo`L00=Oo1000okPC003o
LAX00?lJ8P1Do`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolR0?l001X0
l_l0L@1Do`0a003o6QH00?ma1000okP8003om0<00=Oo1000ZOl4000Jo`@0703o0`3o0;`40040o`@0
01[o1000eol7003om0@00?nh2`00og4R003o6Qh0E?l0103bo`060?ooo`4000000@3oool002P0oooo
00<000000?ooo`3oool01@3ooolR0?l001X0l_l0L@1Do`0a003o6QH00?ma1000okP8003om0<00=Oo
1000ZOl4000Jo`@0703o0`3o0;`40040o`@001[o1000eol7003om0@00?nh2`00og4R003o6Qh0E?l0
103bo`060?ooo`4000000@3oool002P0oooo0`0000050?ooob80o`006P3bo`1a05Co03400?lJ5P00
og44003o^0P00?od0`00eol4002Yo`@001[o100L0?l30?l0_0@00@3o10006_l4003Go`L00?od1000
okP;003oLB800?lJ7P1Do`040?;o00D0oooo0P0000010?ooo`00:03oool00`000000oooo0?ooo`05
0?ooob80o`006P3bo`1a05Co03400?lJ5P00og44003o^0P00?od0`00eol4002Yo`@001[o100L0?l3
0?l0_0@00@3o10006_l4003Go`L00?od1000okP;003oLB800?lJ7P1Do`040?;o00H0oooo0@000001
0?ooo`00:03oool00`000000oooo0?ooo`050?ooob80o`007P3bo`1a05Co03000?lJ4`00og48003o
^0@00?od1`00eol40020o`@005_o0`2<0?l4000Jo`@0083o1000eol3003om0P00?nh1`00og4R003o
6Qh0E?l0203bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolR0?l001h0
l_l0L@1Do`0`003o6Q<00?ma2000okP4003om0L00=Oo1000P?l4001Ko`<0S03o10006_l40020o`@0
0=Oo0`00oo@8003o^0L00?ma8P00oaXN05Co00P0l_l01P3oool100000040oooo000X0?ooo`030000
003oool0oooo00D0oooo8P3o000N0?;o0740E?l0<000oaXC003oL@P00?nh1000oo@7003Go`@0083o
1000Fol308`0o`@001[o1000P?l4003Go`<00?od2000okP7003oLB800?lJ7P1Do`080?;o00H0oooo
0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooobD0o`007`3bo`1`05Co03400?lJ4`00
og44003o^0L00?od1000eol4002Yo`@005_o0`2a0?l401`0o`@0083o1000ZOl3003om0P00?nh1000
og4Q003o6Ql0E?l02`3bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooolU
0?l001l0l_l0L01Do`0a003o6Q<00?ma1000okP7003om0@00=Oo1000ZOl4001Ko`<0/@3o100L0?l4
0020o`@00:Wo0`00oo@8003o^0@00?ma8@00oaXO05Co00/0l_l01P3oool100000040oooo000X0?oo
o`030000003oool0oooo00D0oooo9@3o000O0?;o0700E?l0<@00oaXC003oL@@00?nh1`00oo@4003G
o`@00:Wo1000Fol30;40o`@0703o1000P?l4002Yo`<00?od2000okP4003oLB400?lJ7`1Do`0;0?;o
00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooobD0o`008P3bo`1e05Co02d0
0?lJ3`00og48003o^0<00?od1000eol4002Yo`@0o`3E0`006_l4001Ko`@0=@3o1000>_l3003om0@0
0?nh2000og4N003o6Qh0E?l03`3bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0
1@3ooolU0?l00280l_l0M@1Do`0]003o6Pl00?ma2000okP3003om0@00=Oo1000ZOl40?l0e@<001[o
1000Fol403D0o`@003[o0`00oo@4003o^0P00?ma7P00oaXN05Co00l0l_l01P3oool100000040oooo
000X0?ooo`030000003oool0oooo00D0oooo9@3o000R0?;o07D0E?l0;@00oaX?003oL@P00?nh0`00
oo@4003Go`@00:Wo103o0=D3000Jo`@005_o100e0?l4000jo`<00?od1000okP8003oLAh00?lJ7P1D
o`0?0?;o00H0oooo0@0000010?ooo`00703oool00`3o_g@000000000000300000003001d_`3oool0
oooo00<0oooo00<000000?ooo`3oool01@3ooolU0?l00280l_l0M@1Do`0]003o6Pl00?ma2000okP3
003om0@00=Oo1000ZOl40?l0e@<001[o1000Fol403D0o`@003[o0`00oo@4003o^0P00?ma7P00oaXN
05Co00l0l_l01P3oool100000040oooo000O0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?oo
o`3oool01@3ooolY0?l00280l_l0M@1Do`0Y003o6Q<00?ma1000okP3003om0@00=Oo1000P?l40<80
o`/00:Wo1000P?l3001Ko`@00?nh1000og4N003o6Qh0E?l04`3bo`060?ooo`4000000@3oool001l0
oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`050?ooobT0o`008P3bo`1e05Co02T0
0?lJ4`00og44003o^0<00?od1000eol40020o`@0`P3o2`00ZOl40020o`<005_o1000okP4003oLAh0
0?lJ7P1Do`0C0?;o00H0oooo0@0000010?ooo`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`@00000
103ooolY0?l00280l_l0M@1Do`0Y003o6Q<00?ma1000okP3003om0@00=Oo1000P?l40<80o`/00:Wo
1000P?l3001Ko`@00?nh1000og4N003o6Qh0E?l04`3bo`040?ooo`<000000@3oool001l0oooo00<0
W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`050?ooobT0o`009P3bo`1d05Co02X00?lJ3`00
og47003o^0@00:Wo103o00040020o`<00=Oo3`00oo@4003oLAh00?lJ7P1Do`0G0?;o00H0oooo0@00
00010?ooo`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo00D0oooo:@3o000V
0?;o07@0E?l0:P00oaX?003oL@L00?nh1000ZOl40?l000@0083o0`00eol?003om0@00?ma7P00oaXN
05Co01L0l_l01P3oool100000040oooo000O0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?oo
o`3oool01@3ooolY0?l002H0l_l0M01Do`0Z003o6Pl00?ma1`00okP4002Yo`@0o`001000P?l3003G
o`l00?od1000og4N003o6Qh0E?l05`3bo`060?ooo`4000000@3oool001`0oooo00D0gia800000000
B9`0W4Q809cOo`070?ooo`030000003oool0oooo00D0oooo:@3o000V0?;o07@0E?l0:P00oaX?003o
L@L00?nh1000ZOl40?l000@0083o0`00eol?003om0@00?ma7P00oaXN05Co01L0l_l01P3oool10000
0040oooo000N0?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool01@3oool]0?l002T0
l_l0M@1Do`0U003o6P`00?ma1`00okP8001Ko`@00=Oo3`00okP3003oLAh00?lJ6`1Do`0N0?;o00H0
oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooobd0o`00:@3bo`1e05Co02D00?lJ
3000og47003o^0P005_o1000eol?003o^0<00?ma7P00oaXK05Co01h0l_l01P3oool100000040oooo
000X0?ooo`030000003oool0oooo00D0oooo;@3o000Y0?;o07D0E?l09@00oaX<003oL@L00?nh2000
Fol4003Go`l00?nh0`00og4N003o6Q/0E?l07P3bo`060?ooo`4000000@3oool002P0oooo00<00000
0?ooo`3oool01@3ooola0?l002T0l_l0N01Do`0R003o6PP00?ma1000okP3003om0P00:Wo1000oo@3
003o^0`00?ma6P00oaXN05Co0280l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo
00D0oooo<@3o000Y0?;o07P0E?l08P00oaX8003oL@@00?nh0`00oo@8002Yo`@00?od0`00okP<003o
LAX00?lJ7P1Do`0R0?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooc40
o`00:@3bo`1h05Co02800?lJ2000og44003o^0<00?od2000ZOl4003om0<00?nh3000og4J003o6Qh0
E?l08P3bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooola0?l002T0l_l0
N01Do`0R003o6PP00?ma1000okP3003om0P00:Wo1000oo@3003o^0`00?ma6P00oaXN05Co0280l_l0
1P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo<@3o000a0?;o07@0E?l08P00
oaX4003oL@@00?nh0`00eol4002Yo`@0C@3o1000okP;003oLAX00?lJ7P1Do`0V0?;o00H0oooo0@00
00010?ooo`00:03oool00`000000oooo0?ooo`050?oooc40o`00<@3bo`1d05Co02800?lJ1000og44
003o^0<00=Oo1000ZOl404d0o`@00?nh2`00og4J003o6Qh0E?l09P3bo`060?ooo`4000000@3oool0
02P0oooo0`0000050?oooc40o`00<@3bo`1d05Co02800?lJ1000og44003o^0<00=Oo1000ZOl404d0
o`@00?nh2`00og4J003o6Qh0E?l09P3bo`050?ooo`8000000@3oool002P0oooo00<000000?ooo`3o
ool01@3ooole0?l00300l_l0O01Do`0K003o6P@00?ma2`00okP;003oLAL00?lJ7P1Do`0]0?;o00H0
oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooocD0o`00<03bo`1l05Co01/00?lJ
1000og4;003o^0/00?ma5`00oaXN05Co02d0l_l01P3oool100000040oooo000X0?ooo`030000003o
ool0oooo00D0oooo=@3o000`0?;o07`0E?l06`00oaX4003oL@/00?nh2`00og4G003o6Qh0E?l0;@3b
o`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooole0?l00300l_l0O01Do`0K
003o6P@00?ma2`00okP;003oLAL00?lJ7P1Do`0]0?;o00H0oooo0@0000010?ooo`00:03oool00`00
0000oooo0?ooo`050?ooocD0o`00>03bo`1l05Co01h00?lJ1000og4F003o6R80E?l0=@3bo`060?oo
o`4000000@3oool002P0oooo00<000000?ooo`3oool01@3ooole0?l003P0l_l0O01Do`0N003o6P@0
0?ma5P00oaXR05Co03D0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo
=@3o000h0?;o07`0E?l07P00oaX4003oLAH00?lJ8P1Do`0e0?;o00H0oooo0@0000010?ooo`00:03o
ool00`000000oooo0?ooo`050?ooocP0o`00?03bo`2805Co01H00?lJ:P1Do`0l0?;o00H0oooo0@00
00010?ooo`00:03oool00`000000oooo0?ooo`050?ooocP0o`00?03bo`2805Co01H00?lJ:P1Do`0l
0?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooocP0o`00?03bo`2805Co
01H00?lJ:P1Do`0l0?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?oooc`0
o`00@03bo`2h05Co04@0l_l01P3oool100000040oooo000X0?ooo`030000003oool0oooo00D0oooo
?03o00100?;o0;P0E?l0A03bo`060?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3o
ooll0?l00400l_l0^01Do`140?;o00H0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`05
0?oooc`0o`00@03bo`2h05Co04@0l_l01P3oool100000040oooo000X0?ooo`<00000o`3ooon30?oo
o`8000000@3oool002P0oooo00<000000?ooo`3oool0o`3ooon40?ooo`4000000@3oool002P0oooo
00<000000?ooo`3oool0o`3ooon40?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool0o`3o
oon40?ooo`4000000@3oool002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool100000040oooo000X0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00@0oooo0@0000010?ooo`00:03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`40
00000@3oool002P0ooooo`00002800000040oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {397.688, 0}} -> {-2.33546, -1.44259, \
0.0104018, 0.0104018}}]
}, Closed]],

Cell[TextData[{
  "The figure above has relatively coarse resolution.  If we start playing \
with the resolution and attempt to zoom in on particular regions or to alter \
the color scheme or plotting format, we quickly find that the calculations \
are maddeningly slow.  We can do a little better by using ",
  StyleBox["Compile", "InlineInput"],
  " to optimize the calculation.  However, because ",
  StyleBox["Compile", "InlineInput"],
  " assumes that the arguments are real numbers, we need to specify that ",
  StyleBox["lim", "InlineInput"],
  " is an integer.  Also note that we now use the ",
  StyleBox["++", "InlineInput"],
  " operator to increment ",
  StyleBox["ct", "InlineInput"],
  "; that looks more elegant to users of C but is equivalent to the previous \
version."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[mandelbrotRate];\)\), "\n", 
    \(\(mandelbrotRate\  = 
        Compile[{cx, cy, {lim, \ _Integer}}, \ 
          Module[{c, z, ct = 0}, c = cx\  + \ I\ cy; z\  = \ c; 
            While[\((Abs[z] < 2.0)\)\  && \ \((ct \[LessEqual] 
                    lim)\), \(++ct\); z\  = \ z*z + \ c;]; 
            Return[ct]]\ ];\)\)}], "Input"],

Cell["\<\
It is also useful to save calculations in a data array so that we can vary \
the display format without repeating those calculations.  We now obtain \
higher resolution in similar or shorter time.  Note that the data table is \
arranged to produce a plot with the same orientation.\
\>", "Text"],

Cell[BoxData[
    \(\(\(MandelbrotData\  = \ 
        Table[mandelbrotRate[cx, cy, 50], {cy, \(-1.2\), 1.2, 
            0.01}, {cx, \(-2\), 0.6, 0.01}];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "The display below uses ",
  ButtonBox["ListDensityPlot",
    ButtonStyle->"RefGuideLink"],
  ", where the option ",
  ButtonBox["MeshRange",
    ButtonStyle->"RefGuideLink"],
  " assigns numerical values to array elements so that we can read \
coordinates from the plot.  Click on the figure, then hold down the Ctrl key \
while moving the cursor \[LongDash] you should see cursor coordinates in the \
lower-left corner of the window.  We also used a skeletal function for the ",
  StyleBox["ColorFunction", "InlineInput"],
  " option; note here that the parentheses are needed to define the extent of \
that function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[MandelbrotData, Frame \[Rule] False, 
        Mesh \[Rule] False, 
        MeshRange \[Rule] {{\(-2\), 0.6}, {\(-1.2\), 1.2}}, 
        AspectRatio \[Rule] Automatic, 
        ColorFunction \[Rule] \((Hue[Log[1 + #]] &)\)];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92308 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.758876 0.369822 0.461538 0.369822 [
[ 0 0 0 0 ]
[ 1 .92308 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .92308 L
0 .92308 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01775 translate
.96154 .88758 scale
783 string
261 241 8 [261 0 0 241 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FFC500FFDF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FFAA00FFC500BBFF00
FFDF00FFAA00FFAA00FFC500FFDF00FFAA00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF8F00FFAA00FFAA00FFDF00
2FFF00ECFF00FFDF00FFDF00D4FF00FFC500FFAA00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00
FFDF00FFF90046FF0000FF26FFDF00FFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00
FFC500FFDF00D4FF00ECFF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFC500FFDF00D4FF00D4FF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFC500FFDF00ECFF00BBFF00FFF900FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFC500FFDF00D4FF008BFF00D4FF00D4FF00ECFF00FFC500FFAA00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFDF00FFF9002FFF0000FF8C2FFF00ECFF00FFDF00FFC500FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFDF00D4FF0073FF002800FF46FF00ECFF00FFF900FFC500FFC500FFC500FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFDF00BBFF00FFAA00FF8F00FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFDF008BFF00A3FF002FFF008BFF008BFF0000FFECFFF900FFC500FFC500FFC500
FFAA00FFAA00FFAA00FFAA00FFC500FFC500ECFF00FFDF00FFAA00FF8F00FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500FFF900FFF900ECFF00D4FF0073FF00BBFF00FFF900FFDF00FFDF00FFC500
FFC500FFC500FFC500FFC500FFDF00FFF90073FF00ECFF00FFC500FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500FFDF00FFDF00FFF900ECFF008BFF00A3FF00A3FF00FFF900FFDF00FFDF00
FFDF00FFF900ECFF00ECFF00ECFF00A3FF002FFF00ECFF000034FFFF8F00FF8F00FF8F00
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFC500FFDF00FFDF00FFDF00ECFF0073FF0000FFB38BFF00ECFF00FFF900FFF900
FFF900D4FF0019FF0073FF0019FF0000FFA0ECFF00FFDF00FFC500FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF9008BFF005CFF0000FF64BBFF00D4FF00D4FF00
BBFF00A3FF0019FF00A3FF005CFF00D4FF00ECFF00FFC500FFAA00FF8F00FF8F00FF8F00
FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF900D4FF00BBFF0000FF1119FF00A3FF00A3FF00
00FF6400FF11BBFF00D4FF00ECFF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00D4FF00A3FF002FFF002FFF0003FF00
8BFF00BBFF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00D4FF00BBFF0073FF0000FF268BFF00
BBFF00D4FF00FFF900FFF900FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFF900FFF900ECFF00D4FF00A3FF005CFF0019FF00A3FF00
D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFC500FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFF900ECFF00ECFF00BBFF005CFF0000FF6400FF1100DDFF
D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFC500FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF00FFF900ECFF00D4FF00BBFF00A3FF0046FF0000FF7800FF3B00FFFE
BBFF00ECFF00ECFF00FFF900FFDF00FFC500FFC500FFAA00FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFDF00FFDF00FFF900ECFF00BBFF0000FF50A3FF008BFF0046FF0000FF8C00DDFF73FF00
BBFF00BBFF00D4FF00FFF900FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00
FFDF00FFF9002FFF005CFF005CFF0000DDFF5CFF0003FF0000FFC60054FF00FF3B19FF00
8BFF0073FF0000FF11ECFF00FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFC500FFC500FFF900FFF900FFDF00FFDF00FFF900
FFF900ECFF00D4FF0073FF0046FF0000FF3B2800FF2800FF2800FF2800FF00FFFE03FF00
46FF0000FFFE8BFF00D4FF00FFF900FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFC500FFC500FFDF00D4FF008BFF00ECFF00FFF900FFF900
ECFF00ECFF00D4FF00A3FF0073FF0019FF000054FF2800FF2800FF2800FF2800FF00DDFF
2800FF19FF0000FF2646FF00FFF900FFF900FFDF00FFDF00FFC500FFC500FFC500FFAA00
FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFC500FFC500FFDF00FFF900BBFF000075FF00FFA0D4FF00ECFF00
ECFF00D4FF00BBFF00A3FF005CFF002800FF00BAFF2800FF2800FF2800FF2800FF2800FF
00FFC65CFF008BFF00D4FF00ECFF00FFF900FFF900FFDF00FFDF00FFDF00FFF900D4FF00
FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFC500FFF900FFF900ECFF00D4FF00BBFF005CFF002FFF00BBFF00BBFF00
BBFF00A3FF0003FF0073FF0046FF0000FF110054FF2800FF2800FF2800FF2800FF2800FF
0A00FF46FF00A3FF00BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00ECFF00BBFF00A3FF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFC500ECFF0073FF00BBFF0073FF0000FFD90086FF03FF0000FF268BFF00A3FF00
8BFF0000FF3B00CBFF2FFF0000FF2600FF2600CBFF2800FF2800FF2800FF2800FF2800FF
00FF3B46FF0073FF0046FF00D4FF00ECFF00ECFF00D4FF0073FF005CFF0000FF26ECFF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500ECFF00A3FF0000FF1100EFFF8BFF005CFF0000CBFF2FFF005CFF005CFF00
73FF0019FF002800FF00FF8C2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFFE
00FF5000FF3B19FF0000FF1100FFA0BBFF00BBFF0000FF1100FF1173FF00D4FF00FFDF00
FFC500FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFC500FFDF00ECFF00A3FF00D4FF00A3FF008BFF0000FFA000FFC619FF0000FF64
00FF1100FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF8C73FF00A3FF00A3FF005CFF0000FF1173FF00BBFF00FFF900
FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFDF00FFDF00ECFF00ECFF00D4FF008BFF0003FF002800FF00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF8C2FFF0003FF005CFF0046FF0000FF502FFF0000FFECD4FF00
ECFF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900ECFF00ECFF0046FF000054FF00DDFF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FF782800FF00FF1100EFFF00FFFE8BFF0073FF0000FF26
ECFF00FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900FFF900D4FF00A3FF0046FF0000EFFF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF46FF00A3FF00D4FF00FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900FFF900D4FF00A3FF0073FF0019FF0000FFA02800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B00FF11D4FF00ECFF00FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900D4FF0046FF002FFF005CFF002800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00A8FF0014FFA3FF00D4FF00ECFF00FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFF900D4FF0046FF0000FFC603FF0000FF642800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF5CFF008BFF00BBFF00ECFF00FFDF00
FFDF00FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00ECFF0073FF0003FF002800FF00FFFE2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF5019FF0000FFD900FFC600FFA0FFDF00
FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF00FFDF00ECFF0073FF0073FF0000FF112800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B00FFFE46FF00D4FF00FFF900
FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFC500FFDF00FFDF00FFF900ECFF00D4FF00BBFF008BFF0019FF0000FFA02800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF46FF0000FF50ECFF00FFF900
FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500
FFDF00FFDF00FFDF00FFF900ECFF00ECFF00BBFF002FFF002800FF00FF642800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF782FFF00A3FF00D4FF00ECFF00FFF900
FFDF00FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00
FFDF00FFDF00FFF900FFF900ECFF00ECFF00D4FF0073FF002800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0034FF00FF642800FF8BFF00D4FF00FFF900FFF900
FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFDF00
FFDF00FFF900FFF900FFF900ECFF00ECFF00D4FF0073FF005CFF0000FFEC2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FFBBFF00ECFF00ECFF00FFF900
FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF002FFF00ECFF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFF900FFF900FFF900FFF900ECFF00D4FF00D4FF00A3FF008BFF0000FF3B00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FFB346FF008BFF00BBFF00ECFF00ECFF00FFF900
FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFC500FFC500FFC500
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC50046FF00A3FF00FFAA00FF8F00FF8F00
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FFAA00FFDF00FFDF00FFF900D4FF00FFDF00FFC500FFC500
FFDF00FFDF00ECFF005CFF0019FF0000FF64FFF900FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900ECFF00D4FF00D4FF00BBFF00BBFF00A3FF002FFF0003FF0000CBFF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FF3B73FF00A3FF00BBFF00D4FF00ECFF00ECFF00
ECFF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFF90003FF00FFF900FFDF00
FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFF900BBFF00FFDF00FFC500FF8F00
FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FFAA00FFC500BBFF0000CBFF00FF26D4FF00FFF900FFF900BBFF00
2FFF00ECFF00D4FF0073FF0046FF00BBFF00FFF900FFDF00FFDF00FFDF00FFC500FFDF00
FFDF00FFDF00FFDF00FFDF00D4FF0000FF3BD4FF00D4FF0003FF00BBFF00ECFF00ECFF00
ECFF00ECFF00D4FF00D4FF00D4FF00BBFF00BBFF00A3FF008BFF0073FF0046FF0000FF3B
0044FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00CBFF5CFF0073FF00A3FF00BBFF00BBFF00D4FF00D4FF00
D4FF00ECFF00ECFF00FFF900FFF900FFF900FFF900FFF900ECFF0000FF1103FF00FFF900
FFDF00FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFF900BBFF00D4FF00A3FF00FFAA00
FF8F00FF8F00FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FFAA00FFC500FFDF002FFF005CFF0073FF00BBFF00D4FF00A3FF00
00FF78BBFF002FFF002800FF00FF50D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFF900FFF900D4FF002FFF0003FF002800FF00CBFFA3FF00D4FF00D4FF00
D4FF0000FF508BFF0000FF3BA3FF00A3FF00A3FF008BFF0073FF005CFF0046FF0019FF00
00FF502800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF5019FF005CFF0073FF008BFF008BFF00A3FF00BBFF00BBFF00
BBFF0000FFB3BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00BBFF0073FF005CFF00BBFF00
BBFF00FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF900D4FF0019FF00ECFF00FFAA00
FF8F00FF8F00FF8F00FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFC500FFC500FFF900D4FF0000DDFF00FFA073FF005CFF00
03FF005CFF0000FFEC2FFF008BFF00D4FF00ECFF00FFF900FFF900FFDF00FFDF00FFDF00
FFDF00FFF900FFF900ECFF00BBFF0000FFEC0075FF0044FF0097FF00BAFFA3FF00BBFF00
A3FF0046FF002800FF2800FF5CFF0073FF000024FF03FF0046FF0000FF3B19FF0003FF00
00FF3B00FF7800FFEC2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00FFEC00FF6400FF2603FF002FFF002FFF0046FF005CFF002800FF2FFF008BFF00
5CFF002800FF2800FFA3FF00D4FF00D4FF00D4FF0073FF002800FF00FF5000BAFF00FF11
2FFF00FFF900FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF0003FF000086FFD4FF00FFF900FFAA00
FFAA00FF8F00FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00FFF900BBFF0073FF0000FF6400FF26
00FF640005FF00FF1173FF00A3FF00BBFF00D4FF00D4FF00ECFF00FFF900FFF900FFF900
FFF900FFF900ECFF00A3FF002800FF00A8FF00A8FF2800FF00FFFE19FF0073FF008BFF00
19FF002800FF2800FF00FFFE19FF0000CBFF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FFA02800FF00FF262800FF2800FF2FFF00
00FF1100CBFF0075FF00FF8CA3FF00BBFF00BBFF0073FF0019FF0000FF8C0097FF0086FF
46FF00ECFF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFDF00FFDF00ECFF008BFF0000FF8CA3FF00FFDF00FFC500
FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00ECFF00D4FF00A3FF0046FF0000FF8C
0044FF00FF262FFF005CFF008BFF00A3FF0073FF008BFF000024FFD4FF00ECFF00ECFF00
ECFF00ECFF00D4FF00BBFF0000FF2603FF0000FF782800FF2800FF00BAFF2800FF46FF00
2FFF000034FF2800FF2800FF00FFA000FFC62800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B
2800FF2800FF0044FF00FF1173FF008BFF000014FF0086FF00FF5000BAFF2800FF0054FF
00BAFF46FF00FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFDF00FFDF00FFDF00FFDF00FFF9008BFF0000FF5000CBFFD4FF00FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFDF00A3FF00A3FF0000FFFE00FFC600FF26
00FF640075FF00FF500024FF03FF0073FF0019FF0000FF642800FF8BFF00A3FF00D4FF00
ECFF00D4FF00D4FF00BBFF008BFF002800FF00FFD92800FF2800FF2800FF2800FF00FF11
2800FF00FFB32800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF262800FF46FF0000FF642800FF2800FF2800FF2800FF19FF00
5CFF00BBFF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFF900FFF900FFF900
FFF900FFDF00FFDF00FFF900FFF900ECFF00D4FF00A3FF0046FF00A3FF00FFF900FFC500
FFC500FFC500FFAA00FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFC500ECFF0000FF112FFF0000A8FF46FF0046FF00
00FF782800FF00A8FF2800FF00FF8C03FF0003FF0000FF8C2800FF00FF8C5CFF00BBFF00
D4FF00D4FF00BBFF00A3FF0073FF002800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FF260034FF2800FF2800FF2800FF2800FF2800FF
8BFF00D4FF00ECFF00FFF900FFF900FFF900FFF900FFF900FFF90000A8FF00FF78D4FF00
00FF3BD4FF00ECFF00FFF900ECFF00ECFF00D4FF00A3FF0000FF3BBBFF00ECFF00FFF900
FFDF00FFF900FFC500FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFDF0003FF0000FF7800FFA073FF008BFF0073FF00
2800FF0065FF2800FF2800FF0097FF00FFEC00FFEC2800FF2800FF19FF0073FF00A3FF00
A3FF008BFF0046FF000097FF46FF0003FF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00DDFF2800FF2800FF2800FF2800FF0044FF
8BFF00BBFF00D4FF00ECFF00FFF900FFF900FFF900FFF900ECFF00BBFF0000FF262800FF
00FF5000FF50BBFF00D4FF00ECFF00D4FF00BBFF005CFF0000FF26A3FF00BBFF0046FF00
BBFF005CFF00FFF900FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFC500FFC500FFF900ECFF00D4FF00BBFF00A3FF0073FF00
2800FF0075FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0054FF73FF00
8BFF0003FF002800FF2800FF00FF642800FF2800FF0024FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0014FF19FF00
73FF008BFF000065FFBBFF00D4FF00ECFF00ECFF00ECFF00D4FF00A3FF0073FF000054FF
00FF642FFF008BFF008BFF008BFF00A3FF00A3FF0073FF0000FF7846FF0000FF782FFF00
8BFF00ECFF00FFC500FFAA00FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF900ECFF00D4FF00BBFF0073FF00
00FF2600FF780054FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF5046FF00
5CFF0019FF0000FFD92800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
19FF0000FF7800A8FF00FFFEBBFF00D4FF00D4FF00D4FF00A3FF0000FFC62FFF000A00FF
00FFA003FF002FFF0046FF0000FF8C00FFC646FF0003FF0000DDFF00FF3B8BFF00D4FF00
FFF900FFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFF900ECFF0000FF2619FF00
19FF000044FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19FF00
00FF3B2800FF00FFD92800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
00FF8C2800FF2800FF00FFC68BFF00BBFF00BBFF0073FF0000FFA000A8FF00FF782800FF
2800FF00EFFF0097FF00FF502800FF00A8FF00FF782800FF00FF1146FF0000FF8C5CFF00
FFF900FFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00FFF900D4FF0073FF002800FF
00FF5000EFFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF03FF0046FF008BFF008BFF0073FF0000FF262800FF2800FF2800FF
2800FF2800FF2800FF00A8FF2800FF2800FF2800FF19FF0073FF00A3FF0073FF000034FF
D4FF00FFF900FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900D4FF0000FFD92800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FFC62800FF2FFF005CFF0000FFEC0097FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF0065FF00FF6446FF00BBFF00D4FF0073FF00
00FF3BFFDF00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900BBFF0073FF000044FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FF5019FF0000FF502800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0044FF00EFFF00FF3BBBFF00ECFF00FFF900FFDF00
FFDF00FFC500FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900D4FF00BBFF005CFF00
2FFF002800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF642800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FFEC00FF26A3FF00D4FF00ECFF00FFF900FFDF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900ECFF00ECFF00D4FF00A3FF00
73FF000014FF00FFA02800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFC62800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0024FF19FF0073FF00A3FF00D4FF00FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900FFF900ECFF00ECFF00BBFF00A3FF00
8BFF005CFF0019FF0000FF5000FFC600A8FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF1100DDFF00FFA000FF26FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF00FFF900FFF900FFF900FFF900ECFF00ECFF00D4FF00BBFF008BFF00
73FF0046FF0003FF0000FF8C2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFEC00FF3BFFF900FFC500FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFC500
FFDF00FFF900D4FF00A3FF005CFF00D4FF00ECFF00ECFF00D4FF00A3FF0073FF000A00FF
46FF002800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FFC619FF0073FF0019FF00D4FF00FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00FFDF00
FFF900ECFF00A3FF0000FFC646FF00A3FF00BBFF00BBFF00BBFF002FFF002800FF2800FF
00FF3B0034FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FFC62800FF00FF50BBFF00ECFF00FFF900FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFF900ECFF00D4FF00
D4FF0000FFEC73FF000044FF46FF008BFF00A3FF00A3FF008BFF002FFF002800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
00FFB300FF5003FF002FFF008BFF00BBFF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFDF00BBFF002800FF5CFF00
03FF000086FF00FF6400FF3B2FFF002FFF0000FF7873FF0073FF002FFF0000FF782800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2FFF0073FF00A3FF00D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF900BBFF0046FF00
00A8FF1900FF00FFD900FF5000FF111900FF2800FF2800FF2FFF0000FF112800FF0005FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF0054FF2800FF5CFF008BFF00D4FF00ECFF00FFF900FFF900FFDF00FFC500FFC500
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF90003FF0000FF26
00FFA01900FF2800FF2800FF2800FF2800FF2800FF2800FF00FF502800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FFFE2800FF2800FFBBFF00D4FF00D4FF00FFF900FFDF00FFC500FFC500
FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FFAA00FFDF00
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFF90073FF0073FF00
2800FF00FF640086FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00A8FF8BFF008BFF0000FF64D4FF00FFDF00FFC500FFC500
FFC500FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF8F00FF8F00FFAA00FFDF00
FFDF00FFC500FFC500FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFDF00FFF900ECFF00BBFF00
2800FF2FFF0000FF2600CBFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FF262800FF00DDFF00FFA0A3FF00FFF900FFDF00FFC500
FFC500FFC500FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00ECFF00
D4FF00FFF900FFDF00FFDF00FFDF00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00
A3FF008BFF002800FF00DDFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00EFFF2800FF2800FF2800FF2FFF00FFF900FFF900FFDF00
FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFC500
FFF900D4FF00A3FF00D4FF00ECFF00FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00
BBFF00A3FF0000EFFF0097FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFC6A3FF00ECFF00FFF900FFDF00
FFDF00FFDF00FFDF00FFDF00FFDF0000FF78FFC500FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFDF00FFF900A3FF00D4FF00FFF900FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFF900FFF900ECFF00D4FF00
BBFF00A3FF0073FF0019FF000014FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0075FF2800FF5CFF00BBFF00D4FF00ECFF00FFF900
FFDF00FFDF00FFDF00FFDF00FFF9002FFF00FFF900FFAA00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFC500FFF900BBFF002FFF00FFF900FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFDF008BFF00FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900D4FF00BBFF00
A3FF008BFF0073FF0000FFA000FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF7800FF78A3FF00BBFF00BBFF00BBFF00
ECFF00FFF900FFF900FFF900D4FF008BFF0046FF00FFC500FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFC500ECFF0000FF6403FF00ECFF00FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFF90019FF00A3FF00FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFF900FFF900D4FF0000FFC62800FF
73FF0073FF000086FF2800FF00EFFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF0014FF73FF00A3FF0073FF002800FF
00FF11D4FF00D4FF00D4FF005CFF005CFF00A3FF00FFC500FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFDF00ECFF0046FF00BBFF00ECFF00FFDF00FFC500FFC500FFC500FFC500FFC500FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFF900
FFF900BBFF0000FF11ECFF00FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00ECFF00D4FF0003FF0003FF0000FF64
2FFF002FFF0000FF112800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF46FF002800FF00FFB300BAFF
0044FF8BFF00BBFF008BFF0000FF3BA3FF00FFDF00FFC500FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFDF00
FFF900BBFF0046FF00D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500
FFC500FFC500FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFDF008BFF00
46FF0000FF26A3FF00FFF900FFF900FFDF00FFC500FFC500FFC500FFC500FFC500FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFDF00FFDF00FFF90019FF0046FF000065FF2800FF00FF78
2800FF0075FF00FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF642800FF2800FF2800FF
00FFD919FF0073FF005CFF0000FF64BBFF00FFF900FFDF00FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00ECFF00
5CFF00D4FF0019FF008BFF00ECFF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900D4FF00
00FF8C8BFF00D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00BBFF0000FF112800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00CBFF00FF5019FF0000FF1146FF0003FF00ECFF00FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFDF00
FFF900FFF90073FF0019FF00BBFF00ECFF00ECFF00FFF900FFF900FFDF00FFDF00FFF900
FFF90073FF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFF900FFF90046FF00
03FF008BFF00BBFF00D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFDF00FFDF00FFDF00FFDF00FFF900ECFF00D4FF005CFF0000FF6400FFB32800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FFD900EFFF73FF00ECFF00FFC500FFAA00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500
FFDF00FFF900D4FF002FFF008BFF00D4FF00D4FF00ECFF00BBFF00D4FF00ECFF00ECFF00
BBFF00A3FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFF900FFF900ECFF00BBFF00
00FF8C19FF0000FF3B00FF78D4FF00D4FF00FFF900FFF900FFDF00FFF900FFF900FFF900
ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFC500FFC500FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFDF00FFDF00FFF900FFF900ECFF00D4FF00BBFF0073FF0019FF002800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF0014FF00A8FF46FF0003FF002FFF002FFF00FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500
FFC500FFDF002FFF00A3FF0046FF005CFF0019FF002FFF0046FF008BFF0000FF78BBFF00
A3FF0000EFFFBBFF00ECFF00ECFF00FFF900FFF900FFF900FFF900ECFF00ECFF00D4FF00
A3FF005CFF0000EFFF00FFD98BFF0000FF26D4FF00ECFF00ECFF00FFF900ECFF00D4FF00
00FF50ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFDF00FFF900FFF900FFF900ECFF00D4FF00BBFF008BFF0046FF0000FF3B
00FFEC2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
0034FF03FF008BFF00BBFF0003FF00FFF900FFC500FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFF900ECFF0073FF0000FF26A3FF0000FF1119FF0000FF115CFF0073FF00
2FFF0000FFECA3FF00BBFF00BBFF00BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00BBFF00
A3FF008BFF002FFF000005FF00FF260034FF73FF00D4FF00ECFF00D4FF00A3FF0000FFA0
00FFB3BBFF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFF900FFF900FFF900FFF900ECFF00D4FF0073FF002800FF2FFF002800FF
00A8FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFFE2800FF00FFFE
00CBFF00FFFE00FF26ECFF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFDF00FFF900FFF900ECFF00D4FF00BBFF0073FF0000FFB300FFFE00FF26
0A00FF19FF0073FF008BFF0000CBFFA3FF00D4FF00D4FF00ECFF00D4FF00BBFF00BBFF00
A3FF0073FF002FFF0000FF2600EFFF2800FF0044FFA3FF00BBFF00BBFF0019FF0019FF00
73FF00BBFF00ECFF00FFF900FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFF900FFF900FFF900FFF900ECFF00D4FF00A3FF0000FF2600FF6400FF3B00FFB3
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2FFF0073FF00
8BFF00BBFF00FFF900FFDF00FFC500FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00BBFF0000FFA019FF0019FF0000FF64
2800FF00FF2619FF0046FF000097FF8BFF00BBFF00BBFF00A3FF00A3FF00A3FF00A3FF00
19FF0046FF0000FF1100FFFE2800FF0024FF00FF1100FF3BA3FF008BFF0046FF002800FF
2800FFA3FF00D4FF00ECFF00ECFF00FFF900FFF900FFF900FFDF00FFDF00FFF900FFF900
FFF900FFF900FFF900FFF900ECFF00ECFF002800FF2800FF2800FF2800FF2800FF0065FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0024FF00FFC68BFF00
D4FF00ECFF00FFDF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00D4FF00A3FF0073FF0046FF0000FF11
0086FF00A8FF00FFA000FF3B00FFFE00BAFF8BFF008BFF0046FF0046FF008BFF0073FF00
19FF0000FF8C0086FF2800FF2800FF2800FF2800FF46FF0073FF0073FF005CFF002FFF00
0075FF03FF008BFF00D4FF00D4FF00D4FF00ECFF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900ECFF00ECFF00D4FF00A3FF0000DDFF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF03FF0046FF00
BBFF00FFF900FFDF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFDF00FFDF00FFDF00FFF900ECFF00D4FF00BBFF008BFF0000EFFF2800FF
2800FF2800FF2800FF0097FF2800FF00FF2619FF005CFF0046FF0000FFA000FF3B0034FF
2FFF0000FF3B2800FF2800FF2800FF2800FF00A8FF03FF0000FF782FFF0000FF5003FF00
00FFA00044FF0075FFA3FF00A3FF0000CBFF46FF00D4FF00ECFF00ECFF00ECFF00ECFF00
ECFF00ECFF00ECFF00ECFF00D4FF00D4FF00A3FF0073FF0019FF002800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
BBFF00FFF900FFF900FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFDF00FFDF00FFDF00FFF900ECFF00D4FF00BBFF002FFF0000FF1100FF78
2800FF2800FF2800FF2800FF2800FF2800FF03FF0019FF0019FF002800FF2800FF00FFD9
0024FF00FF780014FF2800FF2800FF2800FF00A8FF00FF8C2800FF2800FF00FF780024FF
2800FF2800FF00FF265CFF002800FF03FF008BFF00D4FF00D4FF00ECFF00ECFF00ECFF00
ECFF00ECFF00ECFF00D4FF00D4FF00D4FF00A3FF0046FF0000FF6400FF782800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFA0
BBFF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFDF00FFDF00FFDF00FFDF00FFF900BBFF00A3FF008BFF0000FF3B0065FF2800FF
2800FF2800FF2800FF2800FF2800FF0A00FF00FF3B00FF502800FF00FFEC2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00CBFF2800FF
2800FF2800FF00FF502FFF0003FF0000FF785CFF00BBFF00BBFF00D4FF00ECFF00ECFF00
ECFF00ECFF00D4FF00D4FF00D4FF00BBFF008BFF0000FFA000FFFE00A8FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF73FF00
A3FF00D4FF00ECFF00ECFF0073FF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFDF00FFDF00FFDF00FFDF00ECFF00A3FF0000FF5019FF002800FF00FF8C2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FFC62800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FFC600FF5000FF500054FF0097FF8BFF00A3FF00A3FF00D4FF00D4FF00
D4FF00D4FF00D4FF00D4FF00BBFF00A3FF0000FF8C2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFFE
00FF5000FF11BBFF00D4FF005CFF00FFF900FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFDF00FFDF00FFDF00FFF900ECFF00D4FF00A3FF0073FF005CFF0000FF3B0044FF
2800FF2800FF2800FF2800FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF0044FF0065FF2800FF0014FF2FFF0000FFB300FFD9A3FF00BBFF00
BBFF00BBFF00BBFF00BBFF00BBFF00A3FF005CFF0000FF112800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00A8FF73FF0000FF7819FF00FFF900FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFDF00FFDF00FFF900FFF900ECFF00ECFF00D4FF00BBFF008BFF005CFF0000FF5000FF78
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF0024FF00FF3B00FFA02FFF008BFF00BBFF00
BBFF00BBFF00BBFF00BBFF00A3FF008BFF005CFF0000FFD92800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00FFEC19FF0000FF8CD4FF00FFDF00FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFDF00
FFF900FFF900FFF900ECFF00ECFF00ECFF00BBFF00BBFF008BFF005CFF002FFF0000FF3B
2800FF0075FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00EFFF00DDFF2800FF5CFF0073FF00
A3FF00A3FF00A3FF00A3FF00A3FF0073FF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00BAFFFFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500D4FF00
D4FF00D4FF00ECFF00ECFF00ECFF00BBFF00A3FF008BFF0046FF002FFF0000FF1100FFA0
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0086FF00A8FF00FF11
8BFF008BFF008BFF008BFF008BFF0073FF0003FF0000FFC62800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFA00075FF
00FFC646FF0000CBFF73FF00FFF900FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00ECFF00
00FF7873FF00BBFF00BBFF00A3FF0000FFA073FF005CFF0003FF002800FF00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFEC00CBFF
5CFF008BFF008BFF008BFF0073FF005CFF000075FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF5CFF00
8BFF00D4FF00ECFF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFF900FFF900
00FFB300FFFE73FF0073FF005CFF0000FF1100FF5000FF3B00FF1100DDFF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFA0
00FFD95CFF0073FF0073FF005CFF002FFF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
D4FF00FFF900FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900FFF900
D4FF00A3FF0073FF0000A8FF2800FF2800FF00FFFE2800FF00FF8C2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2FFF005CFF005CFF0046FF002FFF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B8BFF00
D4FF00ECFF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFDF00FFDF00FFDF00
FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFDF00FFF900ECFF00
ECFF00BBFF00A3FF005CFF0000FFC600BAFF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
00A8FF00FFB32FFF0046FF002FFF0003FF0000FFFE2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0065FF
BBFF00A3FF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500FFDF00BBFF00D4FF00
5CFF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFF900ECFF00
ECFF00D4FF00BBFF002FFF0019FF002800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF19FF0019FF0000FF112800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00A8FF
00FF8C03FF00FFF900FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00ECFF005CFF00
D4FF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFF900ECFF00ECFF00
ECFF00BBFF00A3FF008BFF0046FF0000FF3B0065FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FF6403FF0003FF0000FF262800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
1900FFBBFF00FFDF00FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500BBFF0019FF00
A3FF00ECFF00FFF900FFF900FFF900FFF900FFDF00FFF900FFF900ECFF00ECFF00ECFF00
D4FF00A3FF008BFF005CFF0000FF2600FF8C2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF2600FF2600FF502800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF262800FF0034FF
00FF50ECFF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500ECFF00D4FF00
0086FFBBFF00D4FF00ECFF00ECFF00ECFF00ECFF00BBFF00D4FF00D4FF00D4FF00D4FF00
BBFF000014FF00FF3B00FFFE2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF7800FF5000FF782800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FFBBFF00ECFF00
FFF900FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFF900ECFF00
A3FF0073FF00BBFF00D4FF00ECFF00ECFF00D4FF0000FF5073FF00BBFF00BBFF00BBFF00
A3FF008BFF005CFF000097FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FF7800FFA02800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF8BFF00ECFF00
FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFF900FFF900
D4FF008BFF0003FF008BFF00A3FF00BBFF00BBFF0073FF005CFF008BFF00A3FF00A3FF00
8BFF008BFF0046FF0000FF1100FFB32800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FFC600FFEC2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00DDFFFFF900
FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFF900ECFF00
ECFF00BBFF002FFF0000FF118BFF008BFF008BFF005CFF0000CBFF5CFF0073FF000097FF
73FF005CFF000005FF0054FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00EFFF00DDFF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00BAFF2800FF2800FF00FF64FFDF00
FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00FFF900ECFF00
ECFF00A3FF0019FF0000FF502FFF0003FF0046FF0019FF0000FFA000FF502FFF0019FF00
46FF0046FF0019FF0000FF782800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0086FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF648BFF00ECFF00FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFF900ECFF00
D4FF00A3FF005CFF0000FFC600A8FF2800FF2800FF00FF7800FFEC2800FF00FFEC00FF78
00FF8C03FF0000FF262800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0034FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00DDFFFFF900FFC500FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFC500A3FF00
FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFF900ECFF00D4FF00
BBFF00BBFF0073FF0019FF0000FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00FFFE00FF502800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF46FF008BFF00FFF900FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500ECFF00FFF900FFF900FFF900FFF900FFF900D4FF0000FF26A3FF00
A3FF0073FF002FFF0003FF0000FFA02800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF0014FF00FFA00054FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0024FF2800FFFFF900FFDF00FFC500FFC500FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFDF00ECFF00
FFDF00FFDF00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFDF00FFDF00FFF900BBFF00BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00A3FF0046FF00
8BFF005CFF0003FF0000FFD91900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FFECECFF00FFDF00FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFDF00ECFF00
D4FF00FFF900FFC500FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFDF00
FFDF00D4FF00FFDF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00
FFDF00FFF900FFF900BBFF0000FF26D4FF00ECFF00ECFF00D4FF00BBFF00A3FF0046FF00
00FF2603FF0000FF2600FFC62800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FFA3FF00ECFF00FFDF00FFDF00FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF7300FF7300FF7300FF7300FF7300FF7300FF7300FFAA00FFAA00FFAA00FFAA00
FF8F00FF8F00FF8F00FF8F00FFAA00FFC500FFC500FFC500FFC500FFF900ECFF00BBFF00
00FF78BBFF00ECFF00FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500FFDF00FFDF00
FFF90019FF00D4FF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFF900ECFF00ECFF00BBFF0046FF00BBFF00BBFF0073FF00A3FF00BBFF0073FF0046FF00
00FF640034FF00FFEC2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FF78BBFF00ECFF00FFF900FFDF00FFC500FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF8F00FF8F00FFAA00FFAA00FFAA00FF7300FFC500FFAA00FFAA00FFAA00FFC500
FFC500FFDF00FFF900FFDF00FFC500FFC500FFDF00FFDF00FFF900FFF90000FF1100FF78
2800FF2800FFBBFF00FFF900FFF900FFDF00FFF900FFF900ECFF00ECFF00FFF900FFF900
ECFF008BFF00A3FF00ECFF00FFF900ECFF00D4FF00D4FF00ECFF00FFF900ECFF00D4FF00
A3FF00BBFF00A3FF0073FF0000FF2600FF788BFF0046FF0073FF005CFF0000FFEC00FF26
00FFC62800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
0097FF8BFF00BBFF00ECFF00FFF900FFF900FFDF00FFC500FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF00002800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFB319FF00
73FF00A3FF00D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFC500FFAA00FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF8F00FF8F00FFAA00FFAA00FFAA00FF7300FFC500FFAA00FFAA00FFAA00FFC500
FFC500FFDF00FFF900FFDF00FFC500FFC500FFDF00FFDF00FFF900FFF90000FF1100FF78
2800FF2800FFBBFF00FFF900FFF900FFDF00FFF900FFF900ECFF00ECFF00FFF900FFF900
ECFF008BFF00A3FF00ECFF00FFF900ECFF00D4FF00D4FF00ECFF00FFF900ECFF00D4FF00
A3FF00BBFF00A3FF0073FF0000FF2600FF788BFF0046FF0073FF005CFF0000FFEC00FF26
00FFC62800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
0097FF8BFF00BBFF00ECFF00FFF900FFF900FFDF00FFC500FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF7300FF7300FF7300FF7300FF7300FF7300FF7300FFAA00FFAA00FFAA00FFAA00
FF8F00FF8F00FF8F00FF8F00FFAA00FFC500FFC500FFC500FFC500FFF900ECFF00BBFF00
00FF78BBFF00ECFF00FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500FFDF00FFDF00
FFF90019FF00D4FF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFF900ECFF00ECFF00BBFF0046FF00BBFF00BBFF0073FF00A3FF00BBFF0073FF0046FF00
00FF640034FF00FFEC2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FF78BBFF00ECFF00FFF900FFDF00FFC500FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFDF00ECFF00
D4FF00FFF900FFC500FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFDF00
FFDF00D4FF00FFDF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00
FFDF00FFF900FFF900BBFF0000FF26D4FF00ECFF00ECFF00D4FF00BBFF00A3FF0046FF00
00FF2603FF0000FF2600FFC62800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FFA3FF00ECFF00FFDF00FFDF00FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFDF00ECFF00
FFDF00FFDF00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFDF00FFDF00FFF900BBFF00BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00A3FF0046FF00
8BFF005CFF0003FF0000FFD91900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FFECECFF00FFDF00FFC500FFC500FFAA00FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500ECFF00FFF900FFF900FFF900FFF900FFF900D4FF0000FF26A3FF00
A3FF0073FF002FFF0003FF0000FFA02800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF0014FF00FFA00054FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0024FF2800FFFFF900FFDF00FFC500FFC500FFAA00
FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFC500A3FF00
FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFF900ECFF00D4FF00
BBFF00BBFF0073FF0019FF0000FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00FFFE00FF502800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF46FF008BFF00FFF900FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFF900ECFF00
D4FF00A3FF005CFF0000FFC600A8FF2800FF2800FF00FF7800FFEC2800FF00FFEC00FF78
00FF8C03FF0000FF262800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0034FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00DDFFFFF900FFC500FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00FFF900ECFF00
ECFF00A3FF0019FF0000FF502FFF0003FF0046FF0019FF0000FFA000FF502FFF0019FF00
46FF0046FF0019FF0000FF782800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0086FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF648BFF00ECFF00FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFF900ECFF00
ECFF00BBFF002FFF0000FF118BFF008BFF008BFF005CFF0000CBFF5CFF0073FF000097FF
73FF005CFF000005FF0054FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00EFFF00DDFF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00BAFF2800FF2800FF00FF64FFDF00
FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFF900FFF900
D4FF008BFF0003FF008BFF00A3FF00BBFF00BBFF0073FF005CFF008BFF00A3FF00A3FF00
8BFF008BFF0046FF0000FF1100FFB32800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FFC600FFEC2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00DDFFFFF900
FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFF900ECFF00
A3FF0073FF00BBFF00D4FF00ECFF00ECFF00D4FF0000FF5073FF00BBFF00BBFF00BBFF00
A3FF008BFF005CFF000097FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FF7800FFA02800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF8BFF00ECFF00
FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500ECFF00D4FF00
0086FFBBFF00D4FF00ECFF00ECFF00ECFF00ECFF00BBFF00D4FF00D4FF00D4FF00D4FF00
BBFF000014FF00FF3B00FFFE2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF7800FF5000FF782800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FFBBFF00ECFF00
FFF900FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500BBFF0019FF00
A3FF00ECFF00FFF900FFF900FFF900FFF900FFDF00FFF900FFF900ECFF00ECFF00ECFF00
D4FF00A3FF008BFF005CFF0000FF2600FF8C2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF2600FF2600FF502800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF262800FF0034FF
00FF50ECFF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00ECFF005CFF00
D4FF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFF900ECFF00ECFF00
ECFF00BBFF00A3FF008BFF0046FF0000FF3B0065FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FF6403FF0003FF0000FF262800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
1900FFBBFF00FFDF00FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500FFDF00BBFF00D4FF00
5CFF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFF900ECFF00
ECFF00D4FF00BBFF002FFF0019FF002800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF19FF0019FF0000FF112800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00A8FF
00FF8C03FF00FFF900FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFDF00FFDF00FFDF00
FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFDF00FFF900ECFF00
ECFF00BBFF00A3FF005CFF0000FFC600BAFF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
00A8FF00FFB32FFF0046FF002FFF0003FF0000FFFE2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0065FF
BBFF00A3FF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900FFF900
D4FF00A3FF0073FF0000A8FF2800FF2800FF00FFFE2800FF00FF8C2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2FFF005CFF005CFF0046FF002FFF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B8BFF00
D4FF00ECFF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFF900FFF900
00FFB300FFFE73FF0073FF005CFF0000FF1100FF5000FF3B00FF1100DDFF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFA0
00FFD95CFF0073FF0073FF005CFF002FFF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
D4FF00FFF900FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00ECFF00
00FF7873FF00BBFF00BBFF00A3FF0000FFA073FF005CFF0003FF002800FF00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFEC00CBFF
5CFF008BFF008BFF008BFF0073FF005CFF000075FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF5CFF00
8BFF00D4FF00ECFF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500D4FF00
D4FF00D4FF00ECFF00ECFF00ECFF00BBFF00A3FF008BFF0046FF002FFF0000FF1100FFA0
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0086FF00A8FF00FF11
8BFF008BFF008BFF008BFF008BFF0073FF0003FF0000FFC62800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFA00075FF
00FFC646FF0000CBFF73FF00FFF900FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFDF00
FFF900FFF900FFF900ECFF00ECFF00ECFF00BBFF00BBFF008BFF005CFF002FFF0000FF3B
2800FF0075FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00EFFF00DDFF2800FF5CFF0073FF00
A3FF00A3FF00A3FF00A3FF00A3FF0073FF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00BAFFFFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFDF00FFDF00FFF900FFF900ECFF00ECFF00D4FF00BBFF008BFF005CFF0000FF5000FF78
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF0024FF00FF3B00FFA02FFF008BFF00BBFF00
BBFF00BBFF00BBFF00BBFF00A3FF008BFF005CFF0000FFD92800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00FFEC19FF0000FF8CD4FF00FFDF00FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFDF00FFDF00FFDF00FFF900ECFF00D4FF00A3FF0073FF005CFF0000FF3B0044FF
2800FF2800FF2800FF2800FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF0044FF0065FF2800FF0014FF2FFF0000FFB300FFD9A3FF00BBFF00
BBFF00BBFF00BBFF00BBFF00BBFF00A3FF005CFF0000FF112800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00A8FF73FF0000FF7819FF00FFF900FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFDF00FFDF00FFDF00FFDF00ECFF00A3FF0000FF5019FF002800FF00FF8C2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FFC62800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FFC600FF5000FF500054FF0097FF8BFF00A3FF00A3FF00D4FF00D4FF00
D4FF00D4FF00D4FF00D4FF00BBFF00A3FF0000FF8C2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFFE
00FF5000FF11BBFF00D4FF005CFF00FFF900FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFDF00FFDF00FFDF00FFDF00FFF900BBFF00A3FF008BFF0000FF3B0065FF2800FF
2800FF2800FF2800FF2800FF2800FF0A00FF00FF3B00FF502800FF00FFEC2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00CBFF2800FF
2800FF2800FF00FF502FFF0003FF0000FF785CFF00BBFF00BBFF00D4FF00ECFF00ECFF00
ECFF00ECFF00D4FF00D4FF00D4FF00BBFF008BFF0000FFA000FFFE00A8FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF73FF00
A3FF00D4FF00ECFF00ECFF0073FF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFDF00FFDF00FFDF00FFF900ECFF00D4FF00BBFF002FFF0000FF1100FF78
2800FF2800FF2800FF2800FF2800FF2800FF03FF0019FF0019FF002800FF2800FF00FFD9
0024FF00FF780014FF2800FF2800FF2800FF00A8FF00FF8C2800FF2800FF00FF780024FF
2800FF2800FF00FF265CFF002800FF03FF008BFF00D4FF00D4FF00ECFF00ECFF00ECFF00
ECFF00ECFF00ECFF00D4FF00D4FF00D4FF00A3FF0046FF0000FF6400FF782800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFA0
BBFF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFDF00FFDF00FFDF00FFF900ECFF00D4FF00BBFF008BFF0000EFFF2800FF
2800FF2800FF2800FF0097FF2800FF00FF2619FF005CFF0046FF0000FFA000FF3B0034FF
2FFF0000FF3B2800FF2800FF2800FF2800FF00A8FF03FF0000FF782FFF0000FF5003FF00
00FFA00044FF0075FFA3FF00A3FF0000CBFF46FF00D4FF00ECFF00ECFF00ECFF00ECFF00
ECFF00ECFF00ECFF00ECFF00D4FF00D4FF00A3FF0073FF0019FF002800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
BBFF00FFF900FFF900FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00D4FF00A3FF0073FF0046FF0000FF11
0086FF00A8FF00FFA000FF3B00FFFE00BAFF8BFF008BFF0046FF0046FF008BFF0073FF00
19FF0000FF8C0086FF2800FF2800FF2800FF2800FF46FF0073FF0073FF005CFF002FFF00
0075FF03FF008BFF00D4FF00D4FF00D4FF00ECFF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900ECFF00ECFF00D4FF00A3FF0000DDFF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF03FF0046FF00
BBFF00FFF900FFDF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00BBFF0000FFA019FF0019FF0000FF64
2800FF00FF2619FF0046FF000097FF8BFF00BBFF00BBFF00A3FF00A3FF00A3FF00A3FF00
19FF0046FF0000FF1100FFFE2800FF0024FF00FF1100FF3BA3FF008BFF0046FF002800FF
2800FFA3FF00D4FF00ECFF00ECFF00FFF900FFF900FFF900FFDF00FFDF00FFF900FFF900
FFF900FFF900FFF900FFF900ECFF00ECFF002800FF2800FF2800FF2800FF2800FF0065FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0024FF00FFC68BFF00
D4FF00ECFF00FFDF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFDF00FFF900FFF900ECFF00D4FF00BBFF0073FF0000FFB300FFFE00FF26
0A00FF19FF0073FF008BFF0000CBFFA3FF00D4FF00D4FF00ECFF00D4FF00BBFF00BBFF00
A3FF0073FF002FFF0000FF2600EFFF2800FF0044FFA3FF00BBFF00BBFF0019FF0019FF00
73FF00BBFF00ECFF00FFF900FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFF900FFF900FFF900FFF900ECFF00D4FF00A3FF0000FF2600FF6400FF3B00FFB3
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2FFF0073FF00
8BFF00BBFF00FFF900FFDF00FFC500FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFF900ECFF0073FF0000FF26A3FF0000FF1119FF0000FF115CFF0073FF00
2FFF0000FFECA3FF00BBFF00BBFF00BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00BBFF00
A3FF008BFF002FFF000005FF00FF260034FF73FF00D4FF00ECFF00D4FF00A3FF0000FFA0
00FFB3BBFF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFF900FFF900FFF900FFF900ECFF00D4FF0073FF002800FF2FFF002800FF
00A8FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFFE2800FF00FFFE
00CBFF00FFFE00FF26ECFF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500
FFC500FFDF002FFF00A3FF0046FF005CFF0019FF002FFF0046FF008BFF0000FF78BBFF00
A3FF0000EFFFBBFF00ECFF00ECFF00FFF900FFF900FFF900FFF900ECFF00ECFF00D4FF00
A3FF005CFF0000EFFF00FFD98BFF0000FF26D4FF00ECFF00ECFF00FFF900ECFF00D4FF00
00FF50ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFDF00FFF900FFF900FFF900ECFF00D4FF00BBFF008BFF0046FF0000FF3B
00FFEC2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
0034FF03FF008BFF00BBFF0003FF00FFF900FFC500FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500
FFDF00FFF900D4FF002FFF008BFF00D4FF00D4FF00ECFF00BBFF00D4FF00ECFF00ECFF00
BBFF00A3FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFF900FFF900ECFF00BBFF00
00FF8C19FF0000FF3B00FF78D4FF00D4FF00FFF900FFF900FFDF00FFF900FFF900FFF900
ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFC500FFC500FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFDF00FFDF00FFF900FFF900ECFF00D4FF00BBFF0073FF0019FF002800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF0014FF00A8FF46FF0003FF002FFF002FFF00FFAA00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFDF00
FFF900FFF90073FF0019FF00BBFF00ECFF00ECFF00FFF900FFF900FFDF00FFDF00FFF900
FFF90073FF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFF900FFF90046FF00
03FF008BFF00BBFF00D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFDF00FFDF00FFDF00FFDF00FFF900ECFF00D4FF005CFF0000FF6400FFB32800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FFD900EFFF73FF00ECFF00FFC500FFAA00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00ECFF00
5CFF00D4FF0019FF008BFF00ECFF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900D4FF00
00FF8C8BFF00D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00BBFF0000FF112800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00CBFF00FF5019FF0000FF1146FF0003FF00ECFF00FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFDF00
FFF900BBFF0046FF00D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500
FFC500FFC500FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFDF008BFF00
46FF0000FF26A3FF00FFF900FFF900FFDF00FFC500FFC500FFC500FFC500FFC500FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFDF00FFDF00FFF90019FF0046FF000065FF2800FF00FF78
2800FF0075FF00FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF642800FF2800FF2800FF
00FFD919FF0073FF005CFF0000FF64BBFF00FFF900FFDF00FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFDF00ECFF0046FF00BBFF00ECFF00FFDF00FFC500FFC500FFC500FFC500FFC500FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFF900
FFF900BBFF0000FF11ECFF00FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00ECFF00D4FF0003FF0003FF0000FF64
2FFF002FFF0000FF112800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF46FF002800FF00FFB300BAFF
0044FF8BFF00BBFF008BFF0000FF3BA3FF00FFDF00FFC500FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFC500ECFF0000FF6403FF00ECFF00FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFF90019FF00A3FF00FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFF900FFF900D4FF0000FFC62800FF
73FF0073FF000086FF2800FF00EFFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF0014FF73FF00A3FF0073FF002800FF
00FF11D4FF00D4FF00D4FF005CFF005CFF00A3FF00FFC500FFAA00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFC500FFF900BBFF002FFF00FFF900FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFDF008BFF00FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900D4FF00BBFF00
A3FF008BFF0073FF0000FFA000FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF7800FF78A3FF00BBFF00BBFF00BBFF00
ECFF00FFF900FFF900FFF900D4FF008BFF0046FF00FFC500FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFC500
FFDF00FFF900A3FF00D4FF00FFF900FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFF900FFF900ECFF00D4FF00
BBFF00A3FF0073FF0019FF000014FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0075FF2800FF5CFF00BBFF00D4FF00ECFF00FFF900
FFDF00FFDF00FFDF00FFDF00FFF9002FFF00FFF900FFAA00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFC500
FFF900D4FF00A3FF00D4FF00ECFF00FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00
BBFF00A3FF0000EFFF0097FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFC6A3FF00ECFF00FFF900FFDF00
FFDF00FFDF00FFDF00FFDF00FFDF0000FF78FFC500FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00ECFF00
D4FF00FFF900FFDF00FFDF00FFDF00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00ECFF00
A3FF008BFF002800FF00DDFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00EFFF2800FF2800FF2800FF2FFF00FFF900FFF900FFDF00
FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF8F00FF8F00FFAA00FFDF00
FFDF00FFC500FFC500FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFDF00FFF900ECFF00BBFF00
2800FF2FFF0000FF2600CBFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FF262800FF00DDFF00FFA0A3FF00FFF900FFDF00FFC500
FFC500FFC500FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FFAA00FFDF00
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFF90073FF0073FF00
2800FF00FF640086FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00A8FF8BFF008BFF0000FF64D4FF00FFDF00FFC500FFC500
FFC500FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF90003FF0000FF26
00FFA01900FF2800FF2800FF2800FF2800FF2800FF2800FF00FF502800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF00FFFE2800FF2800FFBBFF00D4FF00D4FF00FFF900FFDF00FFC500FFC500
FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF900BBFF0046FF00
00A8FF1900FF00FFD900FF5000FF111900FF2800FF2800FF2FFF0000FF112800FF0005FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF0054FF2800FF5CFF008BFF00D4FF00ECFF00FFF900FFF900FFDF00FFC500FFC500
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFDF00BBFF002800FF5CFF00
03FF000086FF00FF6400FF3B2FFF002FFF0000FF7873FF0073FF002FFF0000FF782800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2FFF0073FF00A3FF00D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFF900ECFF00D4FF00
D4FF0000FFEC73FF000044FF46FF008BFF00A3FF00A3FF008BFF002FFF002800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
00FFB300FF5003FF002FFF008BFF00BBFF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00FFDF00
FFF900ECFF00A3FF0000FFC646FF00A3FF00BBFF00BBFF00BBFF002FFF002800FF2800FF
00FF3B0034FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FFC62800FF00FF50BBFF00ECFF00FFF900FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFC500
FFDF00FFF900D4FF00A3FF005CFF00D4FF00ECFF00ECFF00D4FF00A3FF0073FF000A00FF
46FF002800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FFC619FF0073FF0019FF00D4FF00FFDF00FFC500FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF00FFF900FFF900FFF900FFF900ECFF00ECFF00D4FF00BBFF008BFF00
73FF0046FF0003FF0000FF8C2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFEC00FF3BFFF900FFC500FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900FFF900ECFF00ECFF00BBFF00A3FF00
8BFF005CFF0019FF0000FF5000FFC600A8FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF1100DDFF00FFA000FF26FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900ECFF00ECFF00D4FF00A3FF00
73FF000014FF00FFA02800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFC62800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0024FF19FF0073FF00A3FF00D4FF00FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFC500FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900D4FF00BBFF005CFF00
2FFF002800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF642800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FFEC00FF26A3FF00D4FF00ECFF00FFF900FFDF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900BBFF0073FF000044FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FF5019FF0000FF502800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0044FF00EFFF00FF3BBBFF00ECFF00FFF900FFDF00
FFDF00FFC500FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00FFDF00FFF900D4FF0000FFD92800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FFC62800FF2FFF005CFF0000FFEC0097FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF0065FF00FF6446FF00BBFF00D4FF0073FF00
00FF3BFFDF00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00FFF900D4FF0073FF002800FF
00FF5000EFFF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF03FF0046FF008BFF008BFF0073FF0000FF262800FF2800FF2800FF
2800FF2800FF2800FF00A8FF2800FF2800FF2800FF19FF0073FF00A3FF0073FF000034FF
D4FF00FFF900FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFF900ECFF0000FF2619FF00
19FF000044FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19FF00
00FF3B2800FF00FFD92800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
00FF8C2800FF2800FF00FFC68BFF00BBFF00BBFF0073FF0000FFA000A8FF00FF782800FF
2800FF00EFFF0097FF00FF502800FF00A8FF00FF782800FF00FF1146FF0000FF8C5CFF00
FFF900FFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF900ECFF00D4FF00BBFF0073FF00
00FF2600FF780054FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF5046FF00
5CFF0019FF0000FFD92800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
19FF0000FF7800A8FF00FFFEBBFF00D4FF00D4FF00D4FF00A3FF0000FFC62FFF000A00FF
00FFA003FF002FFF0046FF0000FF8C00FFC646FF0003FF0000DDFF00FF3B8BFF00D4FF00
FFF900FFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFC500FFC500FFF900ECFF00D4FF00BBFF00A3FF0073FF00
2800FF0075FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0054FF73FF00
8BFF0003FF002800FF2800FF00FF642800FF2800FF0024FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF0014FF19FF00
73FF008BFF000065FFBBFF00D4FF00ECFF00ECFF00ECFF00D4FF00A3FF0073FF000054FF
00FF642FFF008BFF008BFF008BFF00A3FF00A3FF0073FF0000FF7846FF0000FF782FFF00
8BFF00ECFF00FFC500FFAA00FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFDF0003FF0000FF7800FFA073FF008BFF0073FF00
2800FF0065FF2800FF2800FF0097FF00FFEC00FFEC2800FF2800FF19FF0073FF00A3FF00
A3FF008BFF0046FF000097FF46FF0003FF002800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00DDFF2800FF2800FF2800FF2800FF0044FF
8BFF00BBFF00D4FF00ECFF00FFF900FFF900FFF900FFF900ECFF00BBFF0000FF262800FF
00FF5000FF50BBFF00D4FF00ECFF00D4FF00BBFF005CFF0000FF26A3FF00BBFF0046FF00
BBFF005CFF00FFF900FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFC500ECFF0000FF112FFF0000A8FF46FF0046FF00
00FF782800FF00A8FF2800FF00FF8C03FF0003FF0000FF8C2800FF00FF8C5CFF00BBFF00
D4FF00D4FF00BBFF00A3FF0073FF002800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FF260034FF2800FF2800FF2800FF2800FF2800FF
8BFF00D4FF00ECFF00FFF900FFF900FFF900FFF900FFF900FFF90000A8FF00FF78D4FF00
00FF3BD4FF00ECFF00FFF900ECFF00ECFF00D4FF00A3FF0000FF3BBBFF00ECFF00FFF900
FFDF00FFF900FFC500FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFC500FFDF00A3FF00A3FF0000FFFE00FFC600FF26
00FF640075FF00FF500024FF03FF0073FF0019FF0000FF642800FF8BFF00A3FF00D4FF00
ECFF00D4FF00D4FF00BBFF008BFF002800FF00FFD92800FF2800FF2800FF2800FF00FF11
2800FF00FFB32800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF262800FF46FF0000FF642800FF2800FF2800FF2800FF19FF00
5CFF00BBFF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFF900FFF900FFF900
FFF900FFDF00FFDF00FFF900FFF900ECFF00D4FF00A3FF0046FF00A3FF00FFF900FFC500
FFC500FFC500FFAA00FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00ECFF00D4FF00A3FF0046FF0000FF8C
0044FF00FF262FFF005CFF008BFF00A3FF0073FF008BFF000024FFD4FF00ECFF00ECFF00
ECFF00ECFF00D4FF00BBFF0000FF2603FF0000FF782800FF2800FF00BAFF2800FF46FF00
2FFF000034FF2800FF2800FF00FFA000FFC62800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B
2800FF2800FF0044FF00FF1173FF008BFF000014FF0086FF00FF5000BAFF2800FF0054FF
00BAFF46FF00FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFDF00FFDF00FFDF00FFDF00FFF9008BFF0000FF5000CBFFD4FF00FFDF00FFC500
FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFDF00FFF900BBFF0073FF0000FF6400FF26
00FF640005FF00FF1173FF00A3FF00BBFF00D4FF00D4FF00ECFF00FFF900FFF900FFF900
FFF900FFF900ECFF00A3FF002800FF00A8FF00A8FF2800FF00FFFE19FF0073FF008BFF00
19FF002800FF2800FF00FFFE19FF0000CBFF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FFA02800FF00FF262800FF2800FF2FFF00
00FF1100CBFF0075FF00FF8CA3FF00BBFF00BBFF0073FF0019FF0000FF8C0097FF0086FF
46FF00ECFF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFDF00FFDF00ECFF008BFF0000FF8CA3FF00FFDF00FFC500
FFAA00FF8F00FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFC500FFC500FFF900D4FF0000DDFF00FFA073FF005CFF00
03FF005CFF0000FFEC2FFF008BFF00D4FF00ECFF00FFF900FFF900FFDF00FFDF00FFDF00
FFDF00FFF900FFF900ECFF00BBFF0000FFEC0075FF0044FF0097FF00BAFFA3FF00BBFF00
A3FF0046FF002800FF2800FF5CFF0073FF000024FF03FF0046FF0000FF3B19FF0003FF00
00FF3B00FF7800FFEC2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF00FFEC00FF6400FF2603FF002FFF002FFF0046FF005CFF002800FF2FFF008BFF00
5CFF002800FF2800FFA3FF00D4FF00D4FF00D4FF0073FF002800FF00FF5000BAFF00FF11
2FFF00FFF900FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF0003FF000086FFD4FF00FFF900FFAA00
FFAA00FF8F00FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FFAA00FFC500FFDF002FFF005CFF0073FF00BBFF00D4FF00A3FF00
00FF78BBFF002FFF002800FF00FF50D4FF00ECFF00FFF900FFDF00FFDF00FFDF00FFDF00
FFDF00FFDF00FFF900FFF900D4FF002FFF0003FF002800FF00CBFFA3FF00D4FF00D4FF00
D4FF0000FF508BFF0000FF3BA3FF00A3FF00A3FF008BFF0073FF005CFF0046FF0019FF00
00FF502800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF5019FF005CFF0073FF008BFF008BFF00A3FF00BBFF00BBFF00
BBFF0000FFB3BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00BBFF0073FF005CFF00BBFF00
BBFF00FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFF900D4FF0019FF00ECFF00FFAA00
FF8F00FF8F00FF8F00FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FFAA00FFC500BBFF0000CBFF00FF26D4FF00FFF900FFF900BBFF00
2FFF00ECFF00D4FF0073FF0046FF00BBFF00FFF900FFDF00FFDF00FFDF00FFC500FFDF00
FFDF00FFDF00FFDF00FFDF00D4FF0000FF3BD4FF00D4FF0003FF00BBFF00ECFF00ECFF00
ECFF00ECFF00D4FF00D4FF00D4FF00BBFF00BBFF00A3FF008BFF0073FF0046FF0000FF3B
0044FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00CBFF5CFF0073FF00A3FF00BBFF00BBFF00D4FF00D4FF00
D4FF00ECFF00ECFF00FFF900FFF900FFF900FFF900FFF900ECFF0000FF1103FF00FFF900
FFDF00FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFF900BBFF00D4FF00A3FF00FFAA00
FF8F00FF8F00FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FFAA00FFDF00FFDF00FFF900D4FF00FFDF00FFC500FFC500
FFDF00FFDF00ECFF005CFF0019FF0000FF64FFF900FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFDF00FFDF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900ECFF00D4FF00D4FF00BBFF00BBFF00A3FF002FFF0003FF0000CBFF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FF3B73FF00A3FF00BBFF00D4FF00ECFF00ECFF00
ECFF00FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFF90003FF00FFF900FFDF00
FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFF900BBFF00FFDF00FFC500FF8F00
FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF002FFF00ECFF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500
FFC500FFC500FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00
FFF900FFF900FFF900FFF900ECFF00D4FF00D4FF00A3FF008BFF0000FF3B00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF00FFB346FF008BFF00BBFF00ECFF00ECFF00FFF900
FFF900FFF900FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFDF00FFC500FFC500FFC500
FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFC50046FF00A3FF00FFAA00FF8F00FF8F00
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFC500FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500FFDF00FFDF00FFDF00FFDF00
FFDF00FFF900FFF900FFF900ECFF00ECFF00D4FF0073FF005CFF0000FFEC2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FFBBFF00ECFF00ECFF00FFF900
FFF900FFDF00FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00
FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFDF00FFDF00
FFDF00FFDF00FFF900FFF900ECFF00ECFF00D4FF0073FF002800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF0034FF00FF642800FF8BFF00D4FF00FFF900FFF900
FFDF00FFDF00FFC500FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500FFC500
FFDF00FFDF00FFDF00FFF900ECFF00ECFF00BBFF002FFF002800FF00FF642800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF782FFF00A3FF00D4FF00ECFF00FFF900
FFDF00FFC500FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFC500FFDF00FFDF00FFF900ECFF00D4FF00BBFF008BFF0019FF0000FFA02800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF46FF0000FF50ECFF00FFF900
FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF00FFDF00ECFF0073FF0073FF0000FF112800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B00FFFE46FF00D4FF00FFF900
FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00ECFF0073FF0003FF002800FF00FFFE2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00FF5019FF0000FFD900FFC600FFA0FFDF00
FFC500FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFF900D4FF0046FF0000FFC603FF0000FF642800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF5CFF008BFF00BBFF00ECFF00FFDF00
FFDF00FFC500FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900D4FF0046FF002FFF005CFF002800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF00A8FF0014FFA3FF00D4FF00ECFF00FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900FFF900D4FF00A3FF0073FF0019FF0000FFA02800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FF3B00FF11D4FF00ECFF00FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900FFF900D4FF00A3FF0046FF0000EFFF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF46FF00A3FF00D4FF00FFF900
FFDF00FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFF900ECFF00ECFF0046FF000054FF00DDFF2800FF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF2800FF00FF782800FF00FF1100EFFF00FFFE8BFF0073FF0000FF26
ECFF00FFC500FFAA00FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFDF00FFDF00ECFF00ECFF00D4FF008BFF0003FF002800FF00CBFF2800FF
2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF8C2FFF0003FF005CFF0046FF0000FF502FFF0000FFECD4FF00
ECFF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFC500FFDF00ECFF00A3FF00D4FF00A3FF008BFF0000FFA000FFC619FF0000FF64
00FF1100FF642800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF
2800FF2800FF2800FF00FF8C73FF00A3FF00A3FF005CFF0000FF1173FF00BBFF00FFF900
FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500ECFF00A3FF0000FF1100EFFF8BFF005CFF0000CBFF2FFF005CFF005CFF00
73FF0019FF002800FF00FF8C2800FF2800FF2800FF2800FF2800FF2800FF2800FF00FFFE
00FF5000FF3B19FF0000FF1100FFA0BBFF00BBFF0000FF1100FF1173FF00D4FF00FFDF00
FFC500FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00
FFAA00FFC500ECFF0073FF00BBFF0073FF0000FFD90086FF03FF0000FF268BFF00A3FF00
8BFF0000FF3B00CBFF2FFF0000FF2600FF2600CBFF2800FF2800FF2800FF2800FF2800FF
00FF3B46FF0073FF0046FF00D4FF00ECFF00ECFF00D4FF0073FF005CFF0000FF26ECFF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00
FF8F00FFAA00FFC500FFF900FFF900ECFF00D4FF00BBFF005CFF002FFF00BBFF00BBFF00
BBFF00A3FF0003FF0073FF0046FF0000FF110054FF2800FF2800FF2800FF2800FF2800FF
0A00FF46FF00A3FF00BBFF00ECFF00ECFF00ECFF00ECFF00D4FF00ECFF00BBFF00A3FF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00
FF8F00FFAA00FFAA00FFC500FFC500FFDF00FFF900BBFF000075FF00FFA0D4FF00ECFF00
ECFF00D4FF00BBFF00A3FF005CFF002800FF00BAFF2800FF2800FF2800FF2800FF2800FF
00FFC65CFF008BFF00D4FF00ECFF00FFF900FFF900FFDF00FFDF00FFDF00FFF900D4FF00
FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FFAA00FFAA00FFC500FFC500FFDF00D4FF008BFF00ECFF00FFF900FFF900
ECFF00ECFF00D4FF00A3FF0073FF0019FF000054FF2800FF2800FF2800FF2800FF00DDFF
2800FF19FF0000FF2646FF00FFF900FFF900FFDF00FFDF00FFC500FFC500FFC500FFAA00
FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00
FF8F00FF8F00FF8F00FFAA00FFAA00FFC500FFC500FFF900FFF900FFDF00FFDF00FFF900
FFF900ECFF00D4FF0073FF0046FF0000FF3B2800FF2800FF2800FF2800FF00FFFE03FF00
46FF0000FFFE8BFF00D4FF00FFF900FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFC500FFC500FFDF00FFDF00FFDF00
FFDF00FFF9002FFF005CFF005CFF0000DDFF5CFF0003FF0000FFC60054FF00FF3B19FF00
8BFF0073FF0000FF11ECFF00FFDF00FFC500FFC500FFC500FFC500FFAA00FFAA00FFAA00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500FFC500
FFDF00FFDF00FFF900ECFF00BBFF0000FF50A3FF008BFF0046FF0000FF8C00DDFF73FF00
BBFF00BBFF00D4FF00FFF900FFDF00FFC500FFC500FFC500FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500FFC500
FFC500FFC500FFDF00FFF900ECFF00D4FF00BBFF00A3FF0046FF0000FF7800FF3B00FFFE
BBFF00ECFF00ECFF00FFF900FFDF00FFC500FFC500FFAA00FFAA00FFAA00FFAA00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFF900ECFF00ECFF00BBFF005CFF0000FF6400FF1100DDFF
D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFC500FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFC500
FFC500FFC500FFC500FFDF00FFF900FFF900ECFF00D4FF00A3FF005CFF0019FF00A3FF00
D4FF00ECFF00FFF900FFDF00FFDF00FFC500FFC500FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00D4FF00BBFF0073FF0000FF268BFF00
BBFF00D4FF00FFF900FFF900FFDF00FFC500FFAA00FFAA00FFAA00FFAA00FF8F00FF8F00
FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF900ECFF00D4FF00A3FF002FFF002FFF0003FF00
8BFF00BBFF00ECFF00FFF900FFDF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF900D4FF00BBFF0000FF1119FF00A3FF00A3FF00
00FF6400FF11BBFF00D4FF00ECFF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00
FF8F00FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00
FFC500FFC500FFC500FFDF00FFDF00FFF9008BFF005CFF0000FF64BBFF00D4FF00D4FF00
BBFF00A3FF0019FF00A3FF005CFF00D4FF00ECFF00FFC500FFAA00FF8F00FF8F00FF8F00
FF8F00FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00
FFAA00FFC500FFDF00FFDF00FFDF00ECFF0073FF0000FFB38BFF00ECFF00FFF900FFF900
FFF900D4FF0019FF0073FF0019FF0000FFA0ECFF00FFDF00FFC500FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500FFDF00FFDF00FFF900ECFF008BFF00A3FF00A3FF00FFF900FFDF00FFDF00
FFDF00FFF900ECFF00ECFF00ECFF00A3FF002FFF00ECFF000034FFFF8F00FF8F00FF8F00
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFC500FFF900FFF900ECFF00D4FF0073FF00BBFF00FFF900FFDF00FFDF00FFC500
FFC500FFC500FFC500FFC500FFDF00FFF90073FF00ECFF00FFC500FF8F00FF8F00FF7300
FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFDF008BFF00A3FF002FFF008BFF008BFF0000FFECFFF900FFC500FFC500FFC500
FFAA00FFAA00FFAA00FFAA00FFC500FFC500ECFF00FFDF00FFAA00FF8F00FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFDF00D4FF0073FF002800FF46FF00ECFF00FFF900FFC500FFC500FFC500FFAA00
FFAA00FFAA00FFAA00FFAA00FFAA00FFAA00FFDF00BBFF00FFAA00FF8F00FF7300FF7300
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFAA00FFDF00FFF9002FFF0000FF8C2FFF00ECFF00FFDF00FFC500FFAA00FFAA00FF8F00
FF8F00FF8F00FF8F00FF8F00FFAA00FFAA00FFAA00FF8F00FF8F00FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFC500FFDF00D4FF008BFF00D4FF00D4FF00ECFF00FFC500FFAA00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFC500FFDF00ECFF00BBFF00FFF900FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FF8F00FFAA00
FFC500FFDF00D4FF00D4FF00FFDF00FFC500FFAA00FFAA00FF8F00FF8F00FF8F00FF8F00
FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF7300FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00
FFC500FFDF00D4FF00ECFF00FFDF00FFC500FFAA00FF8F00FF8F00FF8F00FF8F00FF8F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF8F00FF8F00FF8F00FFAA00FFAA00
FFDF00FFF90046FF0000FF26FFDF00FFC500FFAA00FF8F00FF8F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF8F00FFAA00FFAA00FFDF00
2FFF00ECFF00FFDF00FFDF00D4FF00FFC500FFAA00FF8F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FFAA00FFC500BBFF00
FFDF00FFAA00FFAA00FFC500FFDF00FFAA00FF8F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF7300FF8F00FFC500FFDF00
FFC500FFAA00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300FF8F00FF8F00
FF8F00FF8F00FF8F00FF8F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF7300FF7300FF7300FF7300FF7300FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700
FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF5700FF5700
FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00
FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF3B00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00FF1D00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.875, 265.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001SR000`400?l00000o`00003oo`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`
0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00o`3ooon`0?ooo`00203ooom10?l004L0oad0c@3o
>`190?lM00T0oooo00080?oood40o`00A`3o7@3=0?lk04T0oad02@3oool000P0oooo?`3o00160?lM
0=<0oc/0AP3o7@090?ooo`00203oooln0?l004@0oad0V03o>`0@0?mG0340oc/0@`3o7@090?ooo`00
203oooln0?l004@0oad0V03o>`0@0?mG0340oc/0@`3o7@090?ooo`00203oooll0?l004<0oad0S`3o
>`0W0?mG02X0oc/0?`3o7@090?ooo`00203oooll0?l003h0oad0S@3o>`0f0?mG02H0oc/0>`3o7@09
0?ooo`00203oooll0?l003h0oad0S@3o>`0f0?mG02H0oc/0>`3o7@090?ooo`00203ooolk0?l003`0
oad0RP3o>`0P0?mG00P0og<06@3oE`0T0?lk03P0oad02@3oool000P0oooo>`3o000l0?lM08X0oc/0
803oE`080?mc01T0oeL0903o>`0h0?lM00T0oooo00080?ooocT0o`00>`3o7@280?lk01h0oeL05@3o
L`0H0?mG02<0oc/0=03o7@090?ooo`00203ooolh0?l003X0oad0Q@3o>`0P0?mG00<0og<02P3oS`0>
0?mc01P0oeL08@3o>`0c0?lM00T0oooo00080?ooocP0o`00>P3o7@250?lk0200oeL00`3oL`0:0?n?
00h0og<0603oE`0Q0?lk03<0oad02@3oool000P0oooo>03o000g0?lM08D0oc/0803oE`050?mc0003
0?n?003oa@00olD00080oml000<0olD00?nZ003oZP00103oS`0@0?mc01X0oeL07`3o>`0`0?lM00T0
oooo00080?ooocH0o`00=P3o7@250?lk0240oeL01@3oL`020?n?00030?nZ003oa@00olD00080^ol0
00@0oml00?nZ003oZP00ojX00P3oa@000`3og`00ojX00?nZ00020?n?00h0og<06`3oE`0P0?lk02`0
oad02@3oool000P0oooo=P3o000f0?lM08D0oc/08@3oE`050?mc0080ohl000<0ojX00?o5003oa@00
0P2ko`00103og`00ojX00?nZ003oZP020?o500030?oO003oZP00ojX00080ohl03P3oL`0K0?mG0200
oc/0;03o7@090?ooo`00203ooold0?l003D0oad0P`3o>`0S0?mG00P0og<00P3oS`030?nZ0080oml0
00<0;ol00>co003/o`000`3og`000`3Do`00olD00?o500020?nZ00030?n?003oL`00og<000h0og<0
6`3oE`0P0?lk02T0oad02@3oool000P0oooo=03o000c0?lM0880oc/09@3oE`080?mc00@0ohl0103o
ZP00103og`00ooT00?oi0016o`02003o9P030?oO003oa@00olD00080ojX00`3oS`0@0?mc01/0oeL0
7`3o>`0X0?lM00T0oooo00080?oooc@0o`00<`3o7@220?lk02D0oeL0203oL`040?n?00@0ojX000@0
oml00?oi003on@00A_l00P00obH00`3og`00olD00?o500020?nZ00<0ohl0403oL`0K0?mG01l0oc/0
:03o7@090?ooo`00203ooolc0?l00340oad0PP3o>`0V0?mG00X0og<0103oS`040?nZ00040?o5003o
g`00oml00=Co0080k?l000<0oml00?o5003oa@000P3oZP080?n?00`0og<07@3oE`0P0?lk02@0oad0
2@3oool000P0oooo<`3o000a0?lM0880oc/09P3oE`0:0?mc00@0ohl0103oZP00103oa@00oml00?oO
003Do`020>co00030?oO003oa@00olD00080ojX0203oS`0<0?mc01d0oeL0803o>`0T0?lM00T0oooo
00080?oooc<0o`00;P3o7@230?lk02H0oeL0303oL`060?n?0080ojX000<0olD00?oO003og`000`3D
o`000`3og`00olD00?o500030?nZ00/0ohl02P3oL`0L0?mG0280oc/08@3o7@090?ooo`00203ooola
0?l002h0oad0PP3o>`0X0?mG00d0og<01P3oS`020?nZ00040?o5003og`00oml00>co0080^ol000<0
ooT00?oO003og`000P3oa@000`3oZP00ohl00?n?000<0?n?00P0og<07`3oE`0O0?lk0200oad02@3o
ool000P0oooo<@3o000^0?lM0880oc/0:03oE`0=0?mc00H0ohl00P3oZP00103oa@00oml00?oO003/
o`020;_o00030?oi003og`00oml00080olD000<0ojX00?n?003oS`00303oS`080?mc01l0oeL07`3o
>`0P0?lM00T0oooo00080?oooc00o`00;03o7@220?lk02T0oeL03`3oL`060?n?0080ojX000@0olD0
0?oO003og`00e?l00P2;o`030=Co0080k?l000<0olD00?nZ003oZP00403oS`040?mc0200oeL08@3o
>`0M0?lM00T0oooo00080?oooc00o`00:P3o7@210?lk02`0oeL03`3oL`060?n?00<0ojX00P3og`00
103on@00;ol002oo0000oh`202oo0080k?l000<0oml00?o5003oa@000`3oZP080?n?00D0ojX00`3o
S`030?mc0240oeL0803o>`0K0?lM00T0oooo00080?oooc00o`00:P3o7@210?lk02`0oeL03`3oL`06
0?n?00<0ojX00P3og`00103on@00;ol002oo0000oh`202oo0080k?l000<0oml00?o5003oa@000`3o
ZP080?n?00D0ojX00`3oS`030?mc0240oeL0803o>`0K0?lM00T0oooo00080?ooobh0o`00:@3o7@22
0?lk02d0oeL0403oL`060?n?00<0ojX00P3og`00103Do`00Lol007?o000X0?l204Ko0080k?l000<0
ooT00?o5003oa@000`3oa@0;0?nZ0080oml000@0^ol00?nZ003oZP00ohl0103oL`0Q0?mG0240oc/0
603o7@090?ooo`00203oool^0?l002T0oad0PP3o>`0]0?mG0100og<01P3oS`030?nZ0080oml000@0
e?l007?o001co`00:03o0P16o`020>co00030?oi003oa@00olD000<0olD02`3oZP020?oO00040;_o
003oZP00ojX00?n?00@0og<08@3oE`0Q0?lk01P0oad02@3oool000P0oooo;03o000Z0?lM0800oc/0
;P3oE`0@0?mc00P0ohl00`3oZP020?oO000408_o002So`00Xol002oo00@0Rol000<00?o/0?oi003o
n@001@3oa@060?nZ00<0olD00P3/o`00103og`00ojX00?nZ003oS`050?mc0240oeL08P3o>`0F0?lM
00T0oooo00080?ooob`0o`00:03o7@210?lk02h0oeL04@3oL`080?n?00<0ojX00P3oa@030?oi0003
0>co003Do`00e?l00080Lol000<0^ol00?oi003on@000`3og`080?o500030?oO003on@00ooT00080
Lol000<0k?l00?o5003oa@000`3oS`050?mc0240oeL08@3o>`0E0?lM00T0oooo00080?ooob`0o`00
:03o7@210?lk02h0oeL04@3oL`080?n?00<0ojX00P3oa@030?oi00030>co003Do`00e?l00080Lol0
00<0^ol00?oi003on@000`3og`080?o500030?oO003on@00ooT00080Lol000<0k?l00?o5003oa@00
0`3oS`050?mc0240oeL08@3o>`0E0?lM00T0oooo00080?ooob/0o`009P3o7@200?lk0300oeL04`3o
L`080?n?00<0ojX00P3oa@030?oO00030?oi003/o`00k?l00080Rol00`2So`000`3on@00oml00?oO
00030?oO0080ooT0103/o`020:?o0080;ol000<0k?l0000do`00=?l01@3oS`040?mc0280oeL08`3o
>`0A0?lM00T0oooo00080?ooob/0o`00903o7@210?lk0340oeL04`3oL`060?n?00D0ojX00P3oa@04
0?oO0080k?l00P1co`001000ok<0Rol008_o003/o`050?oi0080e?l000@06Ol007?o001co`006Ol0
0P00oj020>co00030?oO003oa@00olD000D0ohl0103oL`0S0?mG02<0oc/0403o7@090?ooo`00203o
ool[0?l002@0oad0P@3o>`0a0?mG01<0og<01P3oS`050?nZ0080olD0103og`020>co0080Lol000@0
0?nc08_o002;o`00k?l01@3on@020=Co000401Wo001co`00Lol001Wo00800?nP0P3/o`000`3og`00
olD00?o500050?n?00@0og<08`3oE`0S0?lk0100oad02@3oool000P0oooo:@3o000U0?lM07l0oc/0
<P3oE`0C0?mc00L0ohl01@3oZP040?o500<0oml00P3on@0208_o000405co0000of@00?mT0;_o00@0
e?l000@0^ol00:?o002So`006Ol00P2So`000`1Lo`00e?l00=Co00020>co00030?o5003oZP00ojX0
00H0ohl01@3oL`0S0?mG02<0oc/03P3o7@090?ooo`00203ooolY0?l002<0oad0O`3o>`0c0?mG01@0
og<01`3oS`050?nZ00@0olD00`3og`020?oi0080e?l000@0^ol0003o4@00oa406Ol0102So`001000
of@00?lA003o4@2ko`020=Co00030>co003og`00oml00080olD00`3oZP060?n?00L0og<08P3oE`0S
0?lk00d0oad02@3oool000P0oooo:@3o000S0?lM07l0oc/0<`3oE`0D0?mc00L0ohl01@3oZP040?o5
00<0oml00P3on@020=Co00040;_o0000oa400?lA01Wo00@0Xol000@00?mT003o4@00oa40^ol00P3D
o`000`3/o`00oml00?oO00020?o500<0ojX01P3oS`070?mc0280oeL08`3o>`0=0?lM00T0oooo0008
0?ooobP0o`008@3o7@200?lk03<0oeL05P3oL`050?n?00L0ojX0103oa@030?oO0080ooT00P3/o`00
0`3Do`00Xol00:?o000302oo00800ol000@0Rol00;_o002ko`00k?l00P3on@030?oO0080olD00`3o
ZP060?n?00P0og<08`3oE`0T0?lk00X0oad02@3oool000P0oooo:03o000Q0?lM0800oc/0<`3oE`0F
0?mc00D0ohl01`3oZP040?o500<0oml00P3on@020>co00030=Co002So`00Xol000<0;ol00P03o`00
102;o`00^ol00;_o003/o`020?oi00<0oml00P3oa@030?nZ00H0ohl0203oL`0S0?mG02@0oc/02P3o
7@090?ooo`00203ooolX0?l001l0oad0O`3o>`0e0?mG01H0og<01@3oS`080?nZ00@0olD00`3og`02
0?oi0080k?l000@0e?l00;_o002ko`00Lol00P00obH208_o00030;_o003Do`00e?l000<0ooT000<0
oml00?o5003oa@001P3oZP070?n?00P0og<08`3oE`0T0?lk00P0oad02@3oool000P0oooo9P3o000P
0?lM07l0oc/0=P3oE`0D0?mc00L0ohl01P3oZP060?o50080oml00`3on@020>co00040=Co002So`00
Xol005co00806Ol00P2So`00103Do`00k?l00>co003on@030?oO00@0olD0103oZP070?n?00T0og<0
8`3oE`0U0?lk00H0oad02@3oool000P0oooo9P3o000P0?lM07l0oc/0=P3oE`0D0?mc00L0ohl01P3o
ZP060?o50080oml00`3on@020>co00040=Co002So`00Xol005co00806Ol00P2So`00103Do`00k?l0
0>co003on@030?oO00@0olD0103oZP070?n?00T0og<08`3oE`0U0?lk00H0oad02@3oool000P0oooo
903o000P0?lM07l0oc/0=P3oE`0F0?mc00D0ohl0203oZP060?o50080oml000<0ooT00>co003/o`00
0P3/o`00102ko`00G?l005co0000of@2003o4@800=go00@0e?l00>co003/o`00ooT00`3og`040?o5
00@0ojX01`3oS`0;0?mc02<0oeL0903o>`050?lM00T0oooo00080?ooob@0o`007`3o7@1o0?lk03D0
oeL05`3oL`040?n?00P0ojX01`3oa@00103og`00ooT00?oi003/o`020=Co0080^ol000@0Xol004Ko
0016o`000?mh0P00oc/2003ooP040;_o003/o`00k?l00>co0080ooT000<0oml00?o5003oa@000P3o
a@060?nZ00D0ohl0303oL`0S0?mG02D0oc/00`3o7@090?ooo`00203ooolT0?l001l0oad0O`3o>`0e
0?mG01L0og<0103oS`080?nZ00L0olD000@0oml00?oi003on@00k?l00P3Do`020;_o00040:?o0016
o`00A_l0003oN0800?lk0P00ooh0102ko`00k?l00>co003/o`020?oi00030?oO003oa@00olD00080
olD01P3oZP050?n?00`0og<08`3oE`0U0?lk00<0oad02@3oool000P0oooo8`3o000N0?lM07d0oc/0
>03oE`0F0?mc00D0ohl0203oZP050?o500<0oml000@0ooT00>co003/o`00^ol00P00oe020:?o0004
08_o0016o`00A_l0003oS0800=go0P1co`030;_o00040=Co003on@00ooT00?oO00D0olD01@3oZP06
0?n?00d0og<08`3oE`0T0?lk0080oad02@3oool000P0oooo8`3o000N0?lM07d0oc/0>03oE`0F0?mc
00D0ohl0203oZP050?o500<0oml000@0ooT00>co003/o`00^ol00P00oe020:?o000408_o0016o`00
A_l0003oS0800=go0P1co`030;_o00040=Co003on@00ooT00?oO00D0olD01@3oZP060?n?00d0og<0
8`3oE`0T0?lk0080oad02@3oool000P0oooo8`3o000L0?lM07h0oc/0=`3oE`0F0?mc00L0ohl01@3o
ZP030?o500H0oml00P3on@00100_o`00G?l005co001Lo`02003Mo`80G?l000@00ol0003oaP00olH0
05Co0P00oc/201Wo000408_o001co`00Lol0003o4@80k?l000<0oml00?o5003oa@001@3oa@050?nZ
00@0ohl0403oL`0R0?mG02@0oc/02@3oool000P0oooo8@3o000M0?lM07d0oc/0>03oE`0F0?mc00H0
ohl00`3oZP040?o500<0ooT00`3og`030?oi0080k?l000@0e?l007?o001co`00A_l00P00oc/602P0
o`800?on0P03o`001016o`000?on003ooP2;o`020=Co00030?oi003og`00oml000H0olD0103oZP04
0?n?0180og<0803oE`0T0?lk00T0oooo00080?ooob40o`007@3o7@1m0?lk03P0oeL05P3oL`060?n?
00<0ojX0103oa@030?oi00<0oml00`3on@020>co00040=Co001co`00Lol004Ko00800?lk1P0X0?l2
003ooP800ol000@0A_l0003ooP00ooh0Rol00P3Do`000`3on@00oml00?oO00060?o500@0ojX0103o
S`0B0?mc0200oeL0903o>`090?ooo`00203ooolQ0?l001/0oad0OP3o>`0g0?mG01H0og<01`3oS`03
0?nZ00<0olD00P3og`00103Do`00Rol008_o003/o`040?oi00<0k?l000@0e?l00:?o002So`00Lol0
0P0Io`02001Do`H0:03o0P00gOl0100X0?l06Ol001Wo0000obH204Ko00<0ooT00`3og`050?o500<0
ojX01@3oS`0A0?mc0200oeL08`3o>`090?ooo`00203ooolP0?l001/0oad0N`3o>`0j0?mG01H0og<0
1P3oS`030?nZ00<0olD00P3og`020?oi00040;_o0000MOl007Go003oX080e?l00`3/o`020=Co0004
0;_o002So`00Xol005co0080:03o0P00^_l802P0o`04003oaP1Lo`00G?l008_o0080e?l000<0k?l0
0?oi003on@000P3on@040?oO0080ooT00P3Do`000`3oZP00ohl00?n?00030?n?01D0og<07P3oE`0Q
0?lk00T0oooo00080?ooob00o`006`3o7@1k0?lk03X0oeL05P3oL`060?n?00<0ojX00`3oa@020?oO
0080ooT000@0^ol0001eo`00MOl00?nP0P3Do`030>co0080e?l000@0^ol00:?o002So`00G?l00P0X
0?l2002jo`P0:03o00@00?o605co001Lo`00Rol00P3Do`000`3/o`00ooT00?oi00020?oi00@0oml0
0P3on@020=Co00030?nZ003oS`00ohl000<0ohl05@3oL`0N0?mG0240oc/02@3oool000P0oooo803o
000I0?lM07`0oc/0>@3oE`0F0?mc00P0ohl00P3oZP00103oa@00ooT00?oi003on@020>co0080e?l0
00@0^ol005co001Lo`00;ol01@2ko`020:?o000400?o001co`00Lol004Ko00800?lA0P00E?l802P0
o`0400X0o`16o`00A_l00:?o0080^ol01P3/o`020=Co00030>co002ko`00^ol00080Xol000<0olD0
0?nZ003oZP001@3oS`0D0?mc01h0oeL0803o>`090?ooo`00203ooolN0?l001X0oad0N`3o>`0i0?mG
01D0og<02@3oS`020?nZ0080olD000@0k?l007?o001co`00^ol00P1co`02003of@040026o`03o`00
0ol0003o9P80Rol00P2So`00102;o`000?lk003o>`00bol202oo00<00?lV0P00bol802P0o`04003o
>`16o`00A_l007?o0080A_l000<0e?l00>co003/o`000P3/o`00103Do`00Lol007?o001Lo`02003o
9P80k?l000<0olD00?nZ003oZP001@3oS`0G0?mc01/0oeL0803o>`090?ooo`00203ooolN0?l001X0
oad0N`3o>`0i0?mG01D0og<02@3oS`020?nZ0080olD000@0k?l007?o001co`00^ol00P1co`02003o
f@040026o`03o`000ol0003o9P80Rol00P2So`00102;o`000?lk003o>`00bol202oo00<00?lV0P00
bol802P0o`04003o>`16o`00A_l007?o0080A_l000<0e?l00>co003/o`000P3/o`00103Do`00Lol0
07?o001Lo`02003o9P80k?l000<0olD00?nZ003oZP001@3oS`0G0?mc01/0oeL0803o>`090?ooo`00
203ooolN0?l001P0oad0O03o>`0g0?mG01D0og<02`3oS`030?nZ0080olD000@0k?l00:?o002So`00
0?lA0P00kol208_o000405co0000bol00<_o02oo00@0G?l000@0Lol001Wo000Io`00:03o0P00oh`;
02P0o`800?on00@00?m@003o>`00oc/06Ol00P00oa400`00oj00^ol00;_o00020;_o00<00?lA00<0
Lol00=Co003Do`000P3og`030?o500030?nZ003oS`00ohl000<0ohl0603oL`0K0?mG01h0oc/02@3o
ool000P0oooo7P3o000H0?lM07`0oc/0=`3oE`0E0?mc00/0ohl00`3oZP020?o500040>co002So`00
Xol0003o4@800>oo0P2;o`00101Lo`000<_o003;o`0_o`0405co000407?o000Io`006Ol002P0o`80
0?n<2`0X0?l2003ooP04003oD000oc/00?lk01Wo00800?lA00<00?nP0;_o002ko`000P2ko`03003o
4@0307?o003Do`00e?l00080oml00`3oa@000`3oZP00ohl00?n?00030?n?01P0og<06`3oE`0N0?lk
00T0oooo00080?oooah0o`005P3o7@1l0?lk03P0oeL04`3oL`0<0?n?00D0ojX00P3oa@00103og`00
k?l00>co002So`020=Co0080Xol000@0Rol0003oX000oj000?o60P0Io`02003oI003003o4@00of@0
0?mT01@0:03o0P00oh`00`1co`00Xol00:?o00020:?o000405co0000oa400?lA07?o0080^ol00P3o
n@000`3og`00olD00?o500030?nZ00D0ohl06@3oL`0I0?mG01d0oc/02@3oool000P0oooo7@3o000F
0?lM07X0oc/0>@3oE`0A0?mc00l0ohl0103oZP040?o500<0oml00`3/o`020=Co000408_o0003o`00
0ol002P0o`800<_o6@0X0?l2003oS00302oo0003o`000ol00080G?l000@0A_l0003oD000oe00;ol0
0P00on`20=Co00030>co003oa@00olD000<0ojX01P3oS`0J0?mc01T0oeL06`3o>`090?ooo`00203o
oolM0?l001H0oad0NP3o>`0i0?mG0140og<03`3oS`040?nZ00@0olD00`3og`030>co0080e?l000@0
Rol000?o0003o`00:03o0P00bolI02P0o`800?n<00<0;ol000?o0003o`000P1Lo`001016o`000?m@
003oD00_o`02003ok080e?l000<0k?l00?o5003oa@000`3oZP060?n?01X0og<06@3oE`0K0?lk00T0
oooo00080?oooad0o`00503o7@1j0?lk03T0oeL0403oL`0B0?n?00@0ojX01@3oa@020?oO00030?oi
003/o`00k?l00080k?l000@0A_l0001Do`00E?l00=go7@0X0?l00`00ogP0:03o02P0o`02003o4@04
003_o`00ooh00?on08_o0080Lol00P00obH00`3/o`00olD00?o500050?nZ00@0ohl07@3oL`0F0?mG
01/0oc/02@3oool000P0oooo6`3o000E0?lM07X0oc/0=`3oE`0@0?mc01<0ohl01P3oZP050?o50080
oml00`3on@020=Co00040:?o0016o`00A_l0003_ob<0:03o0P16o`000`2So`00e?l00=Co00020?oi
00030?oO003oa@00olD000D0ojX01`3oS`0K0?mc01L0oeL06@3o>`090?ooo`00203ooolK0?l001D0
oad0NP3o>`0g0?mG0100og<04`3oS`060?nZ00D0olD00P3og`030?oi0080e?l000@0Xol004Ko0016
o`000>oo8`0X0?l204Ko00030:?o003Do`00e?l00080ooT000<0oml00?o5003oa@001@3oZP070?n?
01/0og<05`3oE`0I0?lk00T0oooo00080?oooa/0o`005@3o7@1h0?lk03P0oeL03P3oL`0E0?n?00L0
ojX01@3oa@020?oO00<0ooT00P3Do`00102So`00Lol007?o000Io`02003oX200:03o00@00?lk003o
4@00oa40e?l00P3/o`020?oi00030?oO003oa@00olD000H0ojX0203oS`0M0?mc01<0oeL06@3o>`09
0?ooo`00203ooolK0?l001D0oad0N03o>`0h0?mG00h0og<05@3oS`070?nZ00D0olD00P3og`030?oi
0080e?l000@0Xol007?o001co`006Ol00P00oj0P02P0o`04003o>`00oa400?lA0=Co0080k?l00P3o
n@000`3og`00olD00?o500060?nZ00P0ohl07@3oL`0C0?mG01T0oc/02@3oool000P0oooo6@3o000E
0?lM07T0oc/0=@3oE`0?0?mc01@0ohl02`3oZP050?o50080oml000<0ooT00=Co003Do`000P16o`00
0`0_o`00G?l005co000Q02P0o`800:So00@001Co0:?o002So`00e?l00P3/o`020?oi00030?oO003o
a@00olD000P0ojX0203oS`0L0?mc01<0oeL0603o>`090?ooo`00203ooolI0?l001<0oad0N@3o>`0f
0?mG00d0og<05P3oS`0;0?nZ00H0olD00P3og`000`3on@00e?l00=Co000204Ko0004003oaP03o`00
0ol0003oI280:03o00@0G?l008_o002;o`00^ol00P3/o`030?oO00<0olD0203oZP0:0?n?01/0og<0
4`3oE`0F0?lk00T0oooo00080?oooaT0o`004`3o7@1i0?lk03H0oeL03@3oL`0F0?n?00/0ojX01P3o
a@020?oO00030?oi003Do`00e?l00080A_l000@00?o600?o0003o`000?mT8P0X0?l0101Lo`00Rol0
08_o002ko`020>co00<0oml00`3oa@080?nZ00X0ohl06`3oL`0C0?mG01H0oc/02@3oool000P0oooo
6@3o000B0?lM07L0oc/0=P3oE`0<0?mc01P0ohl03@3oZP060?o50080oml000<0k?l007?o001co`00
0P03o`000`0X0?l00?on003ooP0Q02P0o`800?m@00@06Ol0003of@00omT00?o60P00oj020?oO00@0
olD0203oZP0=0?n?01/0og<0403oE`0F0?lk00T0oooo00080?oooaP0o`004@3o7@1g0?lk03D0oeL0
303oL`0H0?n?00h0ojX01`3oa@030?oO00030>co001co`00Lol00080Lol000<00?lA02P0o`0X0?l0
8`0X0?l01000oc/00?on003ooP16o`020=Co0080ooT000<0oml00?o5003oa@000`3oa@080?nZ0100
ohl0603oL`0?0?mG01D0oc/02@3oool000P0oooo603o000A0?lM07L0oc/0=@3oE`0<0?mc01P0ohl0
3P3oZP070?o500<0oml000<0k?l007?o001co`000P1co`000`00oa40:03o02P0o`0S02P0o`04003o
>`00ooh00?on04Ko0080e?l00P3on@000`3og`00olD00?o500030?o500P0ojX0403oS`0H0?mc00l0
oeL05@3o>`090?ooo`00203ooolH0?l00140oad0MP3o>`0d0?mG00/0og<0603oS`0@0?nZ00H0olD0
0`3og`020?oi00030>co003Do`00e?l00080^ol000@0Rol001Wo000Io`000?nP8`0X0?l204Ko0003
003oD03/o`00k?l00080ooT000<0oml00?o5003oa@001@3oa@070?nZ01D0ohl04`3oL`0>0?mG01D0
oc/02@3oool000P0oooo5P3o000B0?lM07D0oc/0<`3oE`0<0?mc01D0ohl04`3oZP060?o500D0oml0
0P3on@030>co0080^ol000@0;ol002P0o`0X0?l00?mT800X0?l2003oN00402oo002So`00Xol00=Co
0080k?l00P3on@000`3og`00olD00?o500060?o500P0ojX07@3oS`0;0?mc00h0oeL04`3o>`090?oo
o`00203ooolF0?l00180oad0M@3o>`0c0?mG00`0og<05@3oS`0C0?nZ00H0olD01@3og`020?oi00<0
k?l00P2ko`00100_o`00:03o02P0o`00of@P02P0o`800?mh00@0;ol00:?o002So`00e?l00P3/o`02
0?oi00030?oO003oa@00olD000H0olD0203oZP0M0?n?00/0og<03P3oE`0C0?lk00T0oooo00080?oo
oaH0o`00403o7@1e0?lk0380oeL0303oL`070?n?02<0ojX0103oa@070?oO00<0ooT00`3/o`020=Co
000307?o000X0?l0:03o01l0:03o0P00=?l2003oI00402P0o`2;o`00Rol00=Co00@0ooT00`3og`09
0?o500L0ojX07`3oS`080?mc00l0oeL04@3o>`090?ooo`00203ooolF0?l00100oad0M@3o>`0b0?mG
00`0og<01`3oS`0S0?nZ00@0olD01`3og`030?oi00<0k?l00P3Do`000`1co`00:03o02P0o`0O02P0
o`8003Co0P00of@0100X0?l0Rol008_o003Do`040?oi00<0oml02@3oa@070?nZ01l0ohl0203oL`0?
0?mG0140oc/02@3oool000P0oooo5P3o000>0?lM07H0oc/0;`3oE`0?0?mc00@0ohl0303oZP090?o5
00d0ojX01P3oa@080?oO00D0ooT00`3/o`020=Co000407?o001Lo`00G?l0003ok2<0:03o0P2ko`03
0>co00<0ooT01@3og`090?o500L0ojX06@3oS`050?nZ00<0ohl01@3oL`0=0?mG0140oc/02@3oool0
00P0oooo5@3o000?0?lM07<0oc/0;`3oE`0@0?mc00<0ohl0203oZP070?o500040?oO000_o`00;ol0
0>co0080oml04`3oa@090?oO00L0ooT000<0k?l00=Co003Do`000P3Do`00102So`00Rol008_o0000
oc/2003;oa`0:03o0P00ok<204Ko000308_o002ko`00^ol000<0k?l01@3on@0;0?oO00D0olD0103o
ZP0E0?n?00<0ojX00P3oa@000`16o`00Xol00:?o00020?nZ00<0ohl0103oL`0=0?mG0100oc/02@3o
ool000P0oooo5@3o000?0?lM07<0oc/0;`3oE`0@0?mc00<0ohl0203oZP070?o500040?oO000_o`00
;ol00>co0080oml04`3oa@090?oO00L0ooT000<0k?l00=Co003Do`000P3Do`00102So`00Rol008_o
0000oc/2003;oa`0:03o0P00ok<204Ko000308_o002ko`00^ol000<0k?l01@3on@0;0?oO00D0olD0
103oZP0E0?n?00<0ojX00P3oa@000`16o`00Xol00:?o00020?nZ00<0ohl0103oL`0=0?mG0100oc/0
2@3oool000P0oooo5@3o000>0?lM0780oc/0;P3oE`0B0?mc00<0ohl000@0ojX00?oO003og`00oml0
0P3on@020=Co00040?oO003oa@00olD00?o500@0oml000@0k?l005co001Lo`006Ol00P00of@20?oi
00`0olD00`3og`0@0?oi0080k?l00`3Do`030;_o0080Xol000<0;ol000?o0003o`000P00bolJ02P0
o`800?lk0P1co`00102So`00^ol00;_o003Do`050>co00<0ooT0203og`020?oi000300?o003on@00
ooT00080oml000<0olD00?nZ003oZP001P3oZP0;0?n?00P0ojX00P3oa@000`3on@00^ol00;_o0002
0?oO00040?o5003oS`00ohl00?n?00D0og<02`3oE`0@0?lk00T0oooo00080?oooa<0o`003P3o7@1c
0?lk02`0oeL04@3oL`050?n?0080ojX000@0olD00;_o002ko`000<_o0P00obH20=Co00<0ooT000<0
^ol002oo000_o`000P3/o`00103Do`00Lol007?o0016o`020;_o0080ooT0103og`020?o500P0oml0
00<0e?l0003o>`00oc/00`3Do`0200?o00030;_o003/o`00k?l000D0k?l0103Do`040;_o00040:?o
002;o`00Rol007?o0080A_l00P00oc/00`00A?l0:03o02P0o`0F02P0o`03003;o`1Lo`00G?l00080
Lol000@0Xol00;_o002ko`00^ol01@3Do`030>co00P0ooT00P3/o`000`00oa400ol000?o00020?oi
00040?oO003oa@00olD00?o501L0ojX00`3oa@000`3on@00^ol00;_o00020=Co00030:?o003oZP00
ojX000<0ohl00`3oL`0=0?mG00h0oc/02@3oool000P0oooo4`3o000>0?lM07<0oc/0;03oE`0A0?mc
00D0ohl00P3oZP00103oa@00^ol00;_o0000bol2003o9P80e?l00`3on@000`2ko`00;ol002oo0002
0>co00040=Co001co`00Lol004Ko0080^ol00P3on@040?oO0080olD0203og`000`3Do`000?lk003o
>`030=Co00800ol000<0^ol00>co003/o`001@3/o`040=Co00@0^ol000@0Xol008_o002;o`00Lol0
0P16o`02003o>`030014o`0X0?l0:03o01H0:03o00<00<_o05co001Lo`000P1co`00102So`00^ol0
0;_o002ko`050=Co00<0k?l0203on@020>co0003003o4@03o`000ol00080ooT000@0oml00?o5003o
a@00olD05`3oZP030?o500030?oi002ko`00^ol00080e?l000<0Xol00?nZ003oZP000`3oS`030?mc
00d0oeL03P3o>`090?ooo`00203ooolC0?l000h0oad0L@3o>`0Y0?mG01D0og<01P3oS`020?nZ0004
0?o5003og`00oml002oo0080G?l00P1co`00102ko`00e?l00=Co002So`02003oN080^ol000@0;ol0
02P0o`0X0?l00?m@0P3Do`020>co00030?oi003og`00oml000P0oml00`3on@000`3Do`00;ol002oo
000200?o000402P0o`00bol00<_o0:?o00D0e?l00P00oe000`2;o`000?lk003o>`050:?o000408_o
001co`00Lol005co0080A_l00P0Io`000`00oe00:03o02P0o`0D02P0o`800?m@00<06Ol005co001L
o`000P1co`0308_o00030:?o002ko`00^ol000<0^ol00P00ok<00`2ko`00k?l00>co00050>co0004
0=Co002ko`00^ol007?o0080G?l00`2ko`020?oO00D0olD04@3oZP030?o50080oml000<0ooT00=Co
003Do`000P0Io`000`3/o`00ojX00?nZ00040?n?00@0og<02`3oE`0>0?lk00T0oooo00080?oooa<0
o`003P3o7@1a0?lk02T0oeL05@3oL`060?n?0080ojX000@0olD00?oO003og`00;ol00P1Lo`0207?o
00040;_o003Do`00e?l00:?o00800?mh0P2ko`00100_o`00:03o02P0o`00oe020=Co0080k?l000<0
ooT00?oO003og`00203og`030?oi00030=Co000_o`00;ol000800ol000@0:03o003;o`00bol0Xol0
1@3Do`02003oD00308_o0000oc/00?lk00D0Xol000@0Rol007?o001co`00G?l00P16o`0201Wo0003
003oD00X0?l0:03o01@0:03o0P00oe000`0Io`00G?l005co000207?o00<0Rol000<0Xol00;_o002k
o`000`2ko`02003o/`030;_o003/o`00k?l000D0k?l000@0e?l00;_o002ko`00Lol00P1Lo`030;_o
0080oml01@3oa@0A0?nZ00<0olD00P3og`000`3on@00e?l00=Co000201Wo00030>co003oZP00ojX0
00@0ohl0103oL`0;0?mG00h0oc/02@3oool000P0oooo4`3o000=0?lM0700oc/0:03oE`0F0?mc00L0
ohl00`3oZP030?o500030?oi003Do`00e?l000800=go00@00?nP07?o001co`00G?l00P03o`0205co
0004003ok00_o`00;ol008_o0080e?l00P3/o`030?oi00H0oml00`3on@020>co00030;_o0000on`0
0?o/008007Go00@004Co002Go`00Uol00;[o0P2So`000`2ko`00Xol00:?o000204Ko00<0:03o00<0
G?l007?o001co`000P009?l01003o`00A_l004Ko0000oc/201Wo00800ol000@00?lk003oN000ogP0
0?o/400X0?l2003ok004003oI000obH00?lV00?o00@0;ol000@0A_l005co001Lo`00:03o0P0_o`02
08_o000405co000X0?l0:03o02P0o`80Xol01@3Do`00101co`00:03o02P0o`00oe02002jo`800?lA
00@0;ol00?oi003on@00oml01`3oa@0<0?nZ00D0olD00P3og`000`03o`0008Ko0026o`020=Co0004
0?oi003oZP00ojX00?nZ00<0ohl01@3oL`0;0?mG00d0oc/02@3oool000P0oooo4@3o000=0?lM06l0
oc/0:03oE`0H0?mc00P0ohl0103oZP020?o500030?oO003on@00ooT00080^ol000@0Lol0003oI000
of@00?lV0P00of@20005o`04003o4@1co`00Lol00:?o0080^ol00`3Do`020>co00P0ooT000@0k?l0
0:?o002So`00:03o1000Z?l0100X0?l00?on003ooP0Io`0207?o000308_o000Io`006Ol000<0:03o
0P00ooh00`0Io`000<_o003;o`0V02P0o`800?nP00<0:03o003o9P00obH00`0X0?l202oo0004003o
4@00bol00<_o001eo`800?n<0P2So`030;_o000407?o000Io`006Ol0003oS08009Oo0P00Q_l00`16
o`00k?l00>co00030?oO01<0olD00`3og`020>co000308_o0000oh`00?n<0080Xol000@0oml00?o5
003oa@00ojX00`3oS`070?mc00T0oeL03@3o>`090?ooo`00203ooolA0?l000d0oad0K`3o>`0X0?mG
01P0og<0203oS`040?nZ0080olD000<0oml00?oi003on@000P2ko`00101co`000?mT003oI000obH2
003oI08000Go00@00?lA07?o001co`00Xol00P2ko`030=Co0080k?l0203on@00103/o`00Xol00:?o
000X0?l4002Xo`0402P0o`00ooh00?on01Wo0080Lol000<0Rol001Wo000Io`000`0X0?l2003ooP03
01Wo0000bol00<_o02H0:03o0P00oj000`0X0?l00?lV003o9P0302P0o`80;ol000@00?lA003;o`00
bol007Go0P00oh`20:?o00<0^ol000@0Lol001Wo000Io`000?n<0P00Uol20026o`0304Ko003/o`00
k?l000<0oml04`3oa@030?oO0080k?l000<0Rol0003oS000oh`00P2So`00103og`00olD00?o5003o
ZP030?n?00L0og<02@3oE`0=0?lk00T0oooo00080?oooa40o`003@3o7@1^0?lk02@0oeL06`3oL`0:
0?n?00@0ojX00P3oa@000`3og`00k?l00>co00020=Co00040:?o0016o`00A_l0003oS08004Co0P00
obH0100_o`00G?l005co002;o`020:?o0080Lol000@0Rol0000To`009?l0e?l01`3/o`00103Do`00
^ol00;_o0000obH200?o00800?mh0`0X0?l01000^_l0:03o02P0o`16o`0202oo008003Co0`0X0?l0
0`00oj000?o6003oaP0^02P0o`800?lk0`0X0?l00`00A?l00?lA003o4@0207?o000408_o00005?l0
01Co0026o`800?m@00<00;[o02P0o`0X0?l00P00E?l01000^_l0A_l004Ko003on@050?oO00/0olD0
1`3og`00103on@00Rol008_o0000oe02003;o`80e?l000<0oml00?o5003oa@000`3oZP030?n?00D0
og<02`3oE`0;0?lk00T0oooo00080?oooa40o`00303o7@1]0?lk02<0oeL0703oL`0:0?n?00H0ojX0
0P3oa@000`3og`00Xol00:?o00020:?o0004003ooP00olH00?o6003o9P800?mT0P00MOl01000oe00
02Co000To`03o`0207?o00806Ol000@00?mT02P0o`0X0?l0Rol00P2So`000`3Do`00k?l00>co0003
0=Co0080^ol000<0Rol002P0o`0X0?l00P00omT602P0o`03003o4@0X0?l0:03o00800?nc>P0X0?l2
003o9P80:03o00<0A_l0003oI000of@01P0X0?l201Wo000405co002ko`00^ol00>co0080ooT0203o
g`060?oi00<0oml0103on@00103/o`00e?l00=Co002So`0204Ko0080Xol000<0ooT00?o5003oa@00
0`3oa@000`3oZP00ohl00?n?00060?mc00X0oeL02`3o>`090?ooo`00203ooolA0?l000`0oad0K@3o
>`0S0?mG01`0og<02P3oS`060?nZ0080olD000<0oml00:?o002So`000P2So`001000ooh00?o6003o
aP00obH2003oI08007Go00@00?m@000To`009?l00ol00P1co`0201Wo0004003oI00X0?l0:03o08_o
0080Xol000<0e?l00>co003/o`000`3Do`020;_o000308_o000X0?l0:03o00800?oI1P0X0?l00`00
oa40:03o02P0o`02003o/cX0:03o0P00obH202P0o`0304Ko0000of@00?mT00H0:03o0P0Io`00101L
o`00^ol00;_o003/o`020?oi00P0oml01P3on@030?oO00@0ooT000@0k?l00=Co003Do`00Xol00P16
o`020:?o00030?oi003oa@00olD000<0olD000<0ojX00?n?003oS`001P3oL`0:0?mG00/0oc/02@3o
ool000P0oooo403o000=0?lM06/0oc/0803oE`0P0?mc00/0ohl01P3oZP020?o500030>co0000oa40
0?lA0080;ol000@00:So04Ko0016o`00A_l00P00ogP202P0o`04002Xo`0X0?l0:03o003oS0@00ol0
00@00?n<02P0o`0X0?l00?n<0P1Lo`000`2ko`00e?l00=Co00020=Co00040;_o002So`00Xol007?o
04d0:03o00<00?lV000do`00=?l0200X0?l0102;o`00e?l00=Co003/o`0:0?oi0003002Xo`00ogP0
0?mh0080e?l000@00?lk0=Co003Do`00k?l00P3on@030>co0080e?l000<0Xol0003o>`00oc/00P2k
o`00103/o`00ooT00?oi003og`020?oi00030?o5003oS`00ohl000H0og<02`3oE`0:0?lk00T0oooo
00080?oooa00o`003@3o7@1[0?lk0200oeL0803oL`0;0?n?00H0ojX00P3oa@000`3/o`000?lA003o
4@0202oo0004002Xo`16o`00A_l004Ko00800?mh0P0X0?l01000Z?l0:03o02P0o`00oh`400?o0004
003oS00X0?l0:03o003oS080G?l000<0^ol00=Co003Do`000P3Do`00102ko`00Xol00:?o001co`1=
02P0o`03003o9P00=?l003Co00P0:03o00@0Rol00=Co003Do`00k?l02P3on@000`00Z?l00?mh003o
N0020=Co0004003o>`3Do`00e?l00>co0080ooT00`3/o`020=Co00030:?o0000oc/00?lk0080^ol0
00@0k?l00?oi003on@00oml00P3on@000`3oa@00ohl00?n?00060?mc00/0oeL02P3o>`090?ooo`00
203oool@0?l000/0oad0JP3o>`0P0?mG0240og<03@3oS`060?nZ0080oml000<00ol0003oN000ogP0
0P00oj00101co`00Rol008_o001co`0202P0o`8006Go0`0X0?l00`00Uol00?o/003ok002003ok0<0
:03o00<06Ol007?o001co`000`2So`0208_o000404Ko0000Uol009Oo04Ko00800ol0C00X0?l2003M
o`H0:03o0P00A?l0102;o`00^ol00;_o003Do`020>co00H0ooT00P3/o`000`2ko`000?lV003o9P02
02P0o`<00?m@00<0^ol00=Co003Do`000P3/o`00103Do`00^ol00;_o001Lo`02003o9P80Xol000@0
^ol004Ko0016o`00^ol00P1Lo`000`3on@00ohl00?n?00080?mc00T0oeL02P3o>`090?ooo`00203o
ool@0?l000T0oad0J`3o>`0L0?mG02D0og<03P3oS`050?nZ00<0olD000<0ooT00>co003/o`000P3D
o`00102ko`00Xol00:?o001co`0202P0o`8007Go300X0?l2001Do`0307?o002;o`00Rol000800ol0
0`0X0?l00`00of@0:03o02P0o`0202P0o`03000To`0X0?l0:03o04d0:03o0P005?l201Wo000407?o
002;o`00Rol0001Uo`80^ol00P3Do`040>co0080e?l000<0Xol007?o001co`000P00E?l00`00of@0
;ol002oo000508_o00<0Xol000<0Lol0003oN000ogP00P16o`001000ogP0;ol002oo002;o`020>co
00030?o5003oZP00ojX00080ohl01P3oL`090?mG00X0oc/02@3oool000P0oooo403o00090?lM06/0
oc/0703oE`0U0?mc00h0ohl01@3oZP030?o500030?oi003/o`00k?l00080e?l000@0^ol00:?o002S
o`00Lol00P0X0?l2001eo``0:03o0P00E?l00`1co`00Rol008_o000200?o00<0:03o00<00?mT02P0
o`0X0?l00P0X0?l00`009?l0:03o02P0o`1=02P0o`8001Co0P0Io`00101co`00Rol008_o0000IOl2
0;_o0080e?l0103/o`020=Co00030:?o001co`00Lol0008005Co00<00?mT02oo000_o`001@2;o`03
0:?o000307?o0000ogP00?mh0080A_l000@00?mh02oo000_o`00Rol00P3/o`000`3oa@00ojX00?nZ
00020?n?00H0og<02@3oE`0:0?lk00T0oooo00080?ooo`h0o`002`3o7@1Y0?lk01T0oeL0:03oL`0>
0?n?00L0ojX00`3oa@000`3og`00ooT00?oi00020>co00040=Co002ko`00^ol007?o00800?lV0P00
ogP00`00E?l0:03o02P0o`0902P0o`800?m@00<0A_l005co001Lo`000P0Io`000`00omT0:03o02P0
o`1I02P0o`0401Wo0000ogP00?mh002Xo`800?on0P2ko`040=Co0080Xol000<00?o602oo000_o`00
0P0:0?l01000oj000ol000?o000_o`0204Ko00800?n<00@00?o604Ko0016o`000ol00P00gOl2003o
>`0408_o003Do`00e?l00?oi0080olD000<0ojX00?n?003oS`000P3oS`080?mc00T0oeL0203o>`09
0?ooo`00203oool>0?l000X0oad0I`3o>`0I0?mG02X0og<03`3oS`070?nZ00<0olD00`3og`020?oi
00030>co0000obH00?lV00<06Ol00P00A?l>02P0o`0301Wo0000oc/00?lk0080:03o00<00?oI02P0
o`0X0?l0F@0X0?l01000oh`0:03o02P0o`0X0?l2003oaP80Rol00`2ko`00101co`000?nP003oX000
Z?l2003oN0<0:03o0P00kol00`00Uol00?m@003oD00202P0o`04002Xo`00ogP00?mh02P0o`800?lA
0P16o`001000oh`0G?l005co003on@020?o500030?nZ003oS`00ohl00080ohl0203oL`090?mG00P0
oc/02@3oool000P0oooo3P3o000:0?lM06L0oc/06@3oE`0Z0?mc00l0ohl01`3oZP030?o500<0oml0
0P3on@000`3/o`000?lV003o9P0301Wo008004Co3P0X0?l00`0Io`000?lk003o>`0202P0o`03003o
f@0X0?l0:03o05T0:03o00@00?n<02P0o`0X0?l0:03o0P00olH208_o00<0^ol000@0Lol0003oX000
oj000:So0P00ogP302P0o`800>oo00<009Oo003oD000oe000P0X0?l01000Z?l00?mh003oN00X0?l2
003o4@80A_l000@00?n<05co001Lo`00ooT00P3oa@000`3oZP00ohl00?n?00020?n?00P0og<02@3o
E`080?lk00T0oooo00080?ooo`h0o`002P3o7@1U0?lk01L0oeL0;03oL`0@0?n?00H0ojX01@3oa@03
0?oO0080ooT000@0e?l007?o001co`00:03o0P00oe02003_o`h0:03o00<00?lk02P0o`0X0?l0HP0X
0?l200?o0080A_l00`2;o`000`1co`000?lV003o9P0902P0o`800:So1@0X0?l00`0Io`00Lol007?o
00020:?o000407?o0000=?l003Co0=Co0080ooT000<0ojX00?n?003oS`000P3oS`090?mc00X0oeL0
1P3o>`090?ooo`00203oool>0?l000P0oad0I03o>`0F0?mG02h0og<04P3oS`050?nZ00@0olD01@3o
g`020?oi00030=Co0000omT00?oI0140:03o0P00bomU02P0o`800?o60P0X0?l0100_o`00G?l005co
0000on`2002Go`h0:03o0P00IOl00`00of@0A_l004Ko00020;_o00040=Co001co`00Lol0003o>`80
oml000<0ojX00?n?003oS`000P3oS`090?mc00X0oeL01P3o>`090?ooo`00203oool>0?l000P0oad0
I03o>`0F0?mG02h0og<04P3oS`050?nZ00@0olD01@3og`020?oi00030=Co0000omT00?oI0140:03o
0P00bomU02P0o`800?o60P0X0?l0100_o`00G?l005co0000on`2002Go`h0:03o0P00IOl00`00of@0
A_l004Ko00020;_o00040=Co001co`00Lol0003o>`80oml000<0ojX00?n?003oS`000P3oS`090?mc
00X0oeL01P3o>`090?ooo`00203oool=0?l000T0oad0H`3o>`0D0?mG0300og<04`3oS`050?nZ00@0
olD01@3og`020?oi00040;_o001co`00Lol00014og/0:03o00@00?m@01Wo000Io`000?m@3`0X0?l0
1000A?l00>oo003_o`00oc/20;_o0080k?l000@0ooT00?oO003og`00oml00P3oa@050?n?00T0og<0
2`3oE`050?lk00T0oooo00080?ooo`d0o`002@3o7@1S0?lk01@0oeL0<03oL`0C0?n?00D0ojX0103o
a@050?oO0080ooT000@0^ol007?o001co`0004CoN`0X0?l01000oe006Ol001Wo0000oe0?02P0o`04
0014o`00kol00>oo003o>`80^ol00P3/o`00103on@00oml00?oO003og`020?o500D0ohl02@3oL`0;
0?mG00D0oc/02@3oool000P0oooo3@3o00080?lM0600oc/04`3oE`0c0?mc01<0ohl01@3oZP060?o5
00<0oml0103on@00103Do`00^ol00;_o001Lo`0202oo07X0:03o0P00of@@02P0o`04003ok000obH0
0?lV0:?o0080e?l00P3/o`00103on@00oml00?oO003oa@020?nZ00D0ohl02@3oL`0;0?mG00D0oc/0
2@3oool000P0oooo3@3o00080?lM05d0oc/04`3oE`0e0?mc01<0ohl0103oZP070?o500<0oml00`3o
n@030>co0080e?l000<0Xol007?o001co`000P005?l00`00oj00:03o02P0o`1g02P0o`03003oaP0X
0?l0:03o00d0:03o00@002Co01Wo000Io`00Lol00P2So`020=Co00030?oO003oa@00olD000<0ojX0
1@3oS`0;0?mc00T0oeL01@3o>`090?ooo`00203oool=0?l000P0oad0G@3o>`0C0?mG03D0og<04`3o
S`040?nZ00L0olD00`3og`030?oi00<0k?l00P3Do`000`2So`00Lol007?o0002000Do`03003oX00X
0?l0:03o07L0:03o00<00?o602P0o`0X0?l03@0X0?l010009?l06Ol001Wo001co`020:?o0080e?l0
00<0oml00?o5003oa@000`3oZP050?n?00/0og<02@3oE`050?lk00T0oooo00080?ooo`/0o`00203o
7@1N0?lk0140oeL0=P3oL`0E0?n?00<0ojX01P3oa@030?oO00D0ooT00`3/o`020;_o00030:?o002;
o`00Rol00080G?l000@06Ol0003oD000oe000?o60P00Z?n502P0o`800?lA00<00=go003oX000oj00
0P00obH00`3og`00olD00?o500030?nZ00H0ohl02P3oL`0;0?mG00<0oc/02@3oool000P0oooo2`3o
00080?lM05X0oc/04P3oE`0g0?mc01D0ohl00`3oZP070?o500030?oO003on@00ooT000@0ooT0103/
o`00103Do`00^ol00;_o002;o`0207?o0080A_l000<00ol0003oS000oh`0RP0X0?l00`00on`00?lk
003o>`020?oi00<0olD00`3oZP060?n?00X0og<02`3oE`030?lk00T0oooo00080?ooo`/0o`00203o
7@1J0?lk0180oeL0=`3oL`0E0?n?00<0ojX01`3oa@000`3og`00ooT00?oi00040?oi00@0k?l000@0
e?l00;_o002ko`00Rol00P1co`0204Ko000300?o0000oh`00?n<08X0:03o00<00?o/003o>`00oc/0
0P3on@030?o500<0ojX01P3oS`0:0?mc00/0oeL00`3o>`090?ooo`00203oool;0?l000H0oad0F@3o
>`0@0?mG03/0og<0503oS`050?nZ00<0olD00P3og`020?oi00040=Co002So`00Xol005co0080e?l0
0`3/o`020=Co00040:?o001co`00Lol000X0o`80A_l0RP0X0?l2003oaP0401Wo001co`00Lol001Wo
0080e?l00P3og`000`3oa@00ojX00?nZ00030?nZ00H0ohl02P3oL`0;0?mG00<0oc/02@3oool000P0
oooo2`3o00060?lM05T0oc/0403oE`0k0?mc01@0ohl01@3oZP030?o50080oml00P3on@00103Do`00
Xol00:?o001Lo`020=Co00<0k?l00P3Do`00102So`00Lol007?o000:0?l204Ko08X0:03o0P00olH0
100Io`00Lol007?o000Io`020=Co0080oml000<0olD00?nZ003oZP000`3oZP060?n?00X0og<02`3o
E`030?lk00T0oooo00080?ooo`/0o`001P3o7@1F0?lk0100oeL0>`3oL`0F0?n?00D0ojX000@0olD0
0?oO003og`00oml00P3on@020>co00040:?o0000olH00?o604Ko0080Xol01@2ko`00100_o`00:03o
02P0o`0X0?l2003o>`8003CoQP0X0?l2003oaP80:03o00@00?m@0;_o002ko`00k?l00P3on@020?oO
00030?o5003oZP00ojX000<0ojX0203oS`090?mc00/0oeL00P3o>`090?ooo`00203oool:0?l000H0
oad0E03o>`0@0?mG03`0og<05P3oS`050?nZ0080olD000<0ooT00>co003/o`000`3Do`02003ok004
07?o0000A?l004Co04Ko0080Rol00`2So`0208_o000302oo000X0?l0:03o08L0:03o00@00?nc003o
D000oe000ol00P0_o`0208_o00040;_o003/o`00k?l00?oi00@0oml000<0olD00?nZ003oZP000`3o
ZP080?n?00T0og<02`3oE`020?lk00T0oooo00080?ooo`X0o`001P3o7@1D0?lk0100oeL0?03oL`0F
0?n?00D0ojX00P3oa@000`3on@00k?l00>co00030=Co00800?o/00@0Lol00014o`00A?l0A_l00P2;
o`030:?o0080Rol000<0;ol002P0o`0X0?l0Q`0X0?l01000ok<00?m@003oD003o`0202oo0080Rol0
00@0^ol00>co003/o`00ooT0103og`000`3oa@00ojX00?nZ00030?nZ00P0ohl02@3oL`0;0?mG0080
oc/02@3oool000P0oooo2P3o00060?lM0540oc/0403oE`0l0?mc01H0ohl01P3oZP020?o50080oml0
00@0^ol002P0o`0X0?l0G?l00P03o`020026o`03003oI000oc/00?lk00<0;ol000<00?mh07?o001c
o`000P1co`000`0_o`000?mh003oN02:02P0o`0302oo001co`00Lol00080Xol000@0e?l00>co003/
o`00ooT0103og`000`3oa@00ojX00?nZ00040?nZ00L0ohl02@3oL`0=0?mG00T0oooo00080?ooo`X0
o`001P3o7@1<0?lk01<0oeL01@3oL`0A0?n?02D0og<0603oS`060?nZ00<0olD00P3og`00103on@00
^ol00;_o0016o`02002Xo`806@3o00@00?oI003oD000oe000?lA0P0I0?l302P0o`80;ol000@00?lA
02P0o`0X0?l000GoQ`0X0?l2001Do`0302P0o`1Lo`00G?l00080Rol000<0e?l00>co003/o`000`3o
n@020?oO00<0olD0103oZP080?n?00P0og<03@3oE`090?ooo`00203oool:0?l000H0oad0C03o>`0C
0?mG00D0og<04@3oS`0U0?mc01P0ohl01P3oZP030?o50080oml000@0ooT00;_o002ko`00A_l00P00
Z?l201T0o`04003of@00oe000?m@003o4@806@3o0`0X0?l202oo0004003o4@0X0?l0:03o0005ohL0
:03o0P00E?l00`0X0?l0G?l005co000208_o00030=Co003/o`00k?l000<0ooT00P3og`030?o500@0
ojX0203oS`080?mc00d0oeL02@3oool000P0oooo2P3o00040?lM04/0oc/04`3oE`050?mc01/0ohl0
6`3oL`0G0?n?00X0ojX00`3oa@020?oO00040?oi0003o`000ol0003o9P800?nP0P0I0?l902P0o`80
0?m@S@0X0?l00`00ooh0:03o02P0o`0202P0o`040;_o003Do`00e?l00=Co0080ooT00P3og`030?o5
00H0ojX01P3oS`080?mc00d0oeL02@3oool000P0oooo203o00060?lM04H0oc/05@3oE`040?mc0080
ohl00P3oZP000`3og`00ojX00?nZ00030?nZ01/0ohl03P3oL`0J0?n?00`0ojX01@3oa@020?oO0004
0?oi001co`00Lol007?o0080:03o0P00of@00`00Q_l0:03o02P0o`2H02P0o`800:So0`2;o`000`00
of@0e?l00=Co00020?oO00@0olD01`3oZP040?n?00P0og<03@3oE`090?ooo`00203oool80?l000H0
oad0AP3o>`0E0?mG00@0og<00P3oS`020?nZ00030?oO003oZP00ojX000<0ojX06`3oS`0>0?mc01X0
ohl0303oZP050?o50080oml000@0ooT007?o001co`00Lol00P0X0?l2003oI0030026o`0X0?l0:03o
09P0:03o0P00Z?l308_o0003003oI03Do`00e?l00080oml0103oa@070?nZ00@0ohl0203oL`0=0?mG
00T0oooo00080?ooo`P0o`001@3o7@120?lk01L0oeL01P3oL`030?n?0080ojX00`3og`030?o50080
ojX0?03oS`0@0?nZ00H0olD00P3og`00103on@00k?l00>co002ko`0202P0o`80;ol000<00?lV003;
o`00bol0V00X0?l2003o9P0402P0o`00gOl00=go003oX080Xol00P3on@000`3og`00olD00?o50004
0?o500D0ojX01@3oS`060?mc00d0oeL02@3oool000P0oooo203o00050?lM0480oc/05`3oE`060?mc
00<0ohl00P3oZP030?oO00<0olD00P3oZP0l0?n?0100ojX01P3oa@020?oO00040?oi003/o`00k?l0
0;_o0080:03o0P0_o`000`00obH00<_o003;o`2H02P0o`800?lV00@0:03o003Mo`00gOl00?nP0P2S
o`020?oi00030?oO003oa@00olD000@0olD01@3oZP050?n?00H0og<03@3oE`090?ooo`00203oool8
0?l000D0oad0?P3o>`0I0?mG00H0og<01@3oS`020?nZ00040>co003Do`00e?l00?oi00D0oml00P3o
ZP0b0?n?01D0ojX01P3oa@040?oO00040?oi003/o`00k?l00>co0080Xol00P2;o`000`0X0?l00=go
003Mo`2H02P0o`800>oo100X0?l202oo00<0ooT00P3og`080?o500<0ojX00`3oS`080?mc00/0oeL0
2@3oool000P0oooo203o00050?lM03T0oc/06`3oE`090?mc00D0ohl00P3oZP00103oa@00ooT00?oi
003Do`020:?o0080e?l000<0k?l00?o5003oa@00103oZP0O0?n?02<0ojX01`3oa@040?oO00040?oi
003/o`00k?l00>co0080^ol00P2So`000`00kol009Oo002Go`2M02P0o`03003oaP2So`00Xol00080
k?l000<0ooT00?oO003og`00203og`000`00ogP0olD00?o500030?n?00P0og<02`3oE`090?ooo`00
203oool80?l000D0oad0>@3o>`0K0?mG00T0og<01@3oS`020?nZ00040?o5003on@00ooT00=Co0080
Xol00P3Do`000`3/o`00olD00?o500040?nZ01l0ohl08`3oZP070?o500@0oml000@0ooT00>co003/
o`00k?l00P2ko`020:?o0003003_o`00Uol009Oo09d0:03o00<00?o60:?o002So`000P3/o`000`3o
n@00oml00?oO00080?oO0003003oN03oa@00olD000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`P0
o`000`3o7@0f0?lk01h0oeL02P3oL`060?n?0080ojX000@0olD00?oO003og`00ooT00P2So`020=Co
00040?oi003oa@00olD00?o504<0ojX02@3oa@020?oO00<0ooT00P3/o`000`3Do`00^ol00;_o0002
0:?o000407?o000Io`006Ol0000DoiT0:03o00@007Go02P0o`0X0?l0G?l00P2ko`020=Co00030>co
003on@00ooT000H0oml00P3on@00100_o`00ooT00?oi003oZP040?n?00H0og<02`3oE`090?ooo`00
203oool60?l000D0oad0<@3o>`0P0?mG00d0og<01P3oS`020?nZ00<0olD000<0ooT00;_o002ko`00
0P0_o`000`3on@00olD00?o500030?o501H0ojX00`3oa@020?oO000308_o003og`00oml000D0olD0
703oZP0:0?o500<0oml00`3on@020=Co00030;_o002So`00Xol00080Rol000@0Lol0003oX000oj00
0?mTVP0X0?l3003oN080Xol01@2ko`000`3/o`00ooT00?oi00030?oi0080e?l000@0Rol004Ko0016
o`00olD0103oS`060?mc00/0oeL02@3oool000P0oooo1P3o00050?lM0340oc/0803oE`0=0?mc00H0
ohl00P3oZP030?o500030?oi002ko`00^ol00080;ol000<0ooT00?o5003oa@000`3oa@0F0?nZ00<0
olD00P3og`000`2;o`00oml00?oO00050?o501`0ojX02P3oa@030?oO00<0ooT00P3Do`000`2ko`00
Xol00:?o000208_o000407?o0000oj000?nP003oI9X0:03o0`00ogP20:?o00D0^ol000<0k?l00?oi
003on@000`3on@020=Co000408_o0016o`00A_l00?o500@0ohl01P3oL`0;0?mG00T0oooo00080?oo
o`H0o`001@3o7@0]0?lk0280oeL03@3oL`080?n?0080ojX00`3oa@000`3/o`000?mT003oI00200?o
00030>co003oa@00olD000H0olD04P3oZP040?o50080ooT000<06Ol00:?o002So`000P3og`060?o5
01P0ojX02`3oa@000`3og`00ooT00?oi00020?oi00040=Co0000olH00?o602P0o`@0Lol000@008Ko
02P0o`0X0?l00>ooW00X0?l00`005?l0Lol007?o00020:?o000407?o000X0?l0:03o003o4@D0e?l0
0`1Lo`020:?o00030?o5003oZP00ojX00080ohl01P3oL`0;0?mG00T0oooo00080?ooo`H0o`001@3o
7@0]0?lk0280oeL03@3oL`080?n?0080ojX00`3oa@000`3/o`000?mT003oI00200?o00030>co003o
a@00olD000H0olD04P3oZP040?o50080ooT000<06Ol00:?o002So`000P3og`060?o501P0ojX02`3o
a@000`3og`00ooT00?oi00020?oi00040=Co0000olH00?o602P0o`@0Lol000@008Ko02P0o`0X0?l0
0>ooW00X0?l00`005?l0Lol007?o00020:?o000407?o000X0?l0:03o003o4@D0e?l00`1Lo`020:?o
00030?o5003oZP00ojX00080ohl01P3oL`0;0?mG00T0oooo00080?ooo`H0o`00103o7@0Y0?lk02@0
oeL0403oL`080?n?0080ojX000@0olD00?oO003og`00k?l00P16o`020;_o00030>co003og`00oml0
00P0olD0303oZP070?o500<0ooT000<0^ol0003o4@00oa400P3/o`000`3og`00olD00?o500050?o5
01@0ojX02`3oa@030?oO0080k?l00P3Do`0300?o0003003oI00_o`00;ol00080;ol000<00?lA02P0
o`0X0?l0WP0X0?l204Ko0080:03o00@00?nc002jo`00^_l004Co0P2;o`000`2ko`00Rol008_o0002
003o>`040:?o003og`00oml00?o50080ojX00P3oS`060?mc00/0oeL02@3oool000P0oooo1P3o0004
0?lM02H0oc/09P3oE`0@0?mc00T0ohl00P3oZP00103og`00ooT00?oi002ko`0204Ko0080e?l000<0
k?l00?oi003on@00103og`080?o500@0ojX02@3oa@020?oO000408_o0016o`00A_l0003o9P80Xol0
0`3on@020?oO00P0olD03P3oZP0=0?o500<0oml000<0ooT001Wo000Io`000P16o`001000IOl0:03o
02P0o`00ogP202P0o`8007Go00<00?mT02P0o`0X0?l0WP0X0?l2003oI0D0:03o00@00?oI01Wo000I
o`00Lol00P1Lo`02003oI0040;_o003on@00ooT00?oO0080ojX00P3oS`060?mc00/0oeL02@3oool0
00P0oooo1P3o00040?lM02H0oc/09P3oE`0@0?mc00T0ohl00P3oZP00103og`00ooT00?oi002ko`02
04Ko0080e?l000<0k?l00?oi003on@00103og`080?o500@0ojX02@3oa@020?oO000408_o0016o`00
A_l0003o9P80Xol00`3on@020?oO00P0olD03P3oZP0=0?o500<0oml000<0ooT001Wo000Io`000P16
o`001000IOl0:03o02P0o`00ogP202P0o`8007Go00<00?mT02P0o`0X0?l0WP0X0?l2003oI0D0:03o
00@00?oI01Wo000Io`00Lol00P1Lo`02003oI0040;_o003on@00ooT00?oO0080ojX00P3oS`060?mc
00/0oeL02@3oool000P0oooo1P3o00040?lM0240oc/0:@3oE`0B0?mc00T0ohl00P3oZP00103/o`00
G?l005co003Do`0201Wo0080Rol000@0k?l00?oi003on@00ooT02`3og`080?o500D0oml00P3on@00
103Do`000?n<003oS02;o`020=Co0080k?l000<0ooT00?oO003og`001@3og`0L0?o500<0oml00P3o
n@000`3/o`00^ol00;_o0002003o4K40:03o0P00bol00`00oe006Ol001Wo0002003o4@0404Ko0003
o`000ol00>co0080ojX00P3oS`060?mc00/0oeL02@3oool000P0oooo1@3o00030?lM0200oc/0:P3o
E`0D0?mc00T0ohl00P3oZP00103og`00ooT00?oi003on@0207?o00806Ol000@0^ol00>co003/o`00
k?l00`3on@040?oO00<0ooT000<0Lol00?oi003on@002P3og`030?oi000404Ko0003o`000ol008_o
0080^ol00P3Do`000`3/o`00ooT00?oi00090?oO01D0olD01P3og`020?oi00030>co003Do`00e?l0
0080G?l000<00?mT003o/`00ok<0/@0X0?l2003of@800>oo00@0Lol00>co003/o`00olD00P3oZP03
0?n?00D0og<02`3oE`090?ooo`00203oool50?l000<0oad0803o>`0Z0?mG01@0og<02@3oS`020?nZ
00040?oO003on@00ooT00?oi0080Lol00P0Io`00102ko`00k?l00>co003/o`030?oi00@0oml00`3o
n@000`1co`00ooT00?oi000:0?oO00<0ooT000@0A_l000?o0003o`00Rol00P2ko`020=Co00030>co
003on@00ooT000T0oml05@3oa@060?oO0080ooT000<0k?l00=Co003Do`000P1Lo`000`00of@00?nc
003o/`2a02P0o`800?oI0P00kol0101co`00k?l00>co003oa@020?nZ00<0ohl01@3oL`0;0?mG00T0
oooo00080?ooo`D0o`000`3o7@0L0?lk02/0oeL05@3oL`090?n?00@0ojX000@0olD00?oO003og`00
ooT00P3Do`0202oo000408_o003Do`00e?l00=Co0080k?l000<0^ol00=Co003Do`000`3/o`020;_o
00030:?o003/o`00k?l00080ooT01P3og`030?oi0080k?l000@0^ol0003oS000oh`06Ol00P00oc/2
003oN0<0e?l00`3on@020?oO00@0ooT00P3/o`000`3on@00oml00?oO00050?oO00<0olD03@3og`03
0?oi00030>co003Do`00e?l00080^ol000<0Lol001Wo000Io`00[P0X0?l2000Do`03002Xo`16o`00
A_l000800ol00`0_o`000`3oZP00ohl00?n?00030?n?00D0og<02`3oE`090?ooo`00203oool50?l0
00<0oad06@3o>`0]0?mG01H0og<02@3oS`040?nZ00<0olD000<0oml002oo000_o`000P2So`001016
o`00G?l005co000Io`0202oo000304Ko002;o`00Rol000800?mh00@0^ol00:?o002So`000>oo0P2k
o`030>co00L0ooT00`3/o`00103Do`00Xol00:?o001Lo`02003_o`800?oI00@0Rol0003o9P00obH0
e?l0103/o`00103on@00k?l00>co003Do`02003oD0030>co003on@00ooT001<0oml01@3on@000`3/
o`00e?l00=Co00020;_o000408_o0016o`00A_l0003o>`800?o/ZP0X0?l01000=?l00ol000?o002;
o`020;_o00800ol000@0ooT00?o5003oa@00ojX01@3oS`050?mc00/0oeL02@3oool000P0oooo1@3o
00030?lM01T0oc/0;@3oE`0F0?mc00T0ohl0103oZP030?o500030?oO000_o`00;ol00080Xol000@0
A_l005co001Lo`006Ol00P0_o`000`16o`00Rol008_o0002003oN0040;_o002So`00Xol0003_o`80
^ol00`3/o`070?oi00<0k?l000@0e?l00:?o002So`00G?l00P00kol2003of@0408_o0000obH00?lV
0=Co00@0k?l000@0ooT00>co003/o`00e?l00P00oe000`3/o`00ooT00?oi000C0?oO00D0ooT000<0
k?l00=Co003Do`000P2ko`00102;o`00A_l004Ko0000oc/2003ok:X0:03o00@003Co00?o0003o`00
Rol00P2ko`0200?o00040?oi003oa@00olD00?nZ00D0ohl01@3oL`0;0?mG00T0oooo00080?ooo`D0
o`000`3o7@0H0?lk02`0oeL0603oL`080?n?00D0ojX0103oa@020?oi0080k?l000@0Lol0003o9P00
obH0Xol00P00oa400`0Io`000?lA003o4@0205co000407?o000_o`00;ol0003ok080Xol01@2ko`06
0>co0080e?l000@0^ol00:?o002So`00Rol00P0_o`020005o`04003o9P00=?l003Co07?o0080e?l0
0P3/o`00103Do`00Xol00:?o0000oj02003o/`030;_o003on@00ooT00080ooT0403og`060?oi0003
0>co003Do`00e?l00080Lol000@0:03o02oo000_o`00:03o0P00Z?nU02P0o`800?on00@0:03o003o
oP00ooh00<_o0P00ooh00`00obH0k?l00>co00020?oO00040?o5003oZP00ojX00?nZ00D0ohl01@3o
L`0;0?mG00T0oooo00080?ooo`D0o`000`3o7@0H0?lk02`0oeL0603oL`080?n?00D0ojX0103oa@02
0?oi0080k?l000@0Lol0003o9P00obH0Xol00P00oa400`0Io`000?lA003o4@0205co000407?o000_
o`00;ol0003ok080Xol01@2ko`060>co0080e?l000@0^ol00:?o002So`00Rol00P0_o`020005o`04
003o9P00=?l003Co07?o0080e?l00P3/o`00103Do`00Xol00:?o0000oj02003o/`030;_o003on@00
ooT00080ooT0403og`060?oi00030>co003Do`00e?l00080Lol000@0:03o02oo000_o`00:03o0P00
Z?nU02P0o`800?on00@0:03o003ooP00ooh00<_o0P00ooh00`00obH0k?l00>co00020?oO00040?o5
003oZP00ojX00?nZ00D0ohl01@3oL`0;0?mG00T0oooo00080?ooo`D0o`0000<0oad00?lk003o>`00
5@3o>`0^0?mG01T0og<0203oS`050?nZ00@0olD00P3og`030?oi0080k?l000@0e?l00;_o002ko`00
Lol00P00ok<2003ooP04003o9P0:0?l02P3o01Wo0080Lol00P2;o`000`00bol0Xol00:?o00030=Co
0080k?l000@0e?l00;_o002ko`00^ol00P2So`000`1co`00;ol002oo0002003o9P04003_o`0X0?l0
:03o0014o`80Xol00`2ko`0301Wo0080Lol000<0^ol00>co003/o`001@3on@0;0?oO00H0ooT00P3/
o`000`3Do`00Xol00:?o0002003o9P04003oI000oc/00?lk003o/jT0:03o00@0;ol007?o001co`00
Rol00P2ko`000`3on@00oml00?oO00030?o500<0ojX01@3oS`050?mc00/0oeL02@3oool000P0oooo
1@3o00000`3o7@00oc/00?lk000C0?lk02h0oeL06@3oL`080?n?00L0ojX0103oa@040?oO00040?oi
003/o`00k?l00>co0080^ol000<00?nP01Wo000Io`000P0Io`001000of@0:03o02P0o`00obH201Wo
0080A_l000<009Oo08_o002;o`000`2ko`060:?o00806Ol000<0A_l0003o4@00oa400P00ooh0100X
0?l002Co000To`00oa42003o>`80Xol000<0Rol004Ko0016o`000`0X0?l00`2So`00e?l00=Co0003
0>co00D0ooT00`3og`0:0?oi00<0k?l0200X0?l00`00IOl0:03o02P0o`2U02P0o`8002Co00@00?o6
08_o002;o`00e?l00P3/o`030?oO0080olD00`3oZP050?n?00H0og<02`3oE`090?ooo`00203oool5
0?l000030?lM003o>`00oc/001<0oc/0;P3oE`0I0?mc00P0ohl01`3oZP040?o500@0oml000@0ooT0
0>co003/o`00k?l00P2ko`000`00oj006Ol001Wo000201Wo0004003oI00X0?l0:03o003o9P806Ol0
0P16o`000`00Uol0Rol008_o00030;_o00H0Xol00P0Io`000`16o`000?lA003o4@02003ooP0402P0
o`009?l002Co003o4@800?lk0P2So`000`2;o`00A_l004Ko000302P0o`030:?o003Do`00e?l000<0
k?l01@3on@030?oO00X0ooT00`3/o`0802P0o`03001Uo`0X0?l0:03o0:D0:03o0P009?l01000olH0
Rol008_o003Do`020>co00<0oml00P3oa@030?nZ00D0ohl01P3oL`0;0?mG00T0oooo00080?ooo`<0
o`000`3o7@0B0?lk02l0oeL06`3oL`080?n?00L0ojX0103oa@040?oO00040?oi003/o`00k?l00>co
0080e?l000<0Xol007?o001co`000P16o`001000oa4008Ko0026o`00Z?l2003oX0800?lk00<00?on
002jo`00^_l00`2;o`0304Ko0080Rol000@0Lol001Wo000Io`000?n<0P00Q_l602P0o`80A_l00`1c
o`0205co000402oo0000MOl007Go00?o0080Rol01@3Do`000`3/o`00ooT00?oi000;0?oi00<0k?l0
0P3Do`000`2So`000=go003Mo`2_02P0o`0400?o0016o`00A_l00;_o0080ooT00`3og`020?o500<0
ojX01@3oS`060?mc00/0oeL02@3oool000P0oooo0`3o00030?lM0100oc/0<03oE`0L0?mc00L0ohl0
2@3oZP030?o500D0oml00P3on@00103/o`00e?l00=Co002ko`0208_o00800>oo1P0X0?l2002Go`04
02P0o`00obH00?lV01Wo0080G?l00P16o`001000oj000?lk003o>`00=?l202oo0003003o>`0X0?l0
:03o00D0:03o00<00:So00?o0003o`000P00ogP0100_o`000?m@003oD003o`02003oX0030014o`00
MOl007Go00<0Xol00P00bol00`16o`00e?l00=Co000=0>co00<0e?l000<0Xol007?o001co`000P0I
o`2`02P0o`040;_o003on@00ooT00?oi0080oml00P3oa@030?nZ00D0ohl01P3oL`0;0?mG00T0oooo
00080?ooo`<0o`000`3o7@0@0?lk0300oeL0703oL`070?n?00T0ojX00`3oa@050?oO0080ooT000@0
k?l00=Co003Do`00^ol00P2;o`02003_o`H0:03o0P00Uol0100X0?l00?lV003o9P0Io`0205co0080
A_l000@00?nP003o>`00oc/003Co0P0_o`000`00oc/0:03o02P0o`0502P0o`03002Xo`03o`000ol0
00800?mh00@0;ol0003oD000oe000ol00P00oj000`00A?l007Go001eo`030:?o00800<_o00<0A_l0
0=Co003Do`003@3/o`030=Co00030:?o001co`00Lol000806Ol0/00X0?l0102ko`00ooT00?oi003o
n@020?oO0080olD00`3oZP050?n?00H0og<02`3oE`090?ooo`00203oool30?l00080oad0403o>`0_
0?mG01d0og<0203oS`090?nZ00<0olD01@3og`020?oi00040>co003Do`00e?l00;_o0080;ol00P00
oa400`00ogP0:03o02P0o`0802P0o`0300?o000Io`006Ol000806Ol00`0X0?l01000omT002Co000T
o`00ogP2000Do`D0:03o00<00:So003oS000oh`00`0X0?l2003oN004000To`0X0?l0:03o02P0o`80
0?lV0P1Lo`00100X0?l00ol000?o002;o`040=Co00T0k?l01@3Do`000`2So`00A_l004Ko0002003o
I003003oN00X0?l0:03o0:/0:03o0P00oj00102ko`00k?l00>co003on@040?oO00030?o5003oZP00
ojX000D0ohl01P3oL`0;0?mG00T0oooo00080?ooo`<0o`000P3o7@0@0?lk02l0oeL07@3oL`080?n?
00T0ojX00`3oa@050?oO0080ooT000@0k?l00=Co003Do`00^ol00P0_o`02003o4@03003oN00X0?l0
:03o00P0:03o00<00ol001Wo000Io`000P0Io`0302P0o`04003of@009?l002Co003oN08001Co1@0X
0?l00`00Z?l00?n<003oS00302P0o`800?mh00@002Co02P0o`0X0?l0:03o0P00obH205co000402P0
o`03o`000ol008_o00@0e?l02@3/o`050=Co00030:?o0016o`00A_l000800?mT00<00?mh02P0o`0X
0?l0Z`0X0?l2003oX0040;_o003/o`00k?l00?oi00@0oml000<0olD00?nZ003oZP001@3oS`060?mc
00/0oeL02@3oool000P0oooo0`3o00020?lM00h0oc/0<03oE`0N0?mc00H0ohl02`3oZP020?o500H0
oml00P3on@00102ko`00Xol00:?o002;o`02003o>`8006Go2@0X0?l200X0o`03003o>`00oe000?m@
0080:03o00<00?o/02P0o`0X0?l04@0X0?l2003;o`@0:03o0P00oe0202oo000400?o0000ogP00?mh
05co00@0^ol000<0e?l00>co003/o`001@3/o`040=Co0080^ol000<0Rol0003oX000oj000P00ooh0
0`00Z?l0:03o02P0o`2[02P0o`80Lol000<0Xol00=Co003Do`000`3/o`0207?o00030?o5003oZP00
ojX000D0ohl01P3oL`0;0?mG00T0oooo00080?ooo`<0o`000P3o7@0<0?lk0300oeL0803oL`050?n?
00/0ojX00`3oa@060?oO0080k?l000@0Xol0003oD000oe006Ol00P0X0?l2003oS0/0:03o00<00?o6
02P0o`0X0?l0700X0?l2003oaP<00?m@0P00E?l00`00Uol0Rol008_o00030:?o00X0e?l000@0^ol0
0:?o002So`000?n</P0X0?l2003ooP04003oD000oa400?lA0;_o0080e?l00P1Lo`000`3on@00ojX0
0?nZ00050?n?00H0og<02`3oE`090?ooo`00203oool30?l00080oad0303o>`0`0?mG0200og<01@3o
S`0;0?nZ00<0olD01P3og`020>co00040:?o0000oe000?m@01Wo0080:03o0P00oh`;02P0o`03003o
aP0X0?l0:03o01`0:03o0P00olH3003oD08005Co00<009Oo08_o002;o`000`2So`0:0=Co00040;_o
002So`00Xol0003oS;80:03o0P00ooh01000oe000?lA003o4@2ko`020=Co0080G?l000<0ooT00?nZ
003oZP001@3oS`060?mc00/0oeL02@3oool000P0oooo0`3o00020?lM00/0oc/0;`3oE`0P0?mc00D0
ohl03@3oZP030?o500D0oml000@0ooT00>co003/o`00e?l00P2So`000`1co`00G?l005co0002003o
>`030014o`0X0?l0:03o00H0:03o0P0I0?lQ02P0o`8004Co00@006Go02P0o`0X0?l001Co0P0_o`02
003o/`03003of@2So`00Xol000T0^ol00P2So`000`1Lo`000?lA003o4@2c02P0o`800:So00<0Lol0
003oN000ogP00P0Io`000`3on@00ojX00?nZ00030?n?00P0og<02`3oE`090?ooo`00203oool30?l0
0080oad02@3o>`0`0?mG0200og<01P3oS`0=0?nZ00040?o5003og`00oml00?oO00@0ooT00`3/o`00
103Do`00^ol00;_o002;o`0205co00800?m@00<00?mh02P0o`0X0?l0;P0X0?l00`009?l00?lk003o
>`02003oX00302oo002;o`00Rol000P0^ol000@0Xol008_o002;o`00G?l00P00omVc02P0o`800?o/
00<06Ol0003oS000oh`00P3Do`000`3og`00ojX00?nZ00030?n?00P0og<02`3oE`090?ooo`00203o
ool30?l00080oad02@3o>`0`0?mG0200og<01P3oS`0=0?nZ00040?o5003og`00oml00?oO00@0ooT0
0`3/o`00103Do`00^ol00;_o002;o`0205co00800?m@00<00?mh02P0o`0X0?l0;P0X0?l00`009?l0
0?lk003o>`02003oX00302oo002;o`00Rol000P0^ol000@0Xol008_o002;o`00G?l00P00omVc02P0
o`800?o/00<06Ol0003oS000oh`00P3Do`000`3og`00ojX00?nZ00030?n?00P0og<02`3oE`090?oo
o`00203oool30?l000X0oc/0;`3oE`0R0?mc00@0ohl03@3oZP020?o500030?oO003on@00ooT000<0
ooT01@3/o`030;_o000308_o001Lo`00G?l00080;ol000@00?lk02P0o`0X0?l007Go;P0X0?l2003_
o`800=go00@0:03o05co001Lo`00Lol0202So`0207?o0;/0:03o0P00^_l00`3oa@00ojX00?nZ0003
0?n?00P0og<02`3oE`090?ooo`00203oool30?l000X0oc/0;`3oE`0R0?mc00@0ohl03@3oZP020?o5
00030?oO003on@00ooT000<0ooT01@3/o`030;_o000308_o001Lo`00G?l00080;ol000@00?lk02P0
o`0X0?l007Go;P0X0?l2003_o`800=go00@0:03o05co001Lo`00Lol0202So`0207?o0;/0:03o0P00
^_l00`3oa@00ojX00?nZ00030?n?00P0og<02`3oE`090?ooo`00203oool30?l000P0oc/0<03oE`0Q
0?mc00D0ohl0303oZP040?o500@0e?l01@3/o`020;_o00040:?o002;o`00Rol004Ko0080;ol00P00
oa400`00oj00:03o02P0o`0c02P0o`040026o`00Z?l00:So003o4@P0Rol00P1co`000`03o`000?o6
003oaP2_02P0o`04003oX000MOl007Go003oaP80A_l000<00<_o07?o001co`000P3on@030?nZ00<0
ohl0203oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oad00?lk003o>`001P3o>`0^0?mG0240og<0
1@3oS`0;0?nZ00D0olD00P3og`00103/o`000?mh003oN01co`040;_o00040:?o0000oj000?nP07?o
0080G?l000<00ol002P0o`0X0?l00P00bolg02P0o`800?o/00<00<_o05co001Lo`001@2;o`00101c
o`00G?l005co0000MOnb02P0o`80G?l000@0Rol00=Co003Do`00k?l00P3og`020?o500030?nZ003o
S`00ohl000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oad00?lk003o>`001P3o>`0^
0?mG0240og<01@3oS`0;0?nZ00D0olD00P3og`00103/o`000?mh003oN01co`040;_o00040:?o0000
oj000?nP07?o0080G?l000<00ol002P0o`0X0?l00P00bolg02P0o`800?o/00<00<_o05co001Lo`00
1@2;o`00101co`00G?l005co0000MOnb02P0o`80G?l000@0Rol00=Co003Do`00k?l00P3og`020?o5
00030?nZ003oS`00ohl000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oad00?lk003o
>`001@3o>`0^0?mG0240og<01@3oS`030?nZ00`0olD00P3og`030?oi00800?nc00<00?on07?o001c
o`000P1co`00101Lo`000?lA003o4@00oe02003o>`03003o4@00gOl00=go03/0:03o00<00?nP003o
f@00omT00P1Lo`0307?o000305co000_o`00;ol00;D0:03o00@0e?l00?oi003on@00oml00P3oa@03
0?nZ00<0ohl02P3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oad00?lk003o>`000`3o>`0^0?mG
0200og<0103oS`020?nZ00h0olD01@3og`030?oi0080e?l000<0Xol007?o001co`000P00Z?l302P0
o`04003ooP0X0?l0:03o003oS400:03o0P0_o`0305co000304Ko000_o`00;ol00;80:03o00@00?lk
08_o002;o`00e?l00P3/o`000`3og`00olD00?o500030?nZ00<0ohl02P3oL`0;0?mG00T0oooo0008
0?ooo`80o`0000<0oad00?lk003o>`000`3o>`0^0?mG0200og<0103oS`020?nZ00h0olD01@3og`03
0?oi0080e?l000<0Xol007?o001co`000P00Z?l302P0o`04003ooP0X0?l0:03o003oS400:03o0P0_
o`0305co000304Ko000_o`00;ol00;80:03o00@00?lk08_o002;o`00e?l00P3/o`000`3og`00olD0
0?o500030?nZ00<0ohl02P3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oad00?lk003o>`000`3o
>`0/0?mG01h0og<01`3oS`000`3oZP00oml00?oO00030?oO00P0olD0203og`020?oi00<0k?l000<0
^ol00:?o002So`000P1Lo`000`00olH00;[o002jo`1202P0o`800:So0P00ok<0100_o`00A_l004Ko
000_o`0200?o0003003ooP0X0?l0:03o0;00:03o0P00IOl0102ko`00Xol00:?o003og`020?o50080
ojX0103oS`0:0?mc00/0oeL02@3oool000P0oooo0P3o00040?lk02d0oeL06@3oL`0:0?n?00<0ojX0
00<0olD00?oO003og`000P2ko`000`3Do`00G?l005co000>0?oO0080ooT00`3/o`000`3Do`00^ol0
0;_o000202oo000301Wo000X0?l0:03o04L0:03o0`0Io`02003o4K<0:03o0P00Z?l01000oh`00ol0
00?o003on@040?nZ00@0ohl02P3oL`0;0?mG00T0oooo00080?ooo`80o`00103o>`0]0?mG01T0og<0
2P3oS`030?nZ00030?o5003og`00oml00080^ol000<0e?l005co001Lo`003P3og`020?oi00<0k?l0
00<0e?l00;_o002ko`000P0_o`000`0Io`00:03o02P0o`1702P0o`<06Ol00P00oa6c02P0o`800:So
00@00?n<00?o0003o`00ooT0103oZP040?n?00X0og<02`3oE`090?ooo`00203oool20?l000@0oc/0
:`3oE`0C0?mc0100ohl01@3oZP000`3oa@00oml00?oO00020>co000305co003Do`00e?l000<0ooT0
2@3og`020?oi00D0k?l000<0^ol00:?o002So`000P2;o`001016o`000?lk003o>`00IOm502P0o`04
003oI003o`000ol000?o00800?lV]@0X0?l0100I0?l0^ol00;_o003og`040?nZ00<0ohl02`3oL`0;
0?mG00T0oooo00080?ooo`80o`00103o>`0[0?mG01<0og<0403oS`050?nZ00030?o5003og`00oml0
0080k?l000<0G?l00=Co003Do`000`3on@090?oO0080ooT01@3/o`000`2ko`00Xol00:?o000208_o
000404Ko0000oc/00?lk001UodD0:03o00@00?mT00?o0003o`000ol00P00obJe02P0o`0401T0o`2k
o`00^ol00?oO00@0ojX00`3oS`0;0?mc00/0oeL02@3oool000P0oooo0P3o00030?lk02/0oeL0303o
L`0E0?n?00H0ojX01@3oa@020;_o000401Wo002So`00Xol00>co00L0ooT000@0oml00?oi003on@00
ooT01@3/o`020=Co00030:?o002;o`00Rol00080G?l000<00?lV003oS000oh`0A`0X0?l3003o9P80
0?m@/00X0?l2003o9P0402P0o`00=?l003Co003oD080k?l000<0olD00?nZ003oZP001@3oS`0;0?mc
00/0oeL02@3oool000P0oooo0P3o00030?lk02T0oeL02P3oL`0G0?n?00P0ojX01@3oa@020>co0004
0=Co0000Q_l008Ko0;_o0080e?l01P3/o`020;_o00H0e?l00P2ko`000`005?l00?lk003o>`02003o
oTX0:03o0P00ogP00`00oe000?mh003oN02b02P0o`040;_o003/o`00k?l00?oi0080olD00`3oZP05
0?n?00/0og<02`3oE`090?ooo`00203oool20?l000<0oc/0:@3oE`0:0?mc01L0ohl0203oZP050?o5
0080k?l000@0e?l00026o`00Q_l0^ol00P3Do`060>co0080^ol01P3Do`020;_o0003000Do`00oc/0
0?lk00800?onBP0X0?l2003oN003003oD000ogP00?mh0;80:03o00@0^ol00>co003/o`00ooT00P3o
a@030?nZ00D0ohl02`3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oc/00?mG003oE`009`3oE`07
0?mc01T0ohl02P3oZP040?o50080oml00P3on@00103/o`00Xol00:?o001co`020;_o0080e?l00`3/
o`00103Do`000?m@003oD01co`050;_o0080Xol000<0Rol005co001Lo`000P00Uom<02P0o`03003o
N000oj000?nP0;80:03o00@0Rol00>co003/o`00oml00P3oa@000`3oZP00ohl00?n?00050?n?00/0
og<02`3oE`090?ooo`00203oool20?l000030?lk003oE`00oeL002H0oeL01@3oL`0I0?n?00d0ojX0
103oa@020?oO00<0ooT00P3Do`000`2;o`000ol000?o000208_o00040:?o002ko`00^ol00;_o0080
Lol000<0G?l008_o002;o`000`2So`0308_o0080A_l00P00oa400`00ok<0:03o02P0o`1902P0o`03
003oaP00on`00?o/0;80:03o00@00=go0?oi003on@00olD00`3oZP070?n?00/0og<02`3oE`090?oo
o`00203oool20?l000030?lk003oE`00oeL002H0oeL01@3oL`0I0?n?00d0ojX0103oa@020?oO00<0
ooT00P3Do`000`2;o`000ol000?o000208_o00040:?o002ko`00^ol00;_o0080Lol000<0G?l008_o
002;o`000`2So`0308_o0080A_l00P00oa400`00ok<0:03o02P0o`1902P0o`03003oaP00on`00?o/
0;80:03o00@00=go0?oi003on@00olD00`3oZP070?n?00/0og<02`3oE`090?ooo`00203oool20?l0
00030?lk003oE`00oeL002<0oeL0103oL`0K0?n?00l0ojX00`3oa@030?oO0080ooT00`3/o`000`2k
o`00;ol002oo0002003o4@@0Rol00P1Lo`000`00bol0G?l005co000207?o0004002Go`1co`00Lol0
05co008000Go0P00E?m<02P0o`03003_o`00gOl00=go0:d0:03o00<00;[o02P0o`0X0?l00P0X0?l0
1000of@0oml00?oO003oa@030?nZ00D0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oc/0
0?mG003oE`008`3oE`040?mc01/0ohl03`3oZP030?o500<0oml00P3on@030>co00030;_o000_o`00
;ol000800?lA102;o`0205co0003003;o`1Lo`00G?l00080Lol000@009Oo07?o001co`00G?l00P00
1Ol2001Dod`0:03o00<00>oo003Mo`00gOl0[@0X0?l00`00^_l0:03o02P0o`0202P0o`04003oI03o
g`00oml00?o500<0ojX01@3oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o00000`3o>`00oeL00?mG
00060?mG00h0og<02`3oE`050?mc01d0ohl03P3oZP030?o500D0oml00P3on@030>co00030:?o000I
o`006Ol000800?m@00@0;ol000?o0003o`00A_l00P0Io`000`00oj000?m@003oD00202oo000401Wo
0016o`00A_l004Ko00806Ol00P00ogQ=02P0o`8008Ko[@0X0?l00`00of@0Rol008_o00020>co0003
0?oO003oa@00olD000<0ojX01P3oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o00060?mG01`0og<0
103oS`030?nZ01P0ohl03`3oZP040?o500H0oml00P3on@00103/o`00e?l00=Co002So`0205co0080
0?o600@00:So02P0o`0X0?l0:03o0P00ogP00`00on`0:03o02P0o`02003ok004003oN000oh`00?n<
00?o00800?lVC`0X0?l2000dojh0:03o0P00gOl20?oi00<0olD00`3oZP060?n?00d0og<02`3oE`09
0?ooo`00203oool20?l000H0oeL0703oL`040?n?00<0ojX0603oS`0?0?nZ00@0olD01P3og`020?oi
00040>co003Do`00e?l00:?o0080G?l00P00olH01000Z?l0:03o02P0o`0X0?l2003oN003003ok00X
0?l0:03o00800?o/00@00?mh003oS000oh`00ol00P00obI?02P0o`8003Co[P0X0?l2003Mo`80ooT0
0`3oa@030?nZ00H0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`000`3oE`0A0?mc00/0ohl00P3o
ZP000`3oa@00Xol00:?o00020?o500/0ojX03P3oS`0@0?nZ00<0olD01P3og`020?oi0080k?l000@0
e?l00;_o002ko`00^ol00P1co`0201Wo0003003oI00X0?l0:03o00/0:03o00<00?on003oD000oe00
o00X0?l204Ko000308_o003on@00ooT00080oml000<0olD00?nZ003oZP000`3oZP060?n?00d0og<0
2`3oE`090?ooo`00203oool20?l000030?mG003oL`00og<000h0og<02`3oS`050?nZ00030?o5003o
n@00ooT00080oml000<0olD00?nZ003oZP003@3oZP060?n?00D0ojX03P3oa@000`3/o`00ooT00?oi
00060?oi0080e?l00P00obH30:?o000307?o000_o`00;ol000800ol000<00?nP02P0o`0X0?l02`0X
0?l00`005?l00?nP003oX002001DooT0:03o00@002Co02P0o`0X0?l0ooT00P3og`030?o500<0ojX0
203oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o00000`3oE`00og<00?mc000>0?mc00/0ohl01@3o
ZP000`3oa@00ooT00?oi00020?oO00030?o5003oZP00ojX000d0ojX01P3oS`050?nZ00h0olD000<0
k?l00?oi003on@001P3on@020=Co00800?lV0`2So`000`1co`00;ol002oo000200?o0003003oX00X
0?l0:03o00/0:03o00<001Co003oX000oj000P00E?oi02P0o`04000To`0X0?l0:03o0?oi0080oml0
0`3oa@030?nZ00P0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oeL00?mc003oL`002`3o
L`0=0?n?00H0ojX000<0oml00>co003/o`000`3og`0;0?nZ01P0olD00`3og`020?oi00<0^ol01P3/
o`020=Co0080Xol000@0A_l008_o002;o`00G?l00P03o`02003of@0301T0o`0X0?l0:03o0?l0:03o
2P0X0?l01000on`0k?l00>co003og`040?o500@0ojX0203oS`0=0?mc00/0oeL02@3oool000P0oooo
0P3o000<0?mc00d0ohl0203oZP000`3og`00k?l00>co00020=Co00030?oi003oa@00olD000<0ojX0
2P3oa@030?oO00030=Co003og`00oml000<0oml01P3oa@070?oO00<0ooT000<0^ol0003o9P00obH0
0P3Do`030>co00030=Co002ko`00^ol00080Xol000@0A_l0003o9P00obH00ol00P00obH2003oa_l0
:03o2`0X0?l20:?o00040>co003og`00oml00?oO00@0olD0103oZP080?n?00d0og<02`3oE`090?oo
o`00203oool20?l000`0og<03@3oS`080?nZ00030?oO003/o`00k?l00080e?l000<0ooT00?o5003o
a@000`3oZP0:0?o500<0oml000<0e?l00?oO003og`000`3og`060?o500L0oml00`3on@000`2ko`00
0?lV003o9P020=Co00<0k?l000<0e?l00;_o002ko`000P2So`001016o`000?lV003o9P03o`02003o
9P800?o6o`0X0?l;02P0o`80Xol000@0k?l00?oO003og`00oml0103oa@040?nZ00P0ohl03@3oL`0;
0?mG00T0oooo00080?ooo`80o`002`3oL`060?nZ00H0ohl00P3oZP060?o50080ooT000<0k?l00;_o
002ko`000P00ogP0102ko`00k?l00>co003on@050?oO00D0olD00`3og`020?oi000301Wo003Do`00
e?l000<0ooT02`3og`020?oi00<0k?l000<0^ol004Ko0016o`000`2ko`0207?o00030:?o002ko`00
^ol00080Lol000@0A_l0003oI000of@003Co0P00onco02P0o`X0:03o00<00?mh0;_o002ko`000P3/
o`000`3on@00oml00?oO00050?o500@0ojX0203oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o000;
0?mc00H0ojX01P3oS`020?nZ00H0olD00P3on@000`3/o`00^ol00;_o0002003oN0040;_o003/o`00
k?l00?oi00D0oml01@3oa@030?oO0080ooT000<06Ol00=Co003Do`000`3on@0;0?oO0080ooT00`3/
o`000`2ko`00A_l004Ko00030;_o0080Lol000<0Xol00;_o002ko`000P1co`001016o`000?mT003o
I000=?l2003ok?l0:03o2P0X0?l00`00ogP0^ol00;_o00020>co00030?oi003og`00oml000D0olD0
103oZP080?n?00d0og<02`3oE`090?ooo`00203oool20?l000<0ohl01@3oZP000`3oL`00olD00?o5
00040?nZ00@0olD000@0oml00?oi003on@00oml0103oa@030?oO00<0ooT000<00?lA003oN000ogP0
0`0X0?l20;_o00<0ooT00P3og`030?oi00<0k?l00`3on@020>co000408_o002So`00Xol00>co0080
ooT00P3/o`030=Co00030>co003on@00ooT00080k?l000@0e?l00:?o002So`00^ol00P2So`000`1c
o`000?lV003o9P02003oN00408_o0016o`00A_l007?o0080G?l00P00on`00`00obH00?o6003oaP3o
02P0o`X0:03o00@009Oo08_o002;o`00^ol00P3/o`030?oi0080oml01@3oa@040?nZ00P0ohl03@3o
L`0;0?mG00T0oooo00080?ooo`80o`00o`0X0?mU02P0o`800?nc0P0Io`00101co`00Xol00:?o003D
o`020>co0080ooT00`3og`030?o500H0ojX0203oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o003o
02P0ofD0:03o0P00ok<201Wo000407?o002So`00Xol00=Co0080k?l00P3on@030?oO00<0olD01P3o
ZP080?n?00d0og<02`3oE`090?ooo`00203oool20?l000<0ohl01@3oZP000`3oL`00olD00?o50004
0?nZ00@0olD000@0oml00?oi003on@00oml0103oa@030?oO00<0ooT000<00?lA003oN000ogP00`0X
0?l20;_o00<0ooT00P3og`030?oi00<0k?l00`3on@020>co000408_o002So`00Xol00>co0080ooT0
0P3/o`030=Co00030>co003on@00ooT00080k?l000@0e?l00:?o002So`00^ol00P2So`000`1co`00
0?lV003o9P02003oN00408_o0016o`00A_l007?o0080G?l00P00on`00`00obH00?o6003oaP3o02P0
o`X0:03o00@009Oo08_o002;o`00^ol00P3/o`030?oi0080oml01@3oa@040?nZ00P0ohl03@3oL`0;
0?mG00T0oooo00080?ooo`80o`002`3oL`060?nZ00H0ohl00P3oZP060?o50080ooT000<0k?l00;_o
002ko`000P00ogP0102ko`00k?l00>co003on@050?oO00D0olD00`3og`020?oi000301Wo003Do`00
e?l000<0ooT02`3og`020?oi00<0k?l000<0^ol004Ko0016o`000`2ko`0207?o00030:?o002ko`00
^ol00080Lol000@0A_l0003oI000of@003Co0P00onco02P0o`X0:03o00<00?mh0;_o002ko`000P3/
o`000`3on@00oml00?oO00050?o500@0ojX0203oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o000;
0?mc00H0ojX01P3oS`020?nZ00H0olD00P3on@000`3/o`00^ol00;_o0002003oN0040;_o003/o`00
k?l00?oi00D0oml01@3oa@030?oO0080ooT000<06Ol00=Co003Do`000`3on@0;0?oO0080ooT00`3/
o`000`2ko`00A_l004Ko00030;_o0080Lol000<0Xol00;_o002ko`000P1co`001016o`000?mT003o
I000=?l2003ok?l0:03o2P0X0?l00`00ogP0^ol00;_o00020>co00030?oi003og`00oml000D0olD0
103oZP080?n?00d0og<02`3oE`090?ooo`00203oool20?l000`0og<03@3oS`080?nZ00030?oO003/
o`00k?l00080e?l000<0ooT00?o5003oa@000`3oZP0:0?o500<0oml000<0e?l00?oO003og`000`3o
g`060?o500L0oml00`3on@000`2ko`000?lV003o9P020=Co00<0k?l000<0e?l00;_o002ko`000P2S
o`001016o`000?lV003o9P03o`02003o9P800?o6o`0X0?l;02P0o`80Xol000@0k?l00?oO003og`00
oml0103oa@040?nZ00P0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`00303oL`0=0?n?00P0ojX0
00<0oml00>co003/o`000P3Do`000`3on@00olD00?o500030?nZ00X0olD00`3og`000`3Do`00oml0
0?oO00030?oO00H0olD01`3og`030?oi00030;_o0000obH00?lV0080e?l00`3/o`000`3Do`00^ol0
0;_o00020:?o000404Ko0000obH00?lV00?o00800?lV0P00olKo02P0o`/0:03o0P2So`00103/o`00
oml00?oO003og`040?o500@0ojX0203oS`0=0?mc00/0oeL02@3oool000P0oooo0P3o00000`3oE`00
og<00?mc000;0?mc00d0ohl01P3oZP000`3og`00k?l00>co00030?oO00/0ojX0603oa@030?oO0080
ooT00`2ko`060>co0080e?l00P2So`001016o`00Rol008_o001Lo`0200?o00800?oI00<06@3o02P0
o`0X0?l0o`0X0?l:02P0o`04003ok03/o`00k?l00?oO00@0olD0103oZP080?n?00d0og<02`3oE`09
0?ooo`00203oool20?l000030?mG003oL`00og<000h0og<02`3oS`050?nZ00030?o5003on@00ooT0
0080oml000<0olD00?nZ003oZP003@3oZP060?n?00D0ojX03P3oa@000`3/o`00ooT00?oi00060?oi
0080e?l00P00obH30:?o000307?o000_o`00;ol000800ol000<00?nP02P0o`0X0?l02`0X0?l00`00
5?l00?nP003oX002001DooT0:03o00@002Co02P0o`0X0?l0ooT00P3og`030?o500<0ojX0203oS`0=
0?mc00/0oeL02@3oool000P0oooo0P3o00000`3oE`00og<00?mc000>0?mc00/0ohl01@3oZP000`3o
a@00ooT00?oi00020?oO00030?o5003oZP00ojX000d0ojX01P3oS`050?nZ00h0olD000<0k?l00?oi
003on@001P3on@020=Co00800?lV0`2So`000`1co`00;ol002oo000200?o0003003oX00X0?l0:03o
00/0:03o00<001Co003oX000oj000P00E?oi02P0o`04000To`0X0?l0:03o0?oi0080oml00`3oa@03
0?nZ00P0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`000`3oE`0A0?mc00/0ohl00P3oZP000`3o
a@00Xol00:?o00020?o500/0ojX03P3oS`0@0?nZ00<0olD01P3og`020?oi0080k?l000@0e?l00;_o
002ko`00^ol00P1co`0201Wo0003003oI00X0?l0:03o00/0:03o00<00?on003oD000oe00o00X0?l2
04Ko000308_o003on@00ooT00080oml000<0olD00?nZ003oZP000`3oZP060?n?00d0og<02`3oE`09
0?ooo`00203oool20?l000H0oeL0703oL`040?n?00<0ojX0603oS`0?0?nZ00@0olD01P3og`020?oi
00040>co003Do`00e?l00:?o0080G?l00P00olH01000Z?l0:03o02P0o`0X0?l2003oN003003ok00X
0?l0:03o00800?o/00@00?mh003oS000oh`00ol00P00obI?02P0o`8003Co[P0X0?l2003Mo`80ooT0
0`3oa@030?nZ00H0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`001P3oE`0L0?mc00@0ohl00`3o
ZP0H0?n?00l0ojX0103oa@060?oO0080ooT000@0k?l00=Co003Do`00Xol00P1Lo`02003oaP04002X
o`0X0?l0:03o02P0o`800?mh00<00?o/02P0o`0X0?l00P00on`01000ogP00?n<003oS003o`02003o
9Tl0:03o0P00=?n^02P0o`800=go0P3on@030?o500<0ojX01P3oS`0=0?mc00/0oeL02@3oool000P0
oooo0P3o00000`3o>`00oeL00?mG00060?mG00h0og<02`3oE`050?mc01d0ohl03P3oZP030?o500D0
oml00P3on@030>co00030:?o000Io`006Ol000800?m@00@0;ol000?o0003o`00A_l00P0Io`000`00
oj000?m@003oD00202oo000401Wo0016o`00A_l004Ko00806Ol00P00ogQ=02P0o`8008Ko[@0X0?l0
0`00of@0Rol008_o00020>co00030?oO003oa@00olD000<0ojX01P3oS`0=0?mc00/0oeL02@3oool0
00P0oooo0P3o00000`3o>`00oeL00?mG000S0?mG00@0og<06`3oS`0?0?nZ00<0olD00`3og`020?oi
00<0k?l000<0^ol002oo000_o`000P00oa4408_o0080G?l000<00<_o05co001Lo`000P1co`001000
Uol0Lol007?o001Lo`020005o`8005CoC00X0?l00`00kol00=go003Mo`2]02P0o`03002jo`0X0?l0
:03o0080:03o00@00?mT0?oO003og`00olD00`3oZP050?n?00d0og<02`3oE`090?ooo`00203oool2
0?l000030?lk003oE`00oeL002<0oeL0103oL`0K0?n?00l0ojX00`3oa@030?oO0080ooT00`3/o`00
0`2ko`00;ol002oo0002003o4@@0Rol00P1Lo`000`00bol0G?l005co000207?o0004002Go`1co`00
Lol005co008000Go0P00E?m<02P0o`03003_o`00gOl00=go0:d0:03o00<00;[o02P0o`0X0?l00P0X
0?l01000of@0oml00?oO003oa@030?nZ00D0ohl03@3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0
oc/00?mG003oE`009P3oE`050?mc01T0ohl03@3oZP040?o50080oml00`3on@020=Co000308_o0003
o`000ol00080Rol000@0Xol00;_o002ko`00^ol00P1co`000`1Lo`00Rol008_o00030:?o00<0Rol0
0P16o`02003o4@03003o/`0X0?l0:03o04T0:03o00<00?o6003ok000on`0/P0X0?l01000gOl0ooT0
0?oi003oa@030?nZ00L0ohl02`3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oc/00?mG003oE`00
9P3oE`050?mc01T0ohl03@3oZP040?o50080oml00`3on@020=Co000308_o0003o`000ol00080Rol0
00@0Xol00;_o002ko`00^ol00P1co`000`1Lo`00Rol008_o00030:?o00<0Rol00P16o`02003o4@03
003o/`0X0?l0:03o04T0:03o00<00?o6003ok000on`0/P0X0?l01000gOl0ooT00?oi003oa@030?nZ
00L0ohl02`3oL`0;0?mG00T0oooo00080?ooo`80o`0000<0oc/00?mG003oE`009`3oE`070?mc01T0
ohl02P3oZP040?o50080oml00P3on@00103/o`00Xol00:?o001co`020;_o0080e?l00`3/o`00103D
o`000?m@003oD01co`050;_o0080Xol000<0Rol005co001Lo`000P00Uom<02P0o`03003oN000oj00
0?nP0;80:03o00@0Rol00>co003/o`00oml00P3oa@000`3oZP00ohl00?n?00050?n?00/0og<02`3o
E`090?ooo`00203oool20?l000<0oc/0:@3oE`0:0?mc01L0ohl0203oZP050?o50080k?l000@0e?l0
0026o`00Q_l0^ol00P3Do`060>co0080^ol01P3Do`020;_o0003000Do`00oc/00?lk00800?onBP0X
0?l2003oN003003oD000ogP00?mh0;80:03o00@0^ol00>co003/o`00ooT00P3oa@030?nZ00D0ohl0
2`3oL`0;0?mG00T0oooo00080?ooo`80o`000`3o>`0Y0?mG00X0og<05`3oS`080?nZ00D0olD00P3/
o`00103Do`0008Ko0026o`2ko`020=Co00H0k?l00P2ko`060=Co0080^ol000<001Co003o>`00oc/0
0P00ooi:02P0o`800?mh00<00?m@003oN000ogP0/P0X0?l0102ko`00k?l00>co003on@020?o500<0
ojX01@3oS`0;0?mc00/0oeL02@3oool000P0oooo0P3o00030?lk02/0oeL0303oL`0E0?n?00H0ojX0
1@3oa@020;_o000401Wo002So`00Xol00>co00L0ooT000@0oml00?oi003on@00ooT01@3/o`020=Co
00030:?o002;o`00Rol00080G?l000<00?lV003oS000oh`0A`0X0?l3003o9P800?m@/00X0?l2003o
9P0402P0o`00=?l003Co003oD080k?l000<0olD00?nZ003oZP001@3oS`0;0?mc00/0oeL02@3oool0
00P0oooo0P3o00040?lk02/0oeL04`3oL`0@0?n?00D0ojX000<0olD00?oO003og`000P3/o`000`1L
o`00e?l00=Co00030?oi00T0oml00P3on@050>co00030;_o002So`00Xol00080Rol000@0A_l0003o
>`00oc/006GoA@0X0?l01000of@00ol000?o0003o`02003o9[D0:03o00@06@3o0;_o002ko`00oml0
103oZP030?n?00/0og<02`3oE`090?ooo`00203oool20?l000@0oc/0:`3oE`0C0?mc0100ohl01@3o
ZP000`3oa@00oml00?oO00020>co000305co003Do`00e?l000<0ooT02@3og`020?oi00D0k?l000<0
^ol00:?o002So`000P2;o`001016o`000?lk003o>`00IOm502P0o`04003oI003o`000ol000?o0080
0?lV]@0X0?l0100I0?l0^ol00;_o003og`040?nZ00<0ohl02`3oL`0;0?mG00T0oooo00080?ooo`80
o`00103o>`0]0?mG01T0og<02P3oS`030?nZ00030?o5003og`00oml00080^ol000<0e?l005co001L
o`003P3og`020?oi00<0k?l000<0e?l00;_o002ko`000P0_o`000`0Io`00:03o02P0o`1702P0o`<0
6Ol00P00oa6c02P0o`800:So00@00?n<00?o0003o`00ooT0103oZP040?n?00X0og<02`3oE`090?oo
o`00203oool20?l000@0oc/0;@3oE`0I0?mc00X0ohl00`3oZP000`3oa@00oml00?oO00020;_o0003
0=Co001Lo`00G?l000h0oml00P3on@030>co00030=Co002ko`00^ol00080;ol000<06Ol002P0o`0X
0?l0A`0X0?l301Wo00800?lA/`0X0?l2002Xo`04003oS003o`000ol00?oi00@0ojX0103oS`0:0?mc
00/0oeL02@3oool000P0oooo0P3o00000`3o7@00oc/00?lk00030?lk02`0oeL07P3oL`070?n?0003
0?nZ003og`00oml000<0oml0203oa@080?oO0080ooT00`3/o`000`2ko`00Xol00:?o000205co0003
003oaP00^_l00;[o0480:03o0P00Z?l2003o/`0402oo0016o`00A_l002oo00800ol000<00?on02P0
o`0X0?l0/00X0?l2001Uo`040;_o002So`00Xol00?oO0080olD00P3oZP040?n?00X0og<02`3oE`09
0?ooo`00203oool20?l000030?lM003o>`00oc/000<0oc/0;P3oE`0P0?mc00@0ohl00P3oZP0>0?o5
00D0oml00`3on@020=Co00030:?o001co`00Lol000800:So0`0X0?l01000ooh0:03o02P0o`00oha0
02P0o`80;ol00`1Lo`000`16o`00;ol002oo002b02P0o`04003o>`2;o`00Rol00=Co0080k?l000<0
oml00?o5003oa@000`3oZP030?n?00X0og<02`3oE`090?ooo`00203oool20?l000030?lM003o>`00
oc/000<0oc/0;P3oE`0P0?mc00@0ohl00P3oZP0>0?o500D0oml00`3on@020=Co00030:?o001co`00
Lol000800:So0`0X0?l01000ooh0:03o02P0o`00oha002P0o`80;ol00`1Lo`000`16o`00;ol002oo
002b02P0o`04003o>`2;o`00Rol00=Co0080k?l000<0oml00?o5003oa@000`3oZP030?n?00X0og<0
2`3oE`090?ooo`00203oool20?l000030?lM003o>`00oc/000D0oc/0;P3oE`0Q0?mc00D0ohl00`3o
ZP0<0?o50080oml00`3on@02003o/`03003ooP1co`00Lol00080Lol000@0G?l0003o4@00oa400?m@
0P00oc/00`00oa400=go003Mo`0k02P0o`03003oX000omT00?oI0080G?l00`1co`000`1Lo`00;ol0
02oo002e02P0o`040=Co003on@00ooT00?oO0080olD00`3oZP030?n?00X0og<02`3oE`090?ooo`00
203oool20?l000030?lM003o>`00oc/000H0oc/0;P3oE`0Q0?mc00D0ohl02`3oZP050?o50080oml0
00@0k?l0003oN000ogP0Lol0102ko`00102So`000?nP003oX01co`0205co000300?o000X0?l0:03o
00800<_o=`0X0?l2003ok003003;o`1Lo`00G?l000D0Rol000@0Lol005co001Lo`0007Go/P0X0?l2
05co000408_o003Do`00e?l00>co0080oml00P3oa@000`3oZP00ohl00?n?00030?n?00P0og<02`3o
E`090?ooo`00203oool20?l000030?lM003o>`00oc/000H0oc/0;P3oE`0Q0?mc00D0ohl02`3oZP05
0?o50080oml000@0k?l0003oN000ogP0Lol0102ko`00102So`000?nP003oX01co`0205co000300?o
000X0?l0:03o00800<_o=`0X0?l2003ok003003;o`1Lo`00G?l000D0Rol000@0Lol005co001Lo`00
07Go/P0X0?l205co000408_o003Do`00e?l00>co0080oml00P3oa@000`3oZP00ohl00?n?00030?n?
00P0og<02`3oE`090?ooo`00203oool30?l000P0oc/0<03oE`0Q0?mc00D0ohl0303oZP040?o500@0
e?l01@3/o`020;_o00040:?o002;o`00Rol004Ko0080;ol00P00oa400`00oj00:03o02P0o`0c02P0
o`040026o`00Z?l00:So003o4@P0Rol00P1co`000`03o`000?o6003oaP2_02P0o`04003oX000MOl0
07Go003oaP80A_l000<00<_o07?o001co`000P3on@030?nZ00<0ohl0203oL`0;0?mG00T0oooo0008
0?ooo`<0o`002P3o>`0_0?mG0280og<0103oS`0=0?nZ0080olD000<0oml00?oi003on@000`3on@05
0>co00<0^ol000<0Rol005co001Lo`000P0_o`001000oc/0:03o02P0o`00MOl^02P0o`800>oo0P00
gOl0100X0?l0G?l005co001co`080:?o0080Lol0^`0X0?l2002jo`030?o5003oZP00ojX000<0ohl0
203oL`0;0?mG00T0oooo00080?ooo`<0o`002P3o>`0_0?mG0280og<0103oS`0=0?nZ0080olD000<0
oml00?oi003on@000`3on@050>co00<0^ol000<0Rol005co001Lo`000P0_o`001000oc/0:03o02P0
o`00MOl^02P0o`800>oo0P00gOl0100X0?l0G?l005co001co`080:?o0080Lol0^`0X0?l2002jo`03
0?o5003oZP00ojX000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`<0o`000P3o7@090?lk0300oeL0
803oL`060?n?00d0ojX000@0olD00?oO003og`00oml0103on@030>co00040=Co002ko`00^ol008_o
0080G?l00P00oe000`00ogP0:03o02P0o`0^02P0o`03000To`00oc/00?lk00800?nP00<0;ol008_o
002;o`00202ko`00102So`00Rol008_o001Lo`02003ofK<0:03o0P00on`00`0Io`000?n<003oS002
0=Co00030?oO003oZP00ojX000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`<0o`000P3o7@090?lk
0300oeL0803oL`060?n?00d0ojX000@0olD00?oO003og`00oml0103on@030>co00040=Co002ko`00
^ol008_o0080G?l00P00oe000`00ogP0:03o02P0o`0^02P0o`03000To`00oc/00?lk00800?nP00<0
;ol008_o002;o`00202ko`00102So`00Rol008_o001Lo`02003ofK<0:03o0P00on`00`0Io`000?n<
003oS0020=Co00030?oO003oZP00ojX000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`<0o`000P3o
7@0;0?lk02l0oeL0803oL`050?n?00d0ojX00`3oa@050?oO00040?oi003/o`00k?l00=Co0080Xol0
00<0Lol005co001Lo`000P00oc/00`00A?l0:03o02P0o`0602P0o`806@3o8@0X0?l20014o`04001U
o`0X0?l0:03o000Do`80;ol00P00ok<00`00omT0Xol00:?o00090;_o0080Xol000<0G?l0003o4@00
oa40/`0X0?l2002Xo`0307?o0000ogP00?mh00806Ol000<0ooT00?nZ003oZP000`3oS`080?mc00/0
oeL02@3oool000P0oooo0`3o00020?lM00`0oc/0<03oE`0P0?mc00D0ohl02`3oZP030?o500H0oml0
0P3/o`00102So`000?m@003oD00Io`0202P0o`800?n<2`0X0?l00`00olH0:03o02P0o`0L02P0o`80
0?o60`00oe02001Do`03002Go`2;o`00Rol000<0Xol02P3Do`00102ko`00Xol00:?o0000ohbb02P0
o`800?on00@00?m@003o4@00oa40^ol00P3Do`0205co00030?oi003oZP00ojX000D0ohl01P3oL`0;
0?mG00T0oooo00080?ooo`<0o`000P3o7@0<0?lk0300oeL0803oL`050?n?00/0ojX00`3oa@060?oO
0080k?l000@0Xol0003oD000oe006Ol00P0X0?l2003oS0/0:03o00<00?o602P0o`0X0?l0700X0?l2
003oaP<00?m@0P00E?l00`00Uol0Rol008_o00030:?o00X0e?l000@0^ol00:?o002So`000?n</P0X
0?l2003ooP04003oD000oa400?lA0;_o0080e?l00P1Lo`000`3on@00ojX00?nZ00050?n?00H0og<0
2`3oE`090?ooo`00203oool30?l00080oad03P3o>`0`0?mG01h0og<01P3oS`0;0?nZ0080olD01P3o
g`020?oi00040;_o002So`00Xol008_o00800?lk0P00IOl902P0o`802P3o00<00?lk003oD000oe00
0P0X0?l00`00on`0:03o02P0o`0A02P0o`800<_o100X0?l2003oD080;ol000@00ol0003oN000ogP0
G?l0102ko`000`3Do`00k?l00>co00050>co00@0e?l00P2ko`000`2;o`000?nP003oX002003ooP03
002Xo`0X0?l0:03o0:/0:03o0P1co`000`2So`00e?l00=Co00030>co0080Lol000<0olD00?nZ003o
ZP001@3oS`060?mc00/0oeL02@3oool000P0oooo0`3o00020?lM0100oc/0;`3oE`0M0?mc00P0ohl0
2@3oZP030?o500D0oml00P3on@00103/o`00e?l00=Co002ko`0202oo00800?lA00<00?mh02P0o`0X
0?l0200X0?l00`03o`006Ol001Wo000201Wo00<0:03o00@00?oI000To`009?l00?mh0P005?l502P0
o`03002Xo`00oh`00?n<00<0:03o0P00ogP010009?l0:03o02P0o`0X0?l2003o9P80G?l000@0:03o
00?o0003o`00Rol0103Do`090>co00D0e?l000<0Xol004Ko0016o`000P00of@00`00ogP0:03o02P0
o`2[02P0o`800?nP00@0^ol00>co003/o`00ooT0103og`000`3oa@00ojX00?nZ00050?n?00H0og<0
2`3oE`090?ooo`00203oool30?l00080oad0403o>`0_0?mG01d0og<0203oS`090?nZ00<0olD01@3o
g`020?oi00040>co003Do`00e?l00;_o0080;ol00P00oa400`00ogP0:03o02P0o`0802P0o`0300?o
000Io`006Ol000806Ol00`0X0?l01000omT002Co000To`00ogP2000Do`D0:03o00<00:So003oS000
oh`00`0X0?l2003oN004000To`0X0?l0:03o02P0o`800?lV0P1Lo`00100X0?l00ol000?o002;o`04
0=Co00T0k?l01@3Do`000`2So`00A_l004Ko0002003oI003003oN00X0?l0:03o0:/0:03o0P00oj00
102ko`00k?l00>co003on@040?oO00030?o5003oZP00ojX000D0ohl01P3oL`0;0?mG00T0oooo0008
0?ooo`<0o`000`3o7@0@0?lk0300oeL0703oL`070?n?00T0ojX00`3oa@050?oO0080ooT000@0k?l0
0=Co003Do`00^ol00P2;o`02003_o`H0:03o0P00Uol0100X0?l00?lV003o9P0Io`0205co0080A_l0
00@00?nP003o>`00oc/003Co0P0_o`000`00oc/0:03o02P0o`0502P0o`03002Xo`03o`000ol00080
0?mh00@0;ol0003oD000oe000ol00P00oj000`00A?l007Go001eo`030:?o00800<_o00<0A_l00=Co
003Do`003@3/o`030=Co00030:?o001co`00Lol000806Ol0/00X0?l0102ko`00ooT00?oi003on@02
0?oO0080olD00`3oZP050?n?00H0og<02`3oE`090?ooo`00203oool30?l000<0oad0403o>`0`0?mG
01`0og<01`3oS`090?nZ00<0olD01@3og`020?oi00040>co003Do`00e?l00;_o0080Rol00P00kol6
02P0o`8009Oo00@0:03o003o9P00obH06Ol00P1Lo`0204Ko0004003oX000oc/00?lk000do`80;ol0
00<00?lk02P0o`0X0?l01@0X0?l00`00Z?l00ol000?o0002003oN00402oo0000oe000?m@00?o0080
0?nP00<004Co001eo`00MOl00`2So`02003;o`0304Ko003Do`00e?l000d0k?l00`3Do`000`2So`00
Lol007?o000201Wo0;00:03o00@0^ol00?oi003on@00ooT00P3og`020?o500<0ojX01@3oS`060?mc
00/0oeL02@3oool000P0oooo0`3o00030?lM0180oc/0;`3oE`0K0?mc00P0ohl01`3oZP040?o500@0
oml000@0ooT00>co003/o`00k?l00P3Do`000`2So`00Lol007?o000204Ko0004003o4@00Q_l008Ko
002Xo`800?nP0P00oc/00`00ooh00;[o002jo`0308_o00<0A_l00P2;o`00101co`006Ol001Wo0000
oh`20026o`H0:03o0P16o`0307?o0080G?l000@0;ol0001eo`00MOl00ol00P2;o`050=Co00030>co
003on@00ooT000/0ooT00`3/o`020=Co00030:?o0000gOl00=go0:l0:03o00@00ol004Ko0016o`00
^ol00P3on@030?oO0080olD00`3oZP050?n?00H0og<02`3oE`090?ooo`00203oool50?l000030?lM
003o>`00oc/001<0oc/0;P3oE`0I0?mc00P0ohl01`3oZP040?o500@0oml000@0ooT00>co003/o`00
k?l00P2ko`000`00oj006Ol001Wo000201Wo0004003oI00X0?l0:03o003o9P806Ol00P16o`000`00
Uol0Rol008_o00030;_o00H0Xol00P0Io`000`16o`000?lA003o4@02003ooP0402P0o`009?l002Co
003o4@800?lk0P2So`000`2;o`00A_l004Ko000302P0o`030:?o003Do`00e?l000<0k?l01@3on@03
0?oO00X0ooT00`3/o`0802P0o`03001Uo`0X0?l0:03o0:D0:03o0P009?l01000olH0Rol008_o003D
o`020>co00<0oml00P3oa@030?nZ00D0ohl01P3oL`0;0?mG00T0oooo00080?ooo`D0o`0000<0oad0
0?lk003o>`004`3o>`0^0?mG01T0og<0203oS`070?nZ00@0olD0103og`00103on@00k?l00>co003/
o`020;_o0003003oX00Io`006Ol000806Ol000@00?mT02P0o`0X0?l00?lV0P0Io`0204Ko0003002G
o`2;o`00Rol000<0^ol01P2So`0201Wo000304Ko0000oa400?lA00800?on00@0:03o000To`009?l0
0?lA0P00oc/20:?o000308_o0016o`00A_l000<0:03o00<0Xol00=Co003Do`000`3/o`050?oi00<0
oml02P3on@030>co00P0:03o00<006Go02P0o`0X0?l0Y@0X0?l2000To`04003oaP2;o`00Rol00=Co
0080k?l00`3og`020?o500<0ojX01@3oS`060?mc00/0oeL02@3oool000P0oooo1@3o00000`3o7@00
oc/00?lk000E0?lk02h0oeL06@3oL`080?n?00D0ojX0103oa@020?oO00<0ooT00P3/o`00103Do`00
^ol00;_o001co`02003o/`800?on00@00?lV00X0o`0:0?l06Ol00P1co`0208_o0003003;o`2So`00
Xol000<0e?l00P3/o`00103Do`00^ol00;_o002ko`020:?o000307?o000_o`00;ol000800?lV00@0
0>oo02P0o`0X0?l004Co0P2So`030;_o00<06Ol00P1co`000`2ko`00k?l00>co00050?oi00/0oml0
1P3on@020>co00030=Co002So`00Xol000800?lV00@00?mT003o>`00oc/00?ncZ@0X0?l0100_o`00
Lol007?o002;o`020;_o00030?oi003og`00oml000<0olD00`3oZP050?n?00D0og<02`3oE`090?oo
o`00203oool50?l000<0oad0603o>`0/0?mG01P0og<0203oS`050?nZ00@0olD00P3on@020>co0004
07?o0000obH00?lV0:?o00800?lA00<06Ol0003o4@00oa400P1Lo`00101co`00;ol002oo0000on`2
0:?o00D0^ol01P3/o`020=Co00040;_o002So`00Xol008_o0080;ol00P001Ol01000obH003Co000d
o`1co`020=Co0080k?l000@0e?l00:?o002So`000?nP0P00ok<00`2ko`00ooT00?oi00020?oi0100
oml01P3on@000`3/o`00e?l00=Co000207?o000402P0o`0_o`00;ol002P0o`800:SoY@0X0?l2003o
oP0402P0o`00ooh00?on003;o`800?on00<00?lV0>co003/o`000P3og`00103oa@00ojX00?nZ003o
ZP050?n?00D0og<02`3oE`090?ooo`00203oool50?l000<0oad0603o>`0/0?mG01P0og<0203oS`05
0?nZ00@0olD00P3on@020>co000407?o0000obH00?lV0:?o00800?lA00<06Ol0003o4@00oa400P1L
o`00101co`00;ol002oo0000on`20:?o00D0^ol01P3/o`020=Co00040;_o002So`00Xol008_o0080
;ol00P001Ol01000obH003Co000do`1co`020=Co0080k?l000@0e?l00:?o002So`000?nP0P00ok<0
0`2ko`00ooT00?oi00020?oi0100oml01P3on@000`3/o`00e?l00=Co000207?o000402P0o`0_o`00
;ol002P0o`800:SoY@0X0?l2003ooP0402P0o`00ooh00?on003;o`800?on00<00?lV0>co003/o`00
0P3og`00103oa@00ojX00?nZ003oZP050?n?00D0og<02`3oE`090?ooo`00203oool50?l000<0oad0
6@3o>`0]0?mG01H0og<02@3oS`040?nZ00<0olD000<0oml002oo000_o`000P2So`001016o`00G?l0
05co000Io`0202oo000304Ko002;o`00Rol000800?mh00@0^ol00:?o002So`000>oo0P2ko`030>co
00L0ooT00`3/o`00103Do`00Xol00:?o001Lo`02003_o`800?oI00@0Rol0003o9P00obH0e?l0103/
o`00103on@00k?l00>co003Do`02003oD0030>co003on@00ooT001<0oml01@3on@000`3/o`00e?l0
0=Co00020;_o000408_o0016o`00A_l0003o>`800?o/ZP0X0?l01000=?l00ol000?o002;o`020;_o
00800ol000@0ooT00?o5003oa@00ojX01@3oS`050?mc00/0oeL02@3oool000P0oooo1@3o00030?lM
01T0oc/0;@3oE`0F0?mc00T0ohl0103oZP030?o500030?oO000_o`00;ol00080Xol000@0A_l005co
001Lo`006Ol00P0_o`000`16o`00Rol008_o0002003oN0040;_o002So`00Xol0003_o`80^ol00`3/
o`070?oi00<0k?l000@0e?l00:?o002So`00G?l00P00kol2003of@0408_o0000obH00?lV0=Co00@0
k?l000@0ooT00>co003/o`00e?l00P00oe000`3/o`00ooT00?oi000C0?oO00D0ooT000<0k?l00=Co
003Do`000P2ko`00102;o`00A_l004Ko0000oc/2003ok:X0:03o00@003Co00?o0003o`00Rol00P2k
o`0200?o00040?oi003oa@00olD00?nZ00D0ohl01@3oL`0;0?mG00T0oooo00080?ooo`D0o`000`3o
7@0L0?lk02/0oeL05@3oL`090?n?00@0ojX000@0olD00?oO003og`00ooT00P3Do`0202oo000408_o
003Do`00e?l00=Co0080k?l000<0^ol00=Co003Do`000`3/o`020;_o00030:?o003/o`00k?l00080
ooT01P3og`030?oi0080k?l000@0^ol0003oS000oh`06Ol00P00oc/2003oN0<0e?l00`3on@020?oO
00@0ooT00P3/o`000`3on@00oml00?oO00050?oO00<0olD03@3og`030?oi00030>co003Do`00e?l0
0080^ol000<0Lol001Wo000Io`00[P0X0?l2000Do`03002Xo`16o`00A_l000800ol00`0_o`000`3o
ZP00ohl00?n?00030?n?00D0og<02`3oE`090?ooo`00203oool50?l000<0oad0803o>`0Z0?mG01@0
og<02@3oS`020?nZ00040?oO003on@00ooT00?oi0080Lol00P0Io`00102ko`00k?l00>co003/o`03
0?oi00@0oml00`3on@000`1co`00ooT00?oi000:0?oO00<0ooT000@0A_l000?o0003o`00Rol00P2k
o`020=Co00030>co003on@00ooT000T0oml05@3oa@060?oO0080ooT000<0k?l00=Co003Do`000P1L
o`000`00of@00?nc003o/`2a02P0o`800?oI0P00kol0101co`00k?l00>co003oa@020?nZ00<0ohl0
1@3oL`0;0?mG00T0oooo00080?ooo`D0o`000`3o7@0P0?lk02X0oeL0503oL`090?n?0080ojX000@0
oml00?oi003on@00ooT00P1co`0201Wo00040;_o003/o`00k?l00>co00<0ooT0103og`030?oi0003
07?o003on@00ooT000X0oml00`3on@001016o`000ol000?o002;o`020;_o0080e?l000<0k?l00?oi
003on@002@3og`0E0?o500H0oml00P3on@000`3/o`00e?l00=Co000205co0003003oI000ok<00?nc
0;40:03o0P00omT2003_o`0407?o003/o`00k?l00?o50080ojX00`3oS`050?mc00/0oeL02@3oool0
00P0oooo1P3o00040?lM0240oc/0:@3oE`0B0?mc00T0ohl00P3oZP00103/o`00G?l005co003Do`02
01Wo0080Rol000@0k?l00?oi003on@00ooT02`3og`080?o500D0oml00P3on@00103Do`000?n<003o
S02;o`020=Co0080k?l000<0ooT00?oO003og`001@3og`0L0?o500<0oml00P3on@000`3/o`00^ol0
0;_o0002003o4K40:03o0P00bol00`00oe006Ol001Wo0002003o4@0404Ko0003o`000ol00>co0080
ojX00P3oS`060?mc00/0oeL02@3oool000P0oooo1P3o00040?lM02H0oc/09P3oE`0@0?mc00T0ohl0
0P3oZP00103og`00ooT00?oi002ko`0204Ko0080e?l000<0k?l00?oi003on@00103og`080?o500@0
ojX02@3oa@020?oO000408_o0016o`00A_l0003o9P80Xol00`3on@020?oO00P0olD03P3oZP0=0?o5
00<0oml000<0ooT001Wo000Io`000P16o`001000IOl0:03o02P0o`00ogP202P0o`8007Go00<00?mT
02P0o`0X0?l0WP0X0?l2003oI0D0:03o00@00?oI01Wo000Io`00Lol00P1Lo`02003oI0040;_o003o
n@00ooT00?oO0080ojX00P3oS`060?mc00/0oeL02@3oool000P0oooo1P3o00040?lM02H0oc/09P3o
E`0@0?mc00T0ohl00P3oZP00103og`00ooT00?oi002ko`0204Ko0080e?l000<0k?l00?oi003on@00
103og`080?o500@0ojX02@3oa@020?oO000408_o0016o`00A_l0003o9P80Xol00`3on@020?oO00P0
olD03P3oZP0=0?o500<0oml000<0ooT001Wo000Io`000P16o`001000IOl0:03o02P0o`00ogP202P0
o`8007Go00<00?mT02P0o`0X0?l0WP0X0?l2003oI0D0:03o00@00?oI01Wo000Io`00Lol00P1Lo`02
003oI0040;_o003on@00ooT00?oO0080ojX00P3oS`060?mc00/0oeL02@3oool000P0oooo1P3o0004
0?lM02T0oc/0903oE`0@0?mc00P0ohl00P3oZP00103oa@00oml00?oO003/o`0204Ko0080^ol000<0
k?l00?oO003og`00203oa@0<0?nZ00L0olD00`3on@000`2ko`000?lA003o4@020>co00030?oO003o
a@00olD000D0olD0503oZP0;0?o500<0oml00P3/o`020=Co00<00ol000<00?mT02oo000_o`000P0_
o`000`00oa40:03o02P0o`2N02P0o`80A_l00P0X0?l01000ok<00;[o002jo`00A?l208_o00030;_o
002;o`00Rol000800?lk00@0Xol00?oO003og`00olD00P3oZP020?n?00H0og<02`3oE`090?ooo`00
203oool60?l000D0oad0;@3o>`0R0?mG00d0og<0203oS`020?nZ00<0olD000<0k?l0003oI000of@0
0P03o`000`3/o`00olD00?o500060?o50180ojX0103oa@020?oi000301Wo002So`00Xol00080oml0
1P3oa@0H0?nZ00/0olD000<0oml00?oi003on@000P3on@00103Do`000?o6003oaP0X0?l407?o0004
0026o`0X0?l0:03o003_oi`0:03o00<001Co07?o001co`000P2So`00101co`00:03o02P0o`00oa45
0=Co00<0G?l00P2So`000`3oa@00ojX00?nZ00020?n?00H0og<02`3oE`090?ooo`00203oool60?l0
00D0oad0;@3o>`0R0?mG00d0og<0203oS`020?nZ00<0olD000<0k?l0003oI000of@00P03o`000`3/
o`00olD00?o500060?o50180ojX0103oa@020?oi000301Wo002So`00Xol00080oml01P3oa@0H0?nZ
00/0olD000<0oml00?oi003on@000P3on@00103Do`000?o6003oaP0X0?l407?o00040026o`0X0?l0
:03o003_oi`0:03o00<001Co07?o001co`000P2So`00101co`00:03o02P0o`00oa450=Co00<0G?l0
0P2So`000`3oa@00ojX00?nZ00020?n?00H0og<02`3oE`090?ooo`00203oool60?l000D0oad0<@3o
>`0P0?mG00d0og<01P3oS`020?nZ00<0olD000<0ooT00;_o002ko`000P0_o`000`3on@00olD00?o5
00030?o501H0ojX00`3oa@020?oO000308_o003og`00oml000D0olD0703oZP0:0?o500<0oml00`3o
n@020=Co00030;_o002So`00Xol00080Rol000@0Lol0003oX000oj000?mTVP0X0?l3003oN080Xol0
1@2ko`000`3/o`00ooT00?oi00030?oi0080e?l000@0Rol004Ko0016o`00olD0103oS`060?mc00/0
oeL02@3oool000P0oooo1P3o00050?lM0340oc/0803oE`0=0?mc00H0ohl00P3oZP030?o500030?oi
002ko`00^ol00080;ol000<0ooT00?o5003oa@000`3oa@0F0?nZ00<0olD00P3og`000`2;o`00oml0
0?oO00050?o501`0ojX02P3oa@030?oO00<0ooT00P3Do`000`2ko`00Xol00:?o000208_o000407?o
0000oj000?nP003oI9X0:03o0`00ogP20:?o00D0^ol000<0k?l00?oi003on@000`3on@020=Co0004
08_o0016o`00A_l00?o500@0ohl01P3oL`0;0?mG00T0oooo00080?ooo`P0o`000`3o7@0f0?lk01h0
oeL02P3oL`060?n?0080ojX000@0olD00?oO003og`00ooT00P2So`020=Co00040?oi003oa@00olD0
0?o504<0ojX02@3oa@020?oO00<0ooT00P3/o`000`3Do`00^ol00;_o00020:?o000407?o000Io`00
6Ol0000DoiT0:03o00@007Go02P0o`0X0?l0G?l00P2ko`020=Co00030>co003on@00ooT000H0oml0
0P3on@00100_o`00ooT00?oi003oZP040?n?00H0og<02`3oE`090?ooo`00203oool80?l000D0oad0
>@3o>`0K0?mG00T0og<01@3oS`020?nZ00040?o5003on@00ooT00=Co0080Xol00P3Do`000`3/o`00
olD00?o500040?nZ01l0ohl08`3oZP070?o500@0oml000@0ooT00>co003/o`00k?l00P2ko`020:?o
0003003_o`00Uol009Oo09d0:03o00<00?o60:?o002So`000P3/o`000`3on@00oml00?oO00080?oO
0003003oN03oa@00olD000<0ohl0203oL`0;0?mG00T0oooo00080?ooo`P0o`001@3o7@0i0?lk01/0
oeL02@3oL`050?n?0080ojX000@0olD00?oi003on@00e?l00P2So`020=Co00030>co003oa@00olD0
00@0ojX07`3oS`0S0?nZ00L0olD0103og`00103on@00k?l00>co003/o`020;_o0080Xol000<00>oo
002Go`00Uol0W@0X0?l00`00olH0Xol00:?o00020>co00030?oi003og`00oml000P0oml000<00?mh
0?o5003oa@000`3oS`080?mc00/0oeL02@3oool000P0oooo203o00050?lM03h0oc/06@3oE`060?mc
00D0ohl00P3oZP00103/o`00e?l00=Co003on@050?oO0080ojX0<P3oS`0E0?nZ00H0olD0103og`00
103on@00k?l00>co003/o`020:?o0080Rol000<0:03o003Mo`00gOl0V00X0?l2003_o`@0:03o0P0_
o`030?oi0080oml0203oa@030?nZ00<0ohl0203oL`0;0?mG00T0oooo00080?ooo`P0o`001@3o7@12
0?lk01L0oeL01P3oL`030?n?0080ojX00`3og`030?o50080ojX0?03oS`0@0?nZ00H0olD00P3og`00
103on@00k?l00>co002ko`0202P0o`80;ol000<00?lV003;o`00bol0V00X0?l2003o9P0402P0o`00
gOl00=go003oX080Xol00P3on@000`3og`00olD00?o500040?o500D0ojX01@3oS`060?mc00d0oeL0
2@3oool000P0oooo203o00050?lM0480oc/05`3oE`060?mc00<0ohl00P3oZP030?oO00<0olD00P3o
ZP0l0?n?0100ojX01P3oa@020?oO00040?oi003/o`00k?l00;_o0080:03o0P0_o`000`00obH00<_o
003;o`2H02P0o`800?lV00@0:03o003Mo`00gOl00?nP0P2So`020?oi00030?oO003oa@00olD000@0
olD01@3oZP050?n?00H0og<03@3oE`090?ooo`00203oool80?l000H0oad0AP3o>`0E0?mG00@0og<0
0P3oS`020?nZ00030?oO003oZP00ojX000<0ojX06`3oS`0>0?mc01X0ohl0303oZP050?o50080oml0
00@0ooT007?o001co`00Lol00P0X0?l2003oI0030026o`0X0?l0:03o09P0:03o0P00Z?l308_o0003
003oI03Do`00e?l00080oml0103oa@070?nZ00@0ohl0203oL`0=0?mG00T0oooo00080?ooo`P0o`00
1P3o7@160?lk01D0oeL0103oL`020?n?0080ojX000<0oml00?nZ003oZP000`3oZP0K0?n?00h0og<0
6P3oS`0<0?nZ00D0olD00P3og`00103on@00Lol007?o001co`0202P0o`800?mT00<008Ko02P0o`0X
0?l0V00X0?l2002Xo`<0Rol000<00?mT0=Co003Do`000P3og`040?o500L0ojX0103oS`080?mc00d0
oeL02@3oool000P0oooo2P3o00040?lM04/0oc/04`3oE`050?mc01/0ohl06`3oL`0G0?n?00X0ojX0
0`3oa@020?oO00040?oi0003o`000ol0003o9P800?nP0P0I0?l902P0o`800?m@S@0X0?l00`00ooh0
:03o02P0o`0202P0o`040;_o003Do`00e?l00=Co0080ooT00P3og`030?o500H0ojX01P3oS`080?mc
00d0oeL02@3oool000P0oooo2P3o00060?lM04`0oc/04`3oE`050?mc0140ohl09@3oL`0H0?n?00H0
ojX00`3oa@020?oO00040?oi002ko`00^ol004Ko00800:So0P0I0?l01000omT00?m@003oD000oa42
01T0o`<0:03o0P0_o`001000oa40:03o02P0o`001On702P0o`8005Co00<0:03o05co001Lo`000P2;
o`000`3Do`00k?l00>co00030?oi0080oml00`3oa@040?nZ00P0ohl0203oL`0=0?mG00T0oooo0008
0?ooo`X0o`001P3o7@1<0?lk01<0oeL01@3oL`0A0?n?02D0og<0603oS`060?nZ00<0olD00P3og`00
103on@00^ol00;_o0016o`02002Xo`806@3o00@00?oI003oD000oe000?lA0P0I0?l302P0o`80;ol0
00@00?lA02P0o`0X0?l000GoQ`0X0?l2001Do`0302P0o`1Lo`00G?l00080Rol000<0e?l00>co003/
o`000`3on@020?oO00<0olD0103oZP080?n?00P0og<03@3oE`090?ooo`00203oool:0?l000H0oad0
D@3o>`0@0?mG03`0og<05P3oS`060?nZ0080olD00P3og`00102ko`00:03o02P0o`1Lo`0200?o0080
08Ko00<00?mT003o>`00oc/00`0_o`000`00ogP0Lol007?o000207?o000302oo0000ogP00?mh08X0
:03o00<0;ol007?o001co`000P2So`00103Do`00k?l00>co003on@040?oO00030?o5003oZP00ojX0
00@0ojX01`3oS`090?mc00d0oeL02@3oool000P0oooo2P3o00060?lM05@0oc/0403oE`0l0?mc01H0
ohl01@3oZP020?o500030?oi003/o`00k?l000<0e?l00P00on`0101co`0004Co0014o`16o`0208_o
00<0Xol00P2;o`000`0_o`00:03o02P0o`2702P0o`04003o/`00oe000?m@00?o0080;ol00P2;o`00
102ko`00k?l00>co003on@040?oO00030?o5003oZP00ojX000<0ojX0203oS`090?mc00/0oeL00P3o
>`090?ooo`00203oool:0?l000H0oad0E03o>`0@0?mG03`0og<05P3oS`050?nZ0080olD000<0ooT0
0>co003/o`000`3Do`02003ok00407?o0000A?l004Co04Ko0080Rol00`2So`0208_o000302oo000X
0?l0:03o08L0:03o00@00?nc003oD000oe000ol00P0_o`0208_o00040;_o003/o`00k?l00?oi00@0
oml000<0olD00?nZ003oZP000`3oZP080?n?00T0og<02`3oE`020?lk00T0oooo00080?ooo`/0o`00
1P3o7@1F0?lk0100oeL0>`3oL`0F0?n?00D0ojX000@0olD00?oO003og`00oml00P3on@020>co0004
0:?o0000olH00?o604Ko0080Xol01@2ko`00100_o`00:03o02P0o`0X0?l2003o>`8003CoQP0X0?l2
003oaP80:03o00@00?m@0;_o002ko`00k?l00P3on@020?oO00030?o5003oZP00ojX000<0ojX0203o
S`090?mc00/0oeL00P3o>`090?ooo`00203oool;0?l000H0oad0F@3o>`0@0?mG03/0og<0503oS`05
0?nZ00<0olD00P3og`020?oi00040=Co002So`00Xol005co0080e?l00`3/o`020=Co00040:?o001c
o`00Lol000X0o`80A_l0RP0X0?l2003oaP0401Wo001co`00Lol001Wo0080e?l00P3og`000`3oa@00
ojX00?nZ00030?nZ00H0ohl02P3oL`0;0?mG00<0oc/02@3oool000P0oooo2`3o00060?lM05T0oc/0
403oE`0k0?mc01@0ohl01@3oZP030?o50080oml00P3on@00103Do`00Xol00:?o001Lo`020=Co00<0
k?l00P3Do`00102So`00Lol007?o000:0?l204Ko08X0:03o0P00olH0100Io`00Lol007?o000Io`02
0=Co0080oml000<0olD00?nZ003oZP000`3oZP060?n?00X0og<02`3oE`030?lk00T0oooo00080?oo
o`/0o`00203o7@1J0?lk0180oeL0=`3oL`0E0?n?00<0ojX01`3oa@000`3og`00ooT00?oi00040?oi
00@0k?l000@0e?l00;_o002ko`00Rol00P1co`0204Ko000300?o0000oh`00?n<08X0:03o00<00?o/
003o>`00oc/00P3on@030?o500<0ojX01P3oS`0:0?mc00/0oeL00`3o>`090?ooo`00203oool;0?l0
00P0oad0FP3o>`0B0?mG03L0og<05@3oS`030?nZ00L0olD000<0oml00?oi003on@00103on@040>co
00040=Co002ko`00^ol008_o0080Lol00P16o`000`03o`000?n<003oS02:02P0o`03003ok000oc/0
0?lk0080ooT00`3oa@030?nZ00H0ohl02P3oL`0;0?mG00<0oc/02@3oool000P0oooo2`3o00080?lM
05h0oc/04@3oE`0f0?mc01D0ohl00`3oZP060?o500<0oml01@3on@030>co0080^ol000<0Xol008_o
002;o`000P1Lo`00100Io`000?m@003oD000olH2002XohD0:03o0P00oa400`00gOl00?nP003oX002
003o9P030?oO003oa@00olD000<0ojX01P3oS`0:0?mc00/0oeL00`3o>`090?ooo`00203oool=0?l0
00P0oad0G@3o>`0C0?mG03D0og<04`3oS`040?nZ00L0olD00`3og`030?oi00<0k?l00P3Do`000`2S
o`00Lol007?o0002000Do`03003oX00X0?l0:03o07L0:03o00<00?o602P0o`0X0?l03@0X0?l01000
9?l06Ol001Wo001co`020:?o0080e?l000<0oml00?o5003oa@000`3oZP050?n?00/0og<02@3oE`05
0?lk00T0oooo00080?ooo`d0o`00203o7@1M0?lk01<0oeL0=@3oL`0C0?n?00@0ojX01`3oa@030?oO
00<0ooT00`3/o`020=Co00030:?o001co`00Lol0008001Co00<00?nP02P0o`0X0?l0M`0X0?l00`00
olH0:03o02P0o`0=02P0o`04000To`0Io`006Ol007?o0080Xol00P3Do`000`3og`00olD00?o50003
0?nZ00D0ohl02`3oL`090?mG00D0oc/02@3oool000P0oooo3@3o00080?lM0600oc/04`3oE`0c0?mc
01<0ohl01@3oZP060?o500<0oml0103on@00103Do`00^ol00;_o001Lo`0202oo07X0:03o0P00of@@
02P0o`04003ok000obH00?lV0:?o0080e?l00P3/o`00103on@00oml00?oO003oa@020?nZ00D0ohl0
2@3oL`0;0?mG00D0oc/02@3oool000P0oooo3@3o00090?lM06<0oc/0503oE`0`0?mc01<0ohl01@3o
ZP040?o500D0oml00P3on@00102ko`00Lol007?o0000A?mk02P0o`04003oD00Io`006Ol0003oD0l0
:03o00@004Co003_o`00kol00?lk0P2ko`020>co00040?oi003og`00oml00?oO0080olD01@3oS`09
0?mc00/0oeL01@3o>`090?ooo`00203oool=0?l000T0oad0H`3o>`0D0?mG0300og<04`3oS`050?nZ
00@0olD01@3og`020?oi00040;_o001co`00Lol00014og/0:03o00@00?m@01Wo000Io`000?m@3`0X
0?l01000A?l00>oo003_o`00oc/20;_o0080k?l000@0ooT00?oO003og`00oml00P3oa@050?n?00T0
og<02`3oE`050?lk00T0oooo00080?ooo`h0o`00203o7@1T0?lk01H0oeL0;P3oL`0B0?n?00D0ojX0
103oa@050?oO0080ooT000<0e?l0003of@00omT04@0X0?l2003;ofD0:03o0P00olH202P0o`0402oo
001Lo`00G?l0003ok08009Oo3P0X0?l2001Uo`03003oI016o`00A_l00080^ol000@0e?l007?o001c
o`000?lk0P3og`000`3oZP00ohl00?n?00020?n?00T0og<02P3oE`060?lk00T0oooo00080?ooo`h0
o`00203o7@1T0?lk01H0oeL0;P3oL`0B0?n?00D0ojX0103oa@050?oO0080ooT000<0e?l0003of@00
omT04@0X0?l2003;ofD0:03o0P00olH202P0o`0402oo001Lo`00G?l0003ok08009Oo3P0X0?l2001U
o`03003oI016o`00A_l00080^ol000@0e?l007?o001co`000?lk0P3og`000`3oZP00ohl00?n?0002
0?n?00T0og<02P3oE`060?lk00T0oooo00080?ooo`h0o`002P3o7@1U0?lk01L0oeL0;03oL`0@0?n?
00H0ojX01@3oa@030?oO0080ooT000@0e?l007?o001co`00:03o0P00oe02003_o`h0:03o00<00?lk
02P0o`0X0?l0HP0X0?l200?o0080A_l00`2;o`000`1co`000?lV003o9P0902P0o`800:So1@0X0?l0
0`0Io`00Lol007?o00020:?o000407?o0000=?l003Co0=Co0080ooT000<0ojX00?n?003oS`000P3o
S`090?mc00X0oeL01P3o>`090?ooo`00203oool>0?l000X0oad0I`3o>`0I0?mG02X0og<03`3oS`07
0?nZ00<0olD00`3og`020?oi00030>co0000obH00?lV00<06Ol00P00A?l>02P0o`0301Wo0000oc/0
0?lk0080:03o00<00?oI02P0o`0X0?l0F@0X0?l01000oh`0:03o02P0o`0X0?l2003oaP80Rol00`2k
o`00101co`000?nP003oX000Z?l2003oN0<0:03o0P00kol00`00Uol00?m@003oD00202P0o`04002X
o`00ogP00?mh02P0o`800?lA0P16o`001000oh`0G?l005co003on@020?o500030?nZ003oS`00ohl0
0080ohl0203oL`090?mG00P0oc/02@3oool000P0oooo3P3o000:0?lM06L0oc/06@3oE`0Z0?mc00l0
ohl01`3oZP030?o500<0oml00P3on@000`3/o`000?lV003o9P0301Wo008004Co3P0X0?l00`0Io`00
0?lk003o>`0202P0o`03003of@0X0?l0:03o05T0:03o00@00?n<02P0o`0X0?l0:03o0P00olH208_o
00<0^ol000@0Lol0003oX000oj000:So0P00ogP302P0o`800>oo00<009Oo003oD000oe000P0X0?l0
1000Z?l00?mh003oN00X0?l2003o4@80A_l000@00?n<05co001Lo`00ooT00P3oa@000`3oZP00ohl0
0?n?00020?n?00P0og<02@3oE`080?lk00T0oooo00080?ooo`h0o`002`3o7@1Y0?lk01T0oeL0:03o
L`0>0?n?00L0ojX00`3oa@000`3og`00ooT00?oi00020>co00040=Co002ko`00^ol007?o00800?lV
0P00ogP00`00E?l0:03o02P0o`0902P0o`800?m@00<0A_l005co001Lo`000P0Io`000`00omT0:03o
02P0o`1I02P0o`0401Wo0000ogP00?mh002Xo`800?on0P2ko`040=Co0080Xol000<00?o602oo000_
o`000P0:0?l01000oj000ol000?o000_o`0204Ko00800?n<00@00?o604Ko0016o`000ol00P00gOl2
003o>`0408_o003Do`00e?l00?oi0080olD000<0ojX00?n?003oS`000P3oS`080?mc00T0oeL0203o
>`090?ooo`00203oool@0?l000T0oad0J`3o>`0L0?mG02D0og<03P3oS`050?nZ00<0olD000<0ooT0
0>co003/o`000P3Do`00102ko`00Xol00:?o001co`0202P0o`8007Go300X0?l2001Do`0307?o002;
o`00Rol000800ol00`0X0?l00`00of@0:03o02P0o`0202P0o`03000To`0X0?l0:03o04d0:03o0P00
5?l201Wo000407?o002;o`00Rol0001Uo`80^ol00P3Do`040>co0080e?l000<0Xol007?o001co`00
0P00E?l00`00of@0;ol002oo000508_o00<0Xol000<0Lol0003oN000ogP00P16o`001000ogP0;ol0
02oo002;o`020>co00030?o5003oZP00ojX00080ohl01P3oL`090?mG00X0oc/02@3oool000P0oooo
403o00090?lM06/0oc/0703oE`0U0?mc00h0ohl01@3oZP030?o500030?oi003/o`00k?l00080e?l0
00@0^ol00:?o002So`00Lol00P0X0?l2001eo``0:03o0P00E?l00`1co`00Rol008_o000200?o00<0
:03o00<00?mT02P0o`0X0?l00P0X0?l00`009?l0:03o02P0o`1=02P0o`8001Co0P0Io`00101co`00
Rol008_o0000IOl20;_o0080e?l0103/o`020=Co00030:?o001co`00Lol0008005Co00<00?mT02oo
000_o`001@2;o`030:?o000307?o0000ogP00?mh0080A_l000@00?mh02oo000_o`00Rol00P3/o`00
0`3oa@00ojX00?nZ00020?n?00H0og<02@3oE`0:0?lk00T0oooo00080?oooa00o`002`3o7@1Z0?lk
0200oeL08@3oL`0=0?n?00H0ojX00P3og`000`03o`000?mh003oN002003oX00407?o002;o`00Rol0
07?o0080:03o0P00IOl302P0o`03002Go`00on`00?o/00800?o/0`0X0?l00`0Io`00Lol007?o0003
0:?o0080Rol000@0A_l0002Go`00Uol0A_l00P03o`1<02P0o`800=go1P0X0?l20014o`0408_o002k
o`00^ol00=Co0080k?l01P3on@020>co00030;_o0000obH00?lV0080:03o0`00oe000`2ko`00e?l0
0=Co00020>co00040=Co002ko`00^ol005co00800?lV0P2So`00102ko`00A_l004Ko002ko`0205co
00030?oi003oS`00ohl000P0og<02@3oE`0:0?lk00T0oooo00080?oooa00o`003@3o7@1[0?lk0200
oeL0803oL`0;0?n?00H0ojX00P3oa@000`3/o`000?lA003o4@0202oo0004002Xo`16o`00A_l004Ko
00800?mh0P0X0?l01000Z?l0:03o02P0o`00oh`400?o0004003oS00X0?l0:03o003oS080G?l000<0
^ol00=Co003Do`000P3Do`00102ko`00Xol00:?o001co`1=02P0o`03003o9P00=?l003Co00P0:03o
00@0Rol00=Co003Do`00k?l02P3on@000`00Z?l00?mh003oN0020=Co0004003o>`3Do`00e?l00>co
0080ooT00`3/o`020=Co00030:?o0000oc/00?lk0080^ol000@0k?l00?oi003on@00oml00P3on@00
0`3oa@00ohl00?n?00060?mc00/0oeL02P3o>`090?ooo`00203oool@0?l000d0oad0J`3o>`0P0?mG
0200og<02`3oS`060?nZ0080olD000<0k?l0003o4@00oa400P0_o`001000Z?l0A_l004Ko0016o`02
003oN080:03o00@00:So02P0o`0X0?l00?n<1003o`001000oh`0:03o02P0o`00oh`205co00030;_o
003Do`00e?l00080e?l000@0^ol00:?o002So`00Lol0C@0X0?l00`00obH003Co000do`0802P0o`04
08_o003Do`00e?l00>co00X0ooT000<00:So003oN000ogP00P3Do`001000oc/0e?l00=Co003/o`02
0?oi00<0k?l00P3Do`000`2So`000?lk003o>`020;_o00040>co003on@00ooT00?oO0080ooT000<0
olD00?n?003oS`001P3oL`0;0?mG00X0oc/02@3oool000P0oooo4@3o000<0?lM06d0oc/08`3oE`0L
0?mc00X0ohl01P3oZP020?o500030?oO002So`00Xol00080Xol000@00?on003oaP00olH00?lV0P00
of@2001eo`04003oD0009?l002Co00?o0080Lol00P0Io`001000of@0:03o02P0o`2;o`020:?o0003
0=Co003/o`00k?l000<0e?l00P2ko`000`2;o`00:03o02P0o`02003of@H0:03o00<00?lA02P0o`0X
0?l00P00ok<j02P0o`800?lV0P0X0?l00`16o`000?mT003oI00602P0o`806Ol000@0G?l00;_o002k
o`00k?l00P3on@080?oO00H0ooT00`3og`040?oi00040>co003Do`00e?l00:?o0080A_l00P2So`00
0`3on@00olD00?o500030?o500030?nZ003oS`00ohl000H0og<02P3oE`0;0?lk00T0oooo00080?oo
oa40o`00303o7@1]0?lk02<0oeL0703oL`0:0?n?00H0ojX00P3oa@000`3og`00Xol00:?o00020:?o
0004003ooP00olH00?o6003o9P800?mT0P00MOl01000oe0002Co000To`03o`0207?o00806Ol000@0
0?mT02P0o`0X0?l0Rol00P2So`000`3Do`00k?l00>co00030=Co0080^ol000<0Rol002P0o`0X0?l0
0P00omT602P0o`03003o4@0X0?l0:03o00800?nc>P0X0?l2003o9P80:03o00<0A_l0003oI000of@0
1P0X0?l201Wo000405co002ko`00^ol00>co0080ooT0203og`060?oi00<0oml0103on@00103/o`00
e?l00=Co002So`0204Ko0080Xol000<0ooT00?o5003oa@000`3oa@000`3oZP00ohl00?n?00060?mc
00X0oeL02`3o>`090?ooo`00203ooolA0?l000d0oad0KP3o>`0T0?mG01/0og<02P3oS`040?nZ0080
olD000<0oml00>co003/o`000P3Do`00102So`00A_l004Ko0000oh`20014o`800?lV00@0;ol005co
001Lo`00Rol00P2So`0207?o000408_o00009?l002Co0=Co00L0k?l000@0e?l00;_o002ko`000?lV
0P03o`02003oN0<0:03o00@00;[o02P0o`0X0?l0A_l00P0_o`02000do`<0:03o00<00?nP003oaP00
olH0;P0X0?l2003o>`<0:03o00<004Co003o4@00oa400P1co`00102;o`0001Co000Do`00Q_l2003o
D003002jo`0X0?l0:03o008005Co00@00;[o04Ko0016o`00ooT01@3og`0;0?o500L0oml000@0ooT0
08_o002;o`000?m@0P00bol20=Co00030?oO003oa@00olD000<0ojX00`3oS`050?mc00/0oeL02`3o
>`090?ooo`00203ooolA0?l000d0oad0K`3o>`0X0?mG01P0og<0203oS`040?nZ0080olD000<0oml0
0?oi003on@000P2ko`00101co`000?mT003oI000obH2003oI08000Go00@00?lA07?o001co`00Xol0
0P2ko`030=Co0080k?l0203on@00103/o`00Xol00:?o000X0?l4002Xo`0402P0o`00ooh00?on01Wo
0080Lol000<0Rol001Wo000Io`000`0X0?l2003ooP0301Wo0000bol00<_o02H0:03o0P00oj000`0X
0?l00?lV003o9P0302P0o`80;ol000@00?lA003;o`00bol007Go0P00oh`20:?o00<0^ol000@0Lol0
01Wo000Io`000?n<0P00Uol20026o`0304Ko003/o`00k?l000<0oml04`3oa@030?oO0080k?l000<0
Rol0003oS000oh`00P2So`00103og`00olD00?o5003oZP030?n?00L0og<02@3oE`0=0?lk00T0oooo
00080?oooa40o`003@3o7@1_0?lk02P0oeL0603oL`080?n?00@0ojX00P3oa@000`3og`00ooT00?oi
00020;_o000407?o0000of@00?mT003o9P800?mT0P001Ol01000oa40Lol007?o002So`020;_o00<0
e?l00P3/o`080?oi00040>co002So`00Xol002P0o`@00:So00@0:03o003ooP00ooh06Ol00P1co`00
0`2;o`006Ol001Wo000302P0o`800?on00<06Ol0003;o`00bol09P0X0?l2003oX00302P0o`00obH0
0?lV00<0:03o0P0_o`001000oa400<_o003;o`00MOl2003oS080Xol00`2ko`00101co`006Ol001Wo
0000oh`2002Go`8008Ko00<0A_l00>co003/o`000`3og`0C0?o500<0oml00P3/o`000`2;o`000?n<
003oS0020:?o00040?oO003oa@00olD00?nZ00<0ohl01`3oL`090?mG00d0oc/02@3oool000P0oooo
4`3o000=0?lM0700oc/0:03oE`0F0?mc00L0ohl00`3oZP030?o500030?oi003Do`00e?l000800=go
00@00?nP07?o001co`00G?l00P03o`0205co0004003ok00_o`00;ol008_o0080e?l00P3/o`030?oi
00H0oml00`3on@020>co00030;_o0000on`00?o/008007Go00@004Co002Go`00Uol00;[o0P2So`00
0`2ko`00Xol00:?o000204Ko00<0:03o00<0G?l007?o001co`000P009?l01003o`00A_l004Ko0000
oc/201Wo00800ol000@00?lk003oN000ogP00?o/400X0?l2003ok004003oI000obH00?lV00?o00@0
;ol000@0A_l005co001Lo`00:03o0P0_o`0208_o000405co000X0?l0:03o02P0o`80Xol01@3Do`00
101co`00:03o02P0o`00oe02002jo`800?lA00@0;ol00?oi003on@00oml01`3oa@0<0?nZ00D0olD0
0P3og`000`03o`0008Ko0026o`020=Co00040?oi003oZP00ojX00?nZ00<0ohl01@3oL`0;0?mG00d0
oc/02@3oool000P0oooo4`3o000>0?lM0740oc/0:@3oE`0E0?mc00H0ohl00P3oZP00103oa@00oml0
0?oO000_o`0205co0080Lol000@0^ol00=Co003Do`00Xol00P00ogP20;_o000402oo000X0?l0:03o
003oD080e?l00P3/o`000`3on@00oml00?oO00080?oO00<0ooT000<0e?l002oo000_o`000P03o`00
100X0?l00<_o003;o`2So`050=Co00800?m@00<0Rol0003o>`00oc/01@2So`00102;o`00Lol007?o
001Lo`0204Ko00806Ol000<00?m@02P0o`0X0?l0500X0?l2003oD00301Wo001Lo`00G?l00080Lol0
0`2;o`000`2So`00^ol00;_o00030;_o00800?nc00<0^ol00>co003/o`001@3/o`00103Do`00^ol0
0;_o001co`0205co00<0^ol00P3og`050?o50140ojX00`3oa@020?oO00030?oi003Do`00e?l00080
6Ol000<0k?l00?nZ003oZP00103oS`040?mc00/0oeL03P3o>`090?ooo`00203ooolC0?l000h0oad0
L@3o>`0Y0?mG01D0og<01P3oS`020?nZ00040?o5003og`00oml002oo0080G?l00P1co`00102ko`00
e?l00=Co002So`02003oN080^ol000@0;ol002P0o`0X0?l00?m@0P3Do`020>co00030?oi003og`00
oml000P0oml00`3on@000`3Do`00;ol002oo000200?o000402P0o`00bol00<_o0:?o00D0e?l00P00
oe000`2;o`000?lk003o>`050:?o000408_o001co`00Lol005co0080A_l00P0Io`000`00oe00:03o
02P0o`0D02P0o`800?m@00<06Ol005co001Lo`000P1co`0308_o00030:?o002ko`00^ol000<0^ol0
0P00ok<00`2ko`00k?l00>co00050>co00040=Co002ko`00^ol007?o0080G?l00`2ko`020?oO00D0
olD04@3oZP030?o50080oml000<0ooT00=Co003Do`000P0Io`000`3/o`00ojX00?nZ00040?n?00@0
og<02`3oE`0>0?lk00T0oooo00080?oooa<0o`003P3o7@1c0?lk02`0oeL04@3oL`050?n?0080ojX0
00@0olD00;_o002ko`000<_o0P00obH20=Co00<0ooT000<0^ol002oo000_o`000P3/o`00103Do`00
Lol007?o0016o`020;_o0080ooT0103og`020?o500P0oml000<0e?l0003o>`00oc/00`3Do`0200?o
00030;_o003/o`00k?l000D0k?l0103Do`040;_o00040:?o002;o`00Rol007?o0080A_l00P00oc/0
0`00A?l0:03o02P0o`0F02P0o`03003;o`1Lo`00G?l00080Lol000@0Xol00;_o002ko`00^ol01@3D
o`030>co00P0ooT00P3/o`000`00oa400ol000?o00020?oi00040?oO003oa@00olD00?o501L0ojX0
0`3oa@000`3on@00^ol00;_o00020=Co00030:?o003oZP00ojX000<0ohl00`3oL`0=0?mG00h0oc/0
2@3oool000P0oooo4`3o000>0?lM07<0oc/0;03oE`0A0?mc00D0ohl00P3oZP00103oa@00^ol00;_o
0000bol2003o9P80e?l00`3on@000`2ko`00;ol002oo00020>co00040=Co001co`00Lol004Ko0080
^ol00P3on@040?oO0080olD0203og`000`3Do`000?lk003o>`030=Co00800ol000<0^ol00>co003/
o`001@3/o`040=Co00@0^ol000@0Xol008_o002;o`00Lol00P16o`02003o>`030014o`0X0?l0:03o
01H0:03o00<00<_o05co001Lo`000P1co`00102So`00^ol00;_o002ko`050=Co00<0k?l0203on@02
0>co0003003o4@03o`000ol00080ooT000@0oml00?o5003oa@00olD05`3oZP030?o500030?oi002k
o`00^ol00080e?l000<0Xol00?nZ003oZP000`3oS`030?mc00d0oeL03P3o>`090?ooo`00203ooolE
0?l000h0oad0LP3o>`0^0?mG0180og<00`3oS`00103oZP00oml00?oO003og`020?oi0080e?l000@0
oml00?o5003oa@00olD0103og`00103/o`00G?l005co000Io`02003oI080ooT0303oa@030?oO0100
ooT00P3/o`030=Co00<0^ol00P2So`000`0_o`000ol000?o0002003;oaX0:03o0P00oc/207?o0004
0:?o002ko`00^ol00=Co00D0k?l00`3on@080?oO0080ooT000<00ol00?oi003on@000P3og`000`3o
a@00ojX00?nZ00060?nZ00/0ohl0203oZP020?o500030?oi002ko`00^ol00080oml000@0olD00?n?
003oS`00ohl01@3oL`0;0?mG0100oc/02@3oool000P0oooo5@3o000?0?lM07<0oc/0;`3oE`0@0?mc
00<0ohl0203oZP070?o500040?oO000_o`00;ol00>co0080oml04`3oa@090?oO00L0ooT000<0k?l0
0=Co003Do`000P3Do`00102So`00Rol008_o0000oc/2003;oa`0:03o0P00ok<204Ko000308_o002k
o`00^ol000<0k?l01@3on@0;0?oO00D0olD0103oZP0E0?n?00<0ojX00P3oa@000`16o`00Xol00:?o
00020?nZ00<0ohl0103oL`0=0?mG0100oc/02@3oool000P0oooo5@3o000?0?lM07<0oc/0;`3oE`0@
0?mc00<0ohl0203oZP070?o500040?oO000_o`00;ol00>co0080oml04`3oa@090?oO00L0ooT000<0
k?l00=Co003Do`000P3Do`00102So`00Rol008_o0000oc/2003;oa`0:03o0P00ok<204Ko000308_o
002ko`00^ol000<0k?l01@3on@0;0?oO00D0olD0103oZP0E0?n?00<0ojX00P3oa@000`16o`00Xol0
0:?o00020?nZ00<0ohl0103oL`0=0?mG0100oc/02@3oool000P0oooo5P3o000>0?lM07H0oc/0;`3o
E`0?0?mc00@0ohl0303oZP090?o500d0ojX01P3oa@080?oO00D0ooT00`3/o`020=Co000407?o001L
o`00G?l0003ok2<0:03o0P2ko`030>co00<0ooT01@3og`090?o500L0ojX06@3oS`050?nZ00<0ohl0
1@3oL`0=0?mG0140oc/02@3oool000P0oooo5P3o000@0?lM07D0oc/0<P3oE`0<0?mc00L0ohl08`3o
ZP040?o500L0oml00`3on@030>co0080e?l000<0Lol002P0o`0X0?l07`0X0?l2000do`800?mT00@0
:03o08_o002;o`00e?l0103on@030?oO00T0olD01`3oZP0O0?n?00P0og<03`3oE`0A0?lk00T0oooo
00080?oooaH0o`00403o7@1e0?lk0380oeL0303oL`070?n?02<0ojX0103oa@070?oO00<0ooT00`3/
o`020=Co000307?o000X0?l0:03o01l0:03o0P00=?l2003oI00402P0o`2;o`00Rol00=Co00@0ooT0
0`3og`090?o500L0ojX07`3oS`080?mc00l0oeL04@3o>`090?ooo`00203ooolF0?l00180oad0M@3o
>`0c0?mG00`0og<05@3oS`0C0?nZ00H0olD01@3og`020?oi00<0k?l00P2ko`00100_o`00:03o02P0
o`00of@P02P0o`800?mh00@0;ol00:?o002So`00e?l00P3/o`020?oi00030?oO003oa@00olD000H0
olD0203oZP0M0?n?00/0og<03P3oE`0C0?lk00T0oooo00080?oooaH0o`004P3o7@1e0?lk03<0oeL0
303oL`0E0?n?01<0ojX01P3oa@050?oO0080ooT00`3/o`020;_o000402oo000X0?l0:03o003oI200
:03o0P00ogP0100_o`00Xol00:?o003Do`020>co0080ooT000<0oml00?o5003oa@001P3oa@080?nZ
01d0ohl02`3oL`0>0?mG01<0oc/02@3oool000P0oooo603o000A0?lM07H0oc/0=03oE`0;0?mc01P0
ohl0403oZP060?o500<0oml00P3on@000`3/o`00e?l00=Co00020;_o000408_o000Io`006Ol0003o
X2<0:03o0P16o`000`00oe00k?l00>co00020?oi00030?oO003oa@00olD000D0olD01`3oZP0E0?n?
01<0og<03P3oE`0E0?lk00T0oooo00080?oooaP0o`004@3o7@1g0?lk03D0oeL0303oL`0H0?n?00h0
ojX01`3oa@030?oO00030>co001co`00Lol00080Lol000<00?lA02P0o`0X0?l08`0X0?l01000oc/0
0?on003ooP16o`020=Co0080ooT000<0oml00?o5003oa@000`3oa@080?nZ0100ohl0603oL`0?0?mG
01D0oc/02@3oool000P0oooo603o000A0?lM07L0oc/0=@3oE`0<0?mc01P0ohl03P3oZP070?o500<0
oml000<0k?l007?o001co`000P1co`000`00oa40:03o02P0o`0S02P0o`04003o>`00ooh00?on04Ko
0080e?l00P3on@000`3og`00olD00?o500030?o500P0ojX0403oS`0H0?mc00l0oeL05@3o>`090?oo
o`00203ooolI0?l00180oad0M`3o>`0f0?mG00`0og<0603oS`0=0?nZ00H0olD00P3og`000`3/o`00
Lol007?o000200?o000302P0o`00ooh00?on0240:03o0P00oe00100Io`000?oI003of@00olH2003o
X080oml0103oa@080?nZ00d0ohl06`3oL`0@0?mG01H0oc/02@3oool000P0oooo6@3o000C0?lM07T0
oc/0=P3oE`0=0?mc01H0ohl02`3oZP060?o50080oml000<0ooT00=Co003Do`000P16o`001000olH0
0ol000?o0000of@R02P0o`0405co002;o`00Rol00;_o0080k?l00`3og`030?o500P0ojX02P3oS`0K
0?mc01<0oeL05P3o>`090?ooo`00203ooolI0?l001<0oad0N@3o>`0f0?mG00d0og<05P3oS`0;0?nZ
00H0olD00P3og`000`3on@00e?l00=Co000204Ko0004003oaP03o`000ol0003oI280:03o00@0G?l0
08_o002;o`00^ol00P3/o`030?oO00<0olD0203oZP0:0?n?01/0og<04`3oE`0F0?lk00T0oooo0008
0?oooaT0o`005@3o7@1i0?lk03D0oeL03`3oL`0D0?n?00/0ojX01@3oa@020?oO00030?oi003Do`00
e?l00080A_l000<0;ol005co001Lo`008@0X0?l2002Xo`04000Do`2So`00Xol00=Co0080k?l00P3o
n@000`3og`00olD00?o500080?nZ00P0ohl0703oL`0C0?mG01P0oc/02@3oool000P0oooo6`3o000E
0?lM07P0oc/0>03oE`0>0?mc01D0ohl01`3oZP050?o50080oml00`3on@020=Co00040:?o001co`00
Lol001Wo00800?nP800X0?l01000oc/00?lA003o4@3Do`020>co0080ooT000<0oml00?o5003oa@00
1P3oZP080?n?01d0og<04`3oE`0I0?lk00T0oooo00080?oooa/0o`005@3o7@1h0?lk03P0oeL03P3o
L`0E0?n?00L0ojX01@3oa@020?oO00<0ooT00P3Do`00102So`00Lol007?o000Io`02003oX200:03o
00@00?lk003o4@00oa40e?l00P3/o`020?oi00030?oO003oa@00olD000H0ojX0203oS`0M0?mc01<0
oeL06@3o>`090?ooo`00203ooolK0?l001D0oad0NP3o>`0g0?mG0100og<04`3oS`060?nZ00D0olD0
0P3og`030?oi0080e?l000@0Xol004Ko0016o`000>oo8`0X0?l204Ko00030:?o003Do`00e?l00080
ooT000<0oml00?o5003oa@001@3oZP070?n?01/0og<05`3oE`0I0?lk00T0oooo00080?oooa/0o`00
5@3o7@1j0?lk03L0oeL0403oL`0C0?n?00H0ojX01@3oa@020?oO00<0ooT00P3Do`00102So`00A_l0
04Ko0000kolS02P0o`80A_l000<0Xol00=Co003Do`000P3on@000`3og`00olD00?o500050?nZ00L0
ohl06`3oL`0G0?mG01T0oc/02@3oool000P0oooo7@3o000D0?lM07X0oc/0>@3oE`0@0?mc0180ohl0
103oZP050?o50080oml000<0ooT00>co003/o`000P3/o`001016o`0005Co001Do`00gOlM02P0o`03
003oN00X0?l0:03o00800?lA00@00>oo003ooP00ooh0Rol00P1co`02003o9P030>co003oa@00olD0
00D0ojX0103oS`0M0?mc01H0oeL06`3o>`090?ooo`00203ooolM0?l001H0oad0NP3o>`0i0?mG0140
og<03`3oS`040?nZ00@0olD00`3og`030>co0080e?l000@0Rol000?o0003o`00:03o0P00bolI02P0
o`800?n<00<0;ol000?o0003o`000P1Lo`001016o`000?m@003oD00_o`02003ok080e?l000<0k?l0
0?o5003oa@000`3oZP060?n?01X0og<06@3oE`0K0?lk00T0oooo00080?oooad0o`005P3o7@1j0?lk
03T0oeL04@3oL`0?0?n?00@0ojX0103oa@030?oO00<0k?l00P3Do`00102;o`000ol000?o000X0?l2
003;oaT0:03o0P00oh`00`0_o`000ol000?o000205co000404Ko0000oe000?m@02oo00800?o/0P3D
o`000`3/o`00olD00?o500030?nZ00H0ohl06P3oL`0I0?mG01/0oc/02@3oool000P0oooo7P3o000F
0?lM07`0oc/0>03oE`0C0?mc00`0ohl01@3oZP020?o500040?oO003/o`00k?l00:?o0080e?l00P2S
o`00102;o`000?nP003oX000olH201Wo00800?mT00<00?lA003oI000of@0500X0?l2003oS00307?o
002So`00Xol00080Xol000@0G?l0003o4@00oa40Lol00P2ko`020?oi00030?oO003oa@00olD000<0
ojX01@3oS`0I0?mc01T0oeL07@3o>`090?ooo`00203ooolN0?l001P0oad0O03o>`0g0?mG01D0og<0
2`3oS`030?nZ0080olD000@0k?l00:?o002So`000?lA0P00kol208_o000405co0000bol00<_o02oo
00@0G?l000@0Lol001Wo000Io`00:03o0P00oh`;02P0o`800?on00@00?m@003o>`00oc/06Ol00P00
oa400`00oj00^ol00;_o00020;_o00<00?lA00<0Lol00=Co003Do`000P3og`030?o500030?nZ003o
S`00ohl000<0ohl0603oL`0K0?mG01h0oc/02@3oool000P0oooo7P3o000H0?lM07`0oc/0=`3oE`0E
0?mc00/0ohl00`3oZP020?o500040>co002So`00Xol0003o4@800>oo0P2;o`00101Lo`000<_o003;
o`0_o`0405co000407?o000Io`006Ol002P0o`800?n<2`0X0?l2003ooP04003oD000oc/00?lk01Wo
00800?lA00<00?nP0;_o002ko`000P2ko`03003o4@0307?o003Do`00e?l00080oml00`3oa@000`3o
ZP00ohl00?n?00030?n?01P0og<06`3oE`0N0?lk00T0oooo00080?oooah0o`006P3o7@1k0?lk03T0
oeL05@3oL`090?n?0080ojX00P3oa@00103/o`00Lol007?o002ko`0207?o00800?oI00@008Ko00?o
0003o`000?lV0P2;o`020:?o000408_o0000oc/00?lk003;o`80;ol00`00obH2003;o`P0:03o00@0
0?lk04Ko0016o`00Lol00P16o`000`3Do`00k?l00>co00020>co00040=Co001co`00Lol005co0080
0?lV0P3/o`000`3oa@00ojX00?nZ00050?n?01L0og<06`3oE`0P0?lk00T0oooo00080?oooah0o`00
6P3o7@1k0?lk03T0oeL05@3oL`090?n?0080ojX00P3oa@00103/o`00Lol007?o002ko`0207?o0080
0?oI00@008Ko00?o0003o`000?lV0P2;o`020:?o000408_o0000oc/00?lk003;o`80;ol00`00obH2
003;o`P0:03o00@00?lk04Ko0016o`00Lol00P16o`000`3Do`00k?l00>co00020>co00040=Co001c
o`00Lol005co00800?lV0P3/o`000`3oa@00ojX00?nZ00050?n?01L0og<06`3oE`0P0?lk00T0oooo
00080?ooob00o`006@3o7@1l0?lk03T0oeL05P3oL`080?n?0080ojX000@0olD00?oi003on@00ooT0
0P3/o`020=Co00040;_o001Lo`00G?l002oo00D0^ol00P2So`001003o`00Lol007?o0016o`02003o
4@8005Co200X0?l0100:0?l0A_l004Ko002So`020;_o00H0k?l00P3Do`000`3/o`00^ol00;_o0002
0:?o00030?o5003oZP00ojX000D0ohl0503oL`0N0?mG0200oc/02@3oool000P0oooo803o000K0?lM
07/0oc/0>P3oE`0F0?mc00H0ohl00`3oZP030?o50080oml00P3on@00102ko`0007Go001eo`00oj02
0=Co00<0k?l00P3Do`00102ko`00Xol00:?o001Lo`0202P0o`800;[o200X0?l01000olH0G?l005co
002;o`020=Co00030>co003on@00ooT00080ooT0103og`020?oi0080e?l000<0ojX00?n?003oS`00
0`3oS`0E0?mc01h0oeL08@3o>`090?ooo`00203ooolP0?l001/0oad0N`3o>`0j0?mG01H0og<01P3o
S`030?nZ00<0olD00P3og`020?oi00040;_o0000MOl007Go003oX080e?l00`3/o`020=Co00040;_o
002So`00Xol005co0080:03o0P00^_l802P0o`04003oaP1Lo`00G?l008_o0080e?l000<0k?l00?oi
003on@000P3on@040?oO0080ooT00P3Do`000`3oZP00ohl00?n?00030?n?01D0og<07P3oE`0Q0?lk
00T0oooo00080?ooob40o`006`3o7@1n0?lk03L0oeL05P3oL`070?n?00<0ojX00`3oa@020?oO0004
0=Co002;o`00Rol00>co00@0ooT00`3/o`00103Do`00Xol00:?o001co`0201Wo008005Co1P0X0?l2
003Mo`0402P0o`0Io`006Ol0003o9P80A_l00`3on@030?oO00D0olD00`3oZP050?n?0140og<0803o
E`0S0?lk00T0oooo00080?ooob40o`007@3o7@1m0?lk03P0oeL05P3oL`060?n?00<0ojX0103oa@03
0?oi00<0oml00`3on@020>co00040=Co001co`00Lol004Ko00800?lk1P0X0?l2003ooP800ol000@0
A_l0003ooP00ooh0Rol00P3Do`000`3on@00oml00?oO00060?o500@0ojX0103oS`0B0?mc0200oeL0
903o>`090?ooo`00203ooolQ0?l001d0oad0O@3o>`0h0?mG01H0og<01P3oS`030?nZ00@0olD00`3o
n@030?oO00<0ooT00P3/o`00103Do`00Lol007?o0016o`02003o>`H0:03o0P00ooh200?o000404Ko
0000ooh00?on08_o0080e?l000<0ooT00?oO003og`001P3oa@040?nZ00@0ohl04P3oL`0P0?mG02@0
oc/02@3oool000P0oooo8`3o000L0?lM07h0oc/0=`3oE`0F0?mc00L0ohl01@3oZP030?o500H0oml0
0P3on@00100_o`00G?l005co001Lo`02003Mo`80G?l000@00ol0003oaP00olH005Co0P00oc/201Wo
000408_o001co`00Lol0003o4@80k?l000<0oml00?o5003oa@001@3oa@050?nZ00@0ohl0403oL`0R
0?mG02@0oc/02@3oool000P0oooo8`3o000N0?lM07d0oc/0>03oE`0F0?mc00D0ohl0203oZP050?o5
00<0oml000@0ooT00>co003/o`00^ol00P00oe020:?o000408_o0016o`00A_l0003oS0800=go0P1c
o`030;_o00040=Co003on@00ooT00?oO00D0olD01@3oZP060?n?00d0og<08`3oE`0T0?lk0080oad0
2@3oool000P0oooo8`3o000N0?lM07d0oc/0>03oE`0F0?mc00D0ohl0203oZP050?o500<0oml000@0
ooT00>co003/o`00^ol00P00oe020:?o000408_o0016o`00A_l0003oS0800=go0P1co`030;_o0004
0=Co003on@00ooT00?oO00D0olD01@3oZP060?n?00d0og<08`3oE`0T0?lk0080oad02@3oool000P0
oooo903o000O0?lM07l0oc/0=@3oE`0G0?mc00@0ohl0203oZP070?o500040?oO003on@00ooT00>co
0080e?l00P2ko`00102So`00A_l004Ko0000ogP2003o>`800?on00@0^ol00>co003/o`00k?l00P3o
n@000`3og`00olD00?o500020?o500H0ojX01@3oS`0<0?mc02<0oeL09@3o>`030?lM00T0oooo0008
0?ooob@0o`007`3o7@1o0?lk03D0oeL05`3oL`040?n?00P0ojX01`3oa@00103og`00ooT00?oi003/
o`020=Co0080^ol000@0Xol004Ko0016o`000?mh0P00oc/2003ooP040;_o003/o`00k?l00>co0080
ooT000<0oml00?o5003oa@000P3oa@060?nZ00D0ohl0303oL`0S0?mG02D0oc/00`3o7@090?ooo`00
203ooolT0?l00200oad0O`3o>`0f0?mG01H0og<01@3oS`080?nZ00H0olD00P3og`000`3on@00k?l0
0>co00020>co00040;_o001Lo`00G?l0003oI0800?lA0P00gOl0103Do`00k?l00>co003on@030?oO
00@0olD0103oZP070?n?00/0og<08`3oE`0T0?lk00D0oad02@3oool000P0oooo9P3o000P0?lM07l0
oc/0=P3oE`0D0?mc00L0ohl01P3oZP060?o50080oml00`3on@020>co00040=Co002So`00Xol005co
00806Ol00P2So`00103Do`00k?l00>co003on@030?oO00@0olD0103oZP070?n?00T0og<08`3oE`0U
0?lk00H0oad02@3oool000P0oooo9P3o000P0?lM07l0oc/0=P3oE`0D0?mc00L0ohl01P3oZP060?o5
0080oml00`3on@020>co00040=Co002So`00Xol005co00806Ol00P2So`00103Do`00k?l00>co003o
n@030?oO00@0olD0103oZP070?n?00T0og<08`3oE`0U0?lk00H0oad02@3oool000P0oooo:03o000O
0?lM07l0oc/0=@3oE`0F0?mc00D0ohl0203oZP040?o500<0oml00P3on@020>co00040=Co002ko`00
^ol007?o00800?lV0P2;o`000`2ko`00e?l00=Co00030?oi00030?oO003oa@00olD000H0ojX01`3o
S`080?mc02<0oeL0903o>`080?lM00T0oooo00080?ooobP0o`008@3o7@200?lk03<0oeL05P3oL`05
0?n?00L0ojX0103oa@030?oO0080ooT00P3/o`000`3Do`00Xol00:?o000302oo00800ol000@0Rol0
0;_o002ko`00k?l00P3on@030?oO0080olD00`3oZP060?n?00P0og<08`3oE`0T0?lk00X0oad02@3o
ool000P0oooo:03o000Q0?lM0800oc/0<`3oE`0F0?mc00D0ohl01`3oZP040?o500<0oml00P3on@02
0>co00030=Co002So`00Xol000<0;ol00P03o`00102;o`00^ol00;_o003/o`020?oi00<0oml00P3o
a@030?nZ00H0ohl0203oL`0S0?mG02@0oc/02P3o7@090?ooo`00203ooolY0?l002<0oad0O`3o>`0c
0?mG01@0og<01`3oS`050?nZ00@0olD00`3og`020?oi0080e?l000@0^ol0003o4@00oa406Ol0102S
o`001000of@00?lA003o4@2ko`020=Co00030>co003og`00oml00080olD00`3oZP060?n?00L0og<0
8P3oE`0S0?lk00d0oad02@3oool000P0oooo:@3o000S0?lM07l0oc/0<`3oE`0D0?mc00L0ohl01@3o
ZP040?o500<0oml00P3on@020=Co00040;_o0000oa400?lA01Wo00@0Xol000@00?mT003o4@00oa40
^ol00P3Do`000`3/o`00oml00?oO00020?o500<0ojX01P3oS`070?mc0280oeL08`3o>`0=0?lM00T0
oooo00080?ooobT0o`009@3o7@1o0?lk0380oeL04`3oL`070?n?00D0ojX0103oa@030?oO0080ooT0
0P2;o`00101Lo`000?mT003oI02ko`040=Co00040;_o002So`00Xol001Wo0080Xol000<0G?l00=Co
003Do`000P3/o`000`3oa@00ojX00?nZ00060?n?00D0og<08`3oE`0S0?lk00h0oad02@3oool000P0
oooo:`3o000T0?lM0840oc/0<@3oE`0C0?mc00H0ohl01@3oZP020?o500@0oml00P3/o`0207?o0004
003o/`2;o`00Rol00>co00D0ooT00P3Do`00100Io`00Lol007?o000Io`02003oX080k?l000<0oml0
0?o5003oa@001@3oS`040?mc02<0oeL08`3o>`0@0?lM00T0oooo00080?ooob/0o`00903o7@210?lk
0340oeL04`3oL`060?n?00D0ojX00P3oa@040?oO0080k?l00P1co`001000ok<0Rol008_o003/o`05
0?oi0080e?l000@06Ol007?o001co`006Ol00P00oj020>co00030?oO003oa@00olD000D0ohl0103o
L`0S0?mG02<0oc/0403o7@090?ooo`00203oool[0?l002H0oad0P03o>`0`0?mG01<0og<0203oS`03
0?nZ0080olD00`3og`000`3on@00k?l00>co000208_o00<0Xol000<0ooT00?oO003og`000`3og`02
0?oi00@0k?l00P2So`0202oo00030>co0000=?l003Co00D0ohl0103oL`0R0?mG02<0oc/04@3o7@09
0?ooo`00203oool/0?l002P0oad0P@3o>`0^0?mG0140og<0203oS`030?nZ0080olD00`3on@000`3/
o`00e?l00=Co000207?o00030;_o003on@00ooT000<0oml0203oa@000`3og`00ooT00?oi000207?o
00030>co003oa@00olD000<0ohl01@3oL`0Q0?mG0240oc/05@3o7@090?ooo`00203oool/0?l002P0
oad0P@3o>`0^0?mG0140og<0203oS`030?nZ0080olD00`3on@000`3/o`00e?l00=Co000207?o0003
0;_o003on@00ooT000<0oml0203oa@000`3og`00ooT00?oi000207?o00030>co003oa@00olD000<0
ohl01@3oL`0Q0?mG0240oc/05@3o7@090?ooo`00203oool/0?l002X0oad0P03o>`0^0?mG0100og<0
203oS`030?nZ0080oml000@0Rol00:?o002So`00;ol0102;o`000`00on`0ooT00?oi00050?o500H0
ojX00`3oa@020>co00040?oO003oZP00ojX00?n?00D0og<08@3oE`0R0?lk01H0oad02@3oool000P0
oooo;P3o000Y0?lM0880oc/0;@3oE`0@0?mc00H0ohl00`3oZP020?oO00040=Co001co`00Lol002P0
o`80A_l00P3/o`000`3on@00olD00?o500030?o500/0ojX00P3og`00102ko`00ojX00?nZ003oS`04
0?mc0240oeL08@3o>`0H0?lM00T0oooo00080?ooobh0o`00:@3o7@220?lk02d0oeL0403oL`060?n?
00<0ojX00P3og`00103Do`00Lol007?o000X0?l204Ko0080k?l000<0ooT00?o5003oa@000`3oa@0;
0?nZ0080oml000@0^ol00?nZ003oZP00ohl0103oL`0Q0?mG0240oc/0603o7@090?ooo`00203oool`
0?l002X0oad0P@3o>`0/0?mG00l0og<01P3oS`030?nZ0080oml000@0ooT002oo000_o`000?n<0P0_
o`020>co00030?oO003oa@00olD000<0ojX0203oS`050?nZ00<0ohl00`3oL`0Q0?mG0200oc/06`3o
7@090?ooo`00203oool`0?l002X0oad0P@3o>`0/0?mG00l0og<01P3oS`030?nZ0080oml000@0ooT0
02oo000_o`000?n<0P0_o`020>co00030?oO003oa@00olD000<0ojX0203oS`050?nZ00<0ohl00`3o
L`0Q0?mG0200oc/06`3o7@090?ooo`00203oool`0?l002`0oad0PP3o>`0Y0?mG00l0og<01P3oS`02
0?nZ00040?o5003og`00oml00=Co0080Rol00`3Do`020>co00030?o5003oZP00ojX00100ohl0103o
L`0P0?mG0240oc/07@3o7@090?ooo`00203ooola0?l002h0oad0PP3o>`0X0?mG00d0og<01P3oS`02
0?nZ00040?o5003og`00oml00>co0080^ol000<0ooT00?oO003og`000P3oa@000`3oZP00ohl00?n?
000<0?n?00P0og<07`3oE`0O0?lk0200oad02@3oool000P0oooo<@3o000^0?lM0880oc/0:03oE`0=
0?mc00H0ohl00P3oZP00103oa@00oml00?oO003/o`020;_o00030?oi003og`00oml00080olD000<0
ojX00?n?003oS`00303oS`080?mc01l0oeL07`3o>`0P0?lM00T0oooo00080?oooc<0o`00;P3o7@23
0?lk02H0oeL0303oL`060?n?0080ojX000<0olD00?oO003og`000`3Do`000`3og`00olD00?o50003
0?nZ00/0ohl02P3oL`0L0?mG0280oc/08@3o7@090?ooo`00203ooolc0?l00340oad0PP3o>`0V0?mG
00X0og<0103oS`040?nZ00040?o5003og`00oml00=Co0080k?l000<0oml00?o5003oa@000P3oZP08
0?n?00`0og<07@3oE`0P0?lk02@0oad02@3oool000P0oooo<`3o000a0?lM0880oc/09P3oE`0:0?mc
00@0ohl0103oZP00103oa@00oml00?oO003Do`020>co00030?oO003oa@00olD00080ojX0203oS`0<
0?mc01d0oeL0803o>`0T0?lM00T0oooo00080?oooc@0o`00<`3o7@220?lk02D0oeL0203oL`040?n?
00@0ojX000@0oml00?oi003on@00A_l00P00obH00`3og`00olD00?o500020?nZ00<0ohl0403oL`0K
0?mG01l0oc/0:03o7@090?ooo`00203ooold0?l003<0oad0PP3o>`0U0?mG00P0og<0103oS`040?nZ
00040?oO003on@00ooT004Ko00800?lV00<0oml00?o5003oa@000P3oZP030?n?0100og<06`3oE`0O
0?lk02P0oad02@3oool000P0oooo=03o000e0?lM08<0oc/08`3oE`080?mc0080ohl00`3oZP020?oO
000302oo003/o`00k?l000<0oml000<0e?l00?o5003oa@000P3oZP000`3oS`00og<00?mc000>0?mc
01/0oeL0803o>`0Y0?lM00T0oooo00080?ooocH0o`00=P3o7@250?lk0240oeL01@3oL`020?n?0003
0?nZ003oa@00olD00080^ol000@0oml00?nZ003oZP00ojX00P3oa@000`3og`00ojX00?nZ00020?n?
00h0og<06`3oE`0P0?lk02`0oad02@3oool000P0oooo=P3o000f0?lM08D0oc/08@3oE`050?mc0080
ohl000<0ojX00?o5003oa@000P2ko`00103og`00ojX00?nZ003oZP020?o500030?oO003oZP00ojX0
0080ohl03P3oL`0K0?mG0200oc/0;03o7@090?ooo`00203ooolh0?l003L0oad0Q@3o>`0P0?mG00D0
og<000<0ohl00?o5003oa@000P3og`000`3oa@00ojX00?nZ00040?n?0100og<06P3oE`0O0?lk0300
oad02@3oool000P0oooo>03o000j0?lM08D0oc/0803oE`030?mc00X0ohl03P3oL`0H0?mG0240oc/0
<`3o7@090?ooo`00203ooolh0?l003X0oad0Q@3o>`0P0?mG00<0og<02P3oS`0>0?mc01P0oeL08@3o
>`0c0?lM00T0oooo00080?ooocT0o`00>`3o7@280?lk01h0oeL05@3oL`0H0?mG02<0oc/0=03o7@09
0?ooo`00203ooolk0?l003`0oad0RP3o>`0P0?mG00P0og<06@3oE`0T0?lk03P0oad02@3oool000P0
oooo>`3o000l0?lM08X0oc/0803oE`080?mc01T0oeL0903o>`0h0?lM00T0oooo00080?oooc`0o`00
?P3o7@2=0?lk03H0oeL09P3o>`0k0?lM00T0oooo00080?oooc`0o`00?P3o7@2=0?lk03H0oeL09P3o
>`0k0?lM00T0oooo00080?oooc`0o`00@`3o7@2?0?lk02L0oeL0:P3o>`0o0?lM00T0oooo00080?oo
och0o`00A03o7@2H0?lk0100oeL0<@3o>`130?lM00T0oooo00080?oooch0o`00A03o7@2H0?lk0100
oeL0<@3o>`130?lM00T0oooo00080?ooocl0o`00AP3o7@3C0?lk04H0oad02@3oool000P0oooo@@3o
00170?lM0<d0oc/0B@3o7@090?ooo`00203ooom10?l004L0oad0c@3o>`190?lM00T0oooo003o0?oo
ok00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oook00oooo003o0?oo
ok00oooo003o0?oook00oooo0000\
\>"],
  ImageRangeCache->{{{0, 430.813}, {397.438, 0}} -> {-2.05282, -1.24801, \
0.00942049, 0.00942049}}]
}, Closed]],

Cell["\<\
Having an algorithm that works, we should include proper documentation before \
moving on to other projects.  You may find the internal comments \
anal-compulsive, but comments are essential to understanding more complicated \
functions.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Clear[mandelbrotRate];\)\(\n\)
    \)\), "\n", 
    \(\(\(mandelbrotRate::usage\  = \ \*"\"\<mandelbrotRate[cx,cy,lim] \
computes the escape rate for c = cx + I cy under the quadratic map z\[Rule]\!\
\(z\^2\)+c beginning with z=0.  The maximum number of iterations is given by \
lim, which must be an integer.\>\"";\)\(\n\)
    \)\), "\n", 
    \(\(mandelbrotRate\  = \ 
        Compile[{cx, cy, {lim, \ _Integer}}, \ \n\t
          Module[{c, z, ct = 0}, \n (*\ 
              define\ point\ in\ complex\ plane\ *) \n\t\tc = 
              cx\  + \ I\ cy; \n (*\ initialize\ map\ *) \n\t\tz\  = \ 
              c; \n (*\ 
              iterate\ quadratic\ map\ until\ z\ exceeds\ 2\ or\ iteration\ \
limit\ is\ reached\ *) \t\t\t\n\t\tWhile[\((Abs[z] < 
                    2.0)\)\  && \ \((ct \[LessEqual] 
                    lim)\), \n\t\t\t\(++ct\); \n\t\t\tz\  = \ 
                z*z + \ c;]; \n (*\ 
              return\ iteration\ counter\ *) \t\t\t\t\t\t\t\n\t\tReturn[
              ct]]\ ];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?mandelbrotRate\)\)], "Input"],

Cell[BoxData[
    \("mandelbrotRate[cx,cy,lim] computes the escape rate for c = cx + I cy \
under the quadratic map z\[Rule]\!\(z\^2\)+c beginning with z=0.  The maximum \
number of iterations is given by lim, which must be an integer."\)], "Print",
  CellTags->"Info3312796267-9384250"]
}, Closed]],

Cell[TextData[{
  "Produce an appealing display of seahorse valley, which is the Mandelbrot \
set in the vicinity of ",
  Cell[BoxData[
      \(TraditionalForm\`c\  \[TildeTilde] \ \(-0.745\)\  + \ 0.107  I\)]],
  ".  Explore this area with ever increasing resolution and have some fun."
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Optional arguments", "Section",
  CellTags->"optional arguments"],

Cell[TextData[{
  "We have already encountered many built-in functions in which one or more \
arguments may be omitted.  We have also created functions that have \
definitions that apply for various numbers of arguments.  It is often useful \
to specify default values for missing arguments.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " distinguishes between two types of optional arguments.  ",
  StyleBox["Positional",
    FontSlant->"Italic"],
  " arguments are interpreted according to the order they appear in the \
sequence of arguments, while ",
  StyleBox["options",
    FontSlant->"Italic"],
  " are replacement rules which may be placed after the positional arguments \
in arbitrary order.  Positional arguments may be omitted, and replaced by \
pre-defined defaults, beginning from the end and moving forward.  Thus, in \
the design of the function you must carefully consider which arguments the \
user is most likely to omit.  Options, on the other hand, may be given in any \
order or number."
}], "Text"],

Cell[CellGroupData[{

Cell["Optional arguments with default values", "Subsection",
  CellTags->"optional arguments with default values"],

Cell[TextData[{
  "The basic syntax for defining a function with an optional positional \
argument is \n\t",
  StyleBox["f[x_,\[CenterEllipsis],a_:def,\[CenterEllipsis]]:= rhs", 
    "InlineInput"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "where ",
  StyleBox["x_,\[CenterEllipsis]", "InlineInput"],
  " represents the set of mandatory arguments and ",
  StyleBox["a_:def", "InlineInput"],
  " represents an optional argument that is assigned a default value ",
  StyleBox["def", "InlineInput"],
  " if omitted.  Optional positional arguments should be placed after \
mandatory arguments and before optional replacement rules.  If there are \
several optional positional arguments, arguments are dropped from the end of \
the list.  In the example below, the optional exponent is given a default \
value of unity."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f[x_, n_:  1]\  := \ x\^n\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[\[Pi]], \ f[\[Pi], 2], f[f[\[Pi], \[Pi]], \[Pi]], 
      f[\[Pi], f[\[Pi], \[Pi]]]}\)], "Input"],

Cell[BoxData[
    \({\[Pi], \[Pi]\^2, \[Pi]\^\(\[Pi]\^2\), \[Pi]\^\(\[Pi]\^\[Pi]\)}\)], \
"Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Supplying options with defaults to your functions", "Subsection",
  CellTags->"options"],

Cell[TextData[{
  "The pattern ",
  StyleBox["x___", "InlineInput"],
  " using a triple underscore indicates a sequence of zero or more objects \
that collectively will be named ",
  StyleBox["x", "InlineInput"],
  "; this pattern can be used to indicate that an arbitrary number of options \
may be present.  It is usually a good idea to specify explicitly that the \
options must occur in the form of replacement rules by using the more precise \
pattern specification ",
  StyleBox["opts___Rule", "InlineInput"],
  "."
}], "Text"],

Cell["\<\
For example, suppose that we wish to create a function which plots some \
quantity of interest.  Rather than deciding all of the plotting options in \
the definition of that function, we can give the user the flexibility to \
choose those options without revising the function.  Recall our earlier \
definition of a function that plots spherical Bessel functions.\
\>", "Text"],

Cell[BoxData[
    \(plotsbess[n_, xmin_, xmax_] := 
      Plot[{sbessj[n, x], sbessy[n, x]}, {x, xmin, xmax}]\)], "Input"],

Cell[TextData[{
  "If ",
  StyleBox["sbessj", "InlineInput"],
  " and ",
  StyleBox["sbessy", "InlineInput"],
  " are not currently defined, go back to ",
  ButtonBox["sbess",
    ButtonData:>"sbess",
    ButtonStyle->"Hyperlink"],
  " and activate them before proceeding and use the ",
  StyleBox["back",
    FontWeight->"Bold"],
  " button to return here.  As it stands, this version does not display ",
  StyleBox["sbessj", "InlineInput"],
  " very well for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.593867 0.054329 [
[.2619 .58137 -3 -9 ]
[.2619 .58137 3 0 ]
[.5 .58137 -6 -9 ]
[.5 .58137 6 0 ]
[.7381 .58137 -6 -9 ]
[.7381 .58137 6 0 ]
[.97619 .58137 -6 -9 ]
[.97619 .58137 6 0 ]
[.01131 .05058 -18 -4.5 ]
[.01131 .05058 0 4.5 ]
[.01131 .15924 -12 -4.5 ]
[.01131 .15924 0 4.5 ]
[.01131 .26789 -12 -4.5 ]
[.01131 .26789 0 4.5 ]
[.01131 .37655 -12 -4.5 ]
[.01131 .37655 0 4.5 ]
[.01131 .48521 -12 -4.5 ]
[.01131 .48521 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .59387 m
.2619 .60012 L
s
[(5)] .2619 .58137 0 1 Mshowa
.5 .59387 m
.5 .60012 L
s
[(10)] .5 .58137 0 1 Mshowa
.7381 .59387 m
.7381 .60012 L
s
[(15)] .7381 .58137 0 1 Mshowa
.97619 .59387 m
.97619 .60012 L
s
[(20)] .97619 .58137 0 1 Mshowa
.125 Mabswid
.07143 .59387 m
.07143 .59762 L
s
.11905 .59387 m
.11905 .59762 L
s
.16667 .59387 m
.16667 .59762 L
s
.21429 .59387 m
.21429 .59762 L
s
.30952 .59387 m
.30952 .59762 L
s
.35714 .59387 m
.35714 .59762 L
s
.40476 .59387 m
.40476 .59762 L
s
.45238 .59387 m
.45238 .59762 L
s
.54762 .59387 m
.54762 .59762 L
s
.59524 .59387 m
.59524 .59762 L
s
.64286 .59387 m
.64286 .59762 L
s
.69048 .59387 m
.69048 .59762 L
s
.78571 .59387 m
.78571 .59762 L
s
.83333 .59387 m
.83333 .59762 L
s
.88095 .59387 m
.88095 .59762 L
s
.92857 .59387 m
.92857 .59762 L
s
.25 Mabswid
0 .59387 m
1 .59387 L
s
.02381 .05058 m
.03006 .05058 L
s
[(-10)] .01131 .05058 1 0 Mshowa
.02381 .15924 m
.03006 .15924 L
s
[(-8)] .01131 .15924 1 0 Mshowa
.02381 .26789 m
.03006 .26789 L
s
[(-6)] .01131 .26789 1 0 Mshowa
.02381 .37655 m
.03006 .37655 L
s
[(-4)] .01131 .37655 1 0 Mshowa
.02381 .48521 m
.03006 .48521 L
s
[(-2)] .01131 .48521 1 0 Mshowa
.125 Mabswid
.02381 .07774 m
.02756 .07774 L
s
.02381 .10491 m
.02756 .10491 L
s
.02381 .13207 m
.02756 .13207 L
s
.02381 .1864 m
.02756 .1864 L
s
.02381 .21356 m
.02756 .21356 L
s
.02381 .24073 m
.02756 .24073 L
s
.02381 .29506 m
.02756 .29506 L
s
.02381 .32222 m
.02756 .32222 L
s
.02381 .34939 m
.02756 .34939 L
s
.02381 .40372 m
.02756 .40372 L
s
.02381 .43088 m
.02756 .43088 L
s
.02381 .45804 m
.02756 .45804 L
s
.02381 .51237 m
.02756 .51237 L
s
.02381 .53954 m
.02756 .53954 L
s
.02381 .5667 m
.02756 .5667 L
s
.02381 .02341 m
.02756 .02341 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .59387 m
.02499 .59387 L
.02605 .59387 L
.02729 .59387 L
.02846 .59387 L
.02954 .59387 L
.03053 .59387 L
.03163 .59387 L
.03279 .59387 L
.03395 .59387 L
.0352 .59387 L
.03638 .59387 L
.03746 .59387 L
.03873 .59387 L
.03944 .59387 L
.04011 .59387 L
.04132 .59387 L
.04262 .59387 L
.04396 .59387 L
.04519 .59387 L
.04654 .59387 L
.04797 .59387 L
.05038 .59387 L
.05174 .59387 L
.05302 .59387 L
.0554 .59387 L
.05757 .59387 L
.06007 .59387 L
.06244 .59387 L
.06486 .59387 L
.06753 .59387 L
.07031 .59387 L
.07293 .59387 L
.0776 .59388 L
.08263 .59388 L
.08821 .59389 L
.09408 .5939 L
.09909 .59391 L
.10458 .59393 L
.10986 .59396 L
.11485 .59398 L
.12419 .59405 L
.13424 .59415 L
.14514 .5943 L
.15461 .59448 L
.16502 .59471 L
.18606 .59538 L
.20551 .59623 L
.2264 .59737 L
.26768 .60006 L
Mistroke
.28831 .60137 L
.29835 .60194 L
.30744 .60239 L
.31634 .60275 L
.32596 .60306 L
.33126 .60318 L
.33358 .60322 L
.33612 .60326 L
.33853 .60328 L
.34077 .6033 L
.34201 .60331 L
.34314 .60331 L
.34445 .60332 L
.34568 .60332 L
.34683 .60332 L
.34806 .60331 L
.34922 .60331 L
.35029 .6033 L
.35147 .60329 L
.35276 .60328 L
.35536 .60325 L
.35794 .60321 L
.36068 .60315 L
.36563 .60302 L
.37061 .60286 L
.37529 .60266 L
.38406 .60222 L
.40412 .6008 L
.42258 .59907 L
.46204 .59468 L
.48187 .59253 L
.49998 .59085 L
.50931 .59014 L
.51946 .58951 L
.52503 .58923 L
.53019 .58903 L
.53513 .58887 L
.53768 .5888 L
.54037 .58875 L
.5427 .58871 L
.54393 .58869 L
.54525 .58868 L
.54646 .58867 L
.54756 .58866 L
.54867 .58865 L
.54972 .58865 L
.55095 .58865 L
.55224 .58865 L
.55335 .58865 L
.55456 .58866 L
Mistroke
.55587 .58867 L
.55728 .58868 L
.55982 .58872 L
.56216 .58876 L
.56471 .58881 L
.56936 .58893 L
.57809 .58926 L
.58842 .58978 L
.59778 .59037 L
.61875 .59197 L
.63964 .59373 L
.65884 .59527 L
.6776 .59652 L
.68705 .597 L
.69237 .59722 L
.69741 .59739 L
.7023 .59753 L
.70488 .59758 L
.70762 .59763 L
.70992 .59767 L
.71115 .59768 L
.71246 .59769 L
.71367 .5977 L
.71477 .59771 L
.71582 .59772 L
.71693 .59772 L
.71825 .59772 L
.71944 .59772 L
.7201 .59772 L
.72081 .59772 L
.72211 .59771 L
.72333 .59771 L
.72462 .5977 L
.72693 .59767 L
.72962 .59763 L
.73213 .59759 L
.73785 .59746 L
.74284 .59731 L
.74827 .59711 L
.75816 .59667 L
.7767 .5956 L
.79807 .59418 L
.81742 .5929 L
.82736 .59231 L
.83785 .59177 L
.84756 .59136 L
.85662 .59107 L
.86107 .59096 L
.86583 .59087 L
.86854 .59083 L
Mistroke
.87111 .5908 L
.87341 .59079 L
.87472 .59078 L
.87592 .59078 L
.87711 .59077 L
.8784 .59077 L
.87962 .59077 L
.88073 .59077 L
.88203 .59078 L
.88276 .59078 L
.88345 .59079 L
.88603 .59081 L
.88875 .59084 L
.89122 .59087 L
.89676 .59097 L
.90163 .59109 L
.90677 .59125 L
.91599 .59158 L
.93681 .59258 L
.97477 .5947 L
.97619 .59477 L
Mfstroke
.12887 0 m
.12947 .02094 L
.13477 .1532 L
.13953 .24101 L
.1447 .31298 L
.14956 .36451 L
.15412 .40233 L
.15913 .43505 L
.16451 .46256 L
.16986 .48394 L
.17548 .50163 L
.18075 .51482 L
.18553 .5246 L
.1951 .53955 L
.20036 .54579 L
.20531 .55073 L
.21414 .55776 L
.22369 .5635 L
.23318 .56786 L
.24361 .57159 L
.26466 .57707 L
.28415 .58084 L
.30506 .58428 L
.34639 .59047 L
.36706 .59333 L
.3862 .59573 L
.40594 .5978 L
.4245 .59925 L
.43346 .59975 L
.43851 .59997 L
.44314 .60013 L
.44792 .60025 L
.45064 .60031 L
.45316 .60034 L
.45454 .60036 L
.45584 .60037 L
.457 .60037 L
.45827 .60038 L
.45893 .60038 L
.45965 .60038 L
.4604 .60038 L
.46111 .60038 L
.46237 .60037 L
.46308 .60037 L
.46373 .60036 L
.46502 .60035 L
.46623 .60034 L
.4685 .60031 L
.47094 .60026 L
.47358 .6002 L
Mistroke
.47835 .60006 L
.48273 .5999 L
.49281 .59941 L
.50346 .59873 L
.54145 .59542 L
.56261 .59338 L
.58189 .59172 L
.59147 .59102 L
.60189 .59039 L
.60666 .59015 L
.61173 .58993 L
.61616 .58977 L
.62082 .58964 L
.62316 .58959 L
.62572 .58954 L
.62804 .5895 L
.6302 .58948 L
.63152 .58947 L
.63276 .58946 L
.63388 .58945 L
.63509 .58945 L
.63641 .58945 L
.63707 .58945 L
.63781 .58945 L
.6391 .58946 L
.64031 .58946 L
.64144 .58947 L
.64267 .58948 L
.64492 .58951 L
.64913 .58958 L
.65404 .58969 L
.65859 .58983 L
.6692 .59026 L
.67917 .59079 L
.6978 .59201 L
.73642 .59486 L
.75641 .59611 L
.76647 .59659 L
.77214 .59681 L
.77749 .59698 L
.7824 .59711 L
.78499 .59716 L
.78774 .59721 L
.79004 .59724 L
.79126 .59726 L
.79258 .59727 L
.79379 .59728 L
.79489 .59728 L
.796 .59729 L
.79706 .59729 L
Mistroke
.79837 .5973 L
.79957 .5973 L
.80023 .5973 L
.80095 .59729 L
.80224 .59729 L
.80346 .59728 L
.80475 .59728 L
.80706 .59725 L
.80976 .59722 L
.81227 .59718 L
.81799 .59706 L
.82299 .59693 L
.82843 .59675 L
.83833 .59634 L
.85689 .59537 L
.87626 .59419 L
.89766 .5929 L
.9074 .59238 L
.9179 .5919 L
.92775 .59153 L
.93218 .59139 L
.93691 .59127 L
.9417 .59118 L
.94605 .59111 L
.94851 .59108 L
.94981 .59107 L
.95119 .59106 L
.95239 .59105 L
.95303 .59105 L
.95371 .59105 L
.95492 .59104 L
.95604 .59104 L
.95669 .59104 L
.95738 .59104 L
.95862 .59104 L
.95939 .59105 L
.9601 .59105 L
.96144 .59105 L
.96273 .59106 L
.96391 .59107 L
.96657 .5911 L
.9688 .59112 L
.97125 .59116 L
.97619 .59125 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooH`3oool00200
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooof<0oooo000P0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00803oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0?l0ooooH`3oool00200oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`3o0?ooof<0oooo000P0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0o`3ooomS0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0
ooooH`3oool00200oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooof<0oooo
000P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00803oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooH`3oool00200oooo0P00000Y0?oo
o`030000003oool0oooo0?l0ooooH`3oool00200oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`3o0?ooof<0oooo000P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
o`3ooomS0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooH`3o
ool00200oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooof<0oooo000P0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00803oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooH`3oool000X0oooo00<0okmd000000000000
0`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool01@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0ooooH`3oool000d0oooo00<0W4Q809cOo`3oool0
103oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`H0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`3o0?ooof<0oooo000=0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d_`3o
ool00P3oool00`3OW4P0B9cO0?ooo`050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0o`3ooomS0?ooo`003@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo
H`3oool000030?ooo`2LB000000000@0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?oo
o`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01@3oool3000002P0oooo00<0
00000?ooo`3oool0o`3ooomS0?ooo`003@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0?l0ooooH`3oool000d0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@0B9cO0?ooo`020?oo
o`030=nLB018W=l0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
of80oooo000:0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0
B01d0;ooo`H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooof80oooo000<
0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000001809cOo`070?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0ooooHP3oool00200oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`3o0?ooof80oooo000P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3ooomR0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
HP3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooof80oooo000P
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool20000
02X0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0?l0ooooHP3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`3o0?ooof80oooo000P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3o
oomR0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooHP3oool0
0200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooof80oooo000P0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooHP3oool00200oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`3o0?ooof80oooo000P0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0o`3ooomR0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0?l0ooooHP3oool00200oooo0P00000Z0?ooo`030000003oool0oooo0?l0ooooHP3oool00200oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooof80oooo000P0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`00803oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0ooooHP3oool00200oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`3o0?ooof80oooo000P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3ooomR0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
HP3oool00200oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooof40oooo000P
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00803oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooH@3oool00200oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`3o0?ooof40oooo000P0?ooo`800000:`3oool00`000000oooo
0?ooo`3o0?ooof40oooo000P0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3o
oomQ0?ooo`00803oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooH@3oool0
0200oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooof40oooo000P0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00803oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooH@3oool00200oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`3o0?ooof40oooo000P0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0o`3ooomQ0?ooo`00503oool01@2oM000000000000000000007Bo00L0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooof40oooo000C0?ooo`030?noM000M;l0oooo
0080oooo00<0_gA809cOo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0?l0ooooH@3oool001<0oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`004`3oool00`3o_g@004RL
0?ooo`020?ooo`0309a8B02Lgol0oooo00D0oooo0`00000Z0?ooo`030000003oool0oooo0?l0oooo
H@3oool000X0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3oool0gia800<00000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo
H@3oool001<0oooo00<0oono07A8W03oool00P3oool00`2LB7@0_ooo0?ooo`050?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`004`3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o
0?ooof40oooo000C0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00503oool01@3o_g@0000000000000
04P0W=oo00L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooof40oooo000P
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`00803oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooH@3oool00200oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`3o0?ooof00oooo000P0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0o`3ooomP0?ooo`00803oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0?l0ooooH03oool00200oooo0P00000/0?ooo`030000003oool0oooo0?l0ooooH03oool0
0200oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooof00oooo000P0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00803oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooH03oool00200oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`3o0?ooof00oooo000P0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0o`3ooomP0?ooo`00803oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0?l0ooooH03oool00200oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooof00
oooo000P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00803o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooH03oool00200oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooof00oooo000P0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`00803oool2000002`0oooo00<000000?ooo`3o
ool0o`3ooomP0?ooo`00803oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo
H03oool00200oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3o0?ooof00oooo000P
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00803oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooG`3oool00200oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`3o0?oooel0oooo000P0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0o`3ooomO0?ooo`00803oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0?l0ooooG`3oool00200oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o
0?oooel0oooo000P0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomO0?oo
o`00803oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooG`3oool00200oooo
0P00000]0?ooo`030000003oool0oooo0?l0ooooG`3oool00200oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`3o0?oooel0oooo000P0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0o`3ooomO0?ooo`00803oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0?l0ooooG`3oool00200oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?oooel0
oooo000P0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`00803o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooG`3oool001D0oooo00D0_g@0
000000000000001d0;ooo`060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3o
oomO0?ooo`00503oool01P3OW4P007Bo0?ooo`3oool0okmd001d_`H0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`3o0?oooeh0oooo000C0?ooo`030?oo_`1d0000M;oo0080oooo00<0
oono07A8W03oool01@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooGP3o
ool001<0oooo00L0okmd0018B01d07@0_ooo0?ooo`3OW4P007Bo00H0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`3o0?oooeh0oooo000:0?ooo`0309a800000000000000<0000000H0
04RL0?ooo`3oool0omnL04Q8W03o_g@2000000030018W03oool0oooo00D0oooo0`00000]0?ooo`03
0000003oool0oooo0?l0ooooGP3oool001<0oooo00<0oono07@0M02oool02P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooGP3oool001@0oooo00<0_g@004RLg`3oool02@3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooGP3oool001@0oooo00<0oono
07@00000M;l02@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooGP3oool0
01H0oooo00@0_g@000000000000004RL1P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0?l0ooooGP3oool00200oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oo
oeh0oooo000P0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00
803oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooGP3oool00200oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooeh0oooo000P0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00803oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0?l0ooooGP3oool00200oooo0P00000_0?ooo`030000003oool0oooo0?l0
ooooG@3oool00200oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooed0oooo
000P0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`00803oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooG@3oool00200oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`3o0?oooed0oooo000P0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0o`3ooomM0?ooo`00803oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0?l0ooooG@3oool00200oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`3o0?oooed0oooo000P0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooomM
0?ooo`00803oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooG@3oool00200
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooed0oooo000P0?ooo`800000
;`3oool00`000000oooo0?ooo`3o0?oooed0oooo000P0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0o`3ooomM0?ooo`00803oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0?l0ooooG03oool00200oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oo
oe`0oooo000P0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00
803oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooG03oool00200oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooe`0oooo000P0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00803oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0?l0ooooG03oool00200oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`3o0?oooe`0oooo000P0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
o`3ooomL0?ooo`00803oool200000300oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00803oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooF`3oool00200oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`3o0?oooe/0oooo000P0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0o`3ooomK0?ooo`00803oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0?l0ooooF`3oool00200oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`3o0?oooe/0oooo000P0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooomK
0?ooo`00803oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooF`3oool001D0
oooo00D0omnL04P000000000000007Boo`060?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0o`3ooomK0?ooo`005`3oool00`2oM000M;oo0?ooo`060?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0o`3ooomK0?ooo`005`3oool00`2oM000M;oo0?ooo`060?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooomK0?ooo`004`3oool00`3OW4P000000000
00030000000307Boo`3oool0oooo00@0oooo0`00000a0?ooo`030000003oool0oooo0?l0ooooFP3o
ool000X0oooo00<0W4P00000000000000`0000002@00B9`0oooo0?ooo`3o_g@0001d0;ooo`3oool0
_g@007Boo`070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00
503oool01@3OW4P007Bo0?ooo`2oM000M;oo00L0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`3o0?oooeX0oooo000E0?ooo`0409a80018W=l0_g@007Boo`L0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`3o0?oooeX0oooo000E0?ooo`040?oOW01804P0B4P007Boo`L0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oooeX0oooo000F0?ooo`030?no
M0000000M;oo00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?oooeX0oooo
000P0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00803oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooFP3oool00200oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`3o0?oooeT0oooo000P0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00803oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0?l0ooooF@3oool00200oooo0P00000c0?ooo`030000003oool0oooo0?l0ooooF@3o
ool00200oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?oooeT0oooo000P0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00803oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooF@3oool00200oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`3o0?oooeP0oooo000P0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0o`3ooomH0?ooo`00803oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0?l0ooooF03oool00200oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?oo
oeP0oooo000P0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooomH0?ooo`00
803oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooF03oool00200oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oooeL0oooo000P0?ooo`800000=@3oool0
0`000000oooo0?ooo`3o0?oooeL0oooo000P0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0o`3ooomG0?ooo`00803oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0
ooooE`3oool00200oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oooeL0oooo
000P0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00803oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0ooooEP3oool00200oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`3o0?oooeH0oooo000P0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0o`3ooomF0?ooo`00803oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0?l0ooooEP3oool00200oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`3o0?oooeH0oooo000P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooomF
0?ooo`00803oool2000003L0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00803oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooE@3oool00200oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`3o0?oooeD0oooo000P0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0o`3ooomE0?ooo`00803oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo0?l0ooooE@3oool00200oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?oo
oe@0oooo000P0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00
803oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooE03oool00180oooo00<0
oono07@000000000100000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`004`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0
oooo00D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oooe<0oooo000D0?oo
o`030?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oo
oe<0oooo000E0?ooo`030?oOW0180000B9cO00P0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3o0?oooe<0oooo000:0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
103oool00`2LB000B9cO0?ooo`060?ooo`<00000>03oool00`000000oooo0?ooo`3o0?oooe<0oooo
000H0?ooo`0309a8M02oool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`3o0?oooe80oooo000C0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool01@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0ooooDP3oool001<0oooo00L0okmd0000
M02oool0oooo0?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`3o0?oooe40oooo000D0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0?l0ooooD@3oool00200oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`3o0?oooe00oooo000P0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0o`3ooom@0?ooo`00803oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0
ooooD03oool00200oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?ooodl0oooo
000P0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00803oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0ooooC`3oool00200oooo0P00000n0?oo
o`030000003oool0oooo0?l0ooooCP3oool00200oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`3o0?ooodh0oooo000P0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`00803oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooC@3o
ool00200oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooodd0oooo000P0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00803oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooB`3oool00200oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`3o0?oood/0oooo000P0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0o`3ooom:0?ooo`00803oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0?l0ooooB@3oool00200oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oo
odT0oooo000P0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooodP0oooo000P0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooom70?ooo`00803oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo0?l0ooooAP3oool00200oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo000P0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0o`3ooom40?ooo`00803oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0100
oooo00D0_g@0000000000000000007Boo`1G0?ooo`030?noM0000000000000<0000000D007Bo0?oo
o`3oool0oooo0?noM0030000000307Boo`3oool0oooo0500oooo00<0okmd0000000000000`000000
1@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?ooo`3oool0D03oool00`3ookl0M0000000
00040000000507Boo`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`020?ooo`00803o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00L0_g@0001d_`3oool0oooo
0?oOW0180000M;oo05T0oooo00<0W4Q809cOo`3oool0103oool01P2LB7@0_ooo0?ooo`3ookl0M01d
0;oooe@0oooo00<0W4Q809cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0
DP3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0080oooo00H0W4Qd0;ooo`3oool0
oono07@0M02oool30?ooo`00803oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0180
oooo00<0okmd001d_`3oool0F03oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool0D`3oool00`2LB4P0W=oo0?ooo`080?ooo`030?noM000M;l0oooo0580
oooo00<0okmd0000B02Lgol01@3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo0080
oooo000P0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool04@3oool00`3o_g@007Bo
0?ooo`1H0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`1C0?ooo`0309a8B02Lgol0oooo00P0oooo00<0okmd001d_`3oool0D`3oool00`3ogi`0B000
04RLg`040?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool00P3oool00200oooo00<0
00000?ooo`3oool0C03oool200000140oooo00<0W4P007Boo`3oool0F03oool00`2LB4P0W=oo0?oo
o`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0D`3oool00`2LB4P0W=oo0?oo
o`080?ooo`0309a8001d_ol0oooo05D0oooo00<0W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo0080oooo000P0?ooo`030000003oool0oooo04h0oooo0P00000:
0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0F03oool00`2LB4P0W=oo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0D`3oool00`2LB4P0W=oo0?ooo`03
0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0EP3oool01P2LB7@0_ooo0?ooo`3o
ool0gia804RLg`<0oooo00<0okmd001d_`3oool00P3oool00200oooo0P00001A0?ooo`<000001`3o
ool00`3ookl0M01d0;ooo`1M0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`1C0?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool0EP3o
ool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0
B9cO0?ooo`020?ooo`00803oool00`000000oooo0?ooo`1C0?ooo`8000001@3oool00`3ookl0M01d
0;ooo`1J0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d
0;oooe40oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo05H0oooo00L0
okmd0000M02oool0oooo0?noM00004P0W=oo00<0oooo00H0W4P007Boo`3oool0omnL04P0M02oool3
0?ooo`00803oool00`000000oooo0?ooo`1E0?ooo`@0000000<0oooo0?oo_`1d00000`0000000`00
07@0_ooo0?ooo`1G0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000001809cOo`1D
0?ooo`030=nLB00004P0W=oo00@0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`1B
0?ooo`050?noM000000000000000B02Lgol0103oool01@3ookl0M0000000000004P0W=oo00@0oooo
000P0?ooo`030000003oool0oooo05T0oooo1000003o0?oooc40oooo000P0?ooo`030000003oool0
oooo05d0oooo1000003o0?ooobd0oooo000P0?ooo`030000003oool0oooo0640oooo1000003o0?oo
obT0oooo000P0?ooo`030000003oool0oooo06D0oooo1`00003o0?ooob80oooo000P0?ooo`030000
003oool0oooo06`0oooo1`00003o0?oooa/0oooo000P0?ooo`030000003oool0oooo07<0oooo1@00
003o0?oooaH0oooo000P0?ooo`030000003oool0oooo07P0oooo1P0000140?ooob<000001P3ooolG
000008/0oooo000P0?ooo`030000003oool0oooo07h0oooo1`00000`0?ooo`d00000703ooolF0000
00h0oooo5P00000/0?ooocl000002P3oool001H0ooooo`00002J00000040oooo000P0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`040000
003oool0oooo0?oooaT000002P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01@3oool8000000<0oooo00<000000?ooo`3oool02P3oool800000180
oooo00<000000?ooo`3oool01`3oool<00000140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0000000F000000d0oooo=P0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00L0oooo200000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0=0?oooa8000001@3oool00`000000oooo0?ooo`090?oooa400000
2P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`h000004`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo05`0oooo5`00000L0?ooo`h000002P3o
oolA000000L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo00P0oooo000P0?ooo`030000003oool0oooo07<0oooo7000003n0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo
00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P
0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-1.6502, -11.2299, \
0.0770893, 0.0675683}}]
}, Closed]],

Cell["\<\
We can improve this function by allowing the user to select options, such as \
the vertical scale.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[plotsbess];\)\), "\n", 
    \(plotsbess[n_, xmin_, xmax_, opts___Rule] := 
      Plot[{sbessj[n, x], sbessy[n, x]}, {x, xmin, xmax}, opts]\)}], "Input"],

Cell["With one option we can control the scale", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20, 
        PlotRange \[Rule] {Automatic, {\(-1\), 0.5}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.412023 0.412023 [
[.2619 .39952 -3 -9 ]
[.2619 .39952 3 0 ]
[.5 .39952 -6 -9 ]
[.5 .39952 6 0 ]
[.7381 .39952 -6 -9 ]
[.7381 .39952 6 0 ]
[.97619 .39952 -6 -9 ]
[.97619 .39952 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .0824 -24 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -24 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -24 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -24 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -18 -4.5 ]
[.01131 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .41202 m
.2619 .41827 L
s
[(5)] .2619 .39952 0 1 Mshowa
.5 .41202 m
.5 .41827 L
s
[(10)] .5 .39952 0 1 Mshowa
.7381 .41202 m
.7381 .41827 L
s
[(15)] .7381 .39952 0 1 Mshowa
.97619 .41202 m
.97619 .41827 L
s
[(20)] .97619 .39952 0 1 Mshowa
.125 Mabswid
.07143 .41202 m
.07143 .41577 L
s
.11905 .41202 m
.11905 .41577 L
s
.16667 .41202 m
.16667 .41577 L
s
.21429 .41202 m
.21429 .41577 L
s
.30952 .41202 m
.30952 .41577 L
s
.35714 .41202 m
.35714 .41577 L
s
.40476 .41202 m
.40476 .41577 L
s
.45238 .41202 m
.45238 .41577 L
s
.54762 .41202 m
.54762 .41577 L
s
.59524 .41202 m
.59524 .41577 L
s
.64286 .41202 m
.64286 .41577 L
s
.69048 .41202 m
.69048 .41577 L
s
.78571 .41202 m
.78571 .41577 L
s
.83333 .41202 m
.83333 .41577 L
s
.88095 .41202 m
.88095 .41577 L
s
.92857 .41202 m
.92857 .41577 L
s
.25 Mabswid
0 .41202 m
1 .41202 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .0824 m
.03006 .0824 L
s
[(-0.8)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(-0.6)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(-0.4)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(-0.2)] .01131 .32962 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.2)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(0.4)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41202 m
.02499 .41202 L
.02605 .41202 L
.02729 .41202 L
.02846 .41202 L
.02954 .41202 L
.03053 .41202 L
.03163 .41202 L
.03279 .41202 L
.03395 .41202 L
.0352 .41202 L
.03638 .41202 L
.03746 .41202 L
.03873 .41202 L
.03944 .41202 L
.04011 .41202 L
.04132 .41202 L
.04262 .41202 L
.04396 .41202 L
.04519 .41202 L
.04654 .41202 L
.04797 .41202 L
.05038 .41202 L
.05174 .41203 L
.05302 .41203 L
.0554 .41203 L
.05757 .41203 L
.06007 .41203 L
.06244 .41204 L
.06486 .41204 L
.06753 .41205 L
.07031 .41206 L
.07293 .41207 L
.0776 .41209 L
.08263 .41213 L
.08821 .41219 L
.09408 .41228 L
.09909 .41238 L
.10458 .41252 L
.10986 .4127 L
.11485 .4129 L
.12419 .41341 L
.13424 .41418 L
.14514 .41532 L
.15461 .41663 L
.16502 .41845 L
.18606 .4235 L
.20551 .42992 L
.2264 .43858 L
.26768 .45896 L
Mistroke
.28831 .46892 L
.29835 .47321 L
.30744 .47662 L
.31634 .47942 L
.32596 .48172 L
.33126 .48263 L
.33358 .48295 L
.33612 .48323 L
.33853 .48344 L
.34077 .48358 L
.34201 .48364 L
.34314 .48367 L
.34445 .4837 L
.34568 .4837 L
.34683 .48369 L
.34806 .48367 L
.34922 .48363 L
.35029 .48358 L
.35147 .48351 L
.35276 .48342 L
.35536 .48317 L
.35794 .48285 L
.36068 .48243 L
.36563 .48145 L
.37061 .48019 L
.37529 .47873 L
.38406 .47535 L
.40412 .46457 L
.42258 .45148 L
.46204 .4182 L
.48187 .4019 L
.49998 .38916 L
.50931 .38376 L
.51946 .37898 L
.52503 .37689 L
.53019 .3753 L
.53513 .3741 L
.53768 .37361 L
.54037 .37318 L
.5427 .37289 L
.54393 .37277 L
.54525 .37266 L
.54646 .37257 L
.54756 .37252 L
.54867 .37247 L
.54972 .37245 L
.55095 .37244 L
.55224 .37245 L
.55335 .37248 L
.55456 .37252 L
Mistroke
.55587 .3726 L
.55728 .3727 L
.55982 .37295 L
.56216 .37325 L
.56471 .37366 L
.56936 .37462 L
.57809 .37708 L
.58842 .38106 L
.59778 .38551 L
.61875 .39762 L
.63964 .41099 L
.65884 .42268 L
.6776 .43212 L
.68705 .43577 L
.69237 .43744 L
.69741 .43876 L
.7023 .43977 L
.70488 .4402 L
.70762 .44058 L
.70992 .44083 L
.71115 .44094 L
.71246 .44104 L
.71367 .44112 L
.71477 .44117 L
.71582 .44121 L
.71693 .44124 L
.71825 .44125 L
.71944 .44125 L
.7201 .44124 L
.72081 .44122 L
.72211 .44118 L
.72333 .44113 L
.72462 .44105 L
.72693 .44087 L
.72962 .44059 L
.73213 .44025 L
.73785 .43925 L
.74284 .43812 L
.74827 .43662 L
.75816 .43325 L
.7767 .4252 L
.79807 .41436 L
.81742 .40466 L
.82736 .40019 L
.83785 .39608 L
.84756 .39298 L
.85662 .39078 L
.86107 .38996 L
.86583 .38929 L
.86854 .38901 L
Mistroke
.87111 .3888 L
.87341 .38866 L
.87472 .38861 L
.87592 .38857 L
.87711 .38855 L
.8784 .38854 L
.87962 .38855 L
.88073 .38857 L
.88203 .38861 L
.88276 .38863 L
.88345 .38866 L
.88603 .38881 L
.88875 .38904 L
.89122 .3893 L
.89676 .39008 L
.90163 .39099 L
.90677 .39214 L
.91599 .3947 L
.93681 .40226 L
.97477 .41833 L
.97619 .4189 L
Mfstroke
.1951 0 m
.1951 8e-005 L
.20036 .04745 L
.20531 .08488 L
.21414 .13817 L
.22369 .18169 L
.23318 .21476 L
.24361 .24306 L
.26466 .28461 L
.28415 .31319 L
.30506 .33931 L
.34639 .38624 L
.36706 .40797 L
.3862 .42614 L
.40594 .44186 L
.4245 .45287 L
.43346 .45666 L
.43851 .45831 L
.44314 .45953 L
.44792 .46047 L
.45064 .46086 L
.45316 .46113 L
.45454 .46123 L
.45584 .46131 L
.457 .46136 L
.45827 .4614 L
.45893 .46141 L
.45965 .46141 L
.4604 .4614 L
.46111 .46139 L
.46237 .46135 L
.46308 .46132 L
.46373 .46128 L
.46502 .4612 L
.46623 .46109 L
.4685 .46085 L
.47094 .4605 L
.47358 .46004 L
.47835 .45898 L
.48273 .45774 L
.49281 .45402 L
.50346 .44889 L
.54145 .42377 L
.56261 .40834 L
.58189 .39571 L
.59147 .39042 L
.60189 .38564 L
.60666 .38383 L
.61173 .38218 L
.61616 .38098 L
Mistroke
.62082 .37997 L
.62316 .37957 L
.62572 .3792 L
.62804 .37893 L
.6302 .37874 L
.63152 .37866 L
.63276 .37859 L
.63388 .37855 L
.63509 .37853 L
.63641 .37852 L
.63707 .37852 L
.63781 .37853 L
.6391 .37857 L
.64031 .37862 L
.64144 .37868 L
.64267 .37876 L
.64492 .37897 L
.64913 .3795 L
.65404 .38038 L
.65859 .38143 L
.6692 .38469 L
.67917 .38868 L
.6978 .39793 L
.73642 .41958 L
.75641 .429 L
.76647 .43267 L
.77214 .43434 L
.77749 .43565 L
.7824 .43661 L
.78499 .43701 L
.78774 .43737 L
.79004 .43761 L
.79126 .43772 L
.79258 .43781 L
.79379 .43789 L
.79489 .43794 L
.796 .43798 L
.79706 .43801 L
.79837 .43803 L
.79957 .43803 L
.80023 .43803 L
.80095 .43802 L
.80224 .43798 L
.80346 .43794 L
.80475 .43787 L
.80706 .43771 L
.80976 .43746 L
.81227 .43716 L
.81799 .43627 L
.82299 .43523 L
Mistroke
.82843 .43387 L
.83833 .4308 L
.85689 .42344 L
.87626 .41449 L
.89766 .40472 L
.9074 .40076 L
.9179 .39707 L
.92775 .39427 L
.93218 .39326 L
.93691 .39234 L
.9417 .39161 L
.94605 .39112 L
.94851 .39091 L
.94981 .39082 L
.95119 .39074 L
.95239 .39069 L
.95303 .39067 L
.95371 .39064 L
.95492 .39062 L
.95604 .3906 L
.95669 .3906 L
.95738 .3906 L
.95862 .39061 L
.95939 .39063 L
.9601 .39064 L
.96144 .39069 L
.96273 .39074 L
.96391 .39081 L
.96657 .391 L
.9688 .39121 L
.97125 .39148 L
.97619 .39217 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00703oool00`3o_g@000000000
000300000003001d_`3oool0oooo0?l0ooooS03oool001l0oooo00<0W4Q809cOo`3oool0o`3ooon?
0?ooo`007`3oool00`2LB4P0W=oo0?ooo`3o0?ooohl0oooo000O0?ooo`0309a8B02Lgol0oooo0?l0
ooooS`3oool001<0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`030?ooo`0309a8
B02Lgol0oooo00H0oooo100000110?ooo`030000003oool0oooo0?l0oooo@@3oool001l0oooo00<0
W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo@@3o
ool001l0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0?l0oooo@@3oool001`0oooo00D0gia800000000B9`0W4Q809cOo`070?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0o`3ooom10?ooo`007P3oool00`3OW4P0001809cOo`070?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:03oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo@03oool002P0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`3o0?oood00oooo000X0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0o`3ooom00?ooo`00:03oool3000004<0oooo00<000000?ooo`3oool0o`3ooom0
0?ooo`00:03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo@03oool002P0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oood00oooo000X0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooom00?ooo`00:03oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo0?l0oooo@03oool002P0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`3o0?oood00oooo000X0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0o`3ooolo0?ooo`00:03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0
oooo?`3oool002P0oooo0`0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002P0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000X0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00:03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0?l0oooo?`3oool002P0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`3o0?ooocl0oooo000X0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
o`3ooolo0?ooo`00:03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0?l0oooo?P3o
ool002P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?oooch0oooo000X0?oo
o`<00000A@3oool00`000000oooo0?ooo`3o0?oooch0oooo000X0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0?l0oooo?P3oool002P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`3o0?oooch0oooo000X0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0o`3oooln
0?ooo`002`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool0
1@2oM000000000000000000007Bo00H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`3o0?oooch0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000
001d_`040?ooo`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool0103oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0?l0oooo?@3oool000X0oooo00<0okmd001d_`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0_g@007Boo`3oool0103o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0oooo?@3oool000X0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?noM000B9`0oooo0080oooo00<0W4Q8
09cOo`3oool0103oool4000004D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`0000<0oooo09a8
00000000100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool02`3oool0
1@3OW4P00000000000000000B9cO00H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`3o0?ooocd0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool0
0`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`3o0?ooocd0oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RL
g`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`030;md001d_ol0oooo00@0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`3o0?ooocd0oooo000;0?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo2`3oool01`3ogi`0B01d0;ooo`3oool0omnL04P0M02oool01@3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0?l0oooo?03oool000/0oooo00D0oono07@0000000000018
09cOo`0=0?ooo`050?noM000000000000000B02Lgol01P3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0?l0oooo?03oool002P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`3o0?oooc`0oooo000X0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3o
ooll0?ooo`00:03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo?03oool0
02P0oooo0`0000170?ooo`030000003oool0oooo0?l0oooo?03oool002P0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`3o0?oooc/0oooo000X0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0o`3ooolk0?ooo`00:03oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo0?l0oooo>`3oool002P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o
0?oooc/0oooo000X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooolk0?oo
o`00:03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo>P3oool002P0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooocX0oooo000X0?ooo`<00000B@3o
ool00`000000oooo0?ooo`3o0?ooocX0oooo000X0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0o`3ooolj0?ooo`00:03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0?l0oooo>P3oool002P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooocX0
oooo000X0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00:03o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo>@3oool002P0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?ooocT0oooo000X0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0o`3oooli0?ooo`00:03oool3000004X0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`00:03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo
>03oool002P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooocP0oooo000X
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`00:03oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo>03oool000/0oooo00D0okmd00000000
0000000007Boo`050?ooo`030;md0000000007Bo00H0oooo00D0_g@0000000000000001d0;ooo`05
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`002`3oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01@3oool01P3OW4P007Bo0?oo
o`3oool0okmd001d_`D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooocP0
oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3ookl0M000
07Boo`020?ooo`030?oo_`1dB9`0oooo00@0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`3o0?ooocL0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3o
ool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l01@3oool4000004/0oooo00<000000?ooo`3o
ool0o`3ooolg0?ooo`0000<0oooo09a800000000100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0
oooo00<0okmd001d_`3oool02P3oool00`3ogi`0B4RL0?noM002000000030018W03oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooocL0oooo000:0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3ookl0M01d0;ooo`090?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`002P3oool00`3o_g@0B9cO0?oo
o`020?ooo`030=nLB018W=l0oooo00/0oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0?l0oooo=`3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0
M02oool<0?ooo`030?oo_`1d000007Bo00P0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`3o0?ooocL0oooo000;0?ooo`050?oo_`1d000000000000B02Lgol03`3oool0102oM0000000
00000000B9`50?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00
:03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo=P3oool002P0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooocH0oooo000X0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00:03oool3000004h0oooo00<000000?oo
o`3oool0o`3ooole0?ooo`00:03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0
oooo=@3oool002P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3o0?ooocD0oooo
000X0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00:03oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0oooo=03oool002P0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`3o0?oooc@0oooo000X0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0o`3ooold0?ooo`00:03oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo0?l0oooo<`3oool002P0oooo0`00001@0?ooo`030000003oool0oooo0?l0oooo<`3o
ool002P0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?oooc<0oooo000X0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00:03oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo<P3oool002P0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`3o0?oooc80oooo000X0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0o`3ooola0?ooo`00:03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0?l0oooo<@3oool002P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3o0?oo
oc40oooo000X0?ooo`<00000D`3oool00`000000oooo0?ooo`3o0?oooc00oooo000X0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0o`3oool`0?ooo`00:03oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0?l0oooo<03oool002P0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`3o0?ooobl0oooo000X0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0o`3oool_0?ooo`002`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@00000
0000M;l01P3oool01@3ogi`0B000000000000000M;oo00D0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`3o0?ooobl0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103o
ool00`2oM0000000001d_`080?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`3o0?ooobh0oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool03P3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
00X0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`030?ooo`@00000E@3oool00`00
0000oooo0?ooo`3o0?ooobd0oooo00000`3oool0W4P000000004000000050018W03oool0oooo0=nL
B018W=l00`3oool00`3o_g@007Bo0?ooo`0:0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo1P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0?l0oooo;@3oool000X0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0;0?ooo`050=nLB000M;l0oooo0;md001d_ol01P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0?l0oooo;03oool000X0oooo00<0okmd
04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0<0?ooo`0409a80018W=l0_g@007Boo`H0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?ooob`0oooo000;0?ooo`0609a8001d_ol0
oooo0?oOW01807@0_ooo3@3oool0103ogi`0B01804Q8001d_ol60?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0o`3oool[0?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00l0
oooo00<0okmd0000001d_ol01P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0
oooo:`3oool002P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?ooobX0oooo
000X0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00:03oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo:@3oool002P0oooo0`00001K0?oo
o`030000003oool0oooo0?l0oooo:03oool002P0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`3o0?ooobP0oooo000X0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
o`3ooolW0?ooo`00:03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0oooo9`3o
ool002P0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooobH0oooo000X0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00:03oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0oooo9@3oool002P0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`3o0?ooob@0oooo000X0?ooo`<00000G`3oool00`000000oooo0?oo
o`3o0?ooob@0oooo000X0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooolS
0?ooo`00:03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0oooo8P3oool002P0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooob80oooo000X0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`00:03oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0?l0oooo803oool002P0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`3o0?ooob00oooo000X0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0o`3ooolO0?ooo`00:03oool3000006D0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00
:03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?l0oooo7P3oool002P0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?oooad0oooo000X0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00:03oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo0?l0oooo6`3oool000/0oooo00D0okmd000000000000000007Boo`050?oo
o`030;md0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`030?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`002`3oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool00`2oM000001d0;ooo`02
0?ooo`030=nLM02Lgol0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3o
0?oooaX0oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o
_g@0001809cOo`080?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0o`3ooolI0?oo
o`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo00<0omnL04P00018
W=l01`3oool4000006X0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`0000<0oooo09a800000000
100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03P3oool00`2LB000
B9cO0?ooo`050?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00
2P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool0
103oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0oooo5`3oool000X0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0
_g@007Boo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?l0oooo5P3o
ool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o
_g@0001809cOo`050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3ooolE0?oo
o`002`3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd000000000000001809cOo`06
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00:03oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0?l0oooo4`3oool002P0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`3o0?oooa80oooo000X0?ooo`<00000L@3oool00`000000oooo
0?ooo`3o0?oooa80oooo000X0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3o
oolA0?ooo`00:03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo403oool0
02P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3o0?ooo`l0oooo000X0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0o`3oool>0?ooo`00:03oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0?l0oooo3@3oool002P0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`3o0?ooo`d0oooo000X0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0o`3oool<0?ooo`00:03oool00`000000oooo0?ooo`1J0?ooo`050;md000000000000
0000001d_ol06@3oool00`000000oooo0?ooo`0i0?ooo`030?noM0000000000000<0000000D007Bo
0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo04h0oooo00<0okmd0000000000000`00
00001@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?ooo`3oool0C@3oool00`3ookl0M000
000000040000000507Boo`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`020?ooo`00
:03oool3000005T0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo01T0oooo00<000000?oo
o`3oool0>`3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo2@3o
ool700000480oooo00<0W4Q809cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d
_ol0C`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0080oooo00H0W4Qd0;ooo`3o
ool0oono07@0M02oool30?ooo`00:03oool00`000000oooo0?ooo`1N0?ooo`030?noM000M;l0oooo
01T0oooo00<000000?ooo`3oool0>P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo
0080oooo00<0gia804RLg`3oool00`3oool5000000L0oooo1@00000m0?ooo`0309a8B02Lgol0oooo
00P0oooo00<0okmd001d_`3oool0C`3oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo
0080oooo00<0gia804RLg`3oool00P3oool002P0oooo00<000000?ooo`3oool0GP3oool00`3o_g@0
07Bo0?ooo`0J0?ooo`030000003oool0oooo03T0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0
B9cO0?ooo`020?ooo`040?noM000M;l0oooo0?ooo`8000004@3oool3000003X0oooo00<0W4Q809cO
o`3oool0203oool00`3o_g@007Bo0?ooo`1@0?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`020?ooo`00:03oool00`000000oooo0?ooo`1N0?ooo`03
09a8001d_ol0oooo01X0oooo00<000000?ooo`3oool0>@3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00@0okmd00000000000000005P3oool2000000h0oooo3P00000L0?oo
o`0309a8B02Lgol0oooo00P0oooo00<0W4P007Boo`3oool0DP3oool00`2LB000B9cO0?ooo`020?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool00P3oool002P0oooo00<000000?ooo`3o
ool0F@3oool00`3ookl0M000000000020000000304RLg`3oool0oooo01/0oooo00<000000?ooo`3o
ool0>03oool00`2LB4P0W=oo0?ooo`030?ooo`040=nLB018W=l0oooo0?ooo`80000000<007Bo0?oo
o`3oool0603oool2000000P0oooo1000000>0?ooo`<000006@3oool00`2LB4P0W=oo0?ooo`030?oo
o`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0D`3oool01P2LB7@0_ooo0?ooo`3oool0
gia804RLg`<0oooo00<0okmd001d_`3oool00P3oool002P0oooo00<000000?ooo`3oool0F@3oool0
0`3ookl0M01d0;ooo`0Q0?ooo`030000003oool0oooo03L0oooo00<0W4Q809cOo`3oool00`3oool0
1`3o_g@0B9cO000000000000oooo0=nLB018W=l0703oool2000000@0oooo0P00000E0?ooo`<00000
5P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d07@0_ooo05<0oooo00<0gia807Boo`3oool0
0P3oool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00<0gia804RLg`3oool00P3oool002P0
oooo00<000000?ooo`3oool0F@3oool00`3ookl0M01d0;ooo`0R0?ooo`030000003oool0oooo03<0
oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`80000000D0M;oo0?ooo`3ogi`0B01d0;ooo`0N
0?ooo`@000006P3oool200000140oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d
07@0_ooo05<0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00<0oooo00H0W4P007Boo`3o
ool0omnL04P0M02oool30?ooo`00:03oool00`000000oooo0?ooo`1I0?ooo`030?oo_`1d00000000
0080000000<0001d0;ooo`3oool07P3oool00`000000oooo0?ooo`0d0?ooo`030=nLB00004P0W=oo
00<0oooo00L000000?ooo`3ookl0M0000000000004P0W=oo01d0oooo0`0000000`3oool000000000
000L0?ooo`<00000403oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0
001d0;ooo`3oool0:03oool?000001P0oooo00D0okmd000000000000001809cOo`040?ooo`050?oo
_`1d000000000000B02Lgol0103oool002P0oooo0`0000200?ooo`030000003oool0oooo03L0oooo
0P00000S0?ooo`030000003oool0oooo00@0oooo0P00000M0?ooo`800000@P3oool3000000l0oooo
1@00000:0?oooa4000002P3oool002P0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0240oooo0P0000090?ooo`8000007@3oool3000003`0oooo0`00
000G0?ooo`@000000P3oool4000001/0oooo000X0?ooo`030000003oool0oooo0880oooo00<00000
0?ooo`3oool0<P3oool2000002<0oooo00<000000?ooo`3oool02`3oool2000001h0oooo0P00000f
0?ooo`@000007@3oool3000001l0oooo000X0?ooo`030000003oool0oooo08<0oooo00<000000?oo
o`3oool0;`3oool2000002<0oooo0P00000@0?ooo`8000007P3oool200000340oooo0`00000O0?oo
o`8000000`3oool3000001`0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool07@3oool2000002d0oooo0P00000O0?ooo`<00000203oool3000001T0oooo000X0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01@0oooo0P00000O0?ooo`030000003oool0oooo02P0oooo0P00000M0?ooo`@00000
3P3oool2000001L0oooo000X0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0Q0?ooo`8000006@3oool00`000000oooo0?ooo`0M0?ooo`8000009P3o
ool2000001d0oooo0P00000D0?ooo`8000005@3oool002P0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06P3oool2
000001l0oooo0P00000R0?ooo`8000007@3oool2000001P0oooo0P00000C0?ooo`007`3ooooo0000
094000000@3oool002P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo``0
00001`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000l0oooo00<000000?oo
o`3oool0403oool200000140oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`3oool3000000`0oooo00<000000?ooo`3oool03P3oool3
00000180oooo00<000000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool0203oool0
02P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00T0oooo100000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo0`00000@0?ooo`030000003oool0oooo
0100oooo00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`0=0?ooo`80000000<0oooo
0000003oool04@3oool010000000oooo00000000000?0?ooo`030000003oool0oooo00`0oooo0P00
00020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool200000080oooo00<0
00000?ooo`3oool0203oool002P0oooo00<000000?ooo`3oool0=03oool4000002D0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`8000007`3oool200000180oooo0P00000N
0?ooo`800000:03oool3000000X0oooo000X0?ooo`030000003oool0oooo03P0oooo1000001@0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool2000002`0oooo00<000000?oo
o`3oool07@3oool2000000l0oooo0P00000N0?ooo`800000=`3oool002P0oooo00<000000?ooo`3o
ool0?03oool4000004d0oooo00<000000?ooo`3oool06P3oool200000200oooo00<000000?ooo`3o
ool0;@3oool2000001l0oooo0P00000;0?ooo`8000007@3oool3000003T0oooo000X0?ooo`030000
003oool0oooo0400oooo1000001:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
7P3oool200000380oooo0P00000O0?ooo`8000001`3oool2000001d0oooo0P00000l0?ooo`00:03o
ool00`000000oooo0?ooo`140?ooo`<00000B03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0=03oool2000001l0oooo0`0000020?ooo`8000007@3o
ool2000003h0oooo000X0?ooo`<00000A`3oool2000004L0oooo0P00000E0?ooo`030000003oool0
oooo01d0oooo0P00000i0?ooo`800000803oool3000001/0oooo0`0000100?ooo`00:03oool00`00
0000oooo0?ooo`190?ooo`800000A`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0>`3oool2000001`0oooo0P0000030?ooo`<000004`3oool50000
04<0oooo000X0?ooo`030000003oool0oooo04/0oooo0P0000160?ooo`030000003oool0oooo00h0
oooo0P00000N0?ooo`800000@03oool4000001D0oooo0`0000080?ooo`T0000000<0oooo00000000
00001`0000180?ooo`00:03oool00`000000oooo0?ooo`1=0?ooo`<00000A03oool2000000d0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`140?ooo`D000002@3oool7000001<0oooo
0`00001@0?ooo`00:03oool00`000000oooo0?ooo`1@0?ooo`800000A03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01`0oooo0P00001<0?ooo`T00000K@3oool002P0oooo00<00000
0?ooo`3oool0DP3oool2000004<0oooo0P0000080?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0`P3oool002P0oooo00<000000?ooo`3oool0E03oool2000004<0oooo0P0000040?oo
o`8000007@3oool200000<D0oooo000X0?ooo`030000003oool0oooo05H0oooo0P0000130?ooo`80
000000<0oooo0000003oool07@3oool00`000000oooo0?ooo`350?ooo`00:03oool00`000000oooo
0?ooo`1H0?ooo`800000@`3oool2000001`0oooo0P0000380?ooo`00:03oool3000005X0oooo0P00
000o0?ooo`8000000P3oool2000001L0oooo0`00003:0?ooo`00:03oool00`000000oooo0?ooo`1L
0?ooo`800000?03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo0`00003=
0?ooo`00:03oool00`000000oooo0?ooo`1N0?ooo`800000>03oool2000000P0oooo1P0000080?oo
o`D00000d03oool002P0oooo00<000000?ooo`3oool0H03oool2000003@0oooo0P00000@0?ooo`P0
0000e@3oool002P0oooo00<000000?ooo`3oool0HP3oool200000340oooo00<000000?ooo`3oool0
k@3oool002P0oooo00<000000?ooo`3oool0I03oool2000002d0oooo0P00003`0?ooo`00:03oool0
0`000000oooo0?ooo`1V0?ooo`800000:@3oool200000?80oooo000X0?ooo`030000003oool0oooo
06P0oooo0P00000U0?ooo`800000m03oool002P0oooo0`00001Z0?ooo`<00000803oool200000?H0
oooo000X0?ooo`030000003oool0oooo06d0oooo1000000J0?ooo`800000n03oool002P0oooo00<0
00000?ooo`3oool0L@3oool3000001@0oooo0`00003j0?ooo`00:03oool00`000000oooo0?ooo`1d
0?ooo`H000002@3oool500000?d0oooo000X0?ooo`030000003oool0oooo07X0oooo2@00003o0?oo
o`<0oooo000;0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`030?oo
o`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
ohH0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`04
0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0103oool00`000000oooo0?ooo`3o
0?ooohH0oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o
_g@0001809cOo`080?ooo`030000003oool0oooo0?l0ooooQP3oool000X0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00L0oooo1000003o0?ooohD0
oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`2LB000B9cO
0?ooo`050?ooo`030000003oool0oooo0?l0ooooQP3oool000X0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8M02oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia8
07Boo`3oool00P3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo0?l0ooooQP3oool0
00/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0
001809cOo`050?ooo`030000003oool0oooo0?l0ooooQP3oool000/0oooo00D0oono07@000000000
001809cOo`0=0?ooo`050?noM000000000000000B02Lgol01P3oool00`000000oooo0?ooo`3o0?oo
ohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0
o`3ooon60?ooo`00:03oool300000?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon6
0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0
ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`<00000
o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0
oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?oo
o`<00000o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000
003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`002`3oool0
1@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3oool01@3ogi`0B0000000
00000000M;oo00D0oooo00<000000?ooo`3oool0o`3ooon60?ooo`002`3oool01P2LB7@0_ooo0?oo
o`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0203oool00`2oM000M;oo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooQP3oool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO
0?ooo`0>0?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0o`3ooon60?ooo`002P3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia80000000000000`00
00000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooQP3oool000X0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo
1P3oool400000?l0ooooQ@3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0;0?ooo`050=nLB000M;l0oooo0;md001d_ol01P3oool00`000000oooo0?ooo`3o0?ooohH0oooo
000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102LB000B9cO0;md
001d_ol60?ooo`030000003oool0oooo0?l0ooooQP3oool000/0oooo00H0W4P007Boo`3oool0omnL
04P0M02oool=0?ooo`040?oOW01804P0B4P007Boo`H0oooo00<000000?ooo`3oool0o`3ooon60?oo
o`002`3oool01@3ookl0M0000000000004P0W=oo00l0oooo00<0okmd0000001d_ol01P3oool00`00
0000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo
00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X
0?ooo`<00000o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool0
02P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0
oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-2.15489, -1.07791, \
0.0788458, 0.00911249}}]
}, Closed]],

Cell["\<\
and with several more we can add labels and other embellishments.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20, PlotRange \[Rule] {Automatic, {\(-0.2\), 0.2}}, 
        GridLines \[Rule] Automatic, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<x\>", \
\*"\"\<\!\(\[ScriptJ]\_5\),\!\(\[ScriptY]\_5\)\>\""}, 
        PlotLabel \[Rule] "\<Isn't this better?\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5625 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -14.2813 ]
[-0.01875 .30902 -24 14.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -56 0 ]
[.5 .63053 56 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .15451 m
1 .15451 L
s
0 .30902 m
1 .30902 L
s
0 .46353 m
1 .46353 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
[(-0.1)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.1)] -0.0125 .46353 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .12361 m
.00375 .12361 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .27812 m
.00375 .27812 L
s
0 .33992 m
.00375 .33992 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .49443 m
.00375 .49443 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.563 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.2813 10.2813 translate
90 rotate
-75.2813 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
67.438 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
72.125 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
78.313 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
82.875 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
87.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46353 m
1 .46353 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Isn) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(') show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
99.000 12.813 moveto
(this) show
129.000 12.813 moveto
(better) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(?) show
171.000 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04396 .30902 L
.04519 .30902 L
.04654 .30902 L
.04797 .30902 L
.05038 .30902 L
.05174 .30903 L
.05302 .30903 L
.0554 .30904 L
.05757 .30904 L
.06007 .30905 L
.06244 .30907 L
.06486 .30909 L
.06753 .30911 L
.07031 .30914 L
.07293 .30918 L
.0776 .30928 L
.08263 .30942 L
.08821 .30964 L
.09408 .30997 L
.09909 .31035 L
.10458 .31088 L
.10986 .31154 L
.11485 .31231 L
.12419 .31422 L
.13424 .3171 L
.14514 .3214 L
.15461 .3263 L
.16502 .33312 L
.18606 .35207 L
.20551 .37613 L
.2264 .40859 L
.26768 .48503 L
Mistroke
.28831 .52238 L
.29835 .53848 L
.30744 .55127 L
.31634 .56174 L
.32596 .57037 L
.33126 .5738 L
.33358 .57498 L
.33612 .57605 L
.33853 .57683 L
.34077 .57736 L
.34201 .57756 L
.34314 .5777 L
.34445 .57779 L
.34568 .57781 L
.34683 .57778 L
.34806 .57769 L
.34922 .57754 L
.35029 .57735 L
.35147 .5771 L
.35276 .57674 L
.35536 .57583 L
.35794 .57463 L
.36068 .57305 L
.36563 .56938 L
.37061 .56463 L
.37529 .55918 L
.38406 .54651 L
.40412 .50608 L
.42258 .45697 L
.46204 .33218 L
.48187 .27104 L
.49998 .22327 L
.50931 .20304 L
.51946 .18512 L
.52503 .17727 L
.53019 .17131 L
.53513 .16682 L
.53768 .16497 L
.54037 .16337 L
.5427 .16228 L
.54393 .16181 L
.54525 .16139 L
.54646 .16108 L
.54756 .16086 L
.54867 .16071 L
.54972 .16062 L
.55095 .16058 L
.55224 .16062 L
.55335 .16072 L
.55456 .1609 L
Mistroke
.55587 .16117 L
.55728 .16156 L
.55982 .1625 L
.56216 .16364 L
.56471 .16517 L
.56936 .16874 L
.57809 .178 L
.58842 .1929 L
.59778 .2096 L
.61875 .255 L
.63964 .30513 L
.65884 .349 L
.6776 .38438 L
.68705 .39806 L
.69237 .40434 L
.69741 .40927 L
.7023 .41308 L
.70488 .4147 L
.70762 .41611 L
.70992 .41705 L
.71115 .41746 L
.71246 .41784 L
.71367 .41812 L
.71477 .41832 L
.71582 .41846 L
.71693 .41857 L
.71825 .41862 L
.71944 .41861 L
.7201 .41858 L
.72081 .41852 L
.72211 .41837 L
.72333 .41816 L
.72462 .41787 L
.72693 .41719 L
.72962 .41613 L
.73213 .41488 L
.73785 .41113 L
.74284 .40687 L
.74827 .40125 L
.75816 .38864 L
.7767 .35842 L
.79807 .31779 L
.81742 .28142 L
.82736 .26463 L
.83785 .24923 L
.84756 .23759 L
.85662 .22935 L
.86107 .2263 L
.86583 .22378 L
.86854 .2227 L
Mistroke
.87111 .22192 L
.87341 .22142 L
.87472 .22122 L
.87592 .22109 L
.87711 .22101 L
.8784 .22097 L
.87962 .221 L
.88073 .22107 L
.88203 .2212 L
.88276 .2213 L
.88345 .22141 L
.88603 .22198 L
.88875 .22283 L
.89122 .22381 L
.89676 .22674 L
.90163 .23013 L
.90677 .23447 L
.91599 .24407 L
.93681 .27242 L
.97477 .33268 L
.97619 .33479 L
Mfstroke
.2973 0 m
.30506 .03636 L
.34639 .21231 L
.36706 .2938 L
.3862 .36197 L
.40594 .42092 L
.4245 .46219 L
.43346 .47639 L
.43851 .4826 L
.44314 .48715 L
.44792 .49068 L
.45064 .49214 L
.45316 .49315 L
.45454 .49356 L
.45584 .49386 L
.457 .49405 L
.45827 .49417 L
.45893 .4942 L
.45965 .49421 L
.4604 .49419 L
.46111 .49414 L
.46237 .494 L
.46308 .49388 L
.46373 .49374 L
.46502 .49342 L
.46623 .49303 L
.4685 .49211 L
.47094 .49082 L
.47358 .48909 L
.47835 .4851 L
.48273 .48047 L
.49281 .46653 L
.50346 .44728 L
.54145 .35306 L
.56261 .2952 L
.58189 .24785 L
.59147 .228 L
.60189 .21007 L
.60666 .20328 L
.61173 .19711 L
.61616 .19262 L
.62082 .18884 L
.62316 .18731 L
.62572 .18593 L
.62804 .18493 L
.6302 .18422 L
.63152 .1839 L
.63276 .18366 L
.63388 .18351 L
.63509 .18341 L
Mistroke
.63641 .18338 L
.63707 .18339 L
.63781 .18343 L
.6391 .18356 L
.64031 .18374 L
.64144 .18398 L
.64267 .1843 L
.64492 .18505 L
.64913 .18706 L
.65404 .19035 L
.65859 .19429 L
.6692 .20652 L
.67917 .22147 L
.6978 .25615 L
.73642 .33736 L
.75641 .37269 L
.76647 .38643 L
.77214 .39272 L
.77749 .39763 L
.7824 .40121 L
.78499 .40274 L
.78774 .40408 L
.79004 .40498 L
.79126 .40538 L
.79258 .40574 L
.79379 .40601 L
.79489 .40621 L
.796 .40637 L
.79706 .40647 L
.79837 .40654 L
.79957 .40655 L
.80023 .40653 L
.80095 .40649 L
.80224 .40637 L
.80346 .40619 L
.80475 .40595 L
.80706 .40536 L
.80976 .40442 L
.81227 .4033 L
.81799 .39993 L
.82299 .39606 L
.82843 .39094 L
.83833 .37944 L
.85689 .35181 L
.87626 .31828 L
.89766 .28162 L
.9074 .26678 L
.9179 .25293 L
.92775 .24246 L
.93218 .23864 L
Mistroke
.93691 .23522 L
.9417 .23248 L
.94605 .23062 L
.94851 .22984 L
.94981 .22951 L
.95119 .22922 L
.95239 .22902 L
.95303 .22893 L
.95371 .22885 L
.95492 .22875 L
.95604 .22869 L
.95669 .22868 L
.95738 .22868 L
.95862 .22873 L
.95939 .22878 L
.9601 .22884 L
.96144 .22901 L
.96273 .22922 L
.96391 .22947 L
.96657 .23018 L
.9688 .23095 L
.97125 .23197 L
.97619 .23459 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00l@3oool01P3OW4P0000000000000M;l0oooo0;md0080000000<0B9cO0?ooo`3oool0]03o
ool00?80oooo00L0okmd0000001d_ol0oooo0?noM0000000M;oo0;L0oooo003c0?ooo`050?oo_`1d
04P0B7A804P0M02oool0^03oool00?@0oooo00<0W4P004Q8B000B9`0^@3oool00?80oooo00L0oono
07@00018W=l0oooo0=nLB00007@0_ooo0;L0oooo003a0?ooo`090?oOW01800000000001d_`3oool0
_g@00000000004P0W=oo0;H0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001D
0?ooo`050?noM000000000000000001d_ol0BP3oool01@2oM0000000000000000000M;oo04D0oooo
00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3o
ool0?P3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d
_ol0oooo0?ooo`0n0?ooo`030?oo_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM003
0000000307Boo`3oool0oooo01<0oooo001D0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_oooB03o
ool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0A`3oool00`2LB4P0W=oo0?ooo`040?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0
oooo0?ooo`3ogi`0B00007Boo`100?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0
0P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooa@0oooo001C0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool0C03oool00`3o_g@007Bo0?ooo`160?ooo`0309a8B02Lgol0oooo00<0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00P0
oooo00<0okmd001d_`3oool0@03oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool04`3oool005<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`1<0?ooo`030?noM000M;l0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo
0?ooo`110?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0C0?ooo`00D`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04`0oooo00<0
W4P007Boo`3oool0AP3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0@@3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo04<0oooo00<0
W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01<0oooo001C
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04@0oooo00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`030?no
M000M;l0oooo01<0oooo001C0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A`3o
ool00`3ookl0M01d0;ooo`1;0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool0A03o
ool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0
B9cO0?ooo`0C0?ooo`00E03oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooodP0oooo00<0oono07@0
M02oool0B03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol0103oool00`3ookl0M01d0;ooo`140?ooo`07
0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
503oool005@0oooo00D0oono07@000000000001809cOo`190?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0A@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02L
gol0@P3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3o
ool0@03oool01@3o_g@000000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0E
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3ooooo0000050000004`3oool004h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0@03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00X0oooo00<00000
0?ooo`3oool0?`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0:0?oo
o`030000003oool0oooo03l0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo00/0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0C03oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00d0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?ooo`800000
4`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
00h0oooo00<000000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0>0?ooo`030000003oool0oooo03/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo03T0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0i0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100
oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E
0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0>03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?oo
o`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool2000005H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000O`3o
ool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0=`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo
03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0f0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01<0oooo
00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00`3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo
00<000000?ooo`3oool0=@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0D0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool0503oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`2LB0000000000000030000
00050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00H0oooo0`00001/0000O`030000000007l0001o0=X0001o0`00000C0?ooo`00<03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300
oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo03@0
oooo00<0001o0?ooo`3oool02`3oool7000003X0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia80000
0000B9`0W4Q809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05@3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00X0oooo0P0000060?ooo`800000>03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?oo_`1d00000000
0000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01`3oool2000000/0oooo00<000000?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3o
ool0oooo01H0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`800000803oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
0380oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo0`0000020?ooo`8000007P3oool00`0007l0oooo0?ooo`1D0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo0380
oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo0P0000070?ooo`800000703oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0b0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P00
000I0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00D0001o
0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo0340oooo00D0001o0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H
0?ooo`030000003oool0oooo0340oooo00@0001o0?ooo`3oool00000703oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0`0?ooo`040000O`3oool0oooo000001`0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0I0?ooo`030000
003oool0oooo0300oooo00<0001o0?ooo`0000007P3oool2000001H0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3o
ool0000001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool0<03oool00`0007l000000?ooo`0N0?ooo`8000005`3oool0
0`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`00
07l000000?ooo`0M0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool04@3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo
02X0oooo1P00000U0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0
oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0100oooo00<0001o0?oo
o`3oool0:03oool2000000H0oooo0P00000S0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000000O`3oool0
703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0U0?ooo`800000303oool2000000h0oooo2000000:0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0]0?ooo`030000000007l0oooo01`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0903o
ool00`000000oooo0?ooo`0>0?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000O`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0
oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo0P0000070?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0001o
01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00d0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo0P00000E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0001o01/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool0:P3oool010000000oooo
0?ooo`0007lK0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0<0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`00000H0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0001o6P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`00
07l0oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo0P00000H0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo02X0
oooo00@000000?ooo`3oool0001o6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0:03oool01@000000
oooo0?ooo`3oool0001o01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0I0?oo
o`8000006@3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3ogi`0B7Bo0?ooo`0/0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`05
0000003oool0oooo0?ooo`0007l06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0A0?ooo`00803oool00`2o
M7@0_ooo0?ooo`0[0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000O0?ooo`030?noM000B9`0gooo02`0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04@3oool001`0oooo00@0oono07@00000000007Bo;P3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`020?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0A0?ooo`005`3oool00`3Ogml0gia800000002000000030000M02oool0oooo02l0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo01X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04@3oool001@0oooo00D0omnL04P0B02Lgol0gia804RLg`0e0?ooo`030000
003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0J0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool0
0`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool0
0`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0P00000C0?ooo`007`3oool00`3o
_g@0M;oo0?ooo`0/0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0503oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`00
07l0oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo000I0?ooo`090?oo_`1d000000000000
0018W=l0oooo0?oog`2LM9`0gooo02`0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`060?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool001T0oooo00D0oono
09bLg`3oool0oknL09cOo`020?ooo`030=nLW02oool0oooo02/0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3o
ool001T0oooo00T0oono09bLg`3oool0giad09cOo`3oool0oooO09adW03Oool0;03oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool05P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0A0?ooo`00703oool01@3ooml0W4P00000000004P0W=oo02d0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
O`3oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool004<0oooo00D0okmd0000000000000000
07Boo`060?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0140oooo00130?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo1@3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3o
ool0503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0A0?ooo`007@3oool0103o_g@000000000B02LgolQ0?ooo`03
0?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0103oool00`000000oooo0?ooo`1E0?ooo`03
0000O`3oool0oooo0240oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0080oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`00
6`3oool01@3o_g@0000000000000B9`0gooo0280oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`040?ooool00000D000000C0?ooo`006`3oool00`3o_g@004RL0=ooo`0T0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0J0?ooo`/00000
<03oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
203oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
603oool01@000000oooo0?ooo`3oool0001o01D0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00480oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo02D0oooo
1000000/0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`080?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0007l0503oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`00
@P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00@0oooo00<000000?ooo`3oool0
:@3oool3000002T0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00P0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool0001o503oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`00
@`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`D0oooo00<000000?ooo`3oool0;03oool30000
02H0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00T0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo00@000000?ooo`3oool0001o4`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3o
oml0_koO0?ooo`0Q0?ooo`050?oo_`1d000000000000B02Lgol01P3oool00`000000oooo0?ooo`0_
0?ooo`800000903oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool02@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0000O`0C0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo000O0?oo
o`030?oog`2LB7@0_ooo02`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?oo
o`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0001o0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool001L0oooo00<0gmoO0?noM000
00000`0000001@18W=l0oooo0?ooo`2oW9`0gooo02`0oooo00<000000?ooo`3oool0<P3oool20000
0240oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01T0oooo00<000000000O`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`005`3oool00`3OW4P0
07Bo0?ooo`020?ooo`050=nLB01d_ol0oooo0?oOW018M;l0;@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01P0oooo00<000000000O`3oool0403oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`006`3oool01P2oM000B9cO0?ooo`3ogi`0B01d0;ooobd0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
01X0oooo00H0_g@007Boo`2oM00000000018W03Oool^0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`005P3oool00`3ooml0gknL04P00003
0000000307Boo`3oool0oooo02l0oooo0P00000h0?ooo`030000003oool0oooo01/0oooo00<0001o
0?ooo`3oool0903oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0001o
0?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<0001o
0000003oool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo0P00000C
0?ooo`005`3oool00`2oW9`0gooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool06P3oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0603oool00`0007l000000?ooo`0=0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01T0oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00`0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01L0oooo00<0001o0?ooo`000000303oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool001l0oooo00<0okmd07Boo`3oool0
;03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`000000
303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
4@3oool001T0oooo00T0oono07@000000000000004RLg`3oool0oooO09adW03Oool0;03oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00@0001o0?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool0
01T0oooo00D0oono09bLg`3oool0oknL09cOo`020?ooo`030=nLW02oool0oooo02/0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo02D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo00/0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`040000O`3oool0oooo000000X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000I
0?ooo`090?oo_`2LW=l0oooo0=nLM02Lgol0oooo0?oog`2LM9`0gooo02`0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo02H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0E0?ooo`050000O`3oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001`0
oooo00D0oooO09a800000000001809cOo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0503oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool05@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0V0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`090?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
503oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000@@3o
ool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0300oooo0P00000C0?ooo`00CP3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool09`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0103oool0
10000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0
oooo02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00D0oooo0P00000I0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00D0oooo0P00000H0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo00D0
oooo0P00000G0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00H0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00D0oooo
00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03@3oool2000003T0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo
02X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo
00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool04@3oool004h0oooo0P0000180?ooo`030000003oool0oooo00/0
oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140
oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00d0
oooo00D0001o0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0>@3oool2000001<0oooo001>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0303oool0100007l0oooo0?ooo`00000<0?ooo`<000001@3oool3000003d0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0:0?ooo`03
0000O`3oool0oooo02/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0;0?ooo`03
0000O`3oool0000000l0oooo1P0000100?ooo`030000003oool0oooo0140oooo001>0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0/0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`030?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool2000005H0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`080?ooo`030000O`3o
ool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00<0oooo00<000000?ooo`3oool0>P3oool2000000T0oooo00<000000000O`3oool0EP3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00P0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`<000001@3oool3
000000030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo0080oooo00<000000?oo
o`3oool0?`3oool5000000<0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D0001o0?ooo`3o
ool0oooo0000001:0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo02d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`050000O`3oool0oooo0?oo
o`000000BP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0^0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool01@0007l0oooo0?ooo`3oool00000
04X0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0;P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00@0001o0?ooo`3oool00000B`3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000CP3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`040000O`3oool0oooo000004/0oooo00<0001o0?ooo`3oool0E03oool20000
01<0oooo001>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0103oool00`0007l0
oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`0007l0
oooo0000001<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo0300oooo
00D000000?ooo`3oool0oooo0000000G0?ooo`030000O`3oool0000004`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000001L0
oooo00<0001o0000003oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0a0?ooo`030000003oool0000001P0oooo00<0001o0000003oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0a0?ooo`030000003oool0000001P0oooo00<0
001o0000003oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a
0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM000
0000000000<0000000<007Bo0?ooo`3oool00`3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0080oooo00<0001o0?ooo`3oool0<P3oool2000001P0oooo00<000000?ooo`3oool0C03o
ool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool0001o03@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool0001o03@0
oooo0P00000G0?ooo`030000000007l0oooo04d0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`040000003oool0oooo0000Oc@0
oooo0P00000G0?ooo`030000000007l0oooo04d0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool300000580001o00<000000000O`0007l0=00007l010000000001o
0000O`00000E0000O`030000000007l0001o0:@0001o0`00000C0?ooo`00<03oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0001o03<0oooo00@000000?ooo`3oool000005@3oool00`000000
oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300oooo
00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0000O`0b0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0007m>0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool00340oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?oo
o`050=nLB000000004RL09a8B02Lgol01`3oool00`000000oooo0?ooo`1D0?ooo`030000000007l0
oooo0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0007l0CP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a
0?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003o
ool0oooo05@0oooo00<000000000O`3oool0<@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0000003oool0;`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`1<0?oo
o`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0000000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool2000000L0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`000000
;P3oool00`000000oooo0?ooo`090?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool2000005H0oooo00@0001o0?ooo`3oool00000;03oool00`000000oooo0?ooo`0<0?ooo`H00000
2P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`040000O`3oool0oooo000002`0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0E@3oool01@0007l0oooo0?ooo`3oool0000002/0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool01@0007l0oooo0?oo
o`3oool0000002X0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`1<0?ooo`030000
O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool07`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0803oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?oo
o`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0240oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool09P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0W0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000
O`3oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool02`3oool2000002/0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool3000000H0
oooo0P00000^0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01H0oooo
1P00000`0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo
0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?oo
o`8000004`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`1<0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00340oooo
00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00<0oooo00<0oono07@00000
0000100000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo
00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo000`0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0
001809cOo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00300oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00L0oooo
o`00001@000001<0oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3o
ool00`2LB000B9cO0?ooo`3o0?ooofP0oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`3o0?ooofL0oooo000`0?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo
0?l0ooooI`3oool00340oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`3o0?ooofP0oooo000a0?ooo`050?oo_`1d000000000000B02Lgol0
3@3oool01@3o_g@000000000000004P0W=oo0?l0ooooJ@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00:D0oooo00<0gia8000000000000
0`0000001018W=l0oooo0?ooo`2oM004000000040018W03oool0oooo0=nLB080000000<004RL0?oo
o`2oM0000P0000000`18W=l0oooo0?ooo`090?ooo`050?oo_`1d0000000000000000B9`03@3oool0
1@3ookl0M00000000000000004RL0080oooo00H0gia800000000000007Bo0?ooo`2oM00200000003
04RLg`3oool0W4P000D0000000@004RL0?ooo`3oool0_g@0100000000`00B9`0oooo0?ooo`090?oo
o`0409a800000000M9bL04P00080000000<0001d0;ooo`3oool00P3oool01P2oM000000000000000
0000001d0;ooo`<0oooo00D0oono07@00000000000000018W0040?ooo`050?oo_`1d000000000000
0000B9`0103oool02@2oM0000000000000000000001d0;ooo`3oool0oono07@00004000000030000
B02Lgol0oooo00<0oooo00<0gia800000000M;l0K@3oool00:L0oooo00<0oono07@0M02oool0103o
ool00`2oM000B9cO0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@007Bo0`3oool00`2oM000
M;oo0?ooo`0;0?ooo`070=nLB018W=l0oooo0?ooo`3OW4P0001d0;ooo`0;0?ooo`0:0=nLB018W=l0
oooo0?ooo`3OW4P0001d0;ooo`3oool0gia804RLg`<0oooo00<0_g@007Boo`3oool00`3oool00`3o
okl0M01d0;ooo`040?ooo`030;md0018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`2o
M000001809cOo`020?ooo`060?noM000B9`0oooo0?ooo`2oM00007Bo0`3oool00`3o_g@004RL0?oo
o`020?ooo`070=nLB018W=l0oooo0?ooo`3OW4P0001d0;ooo`020?ooo`0:0=nLB018W=l0oooo0?oo
o`3OW4P0001d0;ooo`3oool0_g@0001d_`<0oooo00<0okmd0018W03oool00P3oool00`3ookl0M01d
0;ooo`070?ooo`030=nLB000000007Bo06d0oooo002W0?ooo`030?oo_`1d07@0_ooo00T0oooo00H0
_g@0001d_`3oool0oooo0?noM000M;l30?ooo`030;md001d_ol0oooo00/0oooo00<0gia804RLg`3o
ool03`3oool00`3OW4P0B9cO0?ooo`050?ooo`030=nLB018W=l0oooo0080oooo00<0_g@007Boo`3o
ool00`3oool00`3ookl0M01d0;ooo`090?ooo`030;md0000M;l0oooo00X0oooo00<0_g@007Boo`3o
ool00`3oool01@2oM4P0W=oo0?oo_`1d07@0_ooo00P0oooo00<0gia804RLg`3oool01P3oool00`3O
W4P0B9cO0?ooo`040?ooo`030?oo_`1d07@0_ooo00P0oooo00<0oono07@0M02oool0M`3oool00:L0
oooo00<0oono07@0M02oool01@3oool01@2LB000000000000000000004RL00<0oooo00<0okmd001d
_`3oool00P3oool00`2oM000M;oo0?ooo`0;0?ooo`030=nLB018W=l0oooo00l0oooo00<0gia804RL
g`3oool01@3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo00<0oooo00<0oono07@0
M02oool01@3oool01@2LB000000000000000000004RL00`0oooo00<0_g@004RLg`3oool00`3oool0
102oM000M;oo0?oo_`1d0005000000060018W03oool0oooo0?ooo`3OW4P0B9cO1`3oool00`3OW4P0
B9cO0?ooo`040?ooo`030?oo_`1d0000000000@0000000L004RL0?ooo`3oool0oooo0?oo_`1d07@0
_ooo00L0oooo00<0oono07@0001d_ol0K@3oool00:L0oooo00<0oono07@0M02oool0103oool01`3o
_g@007Bo0?ooo`3oool0oono07@00018W=l00P3oool00`3o_g@0000007Boo`020?ooo`0309a8001d
_ol0oooo00/0oooo00<0gia804RLg`3oool03`3oool00`3OW4P0B9cO0?ooo`050?ooo`030=nLB000
0000B9cO0080oooo00<0W4P007Boo`3oool00`3oool00`3ookl0M01d0;ooo`040?ooo`070?noM000
M;l0oooo0?ooo`3ookl0M00004RLg`0;0?ooo`030;md00000000B9cO0080oooo00H0gia80018W03o
ool0oooo0;md001d_ol30?ooo`0309a80018W=l0oooo0080oooo00<0gia804RLg`3oool01P3oool0
0`3OW4P0B9cO0?ooo`050?ooo`030;md001d_ol0oooo0080oooo00<0W4P004RLg`3oool00P3oool0
103ookl0M0000000001d_ol70?ooo`030?oo_`1d000007Bo06`0oooo002W0?ooo`030?oo_`1d07@0
_ooo00D0oooo00/0_g@0000000000000000007AdM018W=l0oooo0=nLB000000007Ad07@000020000
0003001d_`3oool0oooo00<0oooo00<0omnL04P0B02Lgol00`3oool00`3ogi`0B000000000030000
00030000B02Lgol0oooo00T0oooo00<0omnL04P0000000000`0000001`0004P0W=oo0?ooo`3oool0
gia804RLg`2LB0000P0000002@00M;l0oooo0?ooo`3oool0omnL04P000000000001d0;ooo`050?oo
o`060;md0000000000000000001dM7@0B9cO2`3oool00`2oM000M;oo09a80002000000060018W03o
ool0oooo0?ooo`3ookl0M0000`0000001@18W=l0oooo0?ooo`3ogi`0B00000@0000000D0001809cO
o`3oool0omnL04P00004000000060000B02Lgol0oooo0?ooo`3ookl0M0000`0000002@18W=l0oooo
0?ooo`3oool0gia80000000007@0_ono07@000020000000307Boo`3oool0oooo00@0oooo00<0_g@0
07Boo`3oool0JP3oool00:L0oooo00<0oono07@0M02oool0603oool00`3o_g@0001809cOo`050?oo
o`030=nLB018W=l0oooo00l0oooo00<0gia804RLg`3oool01@3oool00`3OW4P0B9cO0?ooo`0Q0?oo
o`030;md001d_ol0oooo0100oooo00<0gia804RLg`3oool01P3oool00`3OW4P0B9cO0?ooo`0G0?oo
o`030?oOW018B9`0oooo0080oooo00<0gia804RLg`3oool0JP3oool00:D0oooo00<0gia800000000
00000`0000000`18W=l0oooo0?ooo`0D0?ooo`030=nLB0000000M;oo00D0oooo00<0gia804RLg`3o
ool03`3oool00`3OW4P0B9cO0?ooo`050?ooo`030=nLB018W=l0oooo0240oooo00<0_g@007Boo`3o
ool0403oool00`3OW4P0B9cO0?ooo`060?ooo`030=nLB018W=l0oooo01L0oooo00L0omnL04P0B02L
gol0oooo0?oOW01804P0W=oo06/0oooo00320?ooo`030;md00000000B9cO01h0oooo00<0gia80000
0018W=l02@3oool00`3o_g@0001d0;ooo`0E0?ooo`030;md00000000M;oo03D0oooo00D0omnL04P0
00000000000004RLg`1/0?ooo`00k`3oool00`3o_g@0001d0;ooo`2n0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-5.4479, -0.270811, \
0.094377, 0.00290868}}]
}, Closed]],

Cell[TextData[{
  "Default values for the options to be associated with the symbol ",
  StyleBox["f", "InlineInput"],
  " are established using the ",
  ButtonBox["Options",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[f]", "InlineInput"],
  " command.  Note that we clear any existing options and attributes as well \
as the function definition using ",
  StyleBox["ClearAll", "InlineInput"],
  " instead of simply ",
  StyleBox["Clear", "InlineInput"],
  ", which would have left the options intact.  We also use ",
  StyleBox["With", "InlineInput"],
  " to assign default options to a local constant included in the ",
  StyleBox["Plot", "InlineInput"],
  " function.  To apply this technique to a built-in function that expects a \
sequence and will not accept a list, simply apply ",
  StyleBox["Sequence", "InlineInput"],
  " to the list of options; namely ",
  StyleBox["defaults=Sequence@@optionList", "InlineInput"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(\(ClearAll[plotsbess];\)\(\n\)
    \)\), "\n", 
    \(\(Options[
          plotsbess]\  = \ {PlotLabel \[Rule] "\<Spherical Bessel \
Functions\>", \ Frame \[Rule] True, \ 
          FrameLabel \[Rule] {"\<x\>", \*"\"\<\!\(\[ScriptJ]\_\[ScriptL]\),\!\
\(\[ScriptY]\_\[ScriptL]\)\>\""}, \ 
          GridLines \[Rule] Automatic};\)\ \n\), "\n", 
    \(plotsbess[n_, xmin_, xmax_, opts___Rule] := \ 
      With[{defaults = Options[plotsbess]}, 
        Plot[{sbessj[n, x], sbessy[n, x]}, {x, xmin, xmax}, opts, \ 
          defaults]]\)}], "Input"],

Cell[TextData[{
  "Notice that we give ",
  StyleBox["plotsbess", "InlineInput"],
  " the user options ",
  StyleBox["opts", "InlineInput"],
  " first, followed by the default options; then, if the function is called \
with an option in the argument list for which a default has been defined, the \
argument takes precedence over the default.  We now obtain a well-formatted \
plot without supplying as many arguments."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20, PlotRange \[Rule] {Automatic, {\(-0.2\), 0.2}}, 
        FrameLabel \[Rule] {"\<x\>", \
\*"\"\<\!\(\[ScriptJ]\_5\),\!\(\[ScriptY]\_5\)\>\""}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5625 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -14.2813 ]
[-0.01875 .30902 -24 14.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .15451 m
1 .15451 L
s
0 .30902 m
1 .30902 L
s
0 .46353 m
1 .46353 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
[(-0.1)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.1)] -0.0125 .46353 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .12361 m
.00375 .12361 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .27812 m
.00375 .27812 L
s
0 .33992 m
.00375 .33992 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .49443 m
.00375 .49443 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.563 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.2813 10.2813 translate
90 rotate
-75.2813 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
67.438 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
72.125 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
78.313 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
82.875 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
87.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46353 m
1 .46353 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Spherical) show
123.000 12.813 moveto
(Bessel) show
165.000 12.813 moveto
(Functions) show
219.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04396 .30902 L
.04519 .30902 L
.04654 .30902 L
.04797 .30902 L
.05038 .30902 L
.05174 .30903 L
.05302 .30903 L
.0554 .30904 L
.05757 .30904 L
.06007 .30905 L
.06244 .30907 L
.06486 .30909 L
.06753 .30911 L
.07031 .30914 L
.07293 .30918 L
.0776 .30928 L
.08263 .30942 L
.08821 .30964 L
.09408 .30997 L
.09909 .31035 L
.10458 .31088 L
.10986 .31154 L
.11485 .31231 L
.12419 .31422 L
.13424 .3171 L
.14514 .3214 L
.15461 .3263 L
.16502 .33312 L
.18606 .35207 L
.20551 .37613 L
.2264 .40859 L
.26768 .48503 L
Mistroke
.28831 .52238 L
.29835 .53848 L
.30744 .55127 L
.31634 .56174 L
.32596 .57037 L
.33126 .5738 L
.33358 .57498 L
.33612 .57605 L
.33853 .57683 L
.34077 .57736 L
.34201 .57756 L
.34314 .5777 L
.34445 .57779 L
.34568 .57781 L
.34683 .57778 L
.34806 .57769 L
.34922 .57754 L
.35029 .57735 L
.35147 .5771 L
.35276 .57674 L
.35536 .57583 L
.35794 .57463 L
.36068 .57305 L
.36563 .56938 L
.37061 .56463 L
.37529 .55918 L
.38406 .54651 L
.40412 .50608 L
.42258 .45697 L
.46204 .33218 L
.48187 .27104 L
.49998 .22327 L
.50931 .20304 L
.51946 .18512 L
.52503 .17727 L
.53019 .17131 L
.53513 .16682 L
.53768 .16497 L
.54037 .16337 L
.5427 .16228 L
.54393 .16181 L
.54525 .16139 L
.54646 .16108 L
.54756 .16086 L
.54867 .16071 L
.54972 .16062 L
.55095 .16058 L
.55224 .16062 L
.55335 .16072 L
.55456 .1609 L
Mistroke
.55587 .16117 L
.55728 .16156 L
.55982 .1625 L
.56216 .16364 L
.56471 .16517 L
.56936 .16874 L
.57809 .178 L
.58842 .1929 L
.59778 .2096 L
.61875 .255 L
.63964 .30513 L
.65884 .349 L
.6776 .38438 L
.68705 .39806 L
.69237 .40434 L
.69741 .40927 L
.7023 .41308 L
.70488 .4147 L
.70762 .41611 L
.70992 .41705 L
.71115 .41746 L
.71246 .41784 L
.71367 .41812 L
.71477 .41832 L
.71582 .41846 L
.71693 .41857 L
.71825 .41862 L
.71944 .41861 L
.7201 .41858 L
.72081 .41852 L
.72211 .41837 L
.72333 .41816 L
.72462 .41787 L
.72693 .41719 L
.72962 .41613 L
.73213 .41488 L
.73785 .41113 L
.74284 .40687 L
.74827 .40125 L
.75816 .38864 L
.7767 .35842 L
.79807 .31779 L
.81742 .28142 L
.82736 .26463 L
.83785 .24923 L
.84756 .23759 L
.85662 .22935 L
.86107 .2263 L
.86583 .22378 L
.86854 .2227 L
Mistroke
.87111 .22192 L
.87341 .22142 L
.87472 .22122 L
.87592 .22109 L
.87711 .22101 L
.8784 .22097 L
.87962 .221 L
.88073 .22107 L
.88203 .2212 L
.88276 .2213 L
.88345 .22141 L
.88603 .22198 L
.88875 .22283 L
.89122 .22381 L
.89676 .22674 L
.90163 .23013 L
.90677 .23447 L
.91599 .24407 L
.93681 .27242 L
.97477 .33268 L
.97619 .33479 L
Mfstroke
.2973 0 m
.30506 .03636 L
.34639 .21231 L
.36706 .2938 L
.3862 .36197 L
.40594 .42092 L
.4245 .46219 L
.43346 .47639 L
.43851 .4826 L
.44314 .48715 L
.44792 .49068 L
.45064 .49214 L
.45316 .49315 L
.45454 .49356 L
.45584 .49386 L
.457 .49405 L
.45827 .49417 L
.45893 .4942 L
.45965 .49421 L
.4604 .49419 L
.46111 .49414 L
.46237 .494 L
.46308 .49388 L
.46373 .49374 L
.46502 .49342 L
.46623 .49303 L
.4685 .49211 L
.47094 .49082 L
.47358 .48909 L
.47835 .4851 L
.48273 .48047 L
.49281 .46653 L
.50346 .44728 L
.54145 .35306 L
.56261 .2952 L
.58189 .24785 L
.59147 .228 L
.60189 .21007 L
.60666 .20328 L
.61173 .19711 L
.61616 .19262 L
.62082 .18884 L
.62316 .18731 L
.62572 .18593 L
.62804 .18493 L
.6302 .18422 L
.63152 .1839 L
.63276 .18366 L
.63388 .18351 L
.63509 .18341 L
Mistroke
.63641 .18338 L
.63707 .18339 L
.63781 .18343 L
.6391 .18356 L
.64031 .18374 L
.64144 .18398 L
.64267 .1843 L
.64492 .18505 L
.64913 .18706 L
.65404 .19035 L
.65859 .19429 L
.6692 .20652 L
.67917 .22147 L
.6978 .25615 L
.73642 .33736 L
.75641 .37269 L
.76647 .38643 L
.77214 .39272 L
.77749 .39763 L
.7824 .40121 L
.78499 .40274 L
.78774 .40408 L
.79004 .40498 L
.79126 .40538 L
.79258 .40574 L
.79379 .40601 L
.79489 .40621 L
.796 .40637 L
.79706 .40647 L
.79837 .40654 L
.79957 .40655 L
.80023 .40653 L
.80095 .40649 L
.80224 .40637 L
.80346 .40619 L
.80475 .40595 L
.80706 .40536 L
.80976 .40442 L
.81227 .4033 L
.81799 .39993 L
.82299 .39606 L
.82843 .39094 L
.83833 .37944 L
.85689 .35181 L
.87626 .31828 L
.89766 .28162 L
.9074 .26678 L
.9179 .25293 L
.92775 .24246 L
.93218 .23864 L
Mistroke
.93691 .23522 L
.9417 .23248 L
.94605 .23062 L
.94851 .22984 L
.94981 .22951 L
.95119 .22922 L
.95239 .22902 L
.95303 .22893 L
.95371 .22885 L
.95492 .22875 L
.95604 .22869 L
.95669 .22868 L
.95738 .22868 L
.95862 .22873 L
.95939 .22878 L
.9601 .22884 L
.96144 .22901 L
.96273 .22922 L
.96391 .22947 L
.96657 .23018 L
.9688 .23095 L
.97125 .23197 L
.97619 .23459 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00l@3oool01P3OW4P0000000000000M;l0oooo0;md0080000000<0B9cO0?ooo`3oool0]03o
ool00?80oooo00L0okmd0000001d_ol0oooo0?noM0000000M;oo0;L0oooo003c0?ooo`050?oo_`1d
04P0B7A804P0M02oool0^03oool00?@0oooo00<0W4P004Q8B000B9`0^@3oool00?80oooo00L0oono
07@00018W=l0oooo0=nLB00007@0_ooo0;L0oooo003a0?ooo`090?oOW01800000000001d_`3oool0
_g@00000000004P0W=oo0;H0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001D
0?ooo`050?noM000000000000000001d_ol0BP3oool01@2oM0000000000000000000M;oo04D0oooo
00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3o
ool0?P3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d
_ol0oooo0?ooo`0n0?ooo`030?oo_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM003
0000000307Boo`3oool0oooo01<0oooo001D0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_oooB03o
ool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0A`3oool00`2LB4P0W=oo0?ooo`040?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0
oooo0?ooo`3ogi`0B00007Boo`100?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0
0P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooa@0oooo001C0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool0C03oool00`3o_g@007Bo0?ooo`160?ooo`0309a8B02Lgol0oooo00<0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00P0
oooo00<0okmd001d_`3oool0@03oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool04`3oool005<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`1<0?ooo`030?noM000M;l0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo
0?ooo`110?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0C0?ooo`00D`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04`0oooo00<0
W4P007Boo`3oool0AP3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0@@3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo04<0oooo00<0
W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01<0oooo001C
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04@0oooo00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`030?no
M000M;l0oooo01<0oooo001C0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A`3o
ool00`3ookl0M01d0;ooo`1;0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool0A03o
ool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0
B9cO0?ooo`0C0?ooo`00E03oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooodP0oooo00<0oono07@0
M02oool0B03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol0103oool00`3ookl0M01d0;ooo`140?ooo`07
0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
503oool005@0oooo00D0oono07@000000000001809cOo`190?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0A@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02L
gol0@P3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3o
ool0@03oool01@3o_g@000000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0E
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3ooooo0000050000004`3oool004h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0@03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00X0oooo00<00000
0?ooo`3oool0?`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0:0?oo
o`030000003oool0oooo03l0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo00/0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0C03oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00d0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?ooo`800000
4`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
00h0oooo00<000000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0>0?ooo`030000003oool0oooo03/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo03T0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0i0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100
oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E
0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0>03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?oo
o`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool2000005H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000O`3o
ool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0=`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo
03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0f0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01<0oooo
00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00`3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo
00<000000?ooo`3oool0=@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0D0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool0503oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`2LB0000000000000030000
00050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00H0oooo0`00001/0000O`030000000007l0001o0=X0001o0`00000C0?ooo`00<03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300
oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo03@0
oooo00<0001o0?ooo`3oool02`3oool7000003X0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia80000
0000B9`0W4Q809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05@3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00X0oooo0P0000060?ooo`800000>03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?oo_`1d00000000
0000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01`3oool2000000/0oooo00<000000?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3o
ool0oooo01H0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`800000803oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
0380oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo0`0000020?ooo`8000007P3oool00`0007l0oooo0?ooo`1D0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo0380
oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo0P0000070?ooo`800000703oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0b0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P00
000I0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00D0001o
0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo0340oooo00D0001o0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H
0?ooo`030000003oool0oooo0340oooo00@0001o0?ooo`3oool00000703oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0`0?ooo`040000O`3oool0oooo000001`0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0I0?ooo`030000
003oool0oooo0300oooo00<0001o0?ooo`0000007P3oool2000001H0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3o
ool0000001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool0<03oool00`0007l000000?ooo`0N0?ooo`8000005`3oool0
0`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`00
07l000000?ooo`0M0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool04@3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo
02X0oooo1P00000U0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0
oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0100oooo00<0001o0?oo
o`3oool0:03oool2000000H0oooo0P00000S0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000000O`3oool0
703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0U0?ooo`800000303oool2000000h0oooo2000000:0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0]0?ooo`030000000007l0oooo01`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0903o
ool00`000000oooo0?ooo`0>0?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000O`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0
oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo0P0000070?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0001o
01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00d0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo0P00000E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0001o01/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool0:P3oool010000000oooo
0?ooo`0007lK0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0<0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`00000H0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0001o6P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`00
07l0oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo0P00000H0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo02X0
oooo00@000000?ooo`3oool0001o6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0:03oool01@000000
oooo0?ooo`3oool0001o01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0I0?oo
o`8000006@3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3ogi`0B7Bo0?ooo`0/0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`05
0000003oool0oooo0?ooo`0007l06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0A0?ooo`00803oool00`2o
M7@0_ooo0?ooo`0[0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000O0?ooo`030?noM000B9`0gooo02`0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04@3oool001`0oooo00@0oono07@00000000007Bo;P3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`020?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0A0?ooo`005`3oool00`3Ogml0gia800000002000000030000M02oool0oooo02l0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo01X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04@3oool001@0oooo00D0omnL04P0B02Lgol0gia804RLg`0e0?ooo`030000
003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0J0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool0
0`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool0
0`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0P00000C0?ooo`007`3oool00`3o
_g@0M;oo0?ooo`0/0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0503oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`00
07l0oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo000I0?ooo`090?oo_`1d000000000000
0018W=l0oooo0?oog`2LM9`0gooo02`0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`060?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool001T0oooo00D0oono
09bLg`3oool0oknL09cOo`020?ooo`030=nLW02oool0oooo02/0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3o
ool001T0oooo00T0oono09bLg`3oool0giad09cOo`3oool0oooO09adW03Oool0;03oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool05P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0A0?ooo`00703oool01@3ooml0W4P00000000004P0W=oo02d0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
O`3oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool004<0oooo00D0okmd0000000000000000
07Boo`060?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0140oooo00130?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo1@3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3o
ool0503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0A0?ooo`007@3oool0103o_g@000000000B02LgolQ0?ooo`03
0?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0103oool00`000000oooo0?ooo`1E0?ooo`03
0000O`3oool0oooo0240oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0080oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`00
6`3oool01@3o_g@0000000000000B9`0gooo0280oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`040?ooool00000D000000C0?ooo`006`3oool00`3o_g@004RL0=ooo`0T0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0J0?ooo`/00000
<03oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
203oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
603oool01@000000oooo0?ooo`3oool0001o01D0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00480oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo02D0oooo
1000000/0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`080?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0007l0503oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`00
@P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00@0oooo00<000000?ooo`3oool0
:@3oool3000002T0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00P0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool0001o503oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`00
@`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`D0oooo00<000000?ooo`3oool0;03oool30000
02H0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00T0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo00@000000?ooo`3oool0001o4`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3o
oml0_koO0?ooo`0Q0?ooo`050?oo_`1d000000000000B02Lgol01P3oool00`000000oooo0?ooo`0_
0?ooo`800000903oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool02@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0000O`0C0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo000O0?oo
o`030?oog`2LB7@0_ooo02`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?oo
o`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0001o0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool001L0oooo00<0gmoO0?noM000
00000`0000001@18W=l0oooo0?ooo`2oW9`0gooo02`0oooo00<000000?ooo`3oool0<P3oool20000
0240oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01T0oooo00<000000000O`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`005`3oool00`3OW4P0
07Bo0?ooo`020?ooo`050=nLB01d_ol0oooo0?oOW018M;l0;@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01P0oooo00<000000000O`3oool0403oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`006`3oool01P2oM000B9cO0?ooo`3ogi`0B01d0;ooobd0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
01X0oooo00H0_g@007Boo`2oM00000000018W03Oool^0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`005P3oool00`3ooml0gknL04P00003
0000000307Boo`3oool0oooo02l0oooo0P00000h0?ooo`030000003oool0oooo01/0oooo00<0001o
0?ooo`3oool0903oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0001o
0?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<0001o
0000003oool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo0P00000C
0?ooo`005`3oool00`2oW9`0gooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool06P3oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0603oool00`0007l000000?ooo`0=0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01T0oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00`0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01L0oooo00<0001o0?ooo`000000303oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool001l0oooo00<0okmd07Boo`3oool0
;03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`000000
303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
4@3oool001T0oooo00T0oono07@000000000000004RLg`3oool0oooO09adW03Oool0;03oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00@0001o0?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool0
01T0oooo00D0oono09bLg`3oool0oknL09cOo`020?ooo`030=nLW02oool0oooo02/0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo02D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo00/0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`040000O`3oool0oooo000000X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000I
0?ooo`090?oo_`2LW=l0oooo0=nLM02Lgol0oooo0?oog`2LM9`0gooo02`0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo02H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0E0?ooo`050000O`3oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001`0
oooo00D0oooO09a800000000001809cOo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0503oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool05@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0V0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`090?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
503oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000@@3o
ool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0300oooo0P00000C0?ooo`00CP3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool09`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0103oool0
10000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0
oooo02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00D0oooo0P00000I0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00D0oooo0P00000H0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo00D0
oooo0P00000G0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00H0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00D0oooo
00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03@3oool2000003T0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo
02X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo
00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool04@3oool004h0oooo0P0000180?ooo`030000003oool0oooo00/0
oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140
oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00d0
oooo00D0001o0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0>@3oool2000001<0oooo001>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0303oool0100007l0oooo0?ooo`00000<0?ooo`<000001@3oool3000003d0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0:0?ooo`03
0000O`3oool0oooo02/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0;0?ooo`03
0000O`3oool0000000l0oooo1P0000100?ooo`030000003oool0oooo0140oooo001>0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0/0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`030?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool2000005H0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`080?ooo`030000O`3o
ool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00<0oooo00<000000?ooo`3oool0>P3oool2000000T0oooo00<000000000O`3oool0EP3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00P0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`<000001@3oool3
000000030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo0080oooo00<000000?oo
o`3oool0?`3oool5000000<0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D0001o0?ooo`3o
ool0oooo0000001:0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo02d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`050000O`3oool0oooo0?oo
o`000000BP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0^0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool01@0007l0oooo0?ooo`3oool00000
04X0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0;P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00@0001o0?ooo`3oool00000B`3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000CP3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`040000O`3oool0oooo000004/0oooo00<0001o0?ooo`3oool0E03oool20000
01<0oooo001>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0103oool00`0007l0
oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`0007l0
oooo0000001<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo0300oooo
00D000000?ooo`3oool0oooo0000000G0?ooo`030000O`3oool0000004`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000001L0
oooo00<0001o0000003oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0a0?ooo`030000003oool0000001P0oooo00<0001o0000003oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0a0?ooo`030000003oool0000001P0oooo00<0
001o0000003oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a
0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM000
0000000000<0000000<007Bo0?ooo`3oool00`3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0080oooo00<0001o0?ooo`3oool0<P3oool2000001P0oooo00<000000?ooo`3oool0C03o
ool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool0001o03@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool0001o03@0
oooo0P00000G0?ooo`030000000007l0oooo04d0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`040000003oool0oooo0000Oc@0
oooo0P00000G0?ooo`030000000007l0oooo04d0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool300000580001o00<000000000O`0007l0=00007l010000000001o
0000O`00000E0000O`030000000007l0001o0:@0001o0`00000C0?ooo`00<03oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0001o03<0oooo00@000000?ooo`3oool000005@3oool00`000000
oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300oooo
00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0000O`0b0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0007m>0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool00340oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?oo
o`050=nLB000000004RL09a8B02Lgol01`3oool00`000000oooo0?ooo`1D0?ooo`030000000007l0
oooo0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0007l0CP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a
0?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003o
ool0oooo05@0oooo00<000000000O`3oool0<@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0000003oool0;`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`1<0?oo
o`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0000000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool2000000L0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`000000
;P3oool00`000000oooo0?ooo`090?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool2000005H0oooo00@0001o0?ooo`3oool00000;03oool00`000000oooo0?ooo`0<0?ooo`H00000
2P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`040000O`3oool0oooo000002`0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0E@3oool01@0007l0oooo0?ooo`3oool0000002/0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool01@0007l0oooo0?oo
o`3oool0000002X0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`1<0?ooo`030000
O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool07`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0803oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?oo
o`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0240oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool09P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0W0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000
O`3oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool02`3oool2000002/0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool3000000H0
oooo0P00000^0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01H0oooo
1P00000`0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo
0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?oo
o`8000004`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`1<0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00340oooo
00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00<0oooo00<0oono07@00000
0000100000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo
00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo000`0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0
001809cOo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00300oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00L0oooo
o`00001@000001<0oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3o
ool00`2LB000B9cO0?ooo`3o0?ooofP0oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`3o0?ooofL0oooo000`0?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo
0?l0ooooI`3oool00340oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`3o0?ooofP0oooo000a0?ooo`050?oo_`1d000000000000B02Lgol0
3@3oool01@3o_g@000000000000004P0W=oo0?l0ooooJ@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool008T0oooo00D0W4P0000000000000001809cOo`3o0?ooob<0oooo002:0?ooo`030;md001d_ol0
oooo0?l0oooo903oool008X0oooo00<0_g@007Boo`3oool0o`3ooolT0?ooo`00P@3oool00`2LB4P0
M7A800000002000000060000M02oool0oooo0?ooo`2oM000M7Ad0`000000100004P0W=oo0?ooo`3O
W4P200000003001d_`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00`0000001@0007@0_ooo
0?ooo`3ookl0M00000@0000000D0001809cOo`3oool0oooo09a80005000000050018W03oool0oooo
0?ooo`3OW4P00`0000001@0004P0W=oo0?ooo`3oool0gia800<0000000H007Ad07@0000004P0W=oo
0?ooo`2LB005000000030018W03oool0oooo00P0oooo00<0gia8000000000000100000001@1d_ol0
oooo0?ooo`3oool0_g@000<0000000D0001d0;ooo`3oool0oooo0;md0004000000050018W03oool0
oooo0?ooo`2oM000100000000`00B9`0oooo0?ooo`020?ooo`060;md0000000000000000000007@0
_ooo0P3oool00`2LB000000000000003000000030018W03oool0oooo00T0oooo00D0_g@000000000
000000000018W0050?ooo`0809a80000000000000018W02oM000000004RLg`3OW4P2000000030018
W03oool0_g@00080000000@0B9cO0?ooo`3oool0gia80`0000000`0004P0W=oo0?ooo`020?ooo`05
0?oo_`1d0000000000000000B9`00`3oool00`2LB000000000000003000000050018W03oool0oooo
0?oo_`1d00000`000000100007@0_ooo0?ooo`3OW4P2000000030018W03oool0_g@00080000000<0
B9cO0?ooo`2oM000100000000`00B9`0oooo0?ooo`160?ooo`00P@3oool00`2LB00004RL0?ooo`02
0?ooo`070?noM018W=l0oooo0?ooo`2oM000001d0;ooo`020?ooo`060?oOW018B9`0oooo0?ooo`3O
W4P0B9cO0`3oool01P2oM000M;oo0?ooo`3oool0_g@0001d_`<0oooo00<0okmd0018W03oool00P3o
ool00`3ookl0M01d0;ooo`070?ooo`030?oo_`1d07@0_ooo00@0oooo00<0gia80018W03oool00P3o
ool01P3ogi`0B01809cOo`3ookl0M01d0;ooo`80oooo00<0_g@00000M02oool0103oool00`3ookl0
M01d0;ooo`0=0?ooo`030?noM000M;l0oooo0080oooo00H0omnL04P0B02Lgol0oooo0;md0000M;l3
0?ooo`060?noM000B9`0oooo0?ooo`2oM000B9cO0`3oool01P3OW4P0B9cO0?ooo`3oool0_g@004RL
g`<0oooo00H0gia804RLg`3oool0oooo0;md0000M;l30?ooo`030?noM000B9`0oooo00<0oooo00<0
oono07@0M02oool03P3oool00`2oM000M;oo0?ooo`050?ooo`070?noM000B9`0oooo0?ooo`3OW4P0
000007Boo`020?ooo`030?noM000M;l0oooo0080oooo00H0_g@007Boo`3oool0oooo0=nLB000B9`3
0?ooo`030?oOW01804P0W=oo0080oooo00L0gia804RLg`3oool0oooo0=nLB00007@0_ooo00<0oooo
00<0oono07@0M02oool0103oool00`2oM000M;oo0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3o
_g@007Bo0`3oool01P2oM000M;oo0?ooo`3oool0_g@004RLg`<0oooo00<0gia804RLg`3oool0AP3o
ool00840oooo00<0W4Q809cOo`3oool00P3oool01P3ogi`0B4RL0?ooo`3oool0_g@007Boo`@0oooo
00D0_g@007Boo`3oool0gia804RLg`030?ooo`060;md001d_ol0oooo0?oo_`1d07@0_ooo203oool0
0`3ookl0M01d0;ooo`070?ooo`030?oo_`1d07@0_ooo00@0oooo00<0W4Q809cOo`3oool01@3oool0
0`3ookl0M01809cOo`020?ooo`030?oo_`1d07@0_ooo00@0oooo00<0oono07@0M02oool03@3oool0
0`3o_g@007Bo0?ooo`030?ooo`050;md001d_ol0oono07@0M02oool0303oool00`2oM00007Bo0?oo
o`060?ooo`060;md0000M;l0oooo0?oo_`1d07@0_ooo2@3oool00`3ookl0M01d0;ooo`0>0?ooo`03
0;md001d_ol0oooo00D0oooo00<0gia804RLg`3oool00P3oool01P2oM000M;oo0?ooo`3oool0okmd
001d_`<0oooo00H0_g@007Boo`3oool0oooo09a8B02Lgol80?ooo`030=nLB018W=l0oooo00L0oooo
00<0oono07@0M02oool00`3oool00`3ookl0M4RL0?ooo`040?ooo`0509a8B02Lgol0oooo0?noM000
M;l00`3oool00`2oM000M;oo0?ooo`060?ooo`030;md0000M;l0oooo04H0oooo00260?ooo`0609a8
0000M;l0oooo0?ooo`2oM000B9cO103oool01@2oM4P0W=oo0?ooo`3OW4P0B9cO00<0oooo00D0_g@0
07Boo`3oool0oono07@00005000000070018W03oool0oooo0?ooo`3ookl0M01d0;ooo`070?ooo`03
0?oo_`1d07@0_ooo00@0oooo00<0W4Q809cOo`3oool01P3oool00`3ogi`0B0000000000200000003
0000M02oool0oooo00<0oooo00<0oono07@0M02oool03@3oool00`3o_g@007Bo0?ooo`020?ooo`05
0=nLB00007@0_ooo0?oo_`1d00001@0000001@00B9`0oooo0?ooo`3oool0W4P000<0000000<004RL
0?ooo`3oool00P3oool01@2LB000000000000000000004RL0080oooo00<0oono07@0000000001000
00000`00B9`0oooo0?ooo`020?ooo`030?oo_`1d07@0_ooo00h0oooo00D0_g@007Boo`3oool0W4Q8
09cOo`030?ooo`030=nLB018W=l0oooo0080oooo00H0_g@007Boo`3oool0oooo0?noM000M;l30?oo
o`060;md001d_ol0oooo0?ooo`2LB4P0W=oo203oool00`3OW4P0B9cO0?ooo`070?ooo`030?oo_`1d
07@0_ooo00<0oooo00<0oono07A8W03oool0103oool01@2LB4P0W=oo0?ooo`3o_g@007Bo00<0oooo
00<0_g@007Boo`3oool00P3oool01@2LB000000000000000000004RL04P0oooo00220?ooo`050=nL
B0000000000000000018W=l00`3oool00`2oM000000007Boo`020?ooo`070=nLB000B9`0oooo0?oo
o`3OW4P0000004RLg`020?ooo`0609a8001d_ol0oooo0?ooo`2oM000M;oo0`3oool00`2LB000B9cO
0?ooo`020?ooo`040?oo_`1d0000000007Boo`H0oooo00<0oono07@0M02oool0103oool00`3OW4P0
001d0;ooo`020?ooo`060;md000007@0_ooo0?ooo`3ookl0_koo0P3oool00`3ogi`0B01d0;ooo`04
0?ooo`030?oo_`1d07@0_ooo00d0oooo00<0okmd0000000000000P0000001P00B9`0oooo0?ooo`3o
ool0_g@007Boo`<0oooo00H0W4P004RLg`3oool0oooo0?noM000M;l20?ooo`030?oo_`1d0000B9cO
0080oooo00L0okmd001d_`3oool0oooo0?oo_`1d0000B9cO0080oooo00<0_g@007Boo`3oool00P3o
ool00`2LB000B9cO0?ooo`030?ooo`030?oo_`1d07@0_ooo00h0oooo00D0_g@00000000000000018
09cOo`030?ooo`030=nLB018W=l0oooo0080oooo00L0_g@007Boo`3oool0oooo0?noM0000000M;oo
0080oooo00L0W4P007Boo`3oool0oooo0=nLB00007@0_ooo0080oooo00<0_g@00000M02oool00P3o
ool00`3OW4P0B9cO0?ooo`070?ooo`030?oo_`1d07@0_ooo00@0oooo00<0_g@00018W03oool00P3o
ool01`2oM00007Bo0?ooo`3oool0okmd0000001d_ol00P3oool01P2LB000M;oo0?ooo`3oool0okmd
001d_`80oooo00<0oono07@00018W=l0A`3oool00840oooo00<0gia80018W03oool00P3oool01`3o
_g@007Bo0?ooo`2LB000000007Bo_`1d00000P0000001`00B9`0oooo0?ooo`3oool0gia804RLg`2L
B0000P0000001P00M;l0oooo0?ooo`3oool0oono07@000<0000000T0B9cO0?ooo`3oool0oooo0=nL
B0000000001d0;oo_`1d00000P0000001`1d_ol0oooo0?oOW018000000000000M02oool01@3oool0
2P3o_g@0000000000000000007Ad07@0M02oool0oooo0?oOW0180002000000030000B02Lgol0oooo
00@0oooo00<0oono07@0M02oool03@3oool00`3o_g@007Bo0?ooo`020?ooo`060=nLB018W=l0oooo
0?ooo`3ookl0M0000`0000000`18W=l0oooo0?ooo`020?ooo`060;md0000000000000000001dM7@0
B9cO0`3oool01P2oM0000000000000000000M7Ad04RLg`80oooo00<0oono07@0000000000P000000
0`18W=l0oooo0?ooo`030?ooo`030?oo_`1d07@0_ooo00h0oooo01@0_g@007Boo`3oool0W4Q809cO
o`3o_g@007Bo0=nLB0000000B9cO0?ooo`3ogi`0B0000000001d_ol0oooo0=nLB000000007Ad07@0
0080000000<007Bo0?ooo`3oool00P3oool02@3o_g@0000000000000000007Ad07@0M02oool0omnL
04P00004000000090000B02Lgol0oooo0?ooo`3ogi`0B0000000000007@0_ooo00D0oooo00D0gia8
0000000000000000001d_`020?ooo`040=nLB000000007Ad07@00080000000<007Bo0?ooo`3oool0
0P3oool01P2oM0000000000000000000M7Ad04RLgdL0oooo00210?ooo`070?noM000B9`0oooo0?oo
o`3ookl0M000001d_`0;0?ooo`030=nLB018W=l0oooo03D0oooo00<0oono07@0M02oool03@3oool0
0`3o_g@007Bo0?ooo`020?ooo`030=nLB000M;l0oooo02L0oooo00<0oono07@0M02oool03P3oool0
0`2oM000M;oo0?ooo`020?ooo`030?noM000M;l0oooo01`0oooo00<0gia804RLg`3oool0KP3oool0
0880oooo00H0gia8000000000000000007AdM000M;l;0?ooo`030=nLB018W=l0oooo03D0oooo00<0
oono07@0M02oool0303oool00`3OW4P0000000000003000000030018W03oool0oooo02L0oooo00<0
oono07@0M02oool03@3oool00`2oM00000000000000400000003001d_`3oool0oooo01/0oooo00<0
gia804RLg`3oool0KP3oool00980oooo00<0gia800000018W=l06`3oool00`3o_g@0001d0;ooo`0F
0?ooo`050?oOW018000000000000M02oool0>P3oool01@3ogi`0B0000000000007@0_ooo03`0oooo
00<0okmd0000M02oool0I03oool00;00oooo00<0okmd0000M02oool0UP3oool00`3o_g@0001d0;oo
o`1T0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-5.4479, -0.270811, \
0.094377, 0.00290868}}]
}, Closed]],

Cell["\<\
Finally, if we want the default options to use arguments of the function when \
it is evaluated, it is better to define our own version of the options list \
using delayed assignment and pattern arguments.  In the example below the \
Bessel function order is included in the default plot and frame labels by \
using an options list that is evaluated with the plotting function.  You can, \
of course, override the defaults by including appropriate replacement rules \
in the argument list.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(ClearAll[plotsbess];\)\(\n\)
    \)\), "\n", 
    \(\(options[plotsbess, 
          n_] := \ {PlotLabel \[Rule] "\<Spherical Bessel Functions for \
\[ScriptL]=\>" <> ToString[n], \ Frame \[Rule] True, \ 
          FrameLabel \[Rule] {"\<x\>", {Subscript[\[ScriptJ], n], 
                Subscript[\[ScriptY], n]}}, \ 
          GridLines \[Rule] Automatic};\)\ \n\), "\n", 
    \(plotsbess[n_, xmin_, xmax_, opts___Rule] := \ 
      With[{defaults = options[plotsbess, n]}, 
        Plot[{sbessj[n, x], sbessy[n, x]}, {x, xmin, xmax}, opts, \ 
          defaults]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20, 
        PlotRange \[Rule] {Automatic, {\(-0.2\), 0.2}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5625 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -22.0625 ]
[-0.01875 .30902 -24 22.0625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -102.906 0 ]
[.5 .63053 102.906 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .15451 m
1 .15451 L
s
0 .30902 m
1 .30902 L
s
0 .46353 m
1 .46353 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
[(-0.1)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.1)] -0.0125 .46353 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .12361 m
.00375 .12361 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .27812 m
.00375 .27812 L
s
0 .33992 m
.00375 .33992 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .49443 m
.00375 .49443 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -113.344 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
83.0625 10.2813 translate
90 rotate
-83.0625 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
73.438 14.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
78.125 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.875 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
92.438 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.125 12.813 moveto
(<) show
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46353 m
1 .46353 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -163.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Spherical) show
123.000 12.813 moveto
(Bessel) show
165.000 12.813 moveto
(Functions) show
225.000 12.813 moveto
(for) show
249.000 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
({) show
252.813 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
258.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
264.813 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04396 .30902 L
.04519 .30902 L
.04654 .30902 L
.04797 .30902 L
.05038 .30902 L
.05174 .30903 L
.05302 .30903 L
.0554 .30904 L
.05757 .30904 L
.06007 .30905 L
.06244 .30907 L
.06486 .30909 L
.06753 .30911 L
.07031 .30914 L
.07293 .30918 L
.0776 .30928 L
.08263 .30942 L
.08821 .30964 L
.09408 .30997 L
.09909 .31035 L
.10458 .31088 L
.10986 .31154 L
.11485 .31231 L
.12419 .31422 L
.13424 .3171 L
.14514 .3214 L
.15461 .3263 L
.16502 .33312 L
.18606 .35207 L
.20551 .37613 L
.2264 .40859 L
.26768 .48503 L
Mistroke
.28831 .52238 L
.29835 .53848 L
.30744 .55127 L
.31634 .56174 L
.32596 .57037 L
.33126 .5738 L
.33358 .57498 L
.33612 .57605 L
.33853 .57683 L
.34077 .57736 L
.34201 .57756 L
.34314 .5777 L
.34445 .57779 L
.34568 .57781 L
.34683 .57778 L
.34806 .57769 L
.34922 .57754 L
.35029 .57735 L
.35147 .5771 L
.35276 .57674 L
.35536 .57583 L
.35794 .57463 L
.36068 .57305 L
.36563 .56938 L
.37061 .56463 L
.37529 .55918 L
.38406 .54651 L
.40412 .50608 L
.42258 .45697 L
.46204 .33218 L
.48187 .27104 L
.49998 .22327 L
.50931 .20304 L
.51946 .18512 L
.52503 .17727 L
.53019 .17131 L
.53513 .16682 L
.53768 .16497 L
.54037 .16337 L
.5427 .16228 L
.54393 .16181 L
.54525 .16139 L
.54646 .16108 L
.54756 .16086 L
.54867 .16071 L
.54972 .16062 L
.55095 .16058 L
.55224 .16062 L
.55335 .16072 L
.55456 .1609 L
Mistroke
.55587 .16117 L
.55728 .16156 L
.55982 .1625 L
.56216 .16364 L
.56471 .16517 L
.56936 .16874 L
.57809 .178 L
.58842 .1929 L
.59778 .2096 L
.61875 .255 L
.63964 .30513 L
.65884 .349 L
.6776 .38438 L
.68705 .39806 L
.69237 .40434 L
.69741 .40927 L
.7023 .41308 L
.70488 .4147 L
.70762 .41611 L
.70992 .41705 L
.71115 .41746 L
.71246 .41784 L
.71367 .41812 L
.71477 .41832 L
.71582 .41846 L
.71693 .41857 L
.71825 .41862 L
.71944 .41861 L
.7201 .41858 L
.72081 .41852 L
.72211 .41837 L
.72333 .41816 L
.72462 .41787 L
.72693 .41719 L
.72962 .41613 L
.73213 .41488 L
.73785 .41113 L
.74284 .40687 L
.74827 .40125 L
.75816 .38864 L
.7767 .35842 L
.79807 .31779 L
.81742 .28142 L
.82736 .26463 L
.83785 .24923 L
.84756 .23759 L
.85662 .22935 L
.86107 .2263 L
.86583 .22378 L
.86854 .2227 L
Mistroke
.87111 .22192 L
.87341 .22142 L
.87472 .22122 L
.87592 .22109 L
.87711 .22101 L
.8784 .22097 L
.87962 .221 L
.88073 .22107 L
.88203 .2212 L
.88276 .2213 L
.88345 .22141 L
.88603 .22198 L
.88875 .22283 L
.89122 .22381 L
.89676 .22674 L
.90163 .23013 L
.90677 .23447 L
.91599 .24407 L
.93681 .27242 L
.97477 .33268 L
.97619 .33479 L
Mfstroke
.2973 0 m
.30506 .03636 L
.34639 .21231 L
.36706 .2938 L
.3862 .36197 L
.40594 .42092 L
.4245 .46219 L
.43346 .47639 L
.43851 .4826 L
.44314 .48715 L
.44792 .49068 L
.45064 .49214 L
.45316 .49315 L
.45454 .49356 L
.45584 .49386 L
.457 .49405 L
.45827 .49417 L
.45893 .4942 L
.45965 .49421 L
.4604 .49419 L
.46111 .49414 L
.46237 .494 L
.46308 .49388 L
.46373 .49374 L
.46502 .49342 L
.46623 .49303 L
.4685 .49211 L
.47094 .49082 L
.47358 .48909 L
.47835 .4851 L
.48273 .48047 L
.49281 .46653 L
.50346 .44728 L
.54145 .35306 L
.56261 .2952 L
.58189 .24785 L
.59147 .228 L
.60189 .21007 L
.60666 .20328 L
.61173 .19711 L
.61616 .19262 L
.62082 .18884 L
.62316 .18731 L
.62572 .18593 L
.62804 .18493 L
.6302 .18422 L
.63152 .1839 L
.63276 .18366 L
.63388 .18351 L
.63509 .18341 L
Mistroke
.63641 .18338 L
.63707 .18339 L
.63781 .18343 L
.6391 .18356 L
.64031 .18374 L
.64144 .18398 L
.64267 .1843 L
.64492 .18505 L
.64913 .18706 L
.65404 .19035 L
.65859 .19429 L
.6692 .20652 L
.67917 .22147 L
.6978 .25615 L
.73642 .33736 L
.75641 .37269 L
.76647 .38643 L
.77214 .39272 L
.77749 .39763 L
.7824 .40121 L
.78499 .40274 L
.78774 .40408 L
.79004 .40498 L
.79126 .40538 L
.79258 .40574 L
.79379 .40601 L
.79489 .40621 L
.796 .40637 L
.79706 .40647 L
.79837 .40654 L
.79957 .40655 L
.80023 .40653 L
.80095 .40649 L
.80224 .40637 L
.80346 .40619 L
.80475 .40595 L
.80706 .40536 L
.80976 .40442 L
.81227 .4033 L
.81799 .39993 L
.82299 .39606 L
.82843 .39094 L
.83833 .37944 L
.85689 .35181 L
.87626 .31828 L
.89766 .28162 L
.9074 .26678 L
.9179 .25293 L
.92775 .24246 L
.93218 .23864 L
Mistroke
.93691 .23522 L
.9417 .23248 L
.94605 .23062 L
.94851 .22984 L
.94981 .22951 L
.95119 .22922 L
.95239 .22902 L
.95303 .22893 L
.95371 .22885 L
.95492 .22875 L
.95604 .22869 L
.95669 .22868 L
.95738 .22868 L
.95862 .22873 L
.95939 .22878 L
.9601 .22884 L
.96144 .22901 L
.96273 .22922 L
.96391 .22947 L
.96657 .23018 L
.9688 .23095 L
.97125 .23197 L
.97619 .23459 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00l@3oool01P3OW4P0000000000000M;l0oooo0;md0080000000<0B9cO0?ooo`3oool0]03o
ool00?80oooo00L0okmd0000001d_ol0oooo0?noM0000000M;oo0;L0oooo003c0?ooo`050?oo_`1d
04P0B7A804P0M02oool0^03oool00?@0oooo00<0W4P004Q8B000B9`0^@3oool00?80oooo00L0oono
07@00018W=l0oooo0=nLB00007@0_ooo0;L0oooo003a0?ooo`090?oOW01800000000001d_`3oool0
_g@00000000004P0W=oo0;H0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001D
0?ooo`050?noM000000000000000001d_ol0BP3oool01@2oM0000000000000000000M;oo04D0oooo
00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3o
ool0?P3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d
_ol0oooo0?ooo`0n0?ooo`030?oo_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM003
0000000307Boo`3oool0oooo01<0oooo001D0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_oooB03o
ool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0A`3oool00`2LB4P0W=oo0?ooo`040?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0
oooo0?ooo`3ogi`0B00007Boo`100?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0
0P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooa@0oooo001C0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool0C03oool00`3o_g@007Bo0?ooo`160?ooo`0309a8B02Lgol0oooo00<0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00P0
oooo00<0okmd001d_`3oool0@03oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool04`3oool005<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`1<0?ooo`030?noM000M;l0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo
0?ooo`110?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0C0?ooo`00D`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04`0oooo00<0
W4P007Boo`3oool0AP3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0@@3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo04<0oooo00<0
W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01<0oooo001C
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04@0oooo00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`030?no
M000M;l0oooo01<0oooo001C0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A`3o
ool00`3ookl0M01d0;ooo`1;0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool0A03o
ool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0
B9cO0?ooo`0C0?ooo`00E03oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooodP0oooo00<0oono07@0
M02oool0B03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol0103oool00`3ookl0M01d0;ooo`140?ooo`07
0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
503oool005@0oooo00D0oono07@000000000001809cOo`190?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0A@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02L
gol0@P3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3o
ool0@03oool01@3o_g@000000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0E
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3ooooo0000050000004`3oool004h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0@03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00X0oooo00<00000
0?ooo`3oool0?`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0:0?oo
o`030000003oool0oooo03l0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo00/0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0C03oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00d0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?ooo`800000
4`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
00h0oooo00<000000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0>0?ooo`030000003oool0oooo03/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo03T0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0i0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100
oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E
0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0>03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?oo
o`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool2000005H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000O`3o
ool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0=`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo
03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0f0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01<0oooo
00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00`3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo
00<000000?ooo`3oool0=@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0D0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool0503oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`2LB0000000000000030000
00050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00H0oooo0`00001/0000O`030000000007l0001o0=X0001o0`00000C0?ooo`00<03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300
oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo03@0
oooo00<0001o0?ooo`3oool02`3oool7000003X0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia80000
0000B9`0W4Q809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05@3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00X0oooo0P0000060?ooo`800000>03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?oo_`1d00000000
0000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01`3oool2000000/0oooo00<000000?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3o
ool0oooo01H0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`800000803oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
0380oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo0`0000020?ooo`8000007P3oool00`0007l0oooo0?ooo`1D0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo0380
oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo0P0000070?ooo`800000703oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0b0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P00
000I0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00D0001o
0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo0340oooo00D0001o0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H
0?ooo`030000003oool0oooo0340oooo00@0001o0?ooo`3oool00000703oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0`0?ooo`040000O`3oool0oooo000001`0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0I0?ooo`030000
003oool0oooo0300oooo00<0001o0?ooo`0000007P3oool2000001H0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3o
ool0000001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool0<03oool00`0007l000000?ooo`0N0?ooo`8000005`3oool0
0`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`00
07l000000?ooo`0M0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool04@3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo
02X0oooo1P00000U0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0
oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0100oooo00<0001o0?oo
o`3oool0:03oool2000000H0oooo0P00000S0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool001T0oooo00<0omnL04Q8W03Oool0
<P3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0
;@3oool00`000000001o0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02D0oooo0P00000<0?ooo`800000
3P3oool8000000X0oooo00<000000?ooo`3oool04@3oool001@0oooo00<0oooO09a8000000000P00
00000`0007@0_kmd00000003000000030000B02Lgol0oooo02`0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000000O`3oool0703o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo0P00000:0?ooo`800000203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo000D0?ooo`030?oOW01dW=l0
oooo00P0oooo00<0omnL04Qd_`3oool0;03oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000O`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0
oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo0P0000070?ooo`030000003oool0oooo0140oooo000D0?ooo`030?noM01d_ol0oooo
00P0oooo00<0oooO09adW03Oool0;03oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000O`0L0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo
0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`8000005@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01`0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000O`0K0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo0240
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0001o6`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`0007l0
oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool00000603oool00`00
0000oooo0?ooo`0A0?ooo`007`3oool00`3ogi`0B7Bo0?ooo`0/0?ooo`800000EP3oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0001o6P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`00
07l0oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo0P00000H0?ooo`8000004`3oool00200
oooo00<0_gAd0;ooo`3oool0:`3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01`0
oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`0007lJ0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0140oooo000O0?ooo`030?noM000B9`0gooo02`0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo0000O`0I0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?oo
o`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool06@3oool2000001T0oooo00<000000?oo
o`3oool04@3oool001`0oooo00@0oono07@00000000007Bo;P3oool00`000000oooo0?ooo`1E0?oo
o`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0
001o01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00X0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0
oooo000001P0oooo00<000000?ooo`3oool04@3oool001L0oooo00<0gmoO0=nLB00000000P000000
0`0007@0_ooo0?ooo`0_0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool05P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool0
0`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000D0?ooo`050?oOW01804P0W=oo
0=nLB018W=l0=@3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01d0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo01H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<0001o
0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?oo
o`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?oo
o`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3o
ool06P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3o_g@0M;oo0?ooo`0/0?ooo`030000
003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0J0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo000I0?ooo`090?oo_`1d0000000000000018W=l0oooo0?oog`2LM9`0gooo
02`0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool001T0oooo00D0oono09bLg`3oool0oknL09cOo`020?oo
o`030=nLW02oool0oooo02/0oooo0P00001F0?ooo`030000O`3oool0oooo01l0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0403oool2000001<0oooo000I0?ooo`090?oo_`2LW=l0oooo0=nLM02Lgol0oooo0?oog`2L
M9`0gooo02`0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0O0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0D0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`060?ooo`030000O`3o
ool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool001`0oooo00D0oooO09a800000000001809cO
o`0]0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?oo
o`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<0001o
0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3o
ool04P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0103oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo000M0?ooo`040?no
M0000000001809cOobd0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0B0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`03
0000O`3oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool001/0oooo00D0okmd000000000000
04RL0=ooo`0S0?ooo`050?noM000000000000000001d_ol01P3oool00`000000oooo0?ooo`1E0?oo
o`030000O`3oool0oooo0240oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?oo
o`030000O`3oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?oo
o`006`3oool00`3o_g@004RL0=ooo`0U0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo1@3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool0503oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0A0?ooo`00@P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo
00@0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo
01@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool04@3oool00480oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`040?ooool00000D000000C0?ooo`00@P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?no
M000M;l0oooo00@0oooo00<000000?ooo`3oool06P3oool;00000300oooo00<0001o0?ooo`3oool0
8P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0
403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0
oooo0000O`0E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00120?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0U0?ooo`@00000;03oool00`0007l0oooo
0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool00`0007l0oooo
0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0603oool01@000000oooo
0?ooo`3oool0001o01@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00480oooo00<0okmd04RLg`3oool0
0P3oool00`3OW4P0B9cO0?ooo`040?ooo`030000003oool0oooo02T0oooo0`00000Y0?ooo`030000
O`3oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000
O`3oool0oooo00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`040000
003oool0oooo0000Oa@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool004<0oooo00H0W4P007Boo`3oool0
omnL04P0M02oool50?ooo`030000003oool0oooo02`0oooo0`00000V0?ooo`030000O`3oool0oooo
0280oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo
00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo
0000Oa<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool04@3oool004<0oooo00D0oono07@000000000001809cOo`06
0?ooo`030000003oool0oooo02l0oooo0P00000T0?ooo`030000O`3oool0oooo02<0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo00l0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0001o01<0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?oo
o`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0001o0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3o
ool0<P3oool200000240oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01T0oooo00<000000000O`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00
7`3oool00`3ooml0_koO0?ooo`0/0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
2P3oool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
603oool00`000000001o0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo000O0?ooo`030?oog`2L
B7@0_ooo02`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo02@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000O`3o
ool0oooo00d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool001L0oooo00<0gmoO0?noM00000000`000000
1@18W=l0oooo0?ooo`2oW9`0gooo02`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0;0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0140oooo000G0?ooo`030=nLB000M;l0oooo0080oooo00D0gia8
07Boo`3oool0omnL04Qd_`0]0?ooo`800000>03oool00`000000oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`030000O`00
0000oooo00d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`8000004`3o
ool001/0oooo00H0_g@004RLg`3oool0omnL04P0M02oool]0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool06P3oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0603oool00`0007l000000?ooo`0=0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`006P3oool01P2oM000M;oo0;md
0000000004RL0=ooobh0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0I0?ooo`03
0000O`3oool0oooo02D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`03
0000O`3oool0000000`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0140oooo000F0?ooo`030?oog`3O_i`0B00000<0000000<0M;oo0?ooo`3oool0
;`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`000000
303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
4@3oool001L0oooo00<0_ibL0=ooo`3oool0=03oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01L0oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00`0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01H0oooo00@0001o0?ooo`3oool000002P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool001l0oooo00<0okmd07Boo`3oool0;03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool09@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00@0001o0?ooo`3oool00000
2P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
4@3oool001T0oooo00T0oono07@000000000000004RLg`3oool0oooO09adW03Oool0;03oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool09P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool02P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo00D0001o0?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A
0?ooo`006@3oool01@3ookl0W9cO0?ooo`3o_i`0W=oo0080oooo00<0gibL0;ooo`3oool0:`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool09P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool02P3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0A0?ooo`006@3oool02@3ookl0W9cO0?ooo`3OW7@0W=oo0?ooo`3ooml0W7BL
0=ooo`0/0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0503oool00`0007l0oooo
0?ooo`0V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo
0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool00`0007l0oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo0140oooo000L0?ooo`050?oog`2LB00000000000B02Lgol0
;@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0
9`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0A0?ooo`00CP3oool200000440oooo00<000000?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04`3o
ool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0`0?ooo`8000004`3oool004h0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo00@0oooo00@000000?ooo`3oool00000603o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`050?ooo`8000006@3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0140oooo000D0?ooo`030?noM01d_ol0oooo
00P0oooo00<0oooO09adW03Oool0;03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00l0oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00l0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0180oooo00<0001o0?ooo`3oool01@3oool2000001P0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0A0?ooo`00503oool00`3ogi`0M9cO0?ooo`080?ooo`030?oOW018M;l0oooo02`0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo00D0
oooo0P00000G0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool001@0oooo
00<0oooO09a8000000000P0000000`0007@0_mnL04P00003000000030000B02Lgol0oooo02`0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00H0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00D0oooo
00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo
000I0?ooo`030?oOW018B9`0gooo0380oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0=0?ooo`030000O`3oool0oooo02T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0@0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0@0?ooo`030000O`3oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo02T0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0
oooo02X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0
oooo00D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`800000>@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00`0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0140oooo00<0001o0?ooo`3oool01@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00h0oooo00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000004P0
oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool03@3oool01@0007l0oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0i0?ooo`8000004`3oool004h0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo02/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0<0?ooo`040000O`3oool0oooo000000`0oooo0`0000050?oo
o`<00000?@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo00X0oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0180oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00/0oooo00<0001o0?ooo`0000003`3oool600000400oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`090?ooo`030000
O`3oool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`800000
EP3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo00P0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0180oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0j0?ooo`8000002@3o
ool00`000000001o0?ooo`1F0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0/0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo03`0oooo0`0000050?ooo`<0000000<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<0001o0?oo
o`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`D000000`3oool00`0007l0oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04`3oool01@0007l0oooo0?ooo`3oool0000004X0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0
oooo00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0
oooo00D0001o0?ooo`3oool0oooo0000001:0?ooo`030000O`3oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`03
0000O`3oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`05
0000O`3oool0oooo0?ooo`000000BP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool01@3oool00`0007l0
oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool0100007l0
oooo0?ooo`00001;0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo0P00001>0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0;`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@0001o0?ooo`3oool00000B`3oool00`00
07l0oooo0?ooo`1D0?ooo`8000004`3oool004h0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`040?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`030000O`3oool0000004`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00@0oooo
00<0001o0?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000001L0oooo00<0001o0?ooo`00
0000C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0`0?ooo`050000
003oool0oooo0?ooo`0000005`3oool00`0007l000000?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`030?ooo`030000O`3oool0oooo0340oooo00<000000?ooo`000000603oool00`0007l00000
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo0340oooo00<0
00000?ooo`000000603oool00`0007l000000?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool00340oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000
000007Bo00@0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`030?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0b0?ooo`800000603o
ool00`000000oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`00
07l0=03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00<03oool00`3o_g@007Bo0?ooo`020?ooo`030=nL
B018W=l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`050000
003oool0oooo0?ooo`0007l0=03oool2000001L0oooo00<000000000O`3oool0C@3oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo0580oooo
00@000000?ooo`3oool0001o=03oool2000001L0oooo00<000000000O`3oool0C@3oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo
00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`<00000DP0007l00`000000001o
0000O`0d0000O`040000000007l0001o000001D0001o00<000000000O`0007l0Y00007l3000001<0
oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo
0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`0007l0<`3oool010000000oooo
0?ooo`00000E0?ooo`030000003oool0001o04h0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0001o0380oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000Odh0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia800000000B9`0W4Q809cOo`070?ooo`030000003oool0
oooo05@0oooo00<000000000O`3oool0<@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool0oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool00340oooo00D0oono07@000000000001809cOo`0>0?ooo`030=nLB000
04P0W=oo00L0oooo00<000000?ooo`3oool0E03oool00`000000001o0?ooo`0a0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0001o04h0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l000000?ooo`0_0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0000002h0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`8000001`3oool00`0007l0oooo0?ooo`1<0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0000000^0?ooo`030000003oool0oooo00T0oooo0`0000050?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`800000EP3oool0100007l0oooo0?ooo`00000/0?ooo`030000
003oool0oooo00`0oooo1P00000:0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00@0001o0?ooo`3oool00000
;03oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`050000O`3o
ool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`050000O`3oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`0M0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0080oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0
oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0N0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00<0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0O0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo
0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00@0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E
0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0240oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?oo
o`8000004`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`1<0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`080?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool08P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0903oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool09P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0oooo00d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?oo
o`3oool0E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3o
ool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000
003oool0oooo05D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02P0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0403o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0C03o
ool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo05D0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`800000:`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0:`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0C0?ooo`<000001P3oool2000002h0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool05P3oool600000300oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?oo
o`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3o
ool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<@3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000
M;l00`3oool00`3ookl0M000000000040000000307Boo`3oool0oooo00<0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`@0oooo00<0_g@000000000M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0
B9cO0?ooo`0;0?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00`0oooo
00<0omnL04P00018W=l01`3ooooo0000050000004`3oool00300oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0>0?ooo`0309a80018W=l0oooo0?l0ooooJ03oool00300oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8M02oool0oooo0?l0ooooI`3oool0
0300oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo
0080oooo00<0_g@007Boo`3oool0o`3ooomW0?ooo`00<@3oool01P2LB000M;oo0?ooo`3ogi`0B01d
0;ooo`/0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo0?l0ooooJ03oool00340oooo00D0
oono07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol0o`3ooomY0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00I`3oool01@2LB00000000000000004P0W=oo0?l0ooooA@3o
ool006P0oooo00<0_g@007Boo`3oool0o`3ooom60?ooo`00J03oool00`2oM000M;oo0?ooo`3o0?oo
odH0oooo001O0?ooo`0309a8B01dM4P000000080000000H0001d0;ooo`3oool0oooo0;md001dM7@3
000000040000B02Lgol0oooo0=nLB080000000<007Bo0?ooo`2oM0000P0000001018W=l0oooo0?oo
o`2oM003000000050000M02oool0oooo0?oo_`1d0000100000001@0004P0W=oo0?ooo`3oool0W4P0
00D0000000D004RL0?ooo`3oool0oooo0=nLB003000000050000B02Lgol0oooo0?ooo`3OW4P00`00
00001P00M7@0M0000000B02Lgol0oooo09a800D0000000<004RL0?ooo`3oool0203oool00`3OW4P0
0000000000040000000507Boo`3oool0oooo0?ooo`2oM0000`0000001@0007@0_ooo0?ooo`3oool0
_g@000@0000000D004RL0?ooo`3oool0oooo0;md0004000000030018W03oool0oooo0080oooo00H0
_g@000000000000000000000M02oool20?ooo`0309a800000000000000<0000000<004RL0?ooo`3o
ool02@3oool01@2oM000000000000000000004RL00D0oooo00P0W4P000000000000004RL0;md0000
0000B9cO0=nLB080000000<004RL0?ooo`2oM0000P0000001018W=l0oooo0?ooo`3OW4P300000003
0000B02Lgol0oooo0080oooo00D0oono07@00000000000000018W0030?ooo`0309a8000000000000
00<0000000D004RL0?ooo`3oool0oono07@00003000000040000M02oool0oooo0=nLB080000000<0
04RL0?ooo`2oM0000P0000000`18W=l0oooo0;md0004000000030018W03oool0oooo00X0oooo00<0
gia80000000000000`0000001@18W=l0oooo0?ooo`3ookl0M00000<0000000D0001d0;ooo`3oool0
oono07@00004000000030000B02Lgol0oooo00T0oooo00<0oooO09a8B02Lgol03@3oool01@2oM000
0000000000000000M;oo02H0oooo001O0?ooo`0309a80000B9`0oooo0080oooo00L0okmd04RLg`3o
ool0oooo0;md000007@0_ooo0080oooo00H0omnL04Q8W03oool0oooo0=nLB018W=l30?ooo`060;md
001d_ol0oooo0?ooo`2oM00007Bo0`3oool00`3o_g@004RL0?ooo`020?ooo`030?oo_`1d07@0_ooo
00L0oooo00<0oono07@0M02oool0103oool00`3OW4P004RL0?ooo`020?ooo`060?oOW01804P0W=oo
0?oo_`1d07@0_ooo0P3oool00`2oM000001d0;ooo`040?ooo`030?oo_`1d07@0_ooo00d0oooo00<0
okmd001d_`3oool00P3oool01P3ogi`0B01809cOo`3oool0_g@0001d_`<0oooo00H0okmd0018W03o
ool0oooo0;md0018W=l30?ooo`060=nLB018W=l0oooo0?ooo`2oM000B9cO0`3oool01P3OW4P0B9cO
0?ooo`3oool0_g@0001d_`<0oooo00<0okmd0018W03oool00`3oool00`3ookl0M01d0;ooo`0>0?oo
o`030;md001d_ol0oooo00D0oooo00L0okmd0018W03oool0oooo0=nLB0000000M;oo0080oooo00<0
okmd001d_`3oool00P3oool01P2oM000M;oo0?ooo`3oool0gia80018W0<0oooo00<0omnL04P0B02L
gol00P3oool01`3OW4P0B9cO0?ooo`3oool0gia80000M02oool00`3oool00`3ookl0M01d0;ooo`04
0?ooo`030;md001d_ol0oooo0080oooo00H0okmd001d_`3oool0oooo0?noM000M;l30?ooo`060;md
001d_ol0oooo0?ooo`2oM000B9cO0`3oool00`3OW4P0B9cO0?ooo`0<0?ooo`030;md001d_ol0oooo
00@0oooo00<0_g@007Boo`3oool00P3oool00`3o_g@007Bo0?ooo`020?ooo`030?oo_`1d07@0_ooo
00h0oooo00<0_ibL0=ooo`3oool00P3oool00`3OW4P00000000000030000000504RLg`3oool0oooo
0;md0000M;l00P3oool00`3ogi`0B00007Boo`0U0?ooo`00G`3oool00`2LB4P0W=oo0?ooo`020?oo
o`060?oOW018B9`0oooo0?ooo`2oM000M;oo103oool01@2oM000M;oo0?ooo`3OW4P0B9cO00<0oooo
00H0_g@007Boo`3oool0oono07@0M02oool80?ooo`030?oo_`1d07@0_ooo00L0oooo00<0oono07@0
M02oool0103oool00`2LB4P0W=oo0?ooo`050?ooo`030?oo_`1d04P0W=oo0080oooo00<0oono07@0
M02oool0103oool00`3ookl0M01d0;ooo`0=0?ooo`030?noM000M;l0oooo00<0oooo00D0_g@007Bo
o`3ookl0M01d0;ooo`0<0?ooo`030;md0000M;l0oooo00H0oooo00H0_g@0001d_`3oool0oono07@0
M02oool90?ooo`030?oo_`1d07@0_ooo00h0oooo00<0_g@007Boo`3oool01@3oool00`3OW4P0B9cO
0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@007Bo0`3oool01P2oM000M;oo0?ooo`3oool0
W4Q809cOo`P0oooo00<0gia804RLg`3oool01`3oool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1d
B9`0oooo00@0oooo00D0W4Q809cOo`3oool0okmd001d_`030?ooo`030;md001d_ol0oooo00H0oooo
00<0_g@0001d_`3oool0303oool00`2oM000M;oo0?ooo`030?ooo`030?oo_`1dB9`0oooo00@0oooo
00L0W4Q809cOo`3oool0oooo0?oo_`1d07@0_ooo00`0oooo00@0oooO09a8M01dM7@0_ooo4@3oool0
0`3o_g@007Bo0?ooo`0T0?ooo`00I03oool01P2LB00007Bo0?ooo`3oool0_g@004RLg`@0oooo00D0
_gA809cOo`3oool0gia804RLg`030?ooo`050;md001d_ol0oooo0?oo_`1d00001@0000001`00B9`0
oooo0?ooo`3oool0oono07@0M02oool01`3oool00`3ookl0M01d0;ooo`040?ooo`0309a8B02Lgol0
oooo00H0oooo00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`030?ooo`030?oo_`1d07@0
_ooo00d0oooo00<0okmd001d_`3oool00P3oool01@3OW4P0001d0;ooo`3ookl0M00000D0000000D0
04RL0?ooo`3oool0oooo09a80003000000030018W03oool0oooo0080oooo00D0W4P0000000000000
00000018W0020?ooo`030?oo_`1d0000000000@0000000<004RL0?ooo`3oool00P3oool00`3ookl0
M01d0;ooo`0>0?ooo`050;md001d_ol0oooo09a8B02Lgol00`3oool00`3OW4P0B9cO0?ooo`020?oo
o`060;md001d_ol0oooo0?ooo`3o_g@007Bo0`3oool01P2oM000M;oo0?ooo`3oool0W4Q809cOo`P0
oooo00<0gia804RLg`3oool01`3oool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1dB9`0oooo00@0
oooo00D0W4Q809cOo`3oool0okmd001d_`030?ooo`030;md001d_ol0oooo0080oooo00D0W4P00000
0000000000000018W00>0?ooo`030;md001d_ol0oooo00<0oooo00<0oono07A8W03oool0103oool0
1`2LB4P0W=oo0?ooo`3oool0oono07@0M02oool03@3oool00`3ookl0M01809cOo`0A0?ooo`030?no
M000M;l0oooo02@0oooo001P0?ooo`050=nLB0000000000000000018W=l00`3oool00`2oM0000000
07Boo`020?ooo`070=nLB000B9`0oooo0?ooo`3OW4P0000004RLg`020?ooo`0609a8001d_ol0oooo
0?ooo`2oM000M;oo0`3oool00`2LB000B9cO0?ooo`020?ooo`040?oo_`1d0000000007Boo`H0oooo
00<0oono07@0M02oool0103oool00`3OW4P0001d0;ooo`020?ooo`060;md000007@0_ooo0?ooo`3o
okl0_koo0P3oool00`3ogi`0B01d0;ooo`040?ooo`030?oo_`1d07@0_ooo00d0oooo00<0okmd0000
000000000P0000001P00B9`0oooo0?ooo`3oool0_g@007Boo`<0oooo00H0W4P004RLg`3oool0oooo
0?noM000M;l20?ooo`030?oo_`1d0000B9cO0080oooo00L0okmd001d_`3oool0oooo0?oo_`1d0000
B9cO0080oooo00<0_g@007Boo`3oool00P3oool00`2LB000B9cO0?ooo`030?ooo`030?oo_`1d07@0
_ooo00h0oooo00D0_g@0000000000000001809cOo`030?ooo`030=nLB018W=l0oooo0080oooo00L0
_g@007Boo`3oool0oooo0?noM0000000M;oo0080oooo00L0W4P007Boo`3oool0oooo0=nLB00007@0
_ooo0080oooo00<0_g@00000M02oool00P3oool00`3OW4P0B9cO0?ooo`070?ooo`030?oo_`1d07@0
_ooo00@0oooo00<0_g@00018W03oool00P3oool01`2oM00007Bo0?ooo`3oool0okmd0000001d_ol0
0P3oool01P2LB000M;oo0?ooo`3oool0okmd001d_`80oooo00<0oono07@00018W=l03@3oool00`2o
M000M;oo0?ooo`040?ooo`030;md0000B9`0oooo0080oooo00<0_g@0001d_`3oool00P3oool0103o
okl0M0000000001d_ol=0?ooo`030?oOW0180000B9cO0080oooo00<0gia80000000000000`000000
0`18W=l0oooo0?ooo`050?ooo`0309a8001d_ol0oooo02@0oooo001O0?ooo`030=nLB000B9`0oooo
0080oooo00L0okmd001d_`3oool0W4P00000001d_kl0M0000080000000L004RL0?ooo`3oool0oooo
0=nLB018W=l0W4P00080000000H007Bo0?ooo`3oool0oooo0?oo_`1d00030000000904RLg`3oool0
oooo0?ooo`3OW4P000000000M02ookl0M0000080000000L0M;oo0?ooo`3ogi`0B0000000000007@0
_ooo00D0oooo00X0okmd0000000000000000001dM01d07@0_ooo0?ooo`3ogi`0B0000P0000000`00
04P0W=oo0?ooo`040?ooo`030?oo_`1d07@0_ooo00d0oooo00<0okmd001d_`3oool00P3oool01P3O
W4P0B9cO0?ooo`3oool0oono07@000<0000000<0B9cO0?ooo`3oool00P3oool01P2oM00000000000
00000000M7Ad04RLg`<0oooo00H0_g@0000000000000000007AdM018W=l20?ooo`030?oo_`1d0000
00000080000000<0B9cO0?ooo`3oool00`3oool00`3ookl0M01d0;ooo`0>0?ooo`0D0;md001d_ol0
oooo09a8B02Lgol0okmd001d_`3OW4P0000004RLg`3oool0omnL04P000000000M;oo0?ooo`3OW4P0
0000001dM01d000200000003001d_`3oool0oooo0080oooo00T0okmd0000000000000000001dM01d
07@0_ooo0?oOW0180000100000002@0004P0W=oo0?ooo`3oool0omnL04P000000000001d0;ooo`05
0?ooo`050=nLB0000000000000000000M;l00P3oool0103OW4P00000001dM01d000200000003001d
_`3oool0oooo0080oooo00H0_g@0000000000000000007AdM018W=l;0?ooo`030=nLB00000000000
00<0000000D007Bo0?ooo`3oool0oooo0=nLB00300000009001d_`3oool0oooo0?ooo`3OW4P00000
0000M02ookl0M0000080000000<0M;oo0?ooo`3oool0203oool0103ooml0W7BL0;nLB01d_ol:0?oo
o`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0903oool005l0oooo00L0okmd0018W03o
ool0oooo0?oo_`1d000007Bo00/0oooo00<0gia804RLg`3oool0=@3oool00`3ookl0M01d0;ooo`0=
0?ooo`030?noM000M;l0oooo0080oooo00<0gia8001d_`3oool09`3oool00`3ookl0M01d0;ooo`0>
0?ooo`030;md001d_ol0oooo0080oooo00<0okmd001d_`3oool0703oool00`3OW4P0B9cO0?ooo`0d
0?ooo`030;md001d_ol0oooo0200oooo00@0giad09cOg`2LB7@0_ooo2@3oool00`3ookl0M01d0;oo
o`0Y0?ooo`00H03oool01P3OW4P00000000000000000M7Ad001d_`/0oooo00<0gia804RLg`3oool0
=@3oool00`3ookl0M01d0;ooo`0<0?ooo`030=nLB0000000000000<0000000<004RL0?ooo`3oool0
9`3oool00`3ookl0M01d0;ooo`0=0?ooo`030;md00000000000000@0000000<007Bo0?ooo`3oool0
6`3oool00`3OW4P0B9cO0?ooo`0d0?ooo`030;md0018W=l0oooo0200oooo00@0oono07A8W03O_g@0
B9cO2@3oool00`3ookl0M01d0;ooo`0Y0?ooo`00L03oool00`3OW4P0000004RLg`0K0?ooo`030?no
M00007@0_ooo01H0oooo00D0omnL04P000000000001d0;ooo`0j0?ooo`050?oOW018000000000000
M02oool0?03oool00`3o_g@0001d0;ooo`0Z0?ooo`030?oo_`1d000000000080000000<0M;oo0?oo
o`3oool0703oool00`3ogi`0B00004RLg`090?ooo`030?oo_`1d000000000080000000<0001d0;oo
o`3oool0903oool008h0oooo00<0okmd0000M02oool0UP3oool00`3o_g@0001d0;ooo`260?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-5.4479, -0.270811, \
0.094377, 0.00290868}}]
}, Closed]],

Cell["\<\
This technique of specifying default options while permitting the user \
(including yourself, of course!) to choose the options most appropriate to a \
particular application will give your functions considerable flexibility and \
versatility.  We strongly urge you to use this technique liberally.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Modifying default options for built-in functions", "Subsection"],

Cell[TextData[{
  "In the preceding example we used ",
  StyleBox["With", "InlineInput"],
  " to supply the default options because we chose to associate the options \
with our function, ",
  StyleBox["plotsbess", "InlineInput"],
  ", rather than with the built-in function ",
  StyleBox["Plot", "InlineInput"],
  ".  If we had changed the options for ",
  StyleBox["Plot", "InlineInput"],
  " instead, then it would not have been necessary to include the default \
options; however, that procedure is risky because it can affect the operation \
of the built-in function later in undesired ways.  Nevertheless, we \
illustrate the technique here for the sake of completeness ",
  StyleBox["even though we do not recommend this procedure",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell["The function ", "Text"],

Cell[TextData[{
  StyleBox["SetOptions[symbol,option1\[Rule]value1,option2\[Rule]value2,\
\[CenterEllipsis]]", "InlineInput"],
  StyleBox[" ", "InlineInput"]
}], "Text"],

Cell[TextData[{
  "sets a sequence of default options associated with a particular symbol to \
specified values.  Because ",
  StyleBox["SetOptions", "InlineInput"],
  " expects a sequence, we apply ",
  StyleBox["Sequence", "InlineInput"],
  " to the list of options we want for ",
  StyleBox["plotsbess", "InlineInput"],
  ".  Note that we save the default options for ",
  StyleBox["Plot", "InlineInput"],
  " first so that we can reset them before leaving this section.  "
}], "Text"],

Cell[BoxData[{
    \(\(saveOptions[Plot] = Options[Plot];\)\), "\n", 
    \(\(\(SetOptions[Plot, Sequence @@ Options[plotsbess]];\)\(\n\)
    \)\), "\n", 
    \(plotsbess[n_, xmin_, xmax_, opts___Rule] := \ 
      Plot[{sbessj[n, x], sbessy[n, x]}, {x, xmin, xmax}, opts]\)}], "Input"],

Cell["\<\
We now obtain a formatted plot without supplying as many options\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20, 
        PlotRange \[Rule] {Automatic, {\(-0.2\), 0.2}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5625 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -12.8438 ]
[-0.01875 .30902 -24 12.8438 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .15451 m
1 .15451 L
s
0 .30902 m
1 .30902 L
s
0 .46353 m
1 .46353 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
[(-0.1)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.1)] -0.0125 .46353 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .12361 m
.00375 .12361 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .27812 m
.00375 .27812 L
s
0 .33992 m
.00375 .33992 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .49443 m
.00375 .49443 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -104.125 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.8438 10.2813 translate
90 rotate
-73.8438 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
67.438 14.313 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
({) show
70.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
76.875 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
81.438 14.313 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
({) show
84.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46353 m
1 .46353 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Spherical) show
123.000 12.813 moveto
(Bessel) show
165.000 12.813 moveto
(Functions) show
219.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04396 .30902 L
.04519 .30902 L
.04654 .30902 L
.04797 .30902 L
.05038 .30902 L
.05174 .30903 L
.05302 .30903 L
.0554 .30904 L
.05757 .30904 L
.06007 .30905 L
.06244 .30907 L
.06486 .30909 L
.06753 .30911 L
.07031 .30914 L
.07293 .30918 L
.0776 .30928 L
.08263 .30942 L
.08821 .30964 L
.09408 .30997 L
.09909 .31035 L
.10458 .31088 L
.10986 .31154 L
.11485 .31231 L
.12419 .31422 L
.13424 .3171 L
.14514 .3214 L
.15461 .3263 L
.16502 .33312 L
.18606 .35207 L
.20551 .37613 L
.2264 .40859 L
.26768 .48503 L
Mistroke
.28831 .52238 L
.29835 .53848 L
.30744 .55127 L
.31634 .56174 L
.32596 .57037 L
.33126 .5738 L
.33358 .57498 L
.33612 .57605 L
.33853 .57683 L
.34077 .57736 L
.34201 .57756 L
.34314 .5777 L
.34445 .57779 L
.34568 .57781 L
.34683 .57778 L
.34806 .57769 L
.34922 .57754 L
.35029 .57735 L
.35147 .5771 L
.35276 .57674 L
.35536 .57583 L
.35794 .57463 L
.36068 .57305 L
.36563 .56938 L
.37061 .56463 L
.37529 .55918 L
.38406 .54651 L
.40412 .50608 L
.42258 .45697 L
.46204 .33218 L
.48187 .27104 L
.49998 .22327 L
.50931 .20304 L
.51946 .18512 L
.52503 .17727 L
.53019 .17131 L
.53513 .16682 L
.53768 .16497 L
.54037 .16337 L
.5427 .16228 L
.54393 .16181 L
.54525 .16139 L
.54646 .16108 L
.54756 .16086 L
.54867 .16071 L
.54972 .16062 L
.55095 .16058 L
.55224 .16062 L
.55335 .16072 L
.55456 .1609 L
Mistroke
.55587 .16117 L
.55728 .16156 L
.55982 .1625 L
.56216 .16364 L
.56471 .16517 L
.56936 .16874 L
.57809 .178 L
.58842 .1929 L
.59778 .2096 L
.61875 .255 L
.63964 .30513 L
.65884 .349 L
.6776 .38438 L
.68705 .39806 L
.69237 .40434 L
.69741 .40927 L
.7023 .41308 L
.70488 .4147 L
.70762 .41611 L
.70992 .41705 L
.71115 .41746 L
.71246 .41784 L
.71367 .41812 L
.71477 .41832 L
.71582 .41846 L
.71693 .41857 L
.71825 .41862 L
.71944 .41861 L
.7201 .41858 L
.72081 .41852 L
.72211 .41837 L
.72333 .41816 L
.72462 .41787 L
.72693 .41719 L
.72962 .41613 L
.73213 .41488 L
.73785 .41113 L
.74284 .40687 L
.74827 .40125 L
.75816 .38864 L
.7767 .35842 L
.79807 .31779 L
.81742 .28142 L
.82736 .26463 L
.83785 .24923 L
.84756 .23759 L
.85662 .22935 L
.86107 .2263 L
.86583 .22378 L
.86854 .2227 L
Mistroke
.87111 .22192 L
.87341 .22142 L
.87472 .22122 L
.87592 .22109 L
.87711 .22101 L
.8784 .22097 L
.87962 .221 L
.88073 .22107 L
.88203 .2212 L
.88276 .2213 L
.88345 .22141 L
.88603 .22198 L
.88875 .22283 L
.89122 .22381 L
.89676 .22674 L
.90163 .23013 L
.90677 .23447 L
.91599 .24407 L
.93681 .27242 L
.97477 .33268 L
.97619 .33479 L
Mfstroke
.2973 0 m
.30506 .03636 L
.34639 .21231 L
.36706 .2938 L
.3862 .36197 L
.40594 .42092 L
.4245 .46219 L
.43346 .47639 L
.43851 .4826 L
.44314 .48715 L
.44792 .49068 L
.45064 .49214 L
.45316 .49315 L
.45454 .49356 L
.45584 .49386 L
.457 .49405 L
.45827 .49417 L
.45893 .4942 L
.45965 .49421 L
.4604 .49419 L
.46111 .49414 L
.46237 .494 L
.46308 .49388 L
.46373 .49374 L
.46502 .49342 L
.46623 .49303 L
.4685 .49211 L
.47094 .49082 L
.47358 .48909 L
.47835 .4851 L
.48273 .48047 L
.49281 .46653 L
.50346 .44728 L
.54145 .35306 L
.56261 .2952 L
.58189 .24785 L
.59147 .228 L
.60189 .21007 L
.60666 .20328 L
.61173 .19711 L
.61616 .19262 L
.62082 .18884 L
.62316 .18731 L
.62572 .18593 L
.62804 .18493 L
.6302 .18422 L
.63152 .1839 L
.63276 .18366 L
.63388 .18351 L
.63509 .18341 L
Mistroke
.63641 .18338 L
.63707 .18339 L
.63781 .18343 L
.6391 .18356 L
.64031 .18374 L
.64144 .18398 L
.64267 .1843 L
.64492 .18505 L
.64913 .18706 L
.65404 .19035 L
.65859 .19429 L
.6692 .20652 L
.67917 .22147 L
.6978 .25615 L
.73642 .33736 L
.75641 .37269 L
.76647 .38643 L
.77214 .39272 L
.77749 .39763 L
.7824 .40121 L
.78499 .40274 L
.78774 .40408 L
.79004 .40498 L
.79126 .40538 L
.79258 .40574 L
.79379 .40601 L
.79489 .40621 L
.796 .40637 L
.79706 .40647 L
.79837 .40654 L
.79957 .40655 L
.80023 .40653 L
.80095 .40649 L
.80224 .40637 L
.80346 .40619 L
.80475 .40595 L
.80706 .40536 L
.80976 .40442 L
.81227 .4033 L
.81799 .39993 L
.82299 .39606 L
.82843 .39094 L
.83833 .37944 L
.85689 .35181 L
.87626 .31828 L
.89766 .28162 L
.9074 .26678 L
.9179 .25293 L
.92775 .24246 L
.93218 .23864 L
Mistroke
.93691 .23522 L
.9417 .23248 L
.94605 .23062 L
.94851 .22984 L
.94981 .22951 L
.95119 .22922 L
.95239 .22902 L
.95303 .22893 L
.95371 .22885 L
.95492 .22875 L
.95604 .22869 L
.95669 .22868 L
.95738 .22868 L
.95862 .22873 L
.95939 .22878 L
.9601 .22884 L
.96144 .22901 L
.96273 .22922 L
.96391 .22947 L
.96657 .23018 L
.9688 .23095 L
.97125 .23197 L
.97619 .23459 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00l@3oool01P3OW4P0000000000000M;l0oooo0;md0080000000<0B9cO0?ooo`3oool0]03o
ool00?80oooo00L0okmd0000001d_ol0oooo0?noM0000000M;oo0;L0oooo003c0?ooo`050?oo_`1d
04P0B7A804P0M02oool0^03oool00?@0oooo00<0W4P004Q8B000B9`0^@3oool00?80oooo00L0oono
07@00018W=l0oooo0=nLB00007@0_ooo0;L0oooo003a0?ooo`090?oOW01800000000001d_`3oool0
_g@00000000004P0W=oo0;H0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001D
0?ooo`050?noM000000000000000001d_ol0BP3oool01@2oM0000000000000000000M;oo04D0oooo
00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3o
ool0?P3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d
_ol0oooo0?ooo`0n0?ooo`030?oo_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM003
0000000307Boo`3oool0oooo01<0oooo001D0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_oooB03o
ool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0A`3oool00`2LB4P0W=oo0?ooo`040?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0
oooo0?ooo`3ogi`0B00007Boo`100?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0
0P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooa@0oooo001C0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool0C03oool00`3o_g@007Bo0?ooo`160?ooo`0309a8B02Lgol0oooo00<0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00P0
oooo00<0okmd001d_`3oool0@03oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool04`3oool005<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`1<0?ooo`030?noM000M;l0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo
0?ooo`110?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0C0?ooo`00D`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04`0oooo00<0
W4P007Boo`3oool0AP3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0@@3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo04<0oooo00<0
W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01<0oooo001C
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04@0oooo00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`030?no
M000M;l0oooo01<0oooo001C0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A`3o
ool00`3ookl0M01d0;ooo`1;0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool0A03o
ool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0
B9cO0?ooo`0C0?ooo`00E03oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooodP0oooo00<0oono07@0
M02oool0B03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol0103oool00`3ookl0M01d0;ooo`140?ooo`07
0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
503oool005@0oooo00D0oono07@000000000001809cOo`190?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0A@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02L
gol0@P3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3o
ool0@03oool01@3o_g@000000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0E
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3ooooo0000050000004`3oool004h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0@03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00X0oooo00<00000
0?ooo`3oool0?`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0:0?oo
o`030000003oool0oooo03l0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo00/0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0C03oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00d0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?ooo`800000
4`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
00h0oooo00<000000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0>0?ooo`030000003oool0oooo03/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo03T0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0i0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100
oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E
0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0>03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?oo
o`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool2000005H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000O`3o
ool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0=`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo
03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0f0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01<0oooo
00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00`3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo
00<000000?ooo`3oool0=@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0D0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool0503oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`2LB0000000000000030000
00050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00H0oooo0`00001/0000O`030000000007l0001o0=X0001o0`00000C0?ooo`00<03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300
oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo03@0
oooo00<0001o0?ooo`3oool02`3oool7000003X0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia80000
0000B9`0W4Q809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05@3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00X0oooo0P0000060?ooo`800000>03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?oo_`1d00000000
0000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01`3oool2000000/0oooo00<000000?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3o
ool0oooo01H0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`800000803oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
0380oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo0`0000020?ooo`8000007P3oool00`0007l0oooo0?ooo`1D0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo0380
oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo0P0000070?ooo`800000703oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0b0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P00
000I0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00D0001o
0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo0340oooo00D0001o0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H
0?ooo`030000003oool0oooo0340oooo00@0001o0?ooo`3oool00000703oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0`0?ooo`040000O`3oool0oooo000001`0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0I0?ooo`030000
003oool0oooo0300oooo00<0001o0?ooo`0000007P3oool2000001H0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3o
ool0000001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool0<03oool00`0007l000000?ooo`0N0?ooo`8000005`3oool0
0`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`00
07l000000?ooo`0M0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool04@3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo
02X0oooo1P00000U0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0
oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0100oooo00<0001o0?oo
o`3oool0:03oool2000000H0oooo0P00000S0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000000O`3oool0
703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0U0?ooo`800000303oool2000000h0oooo2000000:0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0]0?ooo`030000000007l0oooo01`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0903o
ool00`000000oooo0?ooo`0>0?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000O`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0
oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo0P0000070?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0001o
01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00d0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo0P00000E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0001o01/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool0:P3oool010000000oooo
0?ooo`0007lK0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0<0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`00000H0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0001o6P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`00
07l0oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo0P00000H0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo02X0
oooo00@000000?ooo`3oool0001o6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0:03oool01@000000
oooo0?ooo`3oool0001o01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0I0?oo
o`8000006@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`03
0000O`3oool0oooo01d0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0001o
01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00X0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo
000001P0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool00`00
07l0oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0:0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool001l0
oooo00<0omnL04Qd_`3oool0;03oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01d0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo01H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00803oool00`2oM7@0_ooo
0?ooo`0[0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool05P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo
0?ooo`0K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0140oooo000O0?ooo`030?noM000B9`0gooo02`0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo01X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04@3oool001`0oooo00@0oono07@00000000007Bo;P3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`030?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0A0?ooo`005`3oool00`3Ogml0gia800000002000000030000M02oool0oooo02l0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool00`3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo01T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool001@0oooo00D0omnL04P0B02Lgol0gia804RLg`0e0?ooo`800000EP3oool0
0`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool0
0`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0P00000C0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`040?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`007P3oool0103OW4P000000018M02ogol/0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00@0oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo000K0?ooo`070?noM01d_ml0W4P00000B02Lgol0omoO0=ooo`0/0?ooo`030000003oool0
oooo05D0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00D0oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0140oooo000J0?ooo`040?oOW018M;l0_g@004RLgc00oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`050?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool0
01T0oooo00@0oono07@000000000M;oo<@3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0
oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00@0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`060?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool05@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0A0?ooo`00@`3oool01@3o_g@00000000000000000M;oo00H0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01P3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo01D0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool04@3oool004<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool50?ooo`030000003oool0
oooo05D0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0140oooo000M0?ooo`040?noM0000000001809cOob40oooo00<0okmd001d_`3oool00P3oool0
0`3OW4P0B9cO0?ooo`040?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool08@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool04@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool0
0`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo000K0?ooo`050?noM00000000000
0018W03Oool08P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00@0ooooo`00001@
000001<0oooo000K0?ooo`030?noM000B9`0gooo02@0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`040?ooo`030000003oool0oooo01X0oooo2`00000`0?ooo`030000O`3oool0oooo
0280oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo
0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo
0?ooo`0007l05@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`00@P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00@0oooo00<000000?ooo`3oool09@3oool4000002`0oooo00<0001o0?oo
o`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00<0001o0?oo
o`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01P0oooo00D000000?oo
o`3oool0oooo0000O`0D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00120?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`<00000:@3oool00`00
07l0oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool00`00
07l0oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool01000
0000oooo0?ooo`0007lD0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00130?ooo`0609a8001d_ol0oooo
0?oOW01807@0_ooo1@3oool00`000000oooo0?ooo`0/0?ooo`<000009P3oool00`0007l0oooo0?oo
o`0R0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?oo
o`0?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool010000000oooo0?oo
o`0007lC0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0140oooo000O0?ooo`030?oog`2o_ml0oooo0240oooo00D0
oono07@000000000001809cOo`060?ooo`030000003oool0oooo02l0oooo0P00000T0?ooo`030000
O`3oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000
O`3oool0oooo00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0001o01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool001l0oooo00<0oooO09a8M02oool0;03o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0240oooo00<0001o0?ooo`3oool08`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool03P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0007l04P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`005`3oool00`3Ogml0okmd000000030000000504RLg`3oool0
oooo0;nLW03Oool0;03oool00`000000oooo0?ooo`0b0?ooo`8000008@3oool00`0007l0oooo0?oo
o`0S0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?oo
o`0>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06@3oool00`000000001o0?oo
o`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0140oooo000G0?ooo`030=nLB000M;l0oooo0080oooo00D0gia8
07Boo`3oool0omnL04Qd_`0]0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool07P3o
ool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0603o
ool00`000000001o0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo000K0?ooo`060;md0018W=l0
oooo0?oOW01807@0_ooo;@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01d0oooo
00<0001o0?ooo`3oool0903oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo
00<0001o0?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`006P3oool01P2oM000M;oo0;md
0000000004RL0=ooobh0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`03
0000O`3oool0oooo00d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0140oooo000F0?ooo`030?oog`3O_i`0B00000<0000000<0M;oo0?ooo`3oool0
;`3oool2000003P0oooo00<000000?ooo`3oool06`3oool00`0007l0oooo0?ooo`0T0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0<0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0603oool00`0007l000000?ooo`0=0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0:P3oool2000001<0oooo000G0?ooo`030;nLW03O
ool0oooo03@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0J0?ooo`030000O`3o
ool0oooo02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`030000O`00
0000oooo00d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0140oooo000N0?ooo`040=nLB000000004Qd0;oOob`0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0I0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0G0?ooo`030000O`3oool0000000`0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0140oooo000K0?ooo`070?noM01d_ml0
W4P00000B02Lgol0omoO0=ooo`0/0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
603oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
303oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
5`3oool00`0007l0oooo0000000<0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0A0?ooo`006P3oool0103ogi`0B7Bo0;md0018W=l`0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool05`3oool00`0007l0oooo0?ooo`0U0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0;0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool05P3oool0100007l0oooo0?ooo`00000:0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`00
6@3oool0103ookl0M0000000001d_ola0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0303oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool05P3oool0100007l0oooo0?ooo`00000:0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo01D0oooo00<0001o0?ooo`3oool09P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00d0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01D0oooo00D0001o0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool09P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01@0oooo
00<0001o0?ooo`3oool09P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo
00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo
00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool200000440oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0W
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`08
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0`
0?ooo`8000004`3oool004h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0A0?oo
o`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0C0?oo
o`030000O`3oool0oooo00@0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0403oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool04P3oool00`0007l0oooo0?ooo`050?ooo`8000006@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`050?ooo`800000603oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
4@3oool00`0007l0oooo0?ooo`050?ooo`8000005`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0403o
ool00`0007l0oooo0?ooo`050?ooo`030000003oool0000001D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00d0oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0100oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0100oooo00<0001o0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000001@0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00l0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00`0oooo00<0001o0?oo
o`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<0001o0?oo
o`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00l0oooo00<0001o0?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo0P00000i0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0303oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool04@3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000
B03oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo02/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0=0?ooo`050000O`3oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo0P00000C0?ooo`00CP3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0103oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo00@0001o0?ooo`3oool00000303oool3000000D0
oooo0`00000m0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool02`3oool00`0007l0oooo0000000?0?ooo`H00000@03oool00`000000oooo
0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo00<0
001o0?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<0
001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00X0oooo0P00
001F0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0203oool00`0007l0oooo0?ooo`0/0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo0P000009
0?ooo`030000000007l0oooo05H0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo02`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo0080oooo00<000000?oo
o`3oool0?03oool3000000D0oooo0`0000000`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`0007l0
oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo1@0000030?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0C0?ooo`050000O`3oool0oooo0?ooo`000000BP3oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
1P3oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
503oool01@0007l0oooo0?ooo`3oool0000004X0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo
00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo
00D0001o0?ooo`3oool0oooo0000001:0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`030000
O`3oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`040000
O`3oool0oooo000004/0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool2000004h0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0_0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05@3oool0100007l0oooo0?ooo`00001;0?ooo`03
0000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00@0oooo00<0001o0?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01D0oooo00<0001o0?ooo`000000C03oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0103o
ool00`0007l0oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`0007l0oooo
0000001<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo0300oooo00D0
00000?ooo`3oool0oooo0000000G0?ooo`030000O`000000oooo04`0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00<0oooo00<0001o0?ooo`3oool0<@3oool00`000000oooo0000000H0?ooo`030000O`00
0000oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool0<@3oool0
0`000000oooo0000000H0?ooo`030000O`000000oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00<@3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@0
00000000M;l0103oool00`3o_g@000000000000300000003001d_`3oool0oooo00<0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo0380oooo0P00000H
0?ooo`030000003oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00<@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01`3o
ool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo0540oooo00D000000?ooo`3oool0oooo
0000O`0d0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030?noM000M;l0oooo0080oooo00<0
gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo0540oooo00D0
00000?ooo`3oool0oooo0000O`0d0?ooo`8000005`3oool00`000000001o0?ooo`1=0?ooo`030000
O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0DP3o
ool010000000oooo0?ooo`0007ld0?ooo`8000005`3oool00`000000001o0?ooo`1=0?ooo`030000
O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo0`00001B0000O`0300000000
07l0001o03@0001o00@000000000O`0007l000005@0007l00`000000001o0000O`2T0000O`<00000
4`3oool00300oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02L
gol0oooo00H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0000O`0c0?ooo`040000003o
ool0oooo000001D0oooo00<000000?ooo`0007l0CP3oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo000`0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool03@3o
ool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo05<0oooo00<000000?ooo`0007l0<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0001o
CP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`0609a8001d
_ol0oooo0?oOW01807@0_ooo2`3oool01@3OW4P000000018W02LB4P0W=oo00L0oooo00<000000?oo
o`3oool0E03oool00`000000001o0?ooo`0a0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool0001o04h0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00<@3oool01@3ookl0M0000000000004P0W=oo00h0oooo00<0gia8
0000B02Lgol01`3oool00`000000oooo0?ooo`1D0?ooo`030000000007l0oooo0340oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0007l0CP3o
ool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`000000oooo02l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`000000;P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0000002h0oooo00<000000?ooo`3oool02@3oool3000000D0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`040000O`3oool0oooo000002`0oooo00<0
00000?ooo`3oool0303oool6000000X0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1D0?ooo`8000004`3oool004h0oooo00<000000?ooo`3oool0E@3oool0100007l0oooo0?ooo`00
000/0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00D0001o
0?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0C03o
ool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo05D0oooo00D0001o0?ooo`3oool0oooo0000000Z0?ooo`030000003oool0oooo01d0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E
0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?oo
o`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01h0oooo00<0001o0?oo
o`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo01h0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0
0`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01l0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0103oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0
oooo0P00000C0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Q0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0R0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?oo
o`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000
O`3oool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo00`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0
oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0V0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool03@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1D0?ooo`8000004`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09`3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0:03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0@
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo0P00000[0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0[0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000
O`3oool0oooo01<0oooo0`0000060?ooo`800000;P3oool00`0007l0oooo0?ooo`1<0?ooo`030000
O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`0F0?ooo`H00000<03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?oo
o`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo000a0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000
001d_`030?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool00`3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo103oool00`2oM0000000001d_`040?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0A0?ooo`00<03oool00`3o_g@007Bo0?ooo`020?ooo`030=nL
B018W=l0oooo00/0oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0303o
ool00`3ogi`0B00004RLg`070?ooool00000D000000C0?ooo`00<03oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3oool0o`3ooomX0?ooo`00<03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool0o`3ooomW0?oo
o`00<03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Boo`3o
ool00P3oool00`2oM000M;oo0?ooo`3o0?ooofL0oooo000a0?ooo`0609a8001d_ol0oooo0?oOW018
07@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0o`3ooomX0?ooo`00<@3oool0
1@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd000000000000001809cOo`3o0?ooofT0oooo
003o0?oook40oooo003o0?oook40oooo00290?ooo`0509a80000000000000000B02Lgol0o`3ooolS
0?ooo`00RP3oool00`2oM000M;oo0?ooo`3o0?ooob@0oooo002:0?ooo`030;md001d_ol0oooo0?l0
oooo903oool00840oooo00<0W4Q807AdB00000000P0000001P0007@0_ooo0?ooo`3oool0_g@007Ad
M0<0000000@0001809cOo`3oool0gia80P0000000`00M;l0oooo0;md00020000000404RLg`3oool0
oooo0;md00<0000000D0001d0;ooo`3oool0oono07@00004000000050000B02Lgol0oooo0?ooo`2L
B0001@0000001@00B9`0oooo0?ooo`3oool0gia800<0000000D0001809cOo`3oool0oooo0=nLB003
00000006001dM01d0000001809cOo`3oool0W4P01@0000000`00B9`0oooo0?ooo`080?ooo`030=nL
B0000000000000@0000000D0M;oo0?ooo`3oool0oooo0;md0003000000050000M02oool0oooo0?oo
o`2oM000100000001@00B9`0oooo0?ooo`3oool0_g@000@0000000<004RL0?ooo`3oool00P3oool0
1P2oM0000000000000000000001d0;ooo`80oooo00<0W4P00000000000000`0000000`00B9`0oooo
0?ooo`090?ooo`050;md00000000000000000000B9`01@3oool0202LB000000000000000B9`0_g@0
00000018W=l0gia80P0000000`00B9`0oooo0;md00020000000404RLg`3oool0oooo0=nLB0<00000
00<0001809cOo`3oool00P3oool01@3ookl0M00000000000000004RL00<0oooo00<0W4P000000000
00000`0000001@00B9`0oooo0?ooo`3ookl0M00000<0000000@0001d0;ooo`3oool0gia80P000000
0`00B9`0oooo0;md00020000000304RLg`3oool0_g@000@0000000<004RL0?ooo`3oool0AP3oool0
0840oooo00<0W4P00018W03oool00P3oool01`3o_g@0B9cO0?ooo`3oool0_g@00000M02oool00P3o
ool01P3ogi`0B4RL0?ooo`3oool0gia804RLg`<0oooo00H0_g@007Boo`3oool0oooo0;md0000M;l3
0?ooo`030?noM000B9`0oooo0080oooo00<0oono07@0M02oool01`3oool00`3ookl0M01d0;ooo`04
0?ooo`030=nLB000B9`0oooo0080oooo00H0omnL04P0B02Lgol0oono07@0M02oool20?ooo`030;md
000007@0_ooo00@0oooo00<0oono07@0M02oool03@3oool00`3o_g@007Bo0?ooo`020?ooo`060?oO
W01804P0W=oo0?ooo`2oM00007Bo0`3oool01P3o_g@004RL0?ooo`3oool0_g@004RLg`<0oooo00H0
gia804RLg`3oool0oooo0;md0018W=l30?ooo`060=nLB018W=l0oooo0?ooo`2oM00007Bo0`3oool0
0`3o_g@004RL0?ooo`030?ooo`030?oo_`1d07@0_ooo00h0oooo00<0_g@007Boo`3oool01@3oool0
1`3o_g@004RL0?ooo`3oool0gia80000001d_ol00P3oool00`3o_g@007Bo0?ooo`020?ooo`060;md
001d_ol0oooo0?ooo`3OW4P004RL0`3oool00`3ogi`0B01809cOo`020?ooo`070=nLB018W=l0oooo
0?ooo`3OW4P0001d0;ooo`030?ooo`030?oo_`1d07@0_ooo00@0oooo00<0_g@007Boo`3oool00P3o
ool01P3o_g@007Bo0?ooo`3oool0okmd001d_`<0oooo00H0_g@007Boo`3oool0oooo0;md0018W=l3
0?ooo`030=nLB018W=l0oooo04H0oooo00210?ooo`0309a8B02Lgol0oooo0080oooo00H0omnL04Q8
W03oool0oooo0;md001d_ol40?ooo`050;md001d_ol0oooo0=nLB018W=l00`3oool01P2oM000M;oo
0?ooo`3ookl0M01d0;ooo`P0oooo00<0oono07@0M02oool01`3oool00`3ookl0M01d0;ooo`040?oo
o`0309a8B02Lgol0oooo00D0oooo00<0oono07@0B02Lgol00P3oool00`3ookl0M01d0;ooo`040?oo
o`030?oo_`1d07@0_ooo00d0oooo00<0okmd001d_`3oool00`3oool01@2oM000M;oo0?oo_`1d07@0
_ooo00`0oooo00<0_g@0001d_`3oool01P3oool01P2oM00007Bo0?ooo`3ookl0M01d0;ooo`T0oooo
00<0oono07@0M02oool03P3oool00`2oM000M;oo0?ooo`050?ooo`030=nLB018W=l0oooo0080oooo
00H0_g@007Boo`3oool0oooo0?noM000M;l30?ooo`060;md001d_ol0oooo0?ooo`2LB4P0W=oo203o
ool00`3OW4P0B9cO0?ooo`070?ooo`030?oo_`1d07@0_ooo00<0oooo00<0oono07A8W03oool0103o
ool01@2LB4P0W=oo0?ooo`3o_g@007Bo00<0oooo00<0_g@007Boo`3oool01P3oool00`2oM00007Bo
0?ooo`160?ooo`00QP3oool01P2LB00007Bo0?ooo`3oool0_g@004RLg`@0oooo00D0_gA809cOo`3o
ool0gia804RLg`030?ooo`050;md001d_ol0oooo0?oo_`1d00001@0000001`00B9`0oooo0?ooo`3o
ool0oono07@0M02oool01`3oool00`3ookl0M01d0;ooo`040?ooo`0309a8B02Lgol0oooo00H0oooo
00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`030?ooo`030?oo_`1d07@0_ooo00d0oooo
00<0okmd001d_`3oool00P3oool01@3OW4P0001d0;ooo`3ookl0M00000D0000000D004RL0?ooo`3o
ool0oooo09a80003000000030018W03oool0oooo0080oooo00D0W4P000000000000000000018W002
0?ooo`030?oo_`1d0000000000@0000000<004RL0?ooo`3oool00P3oool00`3ookl0M01d0;ooo`0>
0?ooo`050;md001d_ol0oooo09a8B02Lgol00`3oool00`3OW4P0B9cO0?ooo`020?ooo`060;md001d
_ol0oooo0?ooo`3o_g@007Bo0`3oool01P2oM000M;oo0?ooo`3oool0W4Q809cOo`P0oooo00<0gia8
04RLg`3oool01`3oool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1dB9`0oooo00@0oooo00D0W4Q8
09cOo`3oool0okmd001d_`030?ooo`030;md001d_ol0oooo0080oooo00D0W4P00000000000000000
0018W0180?ooo`00PP3oool01@3OW4P00000000000000000B9cO00<0oooo00<0_g@00000001d_ol0
0P3oool01`3OW4P004RL0?ooo`3oool0gia800000018W=l00P3oool01P2LB000M;oo0?ooo`3oool0
_g@007Boo`<0oooo00<0W4P004RLg`3oool00P3oool0103ookl0M0000000001d_ol60?ooo`030?oo
_`1d07@0_ooo00@0oooo00<0gia80000M02oool00P3oool01P2oM000001d0;ooo`3oool0oono0;no
o`80oooo00<0omnL04P0M02oool0103oool00`3ookl0M01d0;ooo`0=0?ooo`030?noM00000000000
0080000000H004RL0?ooo`3oool0oooo0;md001d_ol30?ooo`0609a80018W=l0oooo0?ooo`3o_g@0
07Bo0P3oool00`3ookl0M00004RLg`020?ooo`070?noM000M;l0oooo0?ooo`3ookl0M00004RLg`02
0?ooo`030;md001d_ol0oooo0080oooo00<0W4P004RLg`3oool00`3oool00`3ookl0M01d0;ooo`0>
0?ooo`050;md0000000000000000B02Lgol00`3oool00`3OW4P0B9cO0?ooo`020?ooo`070;md001d
_ol0oooo0?ooo`3o_g@0000007Boo`020?ooo`0709a8001d_ol0oooo0?ooo`3OW4P0001d0;ooo`02
0?ooo`030;md000007@0_ooo0080oooo00<0gia804RLg`3oool01`3oool00`3ookl0M01d0;ooo`04
0?ooo`030;md0000B9`0oooo0080oooo00L0_g@0001d_`3oool0oooo0?noM0000000M;oo0080oooo
00H0W4P007Boo`3oool0oooo0?noM000M;l20?ooo`030?oo_`1d0000B9cO04L0oooo00210?ooo`03
0=nLB000B9`0oooo0080oooo00L0okmd001d_`3oool0W4P00000001d_kl0M0000080000000L004RL
0?ooo`3oool0oooo0=nLB018W=l0W4P00080000000H007Bo0?ooo`3oool0oooo0?oo_`1d00030000
000904RLg`3oool0oooo0?ooo`3OW4P000000000M02ookl0M0000080000000L0M;oo0?ooo`3ogi`0
B0000000000007@0_ooo00D0oooo00X0okmd0000000000000000001dM01d07@0_ooo0?ooo`3ogi`0
B0000P0000000`0004P0W=oo0?ooo`040?ooo`030?oo_`1d07@0_ooo00d0oooo00<0okmd001d_`3o
ool00P3oool01P3OW4P0B9cO0?ooo`3oool0oono07@000<0000000<0B9cO0?ooo`3oool00P3oool0
1P2oM0000000000000000000M7Ad04RLg`<0oooo00H0_g@0000000000000000007AdM018W=l20?oo
o`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool00`3oool00`3ookl0M01d0;ooo`0>0?oo
o`0D0;md001d_ol0oooo09a8B02Lgol0okmd001d_`3OW4P0000004RLg`3oool0omnL04P000000000
M;oo0?ooo`3OW4P00000001dM01d000200000003001d_`3oool0oooo0080oooo00T0okmd00000000
00000000001dM01d07@0_ooo0?oOW0180000100000002@0004P0W=oo0?ooo`3oool0omnL04P00000
0000001d0;ooo`050?ooo`050=nLB0000000000000000000M;l00P3oool0103OW4P00000001dM01d
000200000003001d_`3oool0oooo0080oooo00H0_g@0000000000000000007AdM018W=m70?ooo`00
P@3oool01`3o_g@004RL0?ooo`3oool0oono07@00000M;l02`3oool00`3OW4P0B9cO0?ooo`0e0?oo
o`030?oo_`1d07@0_ooo00d0oooo00<0okmd001d_`3oool00P3oool00`3OW4P007Bo0?ooo`0W0?oo
o`030?oo_`1d07@0_ooo00h0oooo00<0_g@007Boo`3oool00P3oool00`3o_g@007Bo0?ooo`0L0?oo
o`030=nLB018W=l0oooo06h0oooo00220?ooo`060=nLB000000000000000001dM7@007Bo2`3oool0
0`3OW4P0B9cO0?ooo`0e0?ooo`030?oo_`1d07@0_ooo00`0oooo00<0gia80000000000000`000000
0`00B9`0oooo0?ooo`0W0?ooo`030?oo_`1d07@0_ooo00d0oooo00<0_g@000000000000010000000
0`00M;l0oooo0?ooo`0K0?ooo`030=nLB018W=l0oooo06h0oooo002B0?ooo`030=nLB0000000B9cO
01/0oooo00<0okmd0000M02oool05P3oool01@3ogi`0B0000000000007@0_ooo03X0oooo00D0omnL
04P000000000001d0;ooo`0l0?ooo`030?noM00007@0_ooo06@0oooo002`0?ooo`030?noM00007@0
_ooo09H0oooo00<0okmd0000M02oool0I03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-5.4479, -0.270811, \
0.094377, 0.00290868}}]
}, Closed]],

Cell["but can still override the defaults", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotsbess[5, 0, 20, PlotRange \[Rule] {Automatic, {\(-0.2\), 0.2}}, 
        FrameLabel \[Rule] {"\<x\>", \
\*"\"\<\!\(\[ScriptJ]\_5\),\!\(\[ScriptY]\_5\)\>\""}, 
        PlotLabel \[Rule] "\<override plot label\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 1.54508 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5625 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -14.2813 ]
[-0.01875 .30902 -24 14.2813 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -59 0 ]
[.5 .63053 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .15451 m
1 .15451 L
s
0 .30902 m
1 .30902 L
s
0 .46353 m
1 .46353 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15451 m
.00625 .15451 L
s
[(-0.1)] -0.0125 .15451 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.1)] -0.0125 .46353 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .12361 m
.00375 .12361 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .27812 m
.00375 .27812 L
s
0 .33992 m
.00375 .33992 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .49443 m
.00375 .49443 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.563 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
75.2813 10.2813 translate
90 rotate
-75.2813 -10.2813 translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(j) show
67.438 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
72.125 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
78.313 12.813 moveto
%%IncludeResource: font Mathematica5Mono
%%IncludeFont: Mathematica5Mono
/Mathematica5Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
82.875 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
87.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46353 m
1 .46353 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
gsave
.5 .63053 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(override) show
117.000 12.813 moveto
(plot) show
147.000 12.813 moveto
(label) show
177.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04396 .30902 L
.04519 .30902 L
.04654 .30902 L
.04797 .30902 L
.05038 .30902 L
.05174 .30903 L
.05302 .30903 L
.0554 .30904 L
.05757 .30904 L
.06007 .30905 L
.06244 .30907 L
.06486 .30909 L
.06753 .30911 L
.07031 .30914 L
.07293 .30918 L
.0776 .30928 L
.08263 .30942 L
.08821 .30964 L
.09408 .30997 L
.09909 .31035 L
.10458 .31088 L
.10986 .31154 L
.11485 .31231 L
.12419 .31422 L
.13424 .3171 L
.14514 .3214 L
.15461 .3263 L
.16502 .33312 L
.18606 .35207 L
.20551 .37613 L
.2264 .40859 L
.26768 .48503 L
Mistroke
.28831 .52238 L
.29835 .53848 L
.30744 .55127 L
.31634 .56174 L
.32596 .57037 L
.33126 .5738 L
.33358 .57498 L
.33612 .57605 L
.33853 .57683 L
.34077 .57736 L
.34201 .57756 L
.34314 .5777 L
.34445 .57779 L
.34568 .57781 L
.34683 .57778 L
.34806 .57769 L
.34922 .57754 L
.35029 .57735 L
.35147 .5771 L
.35276 .57674 L
.35536 .57583 L
.35794 .57463 L
.36068 .57305 L
.36563 .56938 L
.37061 .56463 L
.37529 .55918 L
.38406 .54651 L
.40412 .50608 L
.42258 .45697 L
.46204 .33218 L
.48187 .27104 L
.49998 .22327 L
.50931 .20304 L
.51946 .18512 L
.52503 .17727 L
.53019 .17131 L
.53513 .16682 L
.53768 .16497 L
.54037 .16337 L
.5427 .16228 L
.54393 .16181 L
.54525 .16139 L
.54646 .16108 L
.54756 .16086 L
.54867 .16071 L
.54972 .16062 L
.55095 .16058 L
.55224 .16062 L
.55335 .16072 L
.55456 .1609 L
Mistroke
.55587 .16117 L
.55728 .16156 L
.55982 .1625 L
.56216 .16364 L
.56471 .16517 L
.56936 .16874 L
.57809 .178 L
.58842 .1929 L
.59778 .2096 L
.61875 .255 L
.63964 .30513 L
.65884 .349 L
.6776 .38438 L
.68705 .39806 L
.69237 .40434 L
.69741 .40927 L
.7023 .41308 L
.70488 .4147 L
.70762 .41611 L
.70992 .41705 L
.71115 .41746 L
.71246 .41784 L
.71367 .41812 L
.71477 .41832 L
.71582 .41846 L
.71693 .41857 L
.71825 .41862 L
.71944 .41861 L
.7201 .41858 L
.72081 .41852 L
.72211 .41837 L
.72333 .41816 L
.72462 .41787 L
.72693 .41719 L
.72962 .41613 L
.73213 .41488 L
.73785 .41113 L
.74284 .40687 L
.74827 .40125 L
.75816 .38864 L
.7767 .35842 L
.79807 .31779 L
.81742 .28142 L
.82736 .26463 L
.83785 .24923 L
.84756 .23759 L
.85662 .22935 L
.86107 .2263 L
.86583 .22378 L
.86854 .2227 L
Mistroke
.87111 .22192 L
.87341 .22142 L
.87472 .22122 L
.87592 .22109 L
.87711 .22101 L
.8784 .22097 L
.87962 .221 L
.88073 .22107 L
.88203 .2212 L
.88276 .2213 L
.88345 .22141 L
.88603 .22198 L
.88875 .22283 L
.89122 .22381 L
.89676 .22674 L
.90163 .23013 L
.90677 .23447 L
.91599 .24407 L
.93681 .27242 L
.97477 .33268 L
.97619 .33479 L
Mfstroke
.2973 0 m
.30506 .03636 L
.34639 .21231 L
.36706 .2938 L
.3862 .36197 L
.40594 .42092 L
.4245 .46219 L
.43346 .47639 L
.43851 .4826 L
.44314 .48715 L
.44792 .49068 L
.45064 .49214 L
.45316 .49315 L
.45454 .49356 L
.45584 .49386 L
.457 .49405 L
.45827 .49417 L
.45893 .4942 L
.45965 .49421 L
.4604 .49419 L
.46111 .49414 L
.46237 .494 L
.46308 .49388 L
.46373 .49374 L
.46502 .49342 L
.46623 .49303 L
.4685 .49211 L
.47094 .49082 L
.47358 .48909 L
.47835 .4851 L
.48273 .48047 L
.49281 .46653 L
.50346 .44728 L
.54145 .35306 L
.56261 .2952 L
.58189 .24785 L
.59147 .228 L
.60189 .21007 L
.60666 .20328 L
.61173 .19711 L
.61616 .19262 L
.62082 .18884 L
.62316 .18731 L
.62572 .18593 L
.62804 .18493 L
.6302 .18422 L
.63152 .1839 L
.63276 .18366 L
.63388 .18351 L
.63509 .18341 L
Mistroke
.63641 .18338 L
.63707 .18339 L
.63781 .18343 L
.6391 .18356 L
.64031 .18374 L
.64144 .18398 L
.64267 .1843 L
.64492 .18505 L
.64913 .18706 L
.65404 .19035 L
.65859 .19429 L
.6692 .20652 L
.67917 .22147 L
.6978 .25615 L
.73642 .33736 L
.75641 .37269 L
.76647 .38643 L
.77214 .39272 L
.77749 .39763 L
.7824 .40121 L
.78499 .40274 L
.78774 .40408 L
.79004 .40498 L
.79126 .40538 L
.79258 .40574 L
.79379 .40601 L
.79489 .40621 L
.796 .40637 L
.79706 .40647 L
.79837 .40654 L
.79957 .40655 L
.80023 .40653 L
.80095 .40649 L
.80224 .40637 L
.80346 .40619 L
.80475 .40595 L
.80706 .40536 L
.80976 .40442 L
.81227 .4033 L
.81799 .39993 L
.82299 .39606 L
.82843 .39094 L
.83833 .37944 L
.85689 .35181 L
.87626 .31828 L
.89766 .28162 L
.9074 .26678 L
.9179 .25293 L
.92775 .24246 L
.93218 .23864 L
Mistroke
.93691 .23522 L
.9417 .23248 L
.94605 .23062 L
.94851 .22984 L
.94981 .22951 L
.95119 .22922 L
.95239 .22902 L
.95303 .22893 L
.95371 .22885 L
.95492 .22875 L
.95604 .22869 L
.95669 .22868 L
.95738 .22868 L
.95862 .22873 L
.95939 .22878 L
.9601 .22884 L
.96144 .22901 L
.96273 .22922 L
.96391 .22947 L
.96657 .23018 L
.9688 .23095 L
.97125 .23197 L
.97619 .23459 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00l@3oool01P3OW4P0000000000000M;l0oooo0;md0080000000<0B9cO0?ooo`3oool0]03o
ool00?80oooo00L0okmd0000001d_ol0oooo0?noM0000000M;oo0;L0oooo003c0?ooo`050?oo_`1d
04P0B7A804P0M02oool0^03oool00?@0oooo00<0W4P004Q8B000B9`0^@3oool00?80oooo00L0oono
07@00018W=l0oooo0=nLB00007@0_ooo0;L0oooo003a0?ooo`090?oOW01800000000001d_`3oool0
_g@00000000004P0W=oo0;H0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001D
0?ooo`050?noM000000000000000001d_ol0BP3oool01@2oM0000000000000000000M;oo04D0oooo
00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3o
ool0?P3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`2oM0000`0000000`1d
_ol0oooo0?ooo`0n0?ooo`030?oo_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM003
0000000307Boo`3oool0oooo01<0oooo001D0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_oooB03o
ool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol0A`3oool00`2LB4P0W=oo0?ooo`040?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo@P3oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0
oooo0?ooo`3ogi`0B00007Boo`100?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0
0P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooa@0oooo001C0?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool0C03oool00`3o_g@007Bo0?ooo`160?ooo`0309a8B02Lgol0oooo00<0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00P0
oooo00<0okmd001d_`3oool0@03oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool04`3oool005<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`1<0?ooo`030?noM000M;l0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo
0?ooo`110?ooo`030?oOW0180000B9cO00@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0C0?ooo`00D`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04`0oooo00<0
W4P007Boo`3oool0AP3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0@@3oool00`2LB4P0W=oo0?ooo`080?ooo`0309a8001d_ol0oooo04<0oooo00<0
W4P004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01<0oooo001C
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04H0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo0440oooo00<0W4Q809cOo`3oool00`3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo04@0oooo00H0W4Qd0;ooo`3oool0oooo0=nLB018W=l30?ooo`030?no
M000M;l0oooo01<0oooo001C0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A`3o
ool00`3ookl0M01d0;ooo`1;0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0oono07@0M02oool0A03o
ool00`3OW4P0M;oo0?ooo`020?ooo`060;md001d_ol0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0
B9cO0?ooo`0C0?ooo`00E03oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooodP0oooo00<0oono07@0
M02oool0B03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolo0?ooo`050=nLB000000004RL09a8B02Lgol0103oool00`3ookl0M01d0;ooo`140?ooo`07
0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
503oool005@0oooo00D0oono07@000000000001809cOo`190?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0A@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02L
gol0@P3oool00`3OW4P0001809cOo`040?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3o
ool0@03oool01@3o_g@000000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`0E
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00CP3ooooo0000050000004`3oool004h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`100?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0@03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo0400oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00X0oooo00<00000
0?ooo`3oool0?`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0:0?oo
o`030000003oool0oooo03l0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0o0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000005H0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
E03oool2000001<0oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`0n0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo00/0oooo00<000000?ooo`3oool0?P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<0001o0?ooo`3oool0C03oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m0?ooo`030000O`3oool0oooo04`0
oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0m
0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00d0oooo00<000000?oo
o`3oool0?03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?ooo`800000
4`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0=0?ooo`030000003o
ool0oooo03`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
00h0oooo00<000000?ooo`3oool0>`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo
05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0
oooo0?ooo`0>0?ooo`030000003oool0oooo03/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0k0?ooo`030000O`3oool0oooo04`0oooo
00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?oo
o`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo03T0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0403oool00`00
0000oooo0?ooo`0i0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100
oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E
0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0>03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0E@3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo03P0oooo00<0001o0?oo
o`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool2000005H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000O`3o
ool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool0
0`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0=`3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo
03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0f0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01<0oooo
00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00`3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01@0oooo
00<000000?ooo`3oool0=@3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0D0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool0503oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo04`0oooo00<0001o
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`009`3oool00`2LB0000000000000030000
00050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00H0oooo0`00001/0000O`030000000007l0001o0=X0001o0`00000C0?ooo`00<03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300
oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo03@0
oooo00<0001o0?ooo`3oool02`3oool7000003X0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia80000
0000B9`0W4Q809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05@3oool0
0`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00X0oooo0P0000060?ooo`800000>03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`050?oo_`1d00000000
0000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo05D0oooo00<00000
0?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool01`3oool2000000/0oooo00<000000?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool05P3oool00`000000oooo0?ooo`0c0?ooo`03
0000O`3oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3o
ool0oooo01H0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`800000803oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0140oooo001>0?ooo`800000EP3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
0380oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo0`0000020?ooo`8000007P3oool00`0007l0oooo0?ooo`1D0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo0380
oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo0P0000070?ooo`800000703oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0b0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0
001o0?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P00
000I0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00D0001o
0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0
oooo0340oooo00D0001o0?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0H
0?ooo`030000003oool0oooo0340oooo00@0001o0?ooo`3oool00000703oool01@000000oooo0?oo
o`3oool000000180oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`1E0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06@3o
ool00`000000oooo0?ooo`0`0?ooo`040000O`3oool0oooo000001`0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0I0?ooo`030000
003oool0oooo0300oooo00<0001o0?ooo`0000007P3oool2000001H0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3o
ool0000001h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool0<03oool00`0007l000000?ooo`0N0?ooo`8000005`3oool0
0`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3oool00`00
0000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`00
07l000000?ooo`0M0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool04@3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01d0
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo
02X0oooo1P00000U0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0
oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0100oooo00<0001o0?oo
o`3oool0:03oool2000000H0oooo0P00000S0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0
E@3oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo02d0oooo00<000000000O`3oool0
703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0U0?ooo`800000303oool2000000h0oooo2000000:0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0]0?ooo`030000000007l0oooo01`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0903o
ool00`000000oooo0?ooo`0>0?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000O`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0
oooo02<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo0P0000070?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0001o
01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00d0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo0P00000E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0
oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0001o01/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo
0?ooo`1E0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool0:P3oool010000000oooo
0?ooo`0007lK0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0<0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool05P3oool010000000
oooo0?ooo`00000H0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool00`0007l0
oooo0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0001o6P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`00
07l0oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo0P00000H0?ooo`8000004`3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo02X0
oooo00@000000?ooo`3oool0001o6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool0:03oool01@000000
oooo0?ooo`3oool0001o01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0I0?oo
o`8000006@3oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3ogi`0B7Bo0?ooo`0/0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`05
0000003oool0oooo0?ooo`0007l06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo
01T0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0A0?ooo`00803oool00`2o
M7@0_ooo0?ooo`0[0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000O0?ooo`030?noM000B9`0gooo02`0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04@3oool001`0oooo00@0oono07@00000000007Bo;P3oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`020?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0A0?ooo`005`3oool00`3Ogml0gia800000002000000030000M02oool0oooo02l0oooo
00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo01X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04@3oool001@0oooo00D0omnL04P0B02Lgol0gia804RLg`0e0?ooo`030000
003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0J0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool05@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000EP3oool0
0`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool0
0`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0P00000C0?ooo`007`3oool00`3o
_g@0M;oo0?ooo`0/0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0503oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`00
07l0oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo000I0?ooo`090?oo_`1d000000000000
0018W=l0oooo0?oog`2LM9`0gooo02`0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?oo
o`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?oo
o`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`060?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool001T0oooo00D0oono
09bLg`3oool0oknL09cOo`020?ooo`030=nLW02oool0oooo02/0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3o
ool001T0oooo00T0oono09bLg`3oool0giad09cOo`3oool0oooO09adW03Oool0;03oool00`000000
oooo0?ooo`1E0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool05P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0A0?ooo`00703oool01@3ooml0W4P00000000004P0W=oo02d0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`0P0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
O`3oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool004<0oooo00D0okmd0000000000000000
07Boo`060?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0140oooo00130?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo1@3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3o
ool0503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0A0?ooo`007@3oool0103o_g@000000000B02LgolQ0?ooo`03
0?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0103oool00`000000oooo0?ooo`1E0?ooo`03
0000O`3oool0oooo0240oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0080oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`00
6`3oool01@3o_g@0000000000000B9`0gooo0280oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`040?ooool00000D000000C0?ooo`006`3oool00`3o_g@004RL0=ooo`0T0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0J0?ooo`/00000
<03oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
203oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
603oool01@000000oooo0?ooo`3oool0001o01D0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00480oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo02D0oooo
1000000/0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`080?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0007l0503oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`00
@P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00@0oooo00<000000?ooo`3oool0
:@3oool3000002T0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00P0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool0001o503oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`00
@`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`D0oooo00<000000?ooo`3oool0;03oool30000
02H0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00T0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo00@000000?ooo`3oool0001o4`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`007`3oool00`3o
oml0_koO0?ooo`0Q0?ooo`050?oo_`1d000000000000B02Lgol01P3oool00`000000oooo0?ooo`0_
0?ooo`800000903oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool02@3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0000O`0C0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo000O0?oo
o`030?oog`2LB7@0_ooo02`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?oo
o`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0001o0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool001L0oooo00<0gmoO0?noM000
00000`0000001@18W=l0oooo0?ooo`2oW9`0gooo02`0oooo00<000000?ooo`3oool0<P3oool20000
0240oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01T0oooo00<000000000O`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`005`3oool00`3OW4P0
07Bo0?ooo`020?ooo`050=nLB01d_ol0oooo0?oOW018M;l0;@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01P0oooo00<000000000O`3oool0403oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`006`3oool01P2oM000B9cO0?ooo`3ogi`0B01d0;ooobd0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
01X0oooo00H0_g@007Boo`2oM00000000018W03Oool^0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`005P3oool00`3ooml0gknL04P00003
0000000307Boo`3oool0oooo02l0oooo0P00000h0?ooo`030000003oool0oooo01/0oooo00<0001o
0?ooo`3oool0903oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0001o
0?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<0001o
0000003oool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo0P00000C
0?ooo`005`3oool00`2oW9`0gooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool06P3oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0603oool00`0007l000000?ooo`0=0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01T0oooo00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00`0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01L0oooo00<0001o0?ooo`000000303oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool001l0oooo00<0okmd07Boo`3oool0
;03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`000000
303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
4@3oool001T0oooo00T0oono07@000000000000004RLg`3oool0oooO09adW03Oool0;03oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00@0001o0?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool0
01T0oooo00D0oono09bLg`3oool0oknL09cOo`020?ooo`030=nLW02oool0oooo02/0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo02D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo00/0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`040000O`3oool0oooo000000X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000I
0?ooo`090?oo_`2LW=l0oooo0=nLM02Lgol0oooo0?oog`2LM9`0gooo02`0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo02H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0E0?ooo`050000O`3oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool001`0
oooo00D0oooO09a800000000001809cOo`0]0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0503oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool05@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0V0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`090?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
503oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000@@3o
ool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0300oooo0P00000C0?ooo`00CP3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool09`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0103oool0
10000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0
oooo02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00D0oooo0P00000I0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00D0oooo0P00000H0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo00D0
oooo0P00000G0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00H0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo00D0oooo
00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0140oooo001>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`0007l0oooo0?ooo`060?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03@3oool2000003T0oooo00<000000?ooo`3oool04@3oool0
04h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo
02X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo
00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool04@3oool004h0oooo0P0000180?ooo`030000003oool0oooo00/0
oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140
oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00d0
oooo00D0001o0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0>@3oool2000001<0oooo001>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0303oool0100007l0oooo0?ooo`00000<0?ooo`<000001@3oool3000003d0oooo00<000000?oo
o`3oool04@3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0:0?ooo`03
0000O`3oool0oooo02/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0;0?ooo`03
0000O`3oool0000000l0oooo1P0000100?ooo`030000003oool0oooo0140oooo001>0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0/0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`030?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool2000005H0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`080?ooo`030000O`3o
ool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00<0oooo00<000000?ooo`3oool0>P3oool2000000T0oooo00<000000000O`3oool0EP3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00P0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01<0oooo00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`<000001@3oool3
000000030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo0080oooo00<000000?oo
o`3oool0?`3oool5000000<0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?oo
o`00CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D0001o0?ooo`3o
ool0oooo0000001:0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo02d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`050000O`3oool0oooo0?oo
o`000000BP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0^0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool01@0007l0oooo0?ooo`3oool00000
04X0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0;P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00@0001o0?ooo`3oool00000B`3oool00`00
07l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`800000CP3oool00`000000
oooo0?ooo`050?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`040000O`3oool0oooo000004/0oooo00<0001o0?ooo`3oool0E03oool20000
01<0oooo001>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0103oool00`0007l0
oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`0007l0
oooo0000001<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo0300oooo
00D000000?ooo`3oool0oooo0000000G0?ooo`030000O`3oool0000004`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000001L0
oooo00<0001o0000003oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo001>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0a0?ooo`030000003oool0000001P0oooo00<0001o0000003oool0C03oool00`0007l0oooo
0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0a0?ooo`030000003oool0000001P0oooo00<0
001o0000003oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a
0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM000
0000000000<0000000<007Bo0?ooo`3oool00`3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0080oooo00<0001o0?ooo`3oool0<P3oool2000001P0oooo00<000000?ooo`3oool0C03o
ool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a0?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool0001o03@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool00300oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool0001o03@0
oooo0P00000G0?ooo`030000000007l0oooo04d0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`040000003oool0oooo0000Oc@0
oooo0P00000G0?ooo`030000000007l0oooo04d0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool300000580001o00<000000000O`0007l0=00007l010000000001o
0000O`00000E0000O`030000000007l0001o0:@0001o0`00000C0?ooo`00<03oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0001o03<0oooo00@000000?ooo`3oool000005@3oool00`000000
oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00300oooo
00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0000O`0b0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool010000000oooo0?ooo`0007m>0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool00340oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?oo
o`050=nLB000000004RL09a8B02Lgol01`3oool00`000000oooo0?ooo`1D0?ooo`030000000007l0
oooo0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0007l0CP3oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo000a
0?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cOo`070?ooo`030000003o
ool0oooo05@0oooo00<000000000O`3oool0<@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo0000O`1>0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`030000003oool0oooo05D0oooo00<0001o0000003oool0;`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`1<0?oo
o`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3o
ool0E@3oool00`0007l0oooo0000000^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool2000000L0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`000000
;P3oool00`000000oooo0?ooo`090?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool2000005H0oooo00@0001o0?ooo`3oool00000;03oool00`000000oooo0?ooo`0<0?ooo`H00000
2P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`040000O`3oool0oooo000002`0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool0
4@3oool004h0oooo00<000000?ooo`3oool0E@3oool01@0007l0oooo0?ooo`3oool0000002/0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo
00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool01@0007l0oooo0?oo
o`3oool0000002X0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`1<0?ooo`030000
O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3o
ool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07@3o
ool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3o
ool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0
oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`00
07l0oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool00`00
07l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0
oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool07`3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0
oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo
0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`0007l0oooo
0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<0
00000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0803oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<0
00000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?oo
o`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Q0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E03oool2000001<0oooo001>0?ooo`03
0000003oool0oooo05D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0240oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0280oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003o
ool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo
00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo
00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo
001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?oo
o`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o
0?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<0001o
0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?oo
o`800000EP3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool09P3oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05@0oooo0P00000C0?oo
o`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo00h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0W0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000
O`3oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000
O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00CP3o
ool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool02`3oool2000002/0oooo00<0001o0?ooo`3oool0C03oool0
0`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003oool0oooo
05D0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02/0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool04`3oool3000000H0
oooo0P00000^0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo01H0oooo
1P00000`0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo
0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0
001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>
0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<
0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo0P00001F0?oo
o`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1D0?oo
o`8000004`3oool004h0oooo00<000000?ooo`3oool0E@3oool00`0007l0oooo0?ooo`1<0?ooo`03
0000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`00
CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0
C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo001>0?ooo`030000003o
ool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3o
ool0oooo05D0oooo00<000000?ooo`3oool04@3oool004h0oooo00<000000?ooo`3oool0E@3oool0
0`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo04`0oooo00<0001o0?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0A0?ooo`00CP3oool00`000000oooo0?ooo`1E0?ooo`030000O`3oool0oooo
04`0oooo00<0001o0?ooo`3oool0C03oool00`0007l0oooo0?ooo`1E0?ooo`030000003oool0oooo
0140oooo001>0?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3oool0C03oool00`0007l0
oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3oool04@3oool00340oooo
00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00<0oooo00<0oono07@00000
0000100000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo05D0oooo00<0001o0?ooo`3o
ool0C03oool00`0007l0oooo0?ooo`1<0?ooo`030000O`3oool0oooo05D0oooo00<000000?ooo`3o
ool04@3oool00340oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo
00@0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo000`0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0
001809cOo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00300oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00L0oooo
o`00001@000001<0oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3o
ool00`2LB000B9cO0?ooo`3o0?ooofP0oooo000`0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`3o0?ooofL0oooo000`0?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo
0?l0ooooI`3oool00340oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`3o0?ooofP0oooo000a0?ooo`050?oo_`1d000000000000B02Lgol0
3@3oool01@3o_g@000000000000004P0W=oo0?l0ooooJ@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?40oooo00D0W4P0000000000000001809cOo`2j0?ooo`00lP3oool00`2oM000M;oo0?ooo`2k
0?ooo`00lP3oool00`2oM000M;oo0?ooo`2k0?ooo`00X@3oool00`3ookl0M0000000000200000003
0000M02oool0oooo00<0oooo00<0omnL04P0001d_ol01@3oool02@2oM0000000000000000000001d
0;ooo`3oool0oono07@00004000000050000B02Lgol0oooo0?oo_`1d0000100000001@0004P0W=oo
0?ooo`3oool0W4P000D0000000D004RL0?ooo`3oool0omnL04P000030000000307AdM000000004RL
0080oooo00H0_g@000000000000000000000M02oool;0?ooo`030;md001dM7@000000080000000D0
001809cOo`3oool0oooo09a80005000000050018W03oool0oooo0?oo_`1d00000`0000000`0007@0
_ooo0?ooo`020?ooo`050?oo_`1d0000000000000000B9`0303oool00`2LB0000000000000030000
00040018W03oool0oooo0=nLB0<0000000P007Ad07@0000004P0W=oo09a800000000M9bL04P00080
000000<0001d0;ooo`3oool00P3oool01P2oM0000000000000000000001d0;ooo`80oooo00<0W4P0
0000000000000`0000000`00B9`0oooo0?ooo`1T0?ooo`00X@3oool00`2oM000M;oo0?ooo`020?oo
o`030?noM000M;l0oooo00<0oooo00<0gia804Q8B000M;l0103oool00`2oM00007Bo0?ooo`020?oo
o`030?noM000B9`0oooo0080oooo00<0oono07@0M02oool01P3oool00`3ookl0M01d0;ooo`070?oo
o`030?oo_`1d07@0_ooo00@0oooo00L0W4Q809cOo`3oool0oooo0?oo_`1d000007Bo0080oooo00<0
_g@0001d_`3oool00P3oool00`3o_g@004RL0?ooo`0:0?ooo`030;md000007@0_ooo0080oooo00<0
omnL04Q8W03oool00`3oool00`3ookl0M01d0;ooo`040?ooo`030;md001d_ol0oooo0080oooo00<0
okmd001d_`3oool00P3oool01`3OW4P0B9cO0?ooo`3oool0gia80000M02oool0303oool00`3ookl0
M01d0;ooo`030?ooo`030?oo_`1d07@0_ooo0080oooo00<0_g@00000M02oool00P3oool00`2oM000
001809cOo`020?ooo`060?noM000B9`0oooo0?ooo`2oM00007Bo0`3oool00`3o_g@004RL0?ooo`03
0?ooo`030?oo_`1d07@0_ooo06P0oooo002P0?ooo`030?oo_`1dB9`0oooo00@0oooo00T0W4Q809cO
o`3oool0oooo0?oo_`1d07@0_ooo09a8B02Lgol00P3oool00`3ookl0M01d0;ooo`080?ooo`030?oo
_`1d07@0_ooo00H0oooo00<0oono07@0M02oool01`3oool00`3ookl0M01d0;ooo`030?ooo`030?oO
W018M;l0oooo00<0oooo00H0okmd001d_`3oool0oono07@0M02oool@0?ooo`030;md001d_ol0oooo
00<0oooo00<0_g@007Boo`3oool00P3oool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1dB9`0oooo
00@0oooo00H0W4Q809cOo`3oool0oooo0=nLB018W=lA0?ooo`030?oo_`1d07@0_ooo00<0oooo00<0
oono07@0B02Lgol00P3oool00`3ookl0M01d0;ooo`020?ooo`030;md001d_ol0oooo00<0oooo00D0
_gA809cOo`3ookl0M01d0;ooo`090?ooo`030?oo_`1d07@0_ooo06P0oooo002P0?ooo`030?oo_`1d
B9`0oooo00@0oooo00T0W4Q809cOo`3oool0oooo0=nLB018W=l0oooo0?noM000M;l00P3oool00`3o
okl0M00000000004000000070018W03oool0oooo0?ooo`3ookl0M01d0;ooo`060?ooo`030?oo_`1d
07@0_ooo00L0oooo00<0oono07@0M02oool00`3oool00`3ogi`0B7Bo0?ooo`030?ooo`050?noM000
M;l0oooo0?oo_`1d00001@0000000`00B9`0oooo0?ooo`090?ooo`030;md0018W=l0oooo00<0oooo
00<0_gA809cOo`3oool00P3oool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1dB9`0oooo00@0oooo
00H0W4Q809cOo`3oool0oooo0=nLB018W=lA0?ooo`030?oo_`1d07@0_ooo00@0oooo00<0omnL04P0
000000000P0000001P0007@0_ooo0?ooo`3oool0_g@004RLg`@0oooo00@0_g@007Boo`3ookl0M000
1@0000000`00B9`0oooo0?ooo`020?ooo`030?oo_`1d07@0_ooo06P0oooo002Q0?ooo`030;md0000
B9`0oooo0080oooo00L0_g@0001d_`3oool0oooo0?oo_`1d07@0_ooo0080oooo00H0W4Q809cOo`3o
ool0oooo0;md001d_ol30?ooo`0309a80018W=l0oooo0080oooo00@0oono07@000000000M;oo1@3o
ool0103ookl0M0000000001d_ol60?ooo`030?oo_`1d07@0_ooo00@0oooo00L0W4P004RLg`3oool0
oooo0?noM000000007Bo0080oooo00<0_g@007Boo`3oool00P3oool00`2LB000B9cO0?ooo`0:0?oo
o`030;md00000000M;oo0080oooo00<0gia80018W03oool00`3oool00`3ookl0M01d0;ooo`040?oo
o`030;md0000B9`0oooo0080oooo00<0_g@0001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0@0?oo
o`030?oo_`1d07@0_ooo00@0oooo00L0oono0;noo`3oool0oooo0?oOW01807@0_ooo0080oooo00<0
_g@000000018W=l00P3oool01P3OW4P004RL0?ooo`3oool0_g@007Boo`<0oooo00<0W4P004RLg`3o
ool00`3oool00`3ookl0M01d0;ooo`1X0?ooo`00XP3oool01@3OW4P0000000000000000007Bo0080
oooo00H0omnL04P000000000000007BLW01800020000000404RLg`3oool0oono07@000<0000000T0
B9cO0?ooo`3oool0oooo0=nLB0000000001d0;oo_`1d00000P0000001`1d_ol0oooo0=nLB0000000
001d0;oo_`1d00000P0000001`1d_ol0oooo0?oOW018000000000000M02oool01@3oool01P2LB000
00000000000007@0_kmd001d_`80oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`09
0?ooo`0409a800000000M;no07@00080000000<004RL0?ooo`3oool00`3oool00`3ookl0M01d0;oo
o`050?ooo`050=nLB0000000000000000000M;l00P3oool00`3ogi`0B00000000003000000030000
B02Lgol0oooo00`0oooo00<0oono07@0M02oool0103oool01P3ogi`0B000000000000000001809cO
o`<0oooo00<0_g@007Boo`2LB0000P0000001P00B9`0oooo0?ooo`3oool0oono07@000<0000000<0
B9cO0?ooo`3oool00`3oool00`3ookl0M01d0;ooo`1X0?ooo`00g03oool00`3o_g@007Bo0?ooo`0N
0?ooo`030?oo_`1d07@0_ooo00h0oooo00<0gia804RLg`3oool0403oool00`3ookl0M01d0;ooo`0=
0?ooo`030;md001d_ol0oooo0140oooo00<0oono07@0M02oool0J03oool00=`0oooo00<0okmd001d
_`3oool07P3oool00`3ookl0M01d0;ooo`0>0?ooo`030=nLB018W=l0oooo0100oooo00<0oono07@0
M02oool03@3oool00`2oM000M;oo0?ooo`0A0?ooo`030?oo_`1d07@0_ooo06P0oooo003@0?ooo`03
0?noM00007@0_ooo00P0oooo00<0okmd00000000M;l07@3oool01@3ogi`0B0000000000007@0_ooo
01l0oooo00D0omnL04P000000000001d0;ooo`0<0?ooo`030;md00000000M;oo0100oooo00D0omnL
04P000000000001d0;ooo`1X0?ooo`00d03oool00`3o_g@0001d0;ooo`3M0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.813, 0}} -> {-5.4479, -0.270811, \
0.094377, 0.00290868}}]
}, Closed]],

Cell[TextData[{
  "However, we must remember to reset the options for ",
  StyleBox["Plot", "InlineInput"],
  " \[LongDash] otherwise, the options appropriate to ",
  StyleBox["plotsbess", "InlineInput"],
  " would contaminate all other plots made during a session in which the \
options for ",
  StyleBox["Plot", "InlineInput"],
  " were modified."
}], "Text"],

Cell[BoxData[
    \(\(SetOptions[Plot, Sequence @@ saveOptions[Plot]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["More examples", "Section"],

Cell["\<\
Interesting examples require too much code and space for inclusion within \
this notebook, but several can be accessed using the hyperlinks provided \
below.  These examples illustrate many of the programming techniques \
introduced in this notebook.\
\>", "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["cicada.nb",
    ButtonData:>{"Applications/cicada.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " \[LongDash] explores the fascinating phenomenon of synchronized emergence \
of insect populations. "
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["logistic map.nb",
    ButtonData:>{"Applications/logistic map.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\[LongDash] explores the competition between order and chaos in discrete \
models of nonlinear dynamics."
}], "Text"],

Cell[TextData[{
  StyleBox[ButtonBox["cobweb.nb",
    ButtonData:>{"Applications/cobweb.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " \[LongDash] produces cobwebbing diagrams which illustrate the behavior of \
iterated function systems, such as the logistic map.  Some techniques of \
linear stability analysis are introduced."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Reverse integer", "ExerciseTitle"],

Cell["\<\
Write and test a function whose effect upon an integer is to reverse its \
digits.  For example, the input 123 should produce output 321.  Be sure to \
account for the sign.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Apocalyptic numbers", "ExerciseTitle"],

Cell[TextData[{
  "In numerology, a number of the form ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " that contains the ",
  StyleBox["beast number",
    FontSlant->"Italic"],
  " 666 among its sequence of decimal digits is known as an ",
  StyleBox["apocalyptic number",
    FontSlant->"Italic"],
  ".  Write a simple procedure that lists the first ",
  StyleBox["m",
    FontSlant->"Italic"],
  " exponents that generate apocalyptic numbers.  What are the first 10 \
apocalyptic numbers?"
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Scrambled list", "ExerciseTitle"],

Cell[TextData[{
  "The function ",
  StyleBox["RandomPermutation[n]", "InlineInput"],
  " in the ",
  StyleBox["DiscreteMath`Permutations", "InlineInput"],
  " package produces a random permutation of the integers between 1 and ",
  StyleBox["n",
    FontSlant->"Italic"],
  ".  Use this function to write a new function which accepts an input list \
and produces as output the same list in random (scrambled) order.  Test using \
the alphabet, which you can list with ",
  StyleBox["CharacterRange", "InlineInput"],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Making change", "ExerciseTitle"],

Cell[TextData[{
  "Write a function that determines the number of coins of each domination \
needed to provide a specified amount of change using the smallest number of \
coins.  The output should be a list of pairs containing the number of coins \
and its denomination.  For example, the change for 0.87 would be ",
  Cell[BoxData[
      \(TraditionalForm\`{{3, 0.25}, {1, 0.1}, {0, 0.05}, {2, 0.01}}\)]],
  ".  Begin with standard U.S. denominations, namely, ",
  Cell[BoxData[
      \(TraditionalForm\`{0.25, 0.1, 0.05, 0.01}\)]],
  ", and then generalize to an arbitrary list of denominations."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Continued fractions", "ExerciseTitle"],

Cell[TextData[{
  "a) Write a function which takes a list of numerators, of arbitrary length, \
and produces a simple continued fraction of the form   \n\t\t",
  StyleBox["cf[{a,b,c,d}] ", "InlineInput",
    FontWeight->"Plain"],
  "= ",
  Cell[BoxData[
      \(\(\(\ \)\(a\)\)\/\(1 + b\/\(1 + c\/\(1 + d\)\)\)\)],
    FontSize->16],
  "\n [Hint: ",
  StyleBox["Fold", "InlineInput"],
  " and ",
  StyleBox["Reverse", "InlineInput"],
  " are useful and ",
  StyleBox["FoldList", "InlineInput",
    FontWeight->"Bold"],
  " can be used to check the logic of your function.]"
}], "ExerciseText"],

Cell[TextData[{
  "b) Generalize your function so that\n \t\t",
  Cell[BoxData[
      \(TraditionalForm\`cf[{{a\_1, b\_1}, \ {a\_2, b\_2}, {a\_3, 
              b\_3}, {a\_4, b\_4}, \[CenterEllipsis]}]\  = \ 
        a\_1\/\(b\_1 + a\_2\/\(b\_2 + a\_3\/\(b\_3 + a\_4\/\(b\_4 + \
\[CenterEllipsis]\)\)\)\)\)]]
}], "ExerciseText"],

Cell[TextData[{
  "c) Continued-fraction expansions often converge more rapidly and over a \
wider domain than power series.  For example, the continued-fraction \
expansion for the tangent function has the form\n \t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(tan\ x\)\(\ \)\(=\)\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\/\(1\  - \ x\^2\/\(3\  - \ x\^2\/\(5\  - \ \
x\^2\/\(7\  - \ \[CenterEllipsis]\)\)\)\)\)]],
  "\nUsing simple numerical evaluation, demonstrate that this expansion \
converges quickly for ",
  Cell[BoxData[
      \(TraditionalForm\`x = 3\)]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "while the corresponding power series about ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "diverges.  The most efficient algorithms for many functions are based upon \
continued fractions."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Continued-fraction expansion of real numbers", "ExerciseTitle"],

Cell[TextData[{
  "Any real number ",
  StyleBox["x",
    FontSlant->"Italic"],
  " can be approximated by a continued-fraction expansion of the form\n\t",
  Cell[BoxData[
      \(TraditionalForm\`x \[TildeTilde] 
        a\_0 + 1\/\(a\_1 + 1\/\(a\_2 + 1\/\(a\_3 + \
\[CenterEllipsis]\)\)\)\)]],
  "\nwhere all ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_i}\)]],
  " are integers and those with ",
  Cell[BoxData[
      \(TraditionalForm\`i > 0\)]],
  " are all positive.  This representation is useful for irrational numbers, \
but for rational numbers the ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_i}\)]],
  " series terminates and sometimes contains very large integers.  For this \
exercise it is sufficient to concentrate upon irrational numbers and not to \
test for termination of the expansion."
}], "ExerciseText"],

Cell[TextData[{
  "a) Write a function based upon ",
  StyleBox["NestList", "InlineInput"],
  " which produces the list ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_i}\)]],
  " and a function based upon ",
  StyleBox["Fold", "InlineInput"],
  " that constructs the expansion.  [Hint: ",
  StyleBox["Floor", "InlineInput"],
  " is helpful.]"
}], "ExerciseText"],

Cell[TextData[{
  "b) Test your function by showing that all coefficients in the expansion of \
",
  StyleBox["GoldenRatio", "InlineInput"],
  " are equal to 1.  "
}], "ExerciseText"],

Cell["\<\
c) Find the first 10 terms in the continued-fraction expansion of \[Pi].  How \
accurate is this approximation?\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Iterated logarithm function", "ExerciseTitle"],

Cell[TextData[{
  "The iterated logarithm function ",
  Cell[BoxData[
      \(TraditionalForm\`ilg[n]\)]],
  " is defined as the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " for which ",
  Cell[BoxData[
      \(TraditionalForm\`lg[n, i] \[LessEqual] 1\)]],
  " where\n\tlg[n] = Log[2,n]\n\t",
  Cell[BoxData[
      \(TraditionalForm\`lg[n, i]\  = \ n\)]],
  "\t\t\tif ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`lg[n, i]\  = \ lg[lg[n, i - 1]]\)]],
  "\tif ",
  Cell[BoxData[
      \(TraditionalForm\`i > 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`lg[n, i - 1] > 0\)]],
  "\nand is otherwise undefined.  "
}], "ExerciseText"],

Cell[TextData[{
  "a) Write a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function that evaluates ",
  Cell[BoxData[
      \(TraditionalForm\`ilg[n]\)]],
  " and show that ",
  Cell[BoxData[
      \(TraditionalForm\`ilg[65536] = 4\)]],
  ".  "
}], "ExerciseText"],

Cell[TextData[{
  "b) Evaluate ilg[n] for n\[Element]",
  Cell[BoxData[
      \(TraditionalForm\`{2, 4, 16, 65536, 2\^65536, 4\^65536}\)]],
  " and comment."
}], "ExerciseText"],

Cell["\<\
c) Evaluate the following cells and interpret the results.  [Notes: 1) these \
cells are given here in unevaluatable form.  2) Do not try to nest any more \
than 4 times.]\
\>", "ExerciseText"],

Cell[BoxData[
    \(holdstuff = NestList[HoldForm[2\^#] &, 2, 4]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(stuff = holdstuff //. HoldForm[x_] \[Rule] x\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(ilg /@ stuff\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Rabbit multiplication", "ExerciseTitle"],

Cell[TextData[{
  "Leonardo of Pisa, commonly known as Fibonacci (meaning son, or ",
  StyleBox["filius",
    FontSlant->"Italic"],
  ",",
  StyleBox[" ",
    FontSlant->"Italic"],
  "of Bonacci), is credited with popularizing the use of the Arabic (decimal) \
numbering system in Europe with his influential algebra book, ",
  StyleBox["Liber Abaci",
    FontSlant->"Italic"],
  ", published in 1202.  He posed and solved the following problem.  Suppose \
that a pair of rabbits is born at time 0, matures in one month, and the next \
month and every month thereafter produces another pair of offspring.  Each \
new pair also matures in one month and produces a new pair every month, \
beginning with their second month.  Assume that rabbits live forever. "
}], "ExerciseText"],

Cell[TextData[{
  "a) Develop a function ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n\)]],
  " for the number of pairs present at month ",
  StyleBox["n",
    FontSlant->"Italic"],
  ".  Use appropriate type checking, conditions, and/or pattern tests to \
restrict ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "b) Show numerically that ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(n + 1\)/F\_n \[RightArrow] GoldenRatio\)]],
  " for large ",
  StyleBox["n",
    FontSlant->"Italic"],
  ".  "
}], "ExerciseText"],

Cell[TextData[{
  "c) Deduce the limiting value of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(n + 1\)/F\_n\)]],
  " symbolically."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Prime Fibonacci sequence", "ExerciseTitle"],

Cell[TextData[{
  "Fibonacci numbers satisfy the recursion relation ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n = \ F\_\(n - 1\) + \ F\_\(n - 2\)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1 = \(F\_2 = 1\)\)]],
  ".  "
}], "ExerciseText"],

Cell[TextData[{
  "a) Write a function which produces a list of the lowest ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " Fibonacci numbers, given valid input for ",
  StyleBox["m",
    FontSlant->"Italic"],
  ".  Use appropriate type checking, and conditions and/or pattern tests."
}], "ExerciseText"],

Cell[TextData[{
  "b) Write another function which selects those that are prime [hint: use \
the built-in function ",
  StyleBox["Select", "InlineInput"],
  "]."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multistep function", "ExerciseTitle"],

Cell[TextData[{
  "a) Generalize the step function so that ",
  StyleBox["step[x,a,b]", "InlineInput"],
  " produces a step of height ",
  StyleBox["a", "InlineInput"],
  " at ",
  StyleBox["x=b", "InlineInput"],
  ".  Your function should also produce a unit step at ",
  StyleBox["x=b", "InlineInput"],
  " if called as ",
  StyleBox["step[x,b]", "InlineInput"],
  " or a unit step at ",
  StyleBox["x=0", "InlineInput"],
  " if called as ",
  StyleBox["step[x]", "InlineInput"],
  ".  Use multiple definitions with conditions applied to pattern arguments \
rather than ",
  StyleBox["If", "InlineInput"],
  " statements or similar constructions."
}], "ExerciseText"],

Cell[TextData[{
  "b) Write a multistep function such that ",
  StyleBox["multistep[x,{{a,b},\[CenterEllipsis]}]", "InlineInput"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "produces steps of height ",
  StyleBox["a", "InlineInput"],
  " at each ",
  StyleBox["b", "InlineInput"],
  " in a list of ",
  StyleBox["{a,b}", "InlineInput"],
  " pairs.  For example, the following plot uses four ",
  StyleBox["{height,position}", "InlineInput"],
  " pairs to produce a wall and a well."
}], "ExerciseText"],

Cell[TextData[StyleBox["Plot[Evaluate[multistep[x,{{2,-1},{-2,2},{-1,3},{1,3.\
5}}]],{x,-5,5}];", "InlineInput"]], "ExerciseText"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.210916 0.196201 [
[.11905 .19842 -6 -9 ]
[.11905 .19842 6 0 ]
[.30952 .19842 -6 -9 ]
[.30952 .19842 6 0 ]
[.69048 .19842 -3 -9 ]
[.69048 .19842 3 0 ]
[.88095 .19842 -3 -9 ]
[.88095 .19842 3 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .11282 -24 -4.5 ]
[.4875 .11282 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .40712 -6 -4.5 ]
[.4875 .40712 0 4.5 ]
[.4875 .50522 -18 -4.5 ]
[.4875 .50522 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.11905 .21092 m
.11905 .21717 L
s
[(-4)] .11905 .19842 0 1 Mshowa
.30952 .21092 m
.30952 .21717 L
s
[(-2)] .30952 .19842 0 1 Mshowa
.69048 .21092 m
.69048 .21717 L
s
[(2)] .69048 .19842 0 1 Mshowa
.88095 .21092 m
.88095 .21717 L
s
[(4)] .88095 .19842 0 1 Mshowa
.125 Mabswid
.16667 .21092 m
.16667 .21467 L
s
.21429 .21092 m
.21429 .21467 L
s
.2619 .21092 m
.2619 .21467 L
s
.35714 .21092 m
.35714 .21467 L
s
.40476 .21092 m
.40476 .21467 L
s
.45238 .21092 m
.45238 .21467 L
s
.54762 .21092 m
.54762 .21467 L
s
.59524 .21092 m
.59524 .21467 L
s
.64286 .21092 m
.64286 .21467 L
s
.7381 .21092 m
.7381 .21467 L
s
.78571 .21092 m
.78571 .21467 L
s
.83333 .21092 m
.83333 .21467 L
s
.07143 .21092 m
.07143 .21467 L
s
.02381 .21092 m
.02381 .21467 L
s
.92857 .21092 m
.92857 .21467 L
s
.97619 .21092 m
.97619 .21467 L
s
.25 Mabswid
0 .21092 m
1 .21092 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .11282 m
.50625 .11282 L
s
[(-0.5)] .4875 .11282 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.5)] .4875 .30902 1 0 Mshowa
.5 .40712 m
.50625 .40712 L
s
[(1)] .4875 .40712 1 0 Mshowa
.5 .50522 m
.50625 .50522 L
s
[(1.5)] .4875 .50522 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .03434 m
.50375 .03434 L
s
.5 .05396 m
.50375 .05396 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .0932 m
.50375 .0932 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .15206 m
.50375 .15206 L
s
.5 .17168 m
.50375 .17168 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .23054 m
.50375 .23054 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .26978 m
.50375 .26978 L
s
.5 .2894 m
.50375 .2894 L
s
.5 .32864 m
.50375 .32864 L
s
.5 .34826 m
.50375 .34826 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .44636 m
.50375 .44636 L
s
.5 .46598 m
.50375 .46598 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .52484 m
.50375 .52484 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .56408 m
.50375 .56408 L
s
.5 .5837 m
.50375 .5837 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21092 m
.06244 .21092 L
.10458 .21092 L
.14415 .21092 L
.18221 .21092 L
.22272 .21092 L
.26171 .21092 L
.30316 .21092 L
.34309 .21092 L
.3815 .21092 L
.39174 .21092 L
.39675 .21092 L
.40134 .21092 L
.40252 .21092 L
.40381 .21092 L
.40503 .60332 L
.40616 .60332 L
.41134 .60332 L
.42237 .60332 L
.4615 .60332 L
.50308 .60332 L
.54314 .60332 L
.58169 .60332 L
.6227 .60332 L
.64312 .60332 L
.66219 .60332 L
.6716 .60332 L
.68051 .60332 L
.68543 .60332 L
.68678 .60332 L
.68821 .60332 L
.68944 .60332 L
.69013 .60332 L
.69079 .21092 L
.69193 .21092 L
.69314 .21092 L
.6953 .21092 L
.70016 .21092 L
.73827 .21092 L
.75952 .21092 L
.76956 .21092 L
.77883 .21092 L
.78125 .21092 L
.78351 .21092 L
.78465 .21092 L
.78587 .01472 L
.78656 .01472 L
.78722 .01472 L
.78846 .01472 L
.79891 .01472 L
Mistroke
.81787 .01472 L
.82748 .01472 L
.83025 .01472 L
.83161 .01472 L
.83285 .01472 L
.83399 .21092 L
.83519 .21092 L
.83772 .21092 L
.85612 .21092 L
.89414 .21092 L
.93462 .21092 L
.97358 .21092 L
.97619 .21092 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{275, 169.625},
  ImageMargins->{{42.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006L0000oR000`400?l00000o`00003oo`3ooonM
0?ooo`00c@3oool00`000000oooo0?ooo`3<0?ooo`00c@3oool00`000000oooo0?ooo`3<0?ooo`00
`03oool00`3o_g@000000000000300000003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0
c03oool00<<0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`3<0?ooo`00``3oool0
0`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo0<`0oooo00330?ooo`0309a8B02Lgol0oooo
00L0oooo00<000000?ooo`3oool0c03oool00;L0oooo00<0W4P00000000000000`0000000`00B9`0
oooo0?ooo`030?ooo`0309a8B02Lgol0oooo00L0oooo1000001a0?oooa@00000AP3oool00<<0oooo
00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0A03oool00<<0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<00oooo00D0gia8
00000000B9`0W4Q809cOo`080?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`140?ooo`00`P3oool00`3OW4P0001809cOo`080?ooo`030000003oool0
oooo0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`00c@3oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0
oooo003=0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`140?ooo`00c@3oool300000780oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`140?ooo`00c@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0
oooo0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`00c@3oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0
oooo0`00001b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo
003=0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`140?ooo`00c@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo003=0?ooo`<00000LP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo
003=0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`140?ooo`00c@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`140?ooo`00c@3oool300000780oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`00[`3oool01@3o_g@0
0000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000
M;oo00L0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo04@0oooo002_0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d
_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`060?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`00[P3oool00`3o_g@007Bo
0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0okmd001d_`3oool01@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00:h0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo002U
0?ooo`0309a800000000000000<0000000D004RL0?ooo`3oool0gia804RLg`030?ooo`030?noM000
M;l0oooo00l0oooo00<0W4P007Boo`3oool01@3oool400000700oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`140?ooo`00[P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`050?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`00[P3oool00`3o
_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0M02oool02P3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool00:l0
oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo_`1d07@0_ooo00X0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0oooo002_0?oo
o`050?oo_`1d000000000000B02Lgol0303oool00`3ookl0M00000000002000000030000M02oool0
oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo04@0oooo003=0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo04@0oooo003=0?ooo`<00000L@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`00c@3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03o
ool00<d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo04@0oooo003=0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`140?ooo`00c@3oool300000740oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`00=@3o
ool01@3ogi`0B000000000000000M;oo04H0oooo00<0oono07@000000000100000000`1d_ol0oooo
0?ooo`130?ooo`030000003oool0oooo04H0oooo00<0oono07@000000000100000000`1d_ol0oooo
0?ooo`0Q0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool01@3ogi`0B000
000000000000M;oo0300oooo000g0?ooo`030;md001d_ol0oooo04L0oooo00<0_g@00000M02oool0
0P3oool00`3OW7@0W=oo0?ooo`140?ooo`<00000A`3oool00`2oM000001d0;ooo`020?ooo`030=nL
M02Lgol0oooo0280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030;md
001d_ol0oooo0300oooo000g0?ooo`030;md001d_ol0oooo04P0oooo00<0okmd0000B02Lgol0B03o
ool00`000000oooo0?ooo`180?ooo`030?noM00004P0W=oo02H0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030;md001d_ol0oooo0300oooo000c0?ooo`030=nLB0000000
000000<0000000<0M;oo0?ooo`3oool0A`3oool00`3ogi`0B00004RLg`170?ooo`030000003oool0
oooo04T0oooo00<0omnL04P00018W=l09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00d0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`0^0?ooo`00:P3oool00`2L
B000000000000003000000090018W03oool0oooo0?noM00007@0_ooo0?ooo`2oM000M;oo03l0oooo
00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0oooo04D0oooo
00<000000?ooo`3oool0B`3oool00`2LB000B9cO0?ooo`0S0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool03@3oool01P3o_g@0001d0;ooo`3oool0_g@007Booc40oooo000d0?ooo`05
0=nLB000M;l0oooo0;md001d_ol0C@3oool00`2LB7@0_ooo0?ooo`140?ooo`030000003oool0oooo
04`0oooo00<0W4Qd0;ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00h0oooo00D0gia8001d_`3oool0_g@007Boo`0a0?ooo`00=@3oool0102LB000B9cO0;md001d_om8
0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool0A03oool00`000000oooo0?ooo`17
0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool08P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00l0oooo00@0W4P004RLg`2oM000M;oo<@3oool003D0oooo00@0omnL
04P0B018B000M;ooB03oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0A@3oool00`000000
oooo0?ooo`170?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0S0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool03`3oool0103ogi`0B01804Q8001d_ola0?ooo`00=P3oool0
0`3o_g@0000007Boo`190?ooo`050?noM000000000000000B02Lgol0AP3oool00`000000oooo0?oo
o`180?ooo`050?noM000000000000000B02Lgol0903oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<0okmd0000001d_ol0<@3oool00<d0oooo0`00001a0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0oooo003=0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`140?ooo`00c@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool00<d0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0oooo
003=0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`140?ooo`00c@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0A03oool00<d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo04@0oooo00000`3oool000000000003o000009P000000P3oool000/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo
000b0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0`0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0
oooo02@0oooo0`00001;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo
002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`<00000
B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo
002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool3000004/0oooo00<000000?oo
o`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo
002V0?ooo`030000003oool0oooo02@0oooo0`00001;0?ooo`030000003oool0oooo07h0oooo002V
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n
0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo00H0oooo00D0okmd000000000000
000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`070?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3o
ool01P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool0
1`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo00D0oooo00<0okmd001d_`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`050?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool01@3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool01@3oool40000
04X0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool01@3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0
oooo0?ooo`050?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo
00<000000?ooo`3oool01@3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo
00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo
002V0?ooo`030000003oool0oooo00H0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`03
0?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00
YP3oool00`000000oooo0?ooo`060?ooo`050?oo_`1d000000000000B02Lgol0303oool00`3ookl0
M00000000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?oo
o`<00000B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool0
0:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool3000004/0oooo00<0
00000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool0
0:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
07h0oooo002V0?ooo`030000003oool0oooo02@0oooo0`00001;0?ooo`030000003oool0oooo07h0
oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool0
0`000000oooo0?ooo`0T0?ooo`<00000B`3oool00`000000oooo0?ooo`1n0?ooo`00YP3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:H0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0
oooo002V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1n0?ooo`00YP3oool00`000000oooo0?ooo`0G0?ooo`030?noM0000000000000<0000000<0
07Bo0?ooo`3oool0103oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V
0?ooo`030000003oool0oooo01X0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo01X0oooo00<0W4Q809cO
o`3oool01`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002V0?ooo`03
0000003oool0oooo01X0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo07h0oooo002V0?ooo`030000003oool0oooo01X0oooo00<0W4Q809cOo`3oool0
1`3oool4000004X0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool06@3o
ool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3o
ool00:L0oooo00<000000?ooo`3oool06@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool05P3oool01@3O
W4P000000018W02LB4P0W=oo00P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n
0?ooo`00Y`3oool00`000000oooo0?ooo`0H0?ooo`030=nLB00004P0W=oo00P0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool0
0`000000oooo0?ooo`0S0?ooo`<00000B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0
oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool0
8`3oool3000004/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0
oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo0`00001;0?oo
o`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0
oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`<00000B`3oool00`000000oooo0?oo
o`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`040?ooo`030?no
M0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`050?ooo`050;md
0000000000000000001d_ol01`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0
oooo002W0?ooo`030000003oool0oooo00L0oooo00<0W4Q809cOo`3oool01@3oool00`2oM0000000
001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`060?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool01`3oool00`2LB4P0
W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`070?ooo`0309a8B02Lgol0oooo0140oooo
00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo
002W0?ooo`030000003oool0oooo00L0oooo00<0W4Q809cOo`3oool04@3oool00`2LB000M;oo0?oo
o`050?ooo`@00000BP3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`07
0?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`05
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?oo
o`3oool01`3oool00`2LB4P0W=oo0?ooo`0<0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`040?ooo`05
0=nLB000000004RL09a8B02Lgol03@3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool01P3oool00`3OW4P0
001809cOo`0=0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01@3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?oo
o`030000003oool0oooo02<0oooo0`00001;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00
Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?oo
o`0S0?ooo`<00000B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00
Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool3000004/0
oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00
Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo0`00001;0?ooo`030000003oool0
oooo07h0oooo002W0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo07h0oooo002W0?ooo`030000003oool0oooo01D0oooo00<0
oono07@000000000100000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0OP3oool00:L0oooo00<000000?ooo`3oool05P3oool00`2oM000001d0;ooo`02
0?ooo`030=nLM02Lgol0oooo00D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n
0?ooo`00Y`3oool00`000000oooo0?ooo`0G0?ooo`030?noM00004P0W=oo00T0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00Y`3oool00`000000oooo0?ooo`0H0?ooo`03
0?oOW0180000B9cO00P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1n0?ooo`00
Y`3ooome00000800oooo00350?ooo`0309a8M02oool0oooo00D0oooo00<000000?ooo`3oool0c03o
ool00<00oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0
oooo0<`0oooo00300?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`060?ooo`030000003o
ool0oooo0<`0oooo00310?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo0?oo
o`3<0?ooo`00c@3oool00`000000oooo0?ooo`3<0?ooo`00c@3oool00`000000oooo0?ooo`3<0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 411.5}, {253.438, 0}} -> {-5.29975, -1.08439, \
0.0386373, 0.018755}}],

Cell[TextData[{
  "Your function should also respond appropriately to input in the form ",
  StyleBox["multistep[x,a,b]", "InlineInput"],
  ", ",
  StyleBox["multistep[x,b]", "InlineInput"],
  ", or ",
  StyleBox["multistep[x]", "InlineInput"],
  " as well.  [Hint: use multiple definitions for well-defined patterns.  The \
true multistep definition should map ",
  StyleBox["step", "InlineInput"],
  " onto a list and apply ",
  StyleBox["Plus", "InlineInput"],
  " to sum the result.]  "
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simpson's rule ", "ExerciseTitle"],

Cell["Simpson's rule for numerical integration has the form", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_a\%b 
          f \[DifferentialD]x\  \[TildeTilde] \ \(\(b - a\)\/\(3  n\)\)[
        f\_0 + 4  f\_1 + 2  f\_2 + 4  f\_3 + \ \[CenterEllipsis]\  + 
          2  f\_\(n - 2\) + 4  f\_\(n - 1\) + f\_n]\)], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] 2\)]],
  " is an even integer.  Note that standard notation in numerical analysis \
identifies ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_k]\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k = x\_0 + k\ h\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h = \((x\_n - x\_0)\)/n\)]],
  ".  Here we identify ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n = b\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h = \((b - a)\)/n\)]],
  ".  There is no need to use subscripts in your ",
  StyleBox["simpson", "InlineInput"],
  " function."
}], "ExerciseText"],

Cell[TextData[{
  "a) Write a corresponding ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is given as a function."
}], "ExerciseText"],

Cell[TextData[{
  "b) Evaluate and simplify ",
  StyleBox["simpson[f,0,1,4]", "InlineInput"],
  " where ",
  StyleBox["f", "InlineInput"],
  " is undefined.  You should obtain a symbolic expression of Simpson's \
rule."
}], "ExerciseText"],

Cell["\<\
c) Test your function using the fact that Simpson's rule is exact for \
polynomials of degree less than or equal to 3.\
\>", "ExerciseText"],

Cell[TextData[{
  "d) Finally, test your function for a more practical example by comparing \
the Simpson approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(\[Pi]/4\)\(x\^2\) 
          Tan[x] \[DifferentialD]x\)]],
  " with the exact result.  Show that the accuracy improves as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trapezoid rule", "ExerciseTitle"],

Cell[TextData[{
  "The trapezoid rule for numerical integration has the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b 
            f \[DifferentialD]x\  \[TildeTilde] \ \(1\/2\) \(\[Sum]\+\(n = \
1\)\%\(N - 1\)\((x\_\(n + 1\) - x\_n)\) \((f\_\(n + 1\) + \ f\_n)\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\) > x\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1 = a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_N = b\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i = \ f(x\_i)\)]],
  ". "
}], "ExerciseText"],

Cell[TextData[{
  "a) Write a function which accepts data in the form of a two-dimensional \
array ",
  Cell[BoxData[
      \(TraditionalForm\`{{x\_1, 
          f\_1}, \ \[CenterEllipsis] {x\_N, f\_N}}\)]],
  " and uses ",
  StyleBox["Sum", "InlineInput"],
  " to evaluate the trapezoidal integral.  Do not assume that the data are \
equally spaced or arranged in order of increasing ",
  StyleBox["x",
    FontSlant->"Italic"],
  " \[LongDash] your function should sort the data appropriately.  Your \
function should include a usage message and its argument should be in the \
form of a specialized pattern.  "
}], "ExerciseText"],

Cell[TextData[{
  "b) Test your function by evaluating ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Integral]\_0\%\[Pi]\( x\^2\) Sin[3  x] \[DifferentialD]x\)]],
  " using a table containing 101 uniformly spaced points.  Compare with the \
exact value."
}], "ExerciseText"],

Cell["\<\
c) Verify that scrambling the data does not change the result.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple periodic functions", "ExerciseTitle"],

Cell["\<\
a) Write and plot a function which produces a square wave of specified period \
with amplitude \[PlusMinus]1.  Give the period a default value of unity.\
\>", "ExerciseText"],

Cell[TextData[{
  "b) Write and plot a function which produces a sawtooth wave with specified \
period varying between \[PlusMinus]1.  [Hint: ",
  StyleBox["Floor", "InlineInput"],
  " and ",
  StyleBox["Mod", "InlineInput"],
  " can be helpful.]"
}], "ExerciseText"],

Cell["\<\
c) Write and plot a function which produces a triangular wave with specified \
period varying between \[PlusMinus]1.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Propagation of errors", "ExerciseTitle"],

Cell[TextData[{
  "The theory of propagation of errors tells us that if a quantity ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " depends upon several independent variables ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_i}\)]],
  " with errors randomly distributed according to normal distributions with \
standard deviations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]x\_i\)]],
  ", then the square of the uncertainty in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]f\)]],
  ", is given by "
}], "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        StyleBox[
          
          FormBox[\(\((\[Delta]\[VeryThinSpace]f)\)\^2\  = \ \ \[Sum]\+i\((\ \
\(\[PartialD]f\/\[PartialD]x\_i\) \[Delta]\[VeryThinSpace]x\_i)\)\^2\),
            "TraditionalForm"],
          FontFamily->"Times New Roman"], "  "}], 
      TraditionalForm]], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "We wish to write a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function that evaluates the uncertainty in any expression given a list of \
independent variables.  This can be accomplished by mapping the function ",
  Cell[BoxData[
      \(\((Dt[#] D[f, #])\)\^2 &\)],
    FontWeight->"Bold"],
  " onto the list of variables, where the total differential ",
  StyleBox["Dt[x]", "InlineInput"],
  " represents the uncertainty in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", namely ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]x\)]],
  ".  The result is a list of contributions to the variance of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", which can then be added by applying ",
  StyleBox["Plus", "InlineInput"],
  " to the list (don't use ",
  StyleBox["Sum", "InlineInput"],
  ").  Finally, we evaluate the square root and assign the result to the \
uncertainty."
}], "ExerciseText"],

Cell["\<\
a) Write two versions of the uncertainty function, one for handling a list of \
independent variables and another to handle the special case of a single \
variable (instead of a list).  Your function definitions should include \
pattern tests to differentiate between these cases.\
\>", "ExerciseText"],

Cell[TextData[{
  "b) The period for small-amplitude oscillations of a simple pendulum is \
given by ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ 2  \[Pi] \@\( \[ScriptL]\/g\)\)]],
  ".  If you were to use this relationship to measure ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ", the uncertainty ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]g\)]],
  " would involve uncertainties in the measured length and period, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]\[ScriptL]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]T\)]],
  " respectively.  Solve for ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\)]],
  " and obtain an expression for the propagation of errors."
}], "ExerciseText"],

Cell["\<\
c) Demonstrate that the correct result is also obtained if one assumes that \
the length is known perfectly.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianIntegerQ", "ExerciseTitle"],

Cell[TextData[{
  "Write a ",
  StyleBox["GaussianIntegerQ", "InlineInput"],
  " function which returns True for a Gaussian integer or False otherwise.  \
Recall that a Gaussian integer is a complex number whose real and imaginary \
parts are both integers, with real integers comprising a subset of the \
Gaussian integers.  [Hint: use ",
  StyleBox["FullForm", "InlineInput"],
  " to identify the appropriate patterns and ",
  StyleBox["MatchQ", "InlineInput"],
  " to compare the argument with those patterns.]"
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fibonacci sequence by matrix multiplication", "ExerciseTitle"],

Cell[TextData[{
  "Write a recursive function for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " power of the matrix m={{1,1},{1,0}} that uses dynamic programming.  \
Observe that the \[LeftDoubleBracket]1,1\[RightDoubleBracket] element of ",
  Cell[BoxData[
      \(TraditionalForm\`m\^n\)]],
  " appears to generate the Fibonacci sequence ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(n + 1\)\)]],
  "; prove that hypothesis by induction using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Retirement planning", "ExerciseTitle"],

Cell[TextData[{
  "Suppose that you deposit a constant amount ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " at the end of every month beginning at age ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  " and that your money earns an average annual interest rate ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " compounded monthly.  You retire at age ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1\)]],
  " and then draw monthly payments ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " from your nest egg.  Write a function that computes the value of your \
retirement account at the beginning of any year ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ".  To be specific, if you open your retirement account at age 25, retire \
at age 65, deposit $300 per month with 6% interest, how long can you draw a \
monthly payment of $5000 after retirement?  This is a simplified analysis \
that does not account for variations of the deposit or interest rate, but it \
is a reasonable starting point."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Julia sets", "ExerciseTitle"],

Cell[TextData[{
  "Julia sets are very closely related to the Mandelbrot set.  For a fixed \
parameter ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox["cx",
              FontSlant->"Italic"], " ", "+", " ", 
            StyleBox[\(I\ cy\),
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ", each point of the complex plane ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", " ", "=", " ", 
          RowBox[{
            StyleBox["zx",
              FontSlant->"Italic"], " ", "+", " ", 
            RowBox[{"I", " ", 
              StyleBox["zy",
                FontSlant->"Italic"]}]}]}], TraditionalForm]]],
  " will either be trapped or will escape to infinity under the quadratic \
iteration ",
  Cell[BoxData[
      \(TraditionalForm\`z\  \[RightArrow] \ z\^2\  + \ c\)]],
  ".  Note that the Mandelbrot set is displayed in the complex ",
  StyleBox["c",
    FontSlant->"Italic"],
  "-plane given the initial point ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0 = 0\)]],
  ", while the Julia set is displayed in the complex ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-plane given fixed ",
  StyleBox["c.",
    FontSlant->"Italic"],
  "  The Julia set for parameter ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " consists of all points which are trapped, but as for the Mandelbrot set a \
more appealing display can be made by coloring points ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " according to some function of their escape rates.  Write a \
well-documented function which evaluates escape rates as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ".  Display Julia sets for the following parameters, known to give \
beautiful pictures (see Peitgen and Richter).  You may wish to experiment \
with the coloring function.\na) ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(c\  = \ \((\(-0.74543\), \ 
          0.11301)\)\)\)\)]],
  "\t\tb) ",
  Cell[BoxData[
      \(TraditionalForm\`c = \((\(-1.25\), \ 0)\)\)]],
  "\tc) ",
  Cell[BoxData[
      \(TraditionalForm\`c\  = \ \((0.11031, \ \(-0.67037\))\)\)]],
  " "
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
IndexCreationOptions->{"Format"->"Hyperlinks"},
ShowSelection->True,
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "implicit functions"->{
    Cell[6046, 173, 119, 3, 51, "Section",
      CellTags->"implicit functions"]},
  "Info3312795150-1116509"->{
    Cell[9087, 308, 63, 1, 34, "Print",
      CellTags->"Info3312795150-1116509"],
    Cell[9153, 311, 423, 13, 35, "Print",
      CellTags->"Info3312795150-1116509"]},
  "explicit functions"->{
    Cell[12955, 464, 71, 1, 51, "Section",
      CellTags->"explicit functions"],
    Cell[13557, 479, 104, 1, 68, "Subsection",
      CellTags->{"patterns as arguments", "explicit functions"}]},
  "patterns as arguments"->{
    Cell[13557, 479, 104, 1, 68, "Subsection",
      CellTags->{"patterns as arguments", "explicit functions"}]},
  "Info3312795210-5631052"->{
    Cell[18803, 678, 63, 1, 34, "Print",
      CellTags->"Info3312795210-5631052"],
    Cell[18869, 681, 557, 15, 98, "Print",
      CellTags->"Info3312795210-5631052"]},
  "command sequences"->{
    Cell[125248, 2933, 91, 1, 51, "Section",
      CellTags->"command sequences"]},
  "pure functions"->{
    Cell[128297, 3023, 63, 1, 51, "Section",
      CellTags->"pure functions"]},
  "pure functions with names"->{
    Cell[129007, 3048, 88, 1, 68, "Subsection",
      CellTags->"pure functions with names"]},
  "Info3312795303-7827047"->{
    Cell[130007, 3095, 63, 1, 34, "Print",
      CellTags->"Info3312795303-7827047"],
    Cell[130073, 3098, 453, 13, 36, "Print",
      CellTags->"Info3312795303-7827047"]},
  "pure functions of several variables"->{
    Cell[135091, 3286, 108, 1, 68, "Subsection",
      CellTags->"pure functions of several variables"]},
  "anonymous functions"->{
    Cell[138083, 3408, 76, 1, 68, "Subsection",
      CellTags->"anonymous functions"]},
  "skeletal notation"->{
    Cell[139428, 3464, 72, 1, 68, "Subsection",
      CellTags->"skeletal notation"]},
  "Info3312795419-4618591"->{
    Cell[147967, 3768, 63, 1, 34, "Print",
      CellTags->"Info3312795419-4618591"],
    Cell[148033, 3771, 510, 14, 36, "Print",
      CellTags->"Info3312795419-4618591"]},
  "interpolating functions"->{
    Cell[148912, 3798, 93, 1, 68, "Subsection",
      CellTags->"interpolating functions"]},
  "recursive functions"->{
    Cell[196941, 4837, 73, 1, 51, "Section",
      CellTags->"recursive functions"]},
  "Info3312795474-4594259"->{
    Cell[208175, 5135, 71, 1, 34, "Print",
      CellTags->"Info3312795474-4594259"],
    Cell[208249, 5138, 525, 15, 80, "Print",
      CellTags->"Info3312795474-4594259"]},
  "Info3312795480-9399269"->{
    Cell[208862, 5161, 72, 1, 34, "Print",
      CellTags->"Info3312795480-9399269"],
    Cell[208937, 5164, 25184, 618, 6195, "Print",
      CellTags->"Info3312795480-9399269"]},
  "conditions on arguments"->{
    Cell[237378, 5874, 81, 1, 51, "Section",
      CellTags->"conditions on arguments"]},
  "type checking"->{
    Cell[237484, 5879, 64, 1, 68, "Subsection",
      CellTags->"type checking"]},
  "Info3312795544-2481890"->{
    Cell[240288, 6019, 63, 1, 34, "Print",
      CellTags->"Info3312795544-2481890"],
    Cell[240354, 6022, 733, 21, 236, "Print",
      CellTags->"Info3312795544-2481890"]},
  "definitions with conditions"->{
    Cell[241240, 6053, 92, 1, 68, "Subsection",
      CellTags->"definitions with conditions"]},
  "predicates"->{
    Cell[301232, 7600, 61, 1, 68, "Subsection",
      CellTags->"predicates"]},
  "Info3312795629-5419543"->{
    Cell[322558, 8135, 326, 9, 35, "Print",
      CellTags->"Info3312795629-5419543"]},
  "Info3312795630-5419172"->{
    Cell[322967, 8152, 325, 9, 35, "Print",
      CellTags->"Info3312795630-5419172"]},
  "Info3312795631-8819510"->{
    Cell[323374, 8169, 322, 9, 35, "Print",
      CellTags->"Info3312795631-8819510"]},
  "Info3312795632-7419729"->{
    Cell[323781, 8186, 322, 9, 35, "Print",
      CellTags->"Info3312795632-7419729"]},
  "Info3312795634-1579497"->{
    Cell[324189, 8203, 334, 9, 35, "Print",
      CellTags->"Info3312795634-1579497"]},
  "Info3312795635-3734403"->{
    Cell[324608, 8220, 517, 11, 85, "Print",
      CellTags->"Info3312795635-3734403"]},
  "Info3312795638-6034247"->{
    Cell[325210, 8239, 516, 11, 85, "Print",
      CellTags->"Info3312795638-6034247"]},
  "Info3312795644-9360992"->{
    Cell[325930, 8263, 311, 9, 35, "Print",
      CellTags->"Info3312795644-9360992"]},
  "Info3312795645-4283247"->{
    Cell[326327, 8280, 311, 9, 35, "Print",
      CellTags->"Info3312795645-4283247"]},
  "arguments matching patterns"->{
    Cell[334410, 8546, 105, 1, 68, "Subsection",
      CellTags->"arguments matching patterns"]},
  "overlapping definitions"->{
    Cell[338843, 8678, 84, 1, 68, "Subsection",
      CellTags->"overlapping definitions"]},
  "protection of local variables"->{
    Cell[341150, 8748, 93, 1, 51, "Section",
      CellTags->"protection of local variables"]},
  "modular programing"->{
    Cell[348950, 9018, 72, 1, 51, "Section",
      CellTags->"modular programing"]},
  "scoping commands"->{
    Cell[349730, 9036, 70, 1, 68, "Subsection",
      CellTags->"scoping commands"]},
  "Module"->{
    Cell[350065, 9047, 53, 1, 55, "Subsubsection",
      CellTags->"Module"]},
  "With"->{
    Cell[529609, 12722, 49, 1, 55, "Subsubsection",
      CellTags->"With"]},
  "Block"->{
    Cell[534624, 12891, 51, 1, 55, "Subsubsection",
      CellTags->"Block"]},
  "conditional functions"->{
    Cell[541825, 13132, 80, 1, 42, "Subsection",
      CellTags->"conditional functions"]},
  "Switch"->{
    Cell[546918, 13295, 129, 3, 96, "Input",
      CellTags->"Switch"],
    Cell[547050, 13300, 150, 3, 75, "Output",
      CellTags->"Switch"]},
  "loop commands"->{
    Cell[702498, 16838, 64, 1, 42, "Subsection",
      CellTags->"loop commands"]},
  "documentation"->{
    Cell[714284, 17263, 72, 1, 68, "Subsection",
      CellTags->"documentation"]},
  "Info3312796112-2879332"->{
    Cell[715252, 17293, 322, 9, 35, "Print",
      CellTags->"Info3312796112-2879332"]},
  "sbess"->{
    Cell[716361, 17320, 828, 18, 414, "Input",
      CellTags->"sbess"]},
  "Info3312796154-7655491"->{
    Cell[720415, 17434, 152, 3, 35, "Print",
      CellTags->"Info3312796154-7655491"]},
  "compiled functions"->{
    Cell[721543, 17481, 71, 1, 51, "Section",
      CellTags->"compiled functions"]},
  "Mandelbrot"->{
    Cell[725196, 17601, 68, 1, 51, "Section",
      CellTags->"Mandelbrot"]},
  "Info3312796267-9384250"->{
    Cell[1377798, 26913, 287, 4, 62, "Print",
      CellTags->"Info3312796267-9384250"]},
  "optional arguments"->{
    Cell[1378440, 26931, 71, 1, 51, "Section",
      CellTags->"optional arguments"]},
  "optional arguments with default values"->{
    Cell[1379573, 26958, 114, 1, 68, "Subsection",
      CellTags->"optional arguments with default values"]},
  "options"->{
    Cell[1380908, 26999, 94, 1, 68, "Subsection",
      CellTags->"options"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"implicit functions", 1937820, 40015},
  {"Info3312795150-1116509", 1937933, 40018},
  {"explicit functions", 1938128, 40023},
  {"patterns as arguments", 1938353, 40028},
  {"Info3312795210-5631052", 1938497, 40031},
  {"command sequences", 1938693, 40036},
  {"pure functions", 1938799, 40039},
  {"pure functions with names", 1938913, 40042},
  {"Info3312795303-7827047", 1939038, 40045},
  {"pure functions of several variables", 1939256, 40050},
  {"anonymous functions", 1939389, 40053},
  {"skeletal notation", 1939503, 40056},
  {"Info3312795419-4618591", 1939620, 40059},
  {"interpolating functions", 1939826, 40064},
  {"recursive functions", 1939946, 40067},
  {"Info3312795474-4594259", 1940062, 40070},
  {"Info3312795480-9399269", 1940267, 40075},
  {"conditions on arguments", 1940478, 40080},
  {"type checking", 1940589, 40083},
  {"Info3312795544-2481890", 1940702, 40086},
  {"definitions with conditions", 1940913, 40091},
  {"predicates", 1941028, 40094},
  {"Info3312795629-5419543", 1941138, 40097},
  {"Info3312795630-5419172", 1941256, 40100},
  {"Info3312795631-8819510", 1941374, 40103},
  {"Info3312795632-7419729", 1941492, 40106},
  {"Info3312795634-1579497", 1941610, 40109},
  {"Info3312795635-3734403", 1941728, 40112},
  {"Info3312795638-6034247", 1941847, 40115},
  {"Info3312795644-9360992", 1941966, 40118},
  {"Info3312795645-4283247", 1942084, 40121},
  {"arguments matching patterns", 1942207, 40124},
  {"overlapping definitions", 1942336, 40127},
  {"protection of local variables", 1942466, 40130},
  {"modular programing", 1942588, 40133},
  {"scoping commands", 1942697, 40136},
  {"Module", 1942797, 40139},
  {"With", 1942888, 40142},
  {"Block", 1942979, 40145},
  {"conditional functions", 1943087, 40148},
  {"Switch", 1943193, 40151},
  {"loop commands", 1943360, 40156},
  {"documentation", 1943465, 40159},
  {"Info3312796112-2879332", 1943579, 40162},
  {"sbess", 1943681, 40165},
  {"Info3312796154-7655491", 1943785, 40168},
  {"compiled functions", 1943900, 40171},
  {"Mandelbrot", 1944004, 40174},
  {"Info3312796267-9384250", 1944112, 40177},
  {"optional arguments", 1944228, 40180},
  {"optional arguments with default values", 1944361, 40183},
  {"options", 1944487, 40186}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 75, 2, 81, "Title"],
Cell[1854, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2334, 76, 31, 0, 83, "Section"],

Cell[CellGroupData[{
Cell[2390, 80, 41, 0, 68, "Subsection"],
Cell[2434, 82, 870, 15, 145, "Text"],
Cell[3307, 99, 458, 10, 67, "Text"],
Cell[3768, 111, 1371, 25, 197, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5176, 141, 37, 0, 68, "Subsection"],
Cell[5216, 143, 589, 15, 93, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5854, 164, 33, 0, 51, "Section"],
Cell[5890, 166, 119, 2, 99, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6046, 173, 119, 3, 51, "Section",
  CellTags->"implicit functions"],
Cell[6168, 178, 668, 22, 67, "Text"],
Cell[6839, 202, 113, 2, 99, "Input"],
Cell[6955, 206, 178, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[7158, 215, 34, 1, 73, "Input"],
Cell[7195, 218, 52, 1, 61, "Output"]
}, Closed]],
Cell[7262, 222, 146, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[7433, 229, 134, 3, 72, "Input"],
Cell[7570, 234, 36, 1, 59, "Output"]
}, Closed]],
Cell[7621, 238, 67, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[7713, 242, 34, 1, 73, "Input"],
Cell[7750, 245, 52, 1, 61, "Output"]
}, Closed]],
Cell[7817, 249, 56, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[7898, 253, 77, 2, 99, "Input"],
Cell[7978, 257, 49, 1, 61, "Output"]
}, Closed]],
Cell[8042, 261, 29, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[8096, 265, 63, 2, 99, "Input"],
Cell[8162, 269, 36, 1, 59, "Output"]
}, Closed]],
Cell[8213, 273, 267, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[8505, 283, 40, 1, 73, "Input"],
Cell[8548, 286, 270, 4, 35, "Message"],
Cell[8821, 292, 51, 1, 59, "Output"]
}, Closed]],
Cell[8887, 296, 133, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[9045, 305, 39, 1, 73, "Input"],
Cell[9087, 308, 63, 1, 34, "Print",
  CellTags->"Info3312795150-1116509"],
Cell[9153, 311, 423, 13, 35, "Print",
  CellTags->"Info3312795150-1116509"]
}, Closed]],
Cell[9591, 327, 64, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[9680, 331, 72, 2, 99, "Input"],
Cell[9755, 335, 42, 1, 59, "Output"]
}, Closed]],
Cell[9812, 339, 457, 13, 67, "Text"],

Cell[CellGroupData[{
Cell[10294, 356, 66, 1, 73, "Input"],
Cell[10363, 359, 52, 1, 59, "Output"]
}, Closed]],
Cell[10430, 363, 459, 16, 67, "Text"],
Cell[10892, 381, 156, 3, 71, "Advice"],
Cell[11051, 386, 50, 1, 73, "Input"],
Cell[11104, 389, 493, 10, 95, "Text"],
Cell[11600, 401, 110, 2, 73, "Input"],

Cell[CellGroupData[{
Cell[11735, 407, 57, 1, 73, "Input"],
Cell[11795, 410, 49, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[11881, 416, 76, 1, 73, "Input"],
Cell[11960, 419, 36, 1, 59, "Output"]
}, Closed]],
Cell[12011, 423, 140, 3, 41, "Text"],
Cell[12154, 428, 382, 15, 81, "Exercise"],
Cell[12539, 445, 379, 14, 82, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[12955, 464, 71, 1, 51, "Section",
  CellTags->"explicit functions"],
Cell[13029, 467, 503, 8, 93, "Text"],

Cell[CellGroupData[{
Cell[13557, 479, 104, 1, 68, "Subsection",
  CellTags->{"patterns as arguments", "explicit functions"}],
Cell[13664, 482, 183, 4, 41, "Text"],
Cell[13850, 488, 41, 1, 73, "Input"],
Cell[13894, 491, 66, 1, 74, "Input"],
Cell[13963, 494, 759, 19, 96, "Text"],

Cell[CellGroupData[{
Cell[14747, 517, 37, 1, 73, "Input"],
Cell[14787, 520, 66, 1, 65, "Output"]
}, Closed]],
Cell[14868, 524, 47, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[14940, 528, 37, 1, 73, "Input"],
Cell[14980, 531, 66, 1, 65, "Output"]
}, Closed]],
Cell[15061, 535, 178, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[15264, 545, 37, 1, 73, "Input"],
Cell[15304, 548, 55, 1, 75, "Output"]
}, Closed]],
Cell[15374, 552, 66, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[15465, 556, 39, 1, 73, "Input"],
Cell[15507, 559, 54, 1, 59, "Output"]
}, Closed]],
Cell[15576, 563, 133, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[15734, 570, 47, 1, 73, "Input"],
Cell[15784, 573, 78, 1, 65, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[15899, 579, 59, 1, 73, "Input"],
Cell[15961, 582, 263, 7, 59, "Output"]
}, Closed]],
Cell[16239, 592, 147, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[16411, 599, 40, 1, 73, "Input"],
Cell[16454, 602, 117, 2, 70, "Output"]
}, Closed]],
Cell[16586, 607, 195, 4, 41, "Text"],
Cell[16784, 613, 136, 3, 41, "Text"],
Cell[16923, 618, 80, 1, 74, "Input"],

Cell[CellGroupData[{
Cell[17028, 623, 109, 2, 73, "Input"],
Cell[17140, 627, 261, 4, 84, "Output"]
}, Closed]],
Cell[17416, 634, 278, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[17719, 644, 37, 1, 73, "Input"],
Cell[17759, 647, 66, 1, 65, "Output"]
}, Closed]],
Cell[17840, 651, 896, 20, 120, "Text"],

Cell[CellGroupData[{
Cell[18761, 675, 39, 1, 73, "Input"],
Cell[18803, 678, 63, 1, 34, "Print",
  CellTags->"Info3312795210-5631052"],
Cell[18869, 681, 557, 15, 98, "Print",
  CellTags->"Info3312795210-5631052"]
}, Closed]],
Cell[19441, 699, 511, 10, 94, "Text"],

Cell[CellGroupData[{
Cell[19977, 713, 43, 1, 73, "Input"],
Cell[20023, 716, 44, 1, 59, "Output"]
}, Closed]],
Cell[20082, 720, 436, 7, 93, "Text"],
Cell[20521, 729, 127, 3, 58, "Exercise"],
Cell[20651, 734, 369, 11, 167, "Exercise"],
Cell[21023, 747, 395, 8, 158, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[21455, 760, 40, 0, 68, "Subsection"],
Cell[21498, 762, 693, 16, 95, "Text"],
Cell[22194, 780, 125, 2, 73, "Input"],
Cell[22322, 784, 70, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[22417, 788, 77, 1, 73, "Input"],
Cell[22497, 791, 61905, 1123, 279, 6450, 434, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[84417, 1917, 247, 6, 42, "Text"],
Cell[84667, 1925, 41, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[84733, 1930, 127, 2, 73, "Input"],
Cell[84863, 1934, 325, 5, 35, "Message"],
Cell[85191, 1941, 223, 6, 59, "Output"]
}, Closed]],
Cell[85429, 1950, 436, 9, 69, "Text"],
Cell[85868, 1961, 71, 0, 71, "Advice"],

Cell[CellGroupData[{
Cell[85964, 1965, 59, 0, 55, "Subsubsection"],
Cell[86026, 1967, 208, 6, 41, "Text"],
Cell[86237, 1975, 257, 6, 75, "DisplayFormula",
  Evaluatable->False],
Cell[86497, 1983, 248, 6, 75, "DisplayFormula",
  Evaluatable->False],
Cell[86748, 1991, 297, 9, 41, "Text"],
Cell[87048, 2002, 240, 4, 174, "Input"],
Cell[87291, 2008, 838, 18, 122, "Text"],
Cell[88132, 2028, 122, 2, 73, "Input"],

Cell[CellGroupData[{
Cell[88279, 2034, 61, 1, 73, "Input"],
Cell[88343, 2037, 32073, 730, 279, 5969, 403, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[120431, 2770, 202, 7, 42, "Text"],

Cell[CellGroupData[{
Cell[120658, 2781, 45, 1, 73, "Input"],
Cell[120706, 2784, 281, 4, 58, "Message"],
Cell[120990, 2790, 334, 5, 67, "Message"],
Cell[121327, 2797, 47, 1, 59, "Output"]
}, Closed]],
Cell[121389, 2801, 72, 0, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[121498, 2806, 34, 0, 55, "Subsubsection"],
Cell[121535, 2808, 870, 20, 192, "Exercise"],
Cell[122408, 2830, 318, 5, 83, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[122775, 2841, 56, 0, 68, "Subsection"],
Cell[122834, 2843, 572, 13, 95, "Text"],
Cell[123409, 2858, 112, 2, 101, "Input"],
Cell[123524, 2862, 166, 3, 41, "Text"],
Cell[123693, 2867, 62, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[123780, 2872, 51, 1, 73, "Input"],
Cell[123834, 2875, 49, 1, 59, "Output"]
}, Closed]],
Cell[123898, 2879, 616, 15, 95, "Text"],

Cell[CellGroupData[{
Cell[124539, 2898, 90, 1, 73, "Input"],
Cell[124632, 2901, 51, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[124720, 2907, 55, 1, 73, "Input"],
Cell[124778, 2910, 48, 1, 62, "Output"]
}, Closed]],
Cell[124841, 2914, 154, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[125020, 2921, 102, 2, 99, "Input"],
Cell[125125, 2925, 62, 1, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[125248, 2933, 91, 1, 51, "Section",
  CellTags->"command sequences"],
Cell[125342, 2936, 1252, 34, 171, "Text"],
Cell[126597, 2972, 47, 1, 73, "Input"],
Cell[126647, 2975, 128, 2, 73, "Input"],

Cell[CellGroupData[{
Cell[126800, 2981, 41, 1, 73, "Input"],
Cell[126844, 2984, 50, 1, 61, "Output"]
}, Closed]],
Cell[126909, 2988, 192, 4, 41, "Text"],

Cell[CellGroupData[{
Cell[127126, 2996, 37, 1, 73, "Input"],
Cell[127166, 2999, 377, 6, 87, "Output"]
}, Closed]],
Cell[127558, 3008, 702, 10, 119, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[128297, 3023, 63, 1, 51, "Section",
  CellTags->"pure functions"],
Cell[128363, 3026, 619, 18, 69, "Text"],

Cell[CellGroupData[{
Cell[129007, 3048, 88, 1, 68, "Subsection",
  CellTags->"pure functions with names"],
Cell[129098, 3051, 177, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[129300, 3058, 80, 1, 74, "Input"],
Cell[129383, 3061, 65, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[129485, 3067, 50, 1, 74, "Input"],
Cell[129538, 3070, 75, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[129650, 3076, 40, 1, 73, "Input"],
Cell[129693, 3079, 105, 2, 62, "Output"]
}, Closed]],
Cell[129813, 3084, 127, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[129965, 3092, 39, 1, 73, "Input"],
Cell[130007, 3095, 63, 1, 34, "Print",
  CellTags->"Info3312795303-7827047"],
Cell[130073, 3098, 453, 13, 36, "Print",
  CellTags->"Info3312795303-7827047"]
}, Closed]],
Cell[130541, 3114, 408, 8, 68, "Text"],
Cell[130952, 3124, 119, 2, 99, "Input"],

Cell[CellGroupData[{
Cell[131096, 3130, 37, 1, 73, "Input"],
Cell[131136, 3133, 38, 1, 61, "Output"]
}, Closed]],
Cell[131189, 3137, 242, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[131456, 3145, 37, 1, 73, "Input"],
Cell[131496, 3148, 49, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[131582, 3154, 83, 2, 99, "Input"],
Cell[131668, 3158, 52, 1, 61, "Output"]
}, Closed]],
Cell[131735, 3162, 41, 1, 73, "Input"],
Cell[131779, 3165, 540, 9, 94, "Text"],
Cell[132322, 3176, 241, 4, 151, "Input"],

Cell[CellGroupData[{
Cell[132588, 3184, 51, 1, 74, "Input"],
Cell[132642, 3187, 45, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[132724, 3193, 51, 1, 74, "Input"],
Cell[132778, 3196, 48, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[132863, 3202, 50, 1, 74, "Input"],
Cell[132916, 3205, 55, 1, 61, "Output"]
}, Closed]],
Cell[132986, 3209, 510, 11, 94, "Text"],

Cell[CellGroupData[{
Cell[133521, 3224, 43, 1, 73, "Input"],
Cell[133567, 3227, 45, 1, 59, "Output"]
}, Closed]],
Cell[133627, 3231, 196, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[133848, 3240, 35, 1, 73, "Input"],
Cell[133886, 3243, 58, 1, 59, "Output"]
}, Closed]],
Cell[133959, 3247, 137, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[134121, 3254, 62, 1, 96, "Input"],
Cell[134186, 3257, 68, 1, 75, "Output"]
}, Closed]],
Cell[134269, 3261, 289, 5, 83, "Exercise"],
Cell[134561, 3268, 295, 6, 133, "Exercise"],
Cell[134859, 3276, 195, 5, 133, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[135091, 3286, 108, 1, 68, "Subsection",
  CellTags->"pure functions of several variables"],
Cell[135202, 3289, 361, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[135588, 3301, 82, 1, 74, "Input"],
Cell[135673, 3304, 74, 1, 78, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[135784, 3310, 95, 2, 128, "Input"],
Cell[135882, 3314, 49, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[135968, 3320, 43, 1, 73, "Input"],
Cell[136014, 3323, 46, 1, 75, "Output"]
}, Closed]],
Cell[136075, 3327, 104, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[136204, 3334, 37, 1, 73, "Input"],
Cell[136244, 3337, 409, 6, 54, "Message"],
Cell[136656, 3345, 81, 1, 78, "Output"]
}, Closed]],
Cell[136752, 3349, 316, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[137093, 3359, 119, 2, 99, "Input"],
Cell[137215, 3363, 57, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[137309, 3369, 40, 1, 73, "Input"],
Cell[137352, 3372, 56, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[137445, 3378, 75, 2, 99, "Input"],
Cell[137523, 3382, 39, 1, 59, "Output"]
}, Closed]],
Cell[137577, 3386, 72, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[137674, 3390, 138, 2, 99, "Input"],
Cell[137815, 3394, 47, 1, 61, "Output"]
}, Closed]],
Cell[137877, 3398, 169, 5, 83, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[138083, 3408, 76, 1, 68, "Subsection",
  CellTags->"anonymous functions"],
Cell[138162, 3411, 458, 9, 93, "Text"],
Cell[138623, 3422, 47, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[138695, 3427, 72, 1, 74, "Input"],
Cell[138770, 3430, 65, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[138872, 3436, 79, 1, 74, "Input"],
Cell[138954, 3439, 52, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[139043, 3445, 85, 1, 74, "Input"],
Cell[139131, 3448, 64, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[139232, 3454, 80, 1, 74, "Input"],
Cell[139315, 3457, 64, 1, 61, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[139428, 3464, 72, 1, 68, "Subsection",
  CellTags->"skeletal notation"],
Cell[139503, 3467, 1069, 25, 148, "Text"],
Cell[140575, 3494, 50, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[140650, 3499, 72, 1, 74, "Input"],
Cell[140725, 3502, 52, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[140814, 3508, 87, 1, 74, "Input"],
Cell[140904, 3511, 56, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[140997, 3517, 41, 1, 73, "Input"],
Cell[141041, 3520, 60, 1, 61, "Output"]
}, Closed]],
Cell[141116, 3524, 112, 2, 74, "Input"],

Cell[CellGroupData[{
Cell[141253, 3530, 43, 1, 73, "Input"],
Cell[141299, 3533, 76, 1, 65, "Output"]
}, Closed]],
Cell[141390, 3537, 303, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[141718, 3548, 142, 3, 125, "Input"],
Cell[141863, 3553, 46, 1, 61, "Output"]
}, Closed]],
Cell[141924, 3557, 268, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[142217, 3567, 65, 1, 73, "Input"],
Cell[142285, 3570, 48, 1, 82, "Output"]
}, Closed]],
Cell[142348, 3574, 683, 20, 69, "Text"],

Cell[CellGroupData[{
Cell[143056, 3598, 86, 2, 99, "Input"],
Cell[143145, 3602, 76, 1, 65, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[143258, 3608, 47, 1, 73, "Input"],
Cell[143308, 3611, 189, 6, 59, "Output"]
}, Closed]],
Cell[143512, 3620, 110, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[143647, 3627, 65, 1, 73, "Input"],
Cell[143715, 3630, 76, 1, 65, "Output"]
}, Closed]],
Cell[143806, 3634, 116, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[143947, 3641, 44, 1, 73, "Input"],
Cell[143994, 3644, 531, 8, 47, "Message"],
Cell[144528, 3654, 77, 1, 65, "Output"]
}, Closed]],
Cell[144620, 3658, 268, 6, 83, "Exercise"],
Cell[144891, 3666, 278, 6, 84, "Exercise"],
Cell[145172, 3674, 274, 6, 83, "Exercise"],
Cell[145449, 3682, 144, 3, 58, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[145630, 3690, 75, 0, 68, "Subsection"],
Cell[145708, 3692, 362, 6, 68, "Text"],
Cell[146073, 3700, 635, 14, 94, "Text"],

Cell[CellGroupData[{
Cell[146733, 3718, 106, 2, 74, "Input"],
Cell[146842, 3722, 50, 1, 61, "Output"]
}, Closed]],
Cell[146907, 3726, 507, 15, 68, "Text"],
Cell[147417, 3743, 138, 3, 99, "Input"],

Cell[CellGroupData[{
Cell[147580, 3750, 41, 1, 73, "Input"],
Cell[147624, 3753, 50, 1, 61, "Output"]
}, Closed]],
Cell[147689, 3757, 211, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[147925, 3765, 39, 1, 73, "Input"],
Cell[147967, 3768, 63, 1, 34, "Print",
  CellTags->"Info3312795419-4618591"],
Cell[148033, 3771, 510, 14, 36, "Print",
  CellTags->"Info3312795419-4618591"]
}, Closed]],
Cell[148558, 3788, 317, 5, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[148912, 3798, 93, 1, 68, "Subsection",
  CellTags->"interpolating functions"],
Cell[149008, 3801, 1429, 38, 148, "Text"],
Cell[150440, 3841, 810, 19, 94, "Text"],
Cell[151253, 3862, 310, 6, 73, "Input"],
Cell[151566, 3870, 89, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[151680, 3876, 65, 1, 96, "Input"],
Cell[151748, 3879, 232, 6, 59, "Output"]
}, Closed]],
Cell[151995, 3888, 308, 8, 42, "Text"],

Cell[CellGroupData[{
Cell[152328, 3900, 177, 4, 96, "Input"],
Cell[152508, 3906, 156, 4, 59, "Output"]
}, Closed]],
Cell[152679, 3913, 181, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[152885, 3923, 144, 2, 73, "Input"],
Cell[153032, 3927, 42799, 877, 395, 5755, 415, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[195846, 4807, 281, 5, 67, "Text"],
Cell[196130, 4814, 762, 17, 115, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[196941, 4837, 73, 1, 51, "Section",
  CellTags->"recursive functions"],
Cell[197017, 4840, 385, 10, 67, "Text"],
Cell[197405, 4852, 113, 2, 99, "Input"],
Cell[197521, 4856, 325, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[197871, 4866, 78, 1, 73, "Input"],
Cell[197952, 4869, 90, 1, 59, "Output"]
}, Closed]],
Cell[198057, 4873, 261, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[198343, 4882, 53, 1, 73, "Input"],
Cell[198399, 4885, 7674, 166, 209, "Output"]
}, Closed]],
Cell[206088, 5054, 185, 5, 41, "Text"],
Cell[206276, 5061, 134, 2, 99, "Input"],
Cell[206413, 5065, 236, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[206674, 5073, 57, 1, 73, "Input"],
Cell[206734, 5076, 218, 4, 109, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[206989, 5085, 58, 1, 73, "Input"],
Cell[207050, 5088, 218, 4, 109, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[207305, 5097, 58, 1, 73, "Input"],
Cell[207366, 5100, 218, 4, 109, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[207621, 5109, 54, 1, 73, "Input"],
Cell[207678, 5112, 175, 6, 59, "Output"]
}, Closed]],
Cell[207868, 5121, 232, 7, 42, "Text"],

Cell[CellGroupData[{
Cell[208125, 5132, 47, 1, 73, "Input"],
Cell[208175, 5135, 71, 1, 34, "Print",
  CellTags->"Info3312795474-4594259"],
Cell[208249, 5138, 525, 15, 80, "Print",
  CellTags->"Info3312795474-4594259"]
}, Closed]],

Cell[CellGroupData[{
Cell[208811, 5158, 48, 1, 73, "Input"],
Cell[208862, 5161, 72, 1, 34, "Print",
  CellTags->"Info3312795480-9399269"],
Cell[208937, 5164, 25184, 618, 6195, "Print",
  CellTags->"Info3312795480-9399269"]
}, Closed]],
Cell[234136, 5785, 229, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[234390, 5793, 58, 1, 73, "Input"],
Cell[234451, 5796, 296, 4, 35, "Message"],
Cell[234750, 5802, 875, 12, 234, "Output"]
}, Closed]],
Cell[235640, 5817, 119, 3, 41, "Text"],
Cell[235762, 5822, 53, 1, 73, "Input"],
Cell[235818, 5825, 238, 6, 59, "Exercise"],
Cell[236059, 5833, 748, 20, 108, "Exercise"],
Cell[236810, 5855, 531, 14, 84, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[237378, 5874, 81, 1, 51, "Section",
  CellTags->"conditions on arguments"],

Cell[CellGroupData[{
Cell[237484, 5879, 64, 1, 68, "Subsection",
  CellTags->"type checking"],
Cell[237551, 5882, 449, 17, 42, "Text"],
Cell[238003, 5901, 238, 5, 177, "Input"],
Cell[238244, 5908, 143, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[238412, 5915, 49, 1, 73, "Input"],
Cell[238464, 5918, 42, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[238543, 5924, 41, 1, 73, "Input"],
Cell[238587, 5927, 35, 1, 59, "Output"]
}, Closed]],
Cell[238637, 5931, 147, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[238809, 5939, 48, 1, 73, "Input"],
Cell[238860, 5942, 37, 1, 59, "Output"]
}, Closed]],
Cell[238912, 5946, 178, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[239115, 5956, 37, 1, 73, "Input"],
Cell[239155, 5959, 38, 1, 59, "Output"]
}, Closed]],
Cell[239208, 5963, 69, 0, 41, "Text"],
Cell[239280, 5965, 73, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[239378, 5970, 37, 1, 73, "Input"],
Cell[239418, 5973, 53, 1, 59, "Output"]
}, Closed]],
Cell[239486, 5977, 268, 10, 42, "Text"],

Cell[CellGroupData[{
Cell[239779, 5991, 40, 1, 74, "Input"],
Cell[239822, 5994, 41, 1, 61, "Output"]
}, Closed]],
Cell[239878, 5998, 180, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[240083, 6007, 76, 1, 74, "Input"],
Cell[240162, 6010, 47, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[240246, 6016, 39, 1, 73, "Input"],
Cell[240288, 6019, 63, 1, 34, "Print",
  CellTags->"Info3312795544-2481890"],
Cell[240354, 6022, 733, 21, 236, "Print",
  CellTags->"Info3312795544-2481890"]
}, Closed]],
Cell[241102, 6046, 101, 2, 58, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[241240, 6053, 92, 1, 68, "Subsection",
  CellTags->"definitions with conditions"],
Cell[241335, 6056, 1849, 48, 303, "Text"],
Cell[243187, 6106, 174, 3, 125, "Input"],
Cell[243364, 6111, 177, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[243566, 6120, 64, 1, 73, "Input"],
Cell[243633, 6123, 52, 1, 59, "Output"]
}, Closed]],
Cell[243700, 6127, 19, 0, 41, "Text"],
Cell[243722, 6129, 209, 4, 125, "Input"],

Cell[CellGroupData[{
Cell[243956, 6137, 64, 1, 73, "Input"],
Cell[244023, 6140, 64, 1, 59, "Output"]
}, Closed]],
Cell[244102, 6144, 343, 11, 42, "Text"],
Cell[244448, 6157, 157, 3, 125, "Input"],

Cell[CellGroupData[{
Cell[244630, 6164, 64, 1, 73, "Input"],
Cell[244697, 6167, 47, 1, 59, "Output"]
}, Closed]],
Cell[244759, 6171, 167, 3, 125, "Input"],

Cell[CellGroupData[{
Cell[244951, 6178, 64, 1, 73, "Input"],
Cell[245018, 6181, 47, 1, 59, "Output"]
}, Closed]],
Cell[245080, 6185, 217, 6, 41, "Text"],
Cell[245300, 6193, 279, 5, 67, "Text"],
Cell[245582, 6200, 433, 7, 93, "Text"],
Cell[246018, 6209, 452, 7, 151, "Input"],

Cell[CellGroupData[{
Cell[246495, 6220, 67, 1, 73, "Input"],
Cell[246565, 6223, 144, 2, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[246746, 6230, 47, 0, 55, "Subsubsection"],
Cell[246796, 6232, 337, 7, 72, "Text"],
Cell[247136, 6241, 204, 4, 180, "Input"],

Cell[CellGroupData[{
Cell[247365, 6249, 127, 2, 96, "Input"],
Cell[247495, 6253, 58, 1, 75, "Output"]
}, Closed]],
Cell[247568, 6257, 318, 9, 42, "Text"],
Cell[247889, 6268, 121, 3, 41, "Text"],
Cell[248013, 6273, 222, 4, 180, "Input"],

Cell[CellGroupData[{
Cell[248260, 6281, 127, 2, 96, "Input"],
Cell[248390, 6285, 58, 1, 75, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[248497, 6292, 69, 0, 55, "Subsubsection"],
Cell[248569, 6294, 97, 2, 41, "Text"],
Cell[248669, 6298, 164, 3, 136, "Input"],
Cell[248836, 6303, 87, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[248948, 6309, 75, 1, 73, "Input"],
Cell[249026, 6312, 281, 4, 58, "Message"],
Cell[249310, 6318, 334, 5, 67, "Message"],
Cell[249647, 6325, 281, 4, 58, "Message"],
Cell[249931, 6331, 334, 5, 67, "Message"],
Cell[250268, 6338, 281, 4, 58, "Message"],
Cell[250552, 6344, 329, 5, 35, "Message"],
Cell[250884, 6351, 81, 1, 59, "Output"]
}, Closed]],
Cell[250980, 6355, 356, 11, 42, "Text"],

Cell[CellGroupData[{
Cell[251361, 6370, 91, 1, 73, "Input"],
Cell[251455, 6373, 35, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[251527, 6379, 91, 1, 73, "Input"],
Cell[251621, 6382, 35, 1, 59, "Output"]
}, Closed]],
Cell[251671, 6386, 207, 4, 41, "Text"],
Cell[251881, 6392, 307, 7, 192, "Input"],

Cell[CellGroupData[{
Cell[252213, 6403, 105, 2, 73, "Input"],
Cell[252321, 6407, 45633, 1077, 279, 9499, 626, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[297969, 7487, 164, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[298158, 7494, 51, 1, 73, "Input"],
Cell[298212, 7497, 175, 5, 61, "Output"]
}, Closed]],
Cell[298402, 7505, 60, 0, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[298499, 7510, 34, 0, 55, "Subsubsection"],
Cell[298536, 7512, 353, 11, 58, "Exercise"],
Cell[298892, 7525, 811, 21, 108, "Exercise"],
Cell[299706, 7548, 265, 5, 83, "Exercise"],
Cell[299974, 7555, 1209, 39, 133, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[301232, 7600, 61, 1, 68, "Subsection",
  CellTags->"predicates"],
Cell[301296, 7603, 672, 18, 95, "Text"],

Cell[CellGroupData[{
Cell[301993, 7625, 40, 1, 73, "Input"],
Cell[302036, 7628, 20373, 497, 282, "Print"]
}, Closed]],
Cell[322424, 8128, 60, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[322509, 8132, 46, 1, 73, "Input"],
Cell[322558, 8135, 326, 9, 35, "Print",
  CellTags->"Info3312795629-5419543"]
}, Closed]],

Cell[CellGroupData[{
Cell[322921, 8149, 43, 1, 73, "Input"],
Cell[322967, 8152, 325, 9, 35, "Print",
  CellTags->"Info3312795630-5419172"]
}, Closed]],

Cell[CellGroupData[{
Cell[323329, 8166, 42, 1, 73, "Input"],
Cell[323374, 8169, 322, 9, 35, "Print",
  CellTags->"Info3312795631-8819510"]
}, Closed]],

Cell[CellGroupData[{
Cell[323733, 8183, 45, 1, 73, "Input"],
Cell[323781, 8186, 322, 9, 35, "Print",
  CellTags->"Info3312795632-7419729"]
}, Closed]],

Cell[CellGroupData[{
Cell[324140, 8200, 46, 1, 73, "Input"],
Cell[324189, 8203, 334, 9, 35, "Print",
  CellTags->"Info3312795634-1579497"]
}, Closed]],

Cell[CellGroupData[{
Cell[324560, 8217, 45, 1, 73, "Input"],
Cell[324608, 8220, 517, 11, 85, "Print",
  CellTags->"Info3312795635-3734403"]
}, Closed]],

Cell[CellGroupData[{
Cell[325162, 8236, 45, 1, 73, "Input"],
Cell[325210, 8239, 516, 11, 85, "Print",
  CellTags->"Info3312795638-6034247"]
}, Closed]],
Cell[325741, 8253, 115, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[325881, 8260, 46, 1, 73, "Input"],
Cell[325930, 8263, 311, 9, 35, "Print",
  CellTags->"Info3312795644-9360992"]
}, Closed]],

Cell[CellGroupData[{
Cell[326278, 8277, 46, 1, 73, "Input"],
Cell[326327, 8280, 311, 9, 35, "Print",
  CellTags->"Info3312795645-4283247"]
}, Closed]],
Cell[326653, 8292, 613, 13, 94, "Text"],
Cell[327269, 8307, 51, 0, 41, "Text"],
Cell[327323, 8309, 133, 3, 125, "Input"],
Cell[327459, 8314, 39, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[327523, 8318, 60, 1, 73, "Input"],
Cell[327586, 8321, 90, 1, 59, "Output"]
}, Closed]],
Cell[327691, 8325, 50, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[327766, 8329, 39, 1, 73, "Input"],
Cell[327808, 8332, 41, 1, 59, "Output"]
}, Closed]],
Cell[327864, 8336, 72, 0, 41, "Text"],
Cell[327939, 8338, 532, 14, 203, "Input"],

Cell[CellGroupData[{
Cell[328496, 8356, 71, 1, 73, "Input"],
Cell[328570, 8359, 187, 3, 84, "Output"]
}, Closed]],
Cell[328772, 8365, 442, 10, 68, "Text"],
Cell[329217, 8377, 122, 2, 125, "Input"],

Cell[CellGroupData[{
Cell[329364, 8383, 78, 1, 73, "Input"],
Cell[329445, 8386, 88, 1, 75, "Output"]
}, Closed]],
Cell[329548, 8390, 990, 24, 123, "Text"],
Cell[330541, 8416, 100, 2, 58, "Exercise"],
Cell[330644, 8420, 170, 3, 58, "Exercise"],
Cell[330817, 8425, 120, 3, 58, "Exercise"],

Cell[CellGroupData[{
Cell[330962, 8432, 70, 0, 55, "Subsubsection"],
Cell[331035, 8434, 583, 12, 94, "Text"],
Cell[331621, 8448, 358, 7, 203, "Input"],
Cell[331982, 8457, 224, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[332231, 8465, 108, 2, 105, "Input"],
Cell[332342, 8469, 38, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[332417, 8475, 114, 2, 105, "Input"],
Cell[332534, 8479, 39, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[332610, 8485, 53, 1, 73, "Input"],
Cell[332666, 8488, 54, 1, 59, "Output"]
}, Closed]],
Cell[332735, 8492, 316, 9, 42, "Text"],

Cell[CellGroupData[{
Cell[333076, 8505, 129, 2, 105, "Input"],
Cell[333208, 8509, 80, 1, 59, "Output"]
}, Closed]],
Cell[333303, 8513, 47, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[333375, 8517, 335, 8, 172, "Input"],
Cell[333713, 8527, 38, 1, 59, "Output"]
}, Closed]],
Cell[333766, 8531, 595, 9, 133, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[334410, 8546, 105, 1, 68, "Subsection",
  CellTags->"arguments matching patterns"],
Cell[334518, 8549, 632, 18, 69, "Text"],
Cell[335153, 8569, 236, 4, 99, "Input"],
Cell[335392, 8575, 1414, 31, 149, "Text"],
Cell[336809, 8608, 139, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[336973, 8615, 147, 3, 99, "Input"],
Cell[337123, 8620, 131, 2, 59, "Output"]
}, Closed]],
Cell[337269, 8625, 117, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[337411, 8632, 122, 2, 99, "Input"],
Cell[337536, 8636, 88, 1, 59, "Output"]
}, Closed]],
Cell[337639, 8640, 244, 5, 42, "Text"],
Cell[337886, 8647, 585, 15, 69, "Text"],
Cell[338474, 8664, 117, 3, 58, "Exercise"],
Cell[338594, 8669, 212, 4, 83, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[338843, 8678, 84, 1, 68, "Subsection",
  CellTags->"overlapping definitions"],
Cell[338930, 8681, 609, 11, 93, "Text"],
Cell[339542, 8694, 171, 3, 41, "Text"],
Cell[339716, 8699, 205, 4, 151, "Input"],
Cell[339924, 8705, 205, 4, 151, "Input"],
Cell[340132, 8711, 397, 8, 69, "Text"],

Cell[CellGroupData[{
Cell[340554, 8723, 47, 1, 73, "Input"],
Cell[340604, 8726, 47, 1, 75, "Output"]
}, Closed]],
Cell[340666, 8730, 327, 7, 67, "Text"],
Cell[340996, 8739, 105, 3, 71, "Caution"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[341150, 8748, 93, 1, 51, "Section",
  CellTags->"protection of local variables"],

Cell[CellGroupData[{
Cell[341268, 8753, 39, 0, 68, "Subsection"],
Cell[341310, 8755, 214, 4, 41, "Text"],
Cell[341527, 8761, 120, 2, 99, "Input"],
Cell[341650, 8765, 63, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[341738, 8769, 37, 1, 73, "Input"],
Cell[341778, 8772, 43, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[341858, 8778, 37, 1, 73, "Input"],
Cell[341898, 8781, 43, 1, 59, "Output"]
}, Closed]],
Cell[341956, 8785, 102, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[342083, 8792, 37, 1, 73, "Input"],
Cell[342123, 8795, 35, 1, 59, "Output"]
}, Closed]],
Cell[342173, 8799, 181, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[342379, 8809, 48, 1, 73, "Input"],
Cell[342430, 8812, 664, 20, 79, "Output"]
}, Closed]],
Cell[343109, 8835, 930, 21, 122, "Text"],
Cell[344042, 8858, 144, 3, 99, "Input"],

Cell[CellGroupData[{
Cell[344211, 8865, 37, 1, 73, "Input"],
Cell[344251, 8868, 43, 1, 59, "Output"]
}, Closed]],
Cell[344309, 8872, 678, 17, 95, "Text"],
Cell[344990, 8891, 169, 3, 94, "Advice"],
Cell[345162, 8896, 288, 6, 83, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[345487, 8907, 40, 0, 68, "Subsection"],
Cell[345530, 8909, 754, 20, 95, "Text"],
Cell[346287, 8931, 170, 3, 58, "Exercise"],
Cell[346460, 8936, 201, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[346686, 8946, 48, 1, 73, "Input"],
Cell[346737, 8949, 565, 17, 79, "Output"]
}, Closed]],
Cell[347317, 8969, 737, 21, 95, "Text"],
Cell[348057, 8992, 599, 11, 95, "Text"],
Cell[348659, 9005, 94, 2, 58, "Exercise"],
Cell[348756, 9009, 145, 3, 73, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[348950, 9018, 72, 1, 51, "Section",
  CellTags->"modular programing"],
Cell[349025, 9021, 680, 11, 119, "Text"],

Cell[CellGroupData[{
Cell[349730, 9036, 70, 1, 68, "Subsection",
  CellTags->"scoping commands"],
Cell[349803, 9039, 237, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[350065, 9047, 53, 1, 55, "Subsubsection",
  CellTags->"Module"],
Cell[350121, 9050, 771, 19, 96, "Text"],
Cell[350895, 9071, 670, 13, 95, "Text"],
Cell[351568, 9086, 473, 8, 94, "Text"],
Cell[352044, 9096, 70, 1, 73, "Input"],
Cell[352117, 9099, 539, 9, 151, "Input"],
Cell[352659, 9110, 419, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[353103, 9121, 170, 4, 137, "Input"],
Cell[353276, 9127, 175492, 3557, 444, 34004, 1806, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[528783, 12687, 141, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[528949, 12695, 39, 1, 73, "Input"],
Cell[528991, 12698, 40, 1, 59, "Output"]
}, Closed]],
Cell[529046, 12702, 526, 15, 98, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[529609, 12722, 49, 1, 55, "Subsubsection",
  CellTags->"With"],
Cell[529661, 12725, 2129, 64, 150, "Text"],
Cell[531793, 12791, 110, 2, 73, "Input"],
Cell[531906, 12795, 107, 2, 74, "Input"],

Cell[CellGroupData[{
Cell[532038, 12801, 38, 1, 73, "Input"],
Cell[532079, 12804, 52, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[532168, 12810, 42, 1, 73, "Input"],
Cell[532213, 12813, 75, 1, 59, "Output"]
}, Closed]],
Cell[532303, 12817, 128, 4, 42, "Text"],
Cell[532434, 12823, 153, 3, 74, "Input"],

Cell[CellGroupData[{
Cell[532612, 12830, 38, 1, 73, "Input"],
Cell[532653, 12833, 270, 4, 35, "Message"],
Cell[532926, 12839, 270, 4, 35, "Message"],
Cell[533199, 12845, 270, 4, 35, "Message"],
Cell[533472, 12851, 329, 5, 35, "Message"],
Cell[533804, 12858, 52, 1, 61, "Output"]
}, Closed]],
Cell[533871, 12862, 336, 10, 42, "Text"],
Cell[534210, 12874, 377, 12, 84, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[534624, 12891, 51, 1, 55, "Subsubsection",
  CellTags->"Block"],
Cell[534678, 12894, 1826, 51, 150, "Text"],
Cell[536507, 12947, 44, 1, 73, "Input"],
Cell[536554, 12950, 103, 2, 74, "Input"],

Cell[CellGroupData[{
Cell[536682, 12956, 42, 1, 73, "Input"],
Cell[536727, 12959, 75, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[536839, 12965, 37, 1, 73, "Input"],
Cell[536879, 12968, 52, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[536968, 12974, 42, 1, 73, "Input"],
Cell[537013, 12977, 75, 1, 59, "Output"]
}, Closed]],
Cell[537103, 12981, 297, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[537425, 12992, 55, 1, 74, "Input"],
Cell[537483, 12995, 50, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[537570, 13001, 34, 1, 73, "Input"],
Cell[537607, 13004, 41, 1, 59, "Output"]
}, Closed]],
Cell[537663, 13008, 247, 6, 68, "Text"],
Cell[537913, 13016, 78, 1, 96, "Input"],
Cell[537994, 13019, 77, 1, 96, "Input"],

Cell[CellGroupData[{
Cell[538096, 13024, 51, 1, 73, "Input"],
Cell[538150, 13027, 149, 2, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[538336, 13034, 51, 1, 73, "Input"],
Cell[538390, 13037, 287, 4, 37, "Message"],
Cell[538680, 13043, 112, 2, 75, "Output"]
}, Closed]],
Cell[538807, 13048, 756, 19, 95, "Text"],
Cell[539566, 13069, 120, 3, 125, "Input"],
Cell[539689, 13074, 102, 2, 73, "Input"],
Cell[539794, 13078, 104, 2, 73, "Input"],

Cell[CellGroupData[{
Cell[539923, 13084, 52, 1, 73, "Input"],
Cell[539978, 13087, 614, 8, 184, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[540629, 13100, 53, 1, 73, "Input"],
Cell[540685, 13103, 296, 4, 35, "Message"],
Cell[540984, 13109, 604, 8, 159, "Output"]
}, Closed]],
Cell[541603, 13120, 173, 6, 42, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[541825, 13132, 80, 1, 42, "Subsection",
  CellTags->"conditional functions"],

Cell[CellGroupData[{
Cell[541930, 13137, 46, 0, 55, "Subsubsection"],
Cell[541979, 13139, 575, 19, 68, "Text"],
Cell[542557, 13160, 500, 14, 68, "Text"],
Cell[543060, 13176, 99, 2, 99, "Input"],

Cell[CellGroupData[{
Cell[543184, 13182, 111, 2, 73, "Input"],
Cell[543298, 13186, 63, 1, 59, "Output"]
}, Closed]],
Cell[543376, 13190, 655, 13, 96, "Text"],
Cell[544034, 13205, 96, 2, 99, "Input"],

Cell[CellGroupData[{
Cell[544155, 13211, 89, 1, 73, "Input"],
Cell[544247, 13214, 49, 1, 59, "Output"]
}, Closed]],
Cell[544311, 13218, 194, 3, 41, "Text"],
Cell[544508, 13223, 858, 19, 122, "Text"],
Cell[545369, 13244, 142, 3, 125, "Input"],

Cell[CellGroupData[{
Cell[545536, 13251, 111, 2, 73, "Input"],
Cell[545650, 13255, 103, 2, 75, "Output"]
}, Closed]],
Cell[545768, 13260, 851, 24, 96, "Text"],
Cell[546622, 13286, 271, 5, 229, "Input"],

Cell[CellGroupData[{
Cell[546918, 13295, 129, 3, 96, "Input",
  CellTags->"Switch"],
Cell[547050, 13300, 150, 3, 75, "Output",
  CellTags->"Switch"]
}, Closed]],
Cell[547215, 13306, 394, 11, 58, "Exercise"],
Cell[547612, 13319, 192, 4, 58, "Exercise"],
Cell[547807, 13325, 1028, 29, 181, "Exercise"],
Cell[548838, 13356, 261, 5, 83, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[549136, 13366, 64, 0, 55, "Subsubsection"],
Cell[549203, 13368, 1400, 34, 149, "Text"],
Cell[550606, 13404, 244, 6, 41, "Text"],
Cell[550853, 13412, 292, 6, 190, "Input"],
Cell[551148, 13420, 54, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[551227, 13424, 122, 3, 73, "Input"],
Cell[551352, 13429, 68627, 1591, 279, 13706, 908, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[620016, 15025, 128, 3, 73, "Input"],
Cell[620147, 15030, 79152, 1695, 279, 13317, 878, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[699314, 16728, 332, 11, 42, "Text"],

Cell[CellGroupData[{
Cell[699671, 16743, 92, 1, 73, "Input"],
Cell[699766, 16746, 1561, 51, 176, "Output"]
}, Closed]],
Cell[701342, 16800, 1107, 32, 226, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[702498, 16838, 64, 1, 42, "Subsection",
  CellTags->"loop commands"],

Cell[CellGroupData[{
Cell[702587, 16843, 37, 0, 55, "Subsubsection"],
Cell[702627, 16845, 382, 12, 68, "Text"],
Cell[703012, 16859, 881, 24, 95, "Text"],
Cell[703896, 16885, 582, 17, 69, "Text"],
Cell[704481, 16904, 1185, 37, 122, "Text"],

Cell[CellGroupData[{
Cell[705691, 16945, 107, 2, 73, "Input"],
Cell[705801, 16949, 35, 1, 35, "Print"],
Cell[705839, 16952, 36, 1, 35, "Print"],
Cell[705878, 16955, 37, 1, 35, "Print"],
Cell[705918, 16958, 38, 1, 35, "Print"],
Cell[705959, 16961, 39, 1, 35, "Print"],
Cell[706001, 16964, 40, 1, 35, "Print"],
Cell[706044, 16967, 41, 1, 35, "Print"],
Cell[706088, 16970, 42, 1, 35, "Print"],
Cell[706133, 16973, 43, 1, 35, "Print"],
Cell[706179, 16976, 43, 1, 35, "Print"]
}, Closed]],
Cell[706237, 16980, 572, 10, 94, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[706846, 16995, 67, 0, 55, "Subsubsection"],
Cell[706916, 16997, 258, 8, 42, "Text"],

Cell[CellGroupData[{
Cell[707199, 17009, 79, 1, 74, "Input"],
Cell[707281, 17012, 45, 1, 80, "Output"]
}, Closed]],
Cell[707341, 17016, 36, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[707402, 17020, 44, 1, 73, "Input"],
Cell[707449, 17023, 53, 1, 59, "Output"]
}, Closed]],
Cell[707517, 17027, 670, 15, 95, "Text"],

Cell[CellGroupData[{
Cell[708212, 17046, 103, 2, 96, "Input"],
Cell[708318, 17050, 53, 1, 59, "Output"]
}, Closed]],
Cell[708386, 17054, 157, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[708568, 17062, 138, 3, 96, "Input"],
Cell[708709, 17067, 53, 1, 59, "Output"]
}, Closed]],
Cell[708777, 17071, 223, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[709025, 17081, 121, 2, 96, "Input"],
Cell[709149, 17085, 53, 1, 59, "Output"]
}, Closed]],
Cell[709217, 17089, 309, 5, 108, "Exercise"],
Cell[709529, 17096, 491, 12, 97, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[710057, 17113, 55, 0, 55, "Subsubsection"],
Cell[710115, 17115, 646, 18, 95, "Text"],
Cell[710764, 17135, 1932, 49, 255, "Text"],
Cell[712699, 17186, 209, 4, 41, "Text"],

Cell[CellGroupData[{
Cell[712933, 17194, 49, 1, 73, "Input"],
Cell[712985, 17197, 35, 1, 59, "Output"]
}, Closed]],
Cell[713035, 17201, 91, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[713151, 17207, 34, 1, 73, "Input"],
Cell[713188, 17210, 35, 1, 59, "Output"]
}, Closed]],
Cell[713238, 17214, 23, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[713286, 17218, 49, 1, 73, "Input"],
Cell[713338, 17221, 35, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[713410, 17227, 34, 1, 73, "Input"],
Cell[713447, 17230, 35, 1, 59, "Output"]
}, Closed]],
Cell[713497, 17234, 203, 4, 41, "Text"],
Cell[713703, 17240, 327, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[714055, 17251, 112, 2, 96, "Input"],
Cell[714170, 17255, 53, 1, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[714284, 17263, 72, 1, 68, "Subsection",
  CellTags->"documentation"],
Cell[714359, 17266, 665, 13, 94, "Text"],
Cell[715027, 17281, 152, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[715204, 17290, 45, 1, 73, "Input"],
Cell[715252, 17293, 322, 9, 35, "Print",
  CellTags->"Info3312796112-2879332"]
}, Closed]],
Cell[715589, 17305, 769, 13, 121, "Text"],
Cell[716361, 17320, 828, 18, 414, "Input",
  CellTags->"sbess"],

Cell[CellGroupData[{
Cell[717214, 17342, 44, 1, 73, "Input"],
Cell[717261, 17345, 1513, 39, 106, "Print"]
}, Closed]],
Cell[718789, 17387, 811, 22, 96, "Text"],
Cell[719603, 17411, 218, 4, 67, "Text"],
Cell[719824, 17417, 516, 10, 255, "Input"],

Cell[CellGroupData[{
Cell[720365, 17431, 47, 1, 73, "Input"],
Cell[720415, 17434, 152, 3, 35, "Print",
  CellTags->"Info3312796154-7655491"]
}, Closed]],

Cell[CellGroupData[{
Cell[720604, 17442, 50, 1, 73, "Input"],
Cell[720657, 17445, 120, 2, 35, "Message"]
}, Closed]],

Cell[CellGroupData[{
Cell[720814, 17452, 49, 1, 73, "Input"],
Cell[720866, 17455, 113, 2, 35, "Message"]
}, Closed]],

Cell[CellGroupData[{
Cell[721016, 17462, 46, 1, 73, "Input"],
Cell[721065, 17465, 41, 1, 59, "Output"]
}, Closed]],
Cell[721121, 17469, 373, 6, 67, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[721543, 17481, 71, 1, 51, "Section",
  CellTags->"compiled functions"],
Cell[721617, 17484, 1630, 46, 148, "Text"],

Cell[CellGroupData[{
Cell[723272, 17534, 112, 2, 99, "Input"],
Cell[723387, 17538, 201, 5, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[723625, 17548, 81, 1, 73, "Input"],
Cell[723709, 17551, 70, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[723816, 17557, 171, 3, 125, "Input"],
Cell[723990, 17562, 56, 1, 59, "Output"]
}, Closed]],
Cell[724061, 17566, 307, 5, 67, "Text"],
Cell[724371, 17573, 788, 23, 69, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[725196, 17601, 68, 1, 51, "Section",
  CellTags->"Mandelbrot"],
Cell[725267, 17604, 392, 8, 67, "Text"],
Cell[725662, 17614, 102, 2, 41, "Text"],
Cell[725767, 17618, 130, 3, 43, "DisplayFormula"],
Cell[725900, 17623, 1322, 40, 93, "Text"],
Cell[727225, 17665, 1371, 30, 147, "Text"],
Cell[728599, 17697, 314, 6, 125, "Input"],
Cell[728916, 17705, 260, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[729201, 17714, 262, 5, 99, "Input"],
Cell[729466, 17721, 147754, 2336, 411, 65999, 1322, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[877235, 20060, 798, 16, 121, "Text"],
Cell[878036, 20078, 366, 7, 125, "Input"],
Cell[878405, 20087, 305, 5, 67, "Text"],
Cell[878713, 20094, 176, 3, 73, "Input"],
Cell[878892, 20099, 650, 14, 95, "Text"],

Cell[CellGroupData[{
Cell[879567, 20117, 276, 5, 99, "Input"],
Cell[879846, 20124, 496547, 6752, 411, 383516, 5352, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1376408, 26879, 261, 5, 67, "Text"],
Cell[1376672, 26886, 1046, 20, 515, "Input"],

Cell[CellGroupData[{
Cell[1377743, 26910, 52, 1, 73, "Input"],
Cell[1377798, 26913, 287, 4, 62, "Print",
  CellTags->"Info3312796267-9384250"]
}, Closed]],
Cell[1378100, 26920, 303, 6, 83, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[1378440, 26931, 71, 1, 51, "Section",
  CellTags->"optional arguments"],
Cell[1378514, 26934, 1034, 20, 145, "Text"],

Cell[CellGroupData[{
Cell[1379573, 26958, 114, 1, 68, "Subsection",
  CellTags->"optional arguments with default values"],
Cell[1379690, 26961, 830, 18, 171, "Text"],
Cell[1380523, 26981, 90, 2, 99, "Input"],

Cell[CellGroupData[{
Cell[1380638, 26987, 119, 2, 73, "Input"],
Cell[1380760, 26991, 99, 2, 67, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1380908, 26999, 94, 1, 68, "Subsection",
  CellTags->"options"],
Cell[1381005, 27002, 533, 12, 95, "Text"],
Cell[1381541, 27016, 387, 6, 67, "Text"],
Cell[1381931, 27024, 122, 2, 73, "Input"],
Cell[1382056, 27028, 533, 18, 69, "Text"],

Cell[CellGroupData[{
Cell[1382614, 27050, 57, 1, 73, "Input"],
Cell[1382674, 27053, 31277, 816, 279, 7851, 522, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1413966, 27872, 122, 3, 41, "Text"],
Cell[1414091, 27877, 181, 3, 99, "Input"],
Cell[1414275, 27882, 56, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1414356, 27886, 112, 2, 73, "Input"],
Cell[1414471, 27890, 35511, 883, 279, 8066, 540, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1449997, 28776, 89, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[1450111, 28782, 310, 5, 99, "Input"],
Cell[1450424, 28789, 76005, 1643, 279, 14820, 883, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1526444, 30435, 945, 22, 123, "Text"],
Cell[1527392, 30459, 568, 12, 229, "Input"],
Cell[1527963, 30473, 431, 9, 68, "Text"],

Cell[CellGroupData[{
Cell[1528419, 30486, 199, 3, 73, "Input"],
Cell[1528621, 30491, 77997, 1656, 279, 14435, 867, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1606633, 32150, 513, 8, 93, "Text"],
Cell[1607149, 32160, 603, 12, 229, "Input"],

Cell[CellGroupData[{
Cell[1607777, 32176, 114, 2, 73, "Input"],
Cell[1607894, 32180, 81098, 1725, 279, 15604, 912, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1689007, 33908, 322, 5, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1689366, 33918, 70, 0, 68, "Subsection"],
Cell[1689439, 33920, 808, 18, 123, "Text"],
Cell[1690250, 33940, 29, 0, 41, "Text"],
Cell[1690282, 33942, 169, 4, 42, "Text"],
Cell[1690454, 33948, 488, 11, 69, "Text"],
Cell[1690945, 33961, 285, 5, 151, "Input"],
Cell[1691233, 33968, 88, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[1691346, 33974, 114, 2, 73, "Input"],
Cell[1691463, 33978, 77811, 1654, 279, 14459, 867, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1769289, 35635, 51, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1769365, 35639, 253, 4, 99, "Input"],
Cell[1769621, 35645, 76103, 1633, 279, 14428, 867, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1845739, 37281, 361, 9, 69, "Text"],
Cell[1846103, 37292, 85, 1, 73, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1846237, 37299, 32, 0, 51, "Section"],
Cell[1846272, 37301, 274, 5, 67, "Text"],
Cell[1846549, 37308, 297, 8, 42, "Text"],
Cell[1846849, 37318, 379, 11, 42, "Text"],
Cell[1847231, 37331, 390, 9, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1847658, 37345, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[1847716, 37349, 40, 0, 58, "ExerciseTitle"],
Cell[1847759, 37351, 205, 4, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1848001, 37360, 44, 0, 58, "ExerciseTitle"],
Cell[1848048, 37362, 521, 15, 67, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1848606, 37382, 39, 0, 58, "ExerciseTitle"],
Cell[1848648, 37384, 542, 13, 95, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1849227, 37402, 38, 0, 58, "ExerciseTitle"],
Cell[1849268, 37404, 618, 11, 93, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1849923, 37420, 44, 0, 58, "ExerciseTitle"],
Cell[1849970, 37422, 593, 17, 133, "ExerciseText"],
Cell[1850566, 37441, 328, 7, 123, "ExerciseText"],
Cell[1850897, 37450, 894, 22, 219, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1851828, 37477, 69, 0, 58, "ExerciseTitle"],
Cell[1851900, 37479, 833, 22, 169, "ExerciseText"],
Cell[1852736, 37503, 363, 11, 42, "ExerciseText"],
Cell[1853102, 37516, 183, 5, 42, "ExerciseText"],
Cell[1853288, 37523, 143, 3, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1853468, 37531, 52, 0, 58, "ExerciseTitle"],
Cell[1853523, 37533, 730, 26, 177, "ExerciseText"],
Cell[1854256, 37561, 278, 11, 41, "ExerciseText"],
Cell[1854537, 37574, 177, 5, 41, "ExerciseText"],
Cell[1854717, 37581, 203, 4, 41, "ExerciseText"],
Cell[1854923, 37587, 99, 2, 74, "Input",
  Evaluatable->False],
Cell[1855025, 37591, 99, 2, 73, "Input",
  Evaluatable->False],
Cell[1855127, 37595, 67, 2, 73, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[1855231, 37602, 46, 0, 58, "ExerciseTitle"],
Cell[1855280, 37604, 778, 16, 119, "ExerciseText"],
Cell[1856061, 37622, 345, 12, 41, "ExerciseText"],
Cell[1856409, 37636, 223, 8, 41, "ExerciseText"],
Cell[1856635, 37646, 156, 5, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1856828, 37656, 49, 0, 58, "ExerciseTitle"],
Cell[1856880, 37658, 261, 8, 41, "ExerciseText"],
Cell[1857144, 37668, 310, 8, 41, "ExerciseText"],
Cell[1857457, 37678, 181, 5, 42, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1857675, 37688, 43, 0, 58, "ExerciseTitle"],
Cell[1857721, 37690, 669, 19, 69, "ExerciseText"],
Cell[1858393, 37711, 503, 14, 69, "ExerciseText"],
Cell[1858899, 37727, 130, 1, 42, "ExerciseText"],
Cell[1859032, 37730, 31373, 636, 267, 4069, 294, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1890408, 38368, 510, 13, 69, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1890955, 38386, 40, 0, 58, "ExerciseTitle"],
Cell[1890998, 38388, 77, 0, 41, "ExerciseText"],
Cell[1891078, 38390, 272, 4, 64, "DisplayFormula"],
Cell[1891353, 38396, 801, 29, 68, "ExerciseText"],
Cell[1892157, 38427, 225, 8, 41, "ExerciseText"],
Cell[1892385, 38437, 239, 7, 42, "ExerciseText"],
Cell[1892627, 38446, 150, 3, 41, "ExerciseText"],
Cell[1892780, 38451, 393, 10, 68, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1893210, 38466, 39, 0, 58, "ExerciseTitle"],
Cell[1893252, 38468, 598, 19, 46, "ExerciseText"],
Cell[1893853, 38489, 633, 15, 94, "ExerciseText"],
Cell[1894489, 38506, 281, 7, 42, "ExerciseText"],
Cell[1894773, 38515, 94, 2, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1894904, 38522, 50, 0, 58, "ExerciseTitle"],
Cell[1894957, 38524, 184, 3, 41, "ExerciseText"],
Cell[1895144, 38529, 267, 7, 42, "ExerciseText"],
Cell[1895414, 38538, 148, 3, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1895599, 38546, 46, 0, 58, "ExerciseTitle"],
Cell[1895648, 38548, 636, 18, 67, "ExerciseText"],
Cell[1896287, 38568, 386, 10, 73, "DisplayFormula"],
Cell[1896676, 38580, 964, 26, 95, "ExerciseText"],
Cell[1897643, 38608, 312, 5, 67, "ExerciseText"],
Cell[1897958, 38615, 916, 27, 95, "ExerciseText"],
Cell[1898877, 38644, 140, 3, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1899054, 38652, 41, 0, 58, "ExerciseTitle"],
Cell[1899098, 38654, 534, 11, 95, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1899669, 38670, 68, 0, 58, "ExerciseTitle"],
Cell[1899740, 38672, 545, 15, 67, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1900322, 38692, 44, 0, 58, "ExerciseTitle"],
Cell[1900369, 38694, 1048, 25, 119, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1901454, 38724, 35, 0, 58, "ExerciseTitle"],
Cell[1901492, 38726, 2287, 65, 179, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

